class ComConversionLossAttribute(Attribute,_Attribute):
 """
 Indicates that information was lost about a class or interface when it was imported from a type library to an assembly.

 

 ComConversionLossAttribute()
 """
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
