class ListChangedType(Enum,IComparable,IFormattable,IConvertible):
 """
 Specifies how the list changed.

 

 enum ListChangedType,values: ItemAdded (1),ItemChanged (4),ItemDeleted (2),ItemMoved (3),PropertyDescriptorAdded (5),PropertyDescriptorChanged (7),PropertyDescriptorDeleted (6),Reset (0)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 ItemAdded=None
 ItemChanged=None
 ItemDeleted=None
 ItemMoved=None
 PropertyDescriptorAdded=None
 PropertyDescriptorChanged=None
 PropertyDescriptorDeleted=None
 Reset=None
 value__=None

