# this entry is added to a journal when Revit stops the execution
# in journal mode. Checking for this string will help in determining if
# Revit has stopped the journal execution.
MODAL_OPEN = '0:< ADialog::doModal start'
