# encoding: utf-8
# module System.Windows.Shapes calls itself Shapes
# from PresentationFramework,Version=4.0.0.0,Culture=neutral,PublicKeyToken=31bf3856ad364e35
# by generator 1.145
""" NamespaceTracker represent a CLS namespace. """
# no imports

# no functions
# classes
from Shapes_parts.Shape import Shape
from Shapes_parts.Ellipse import Ellipse
from Shapes_parts.Line import Line
from Shapes_parts.Path import Path
from Shapes_parts.Polygon import Polygon
from Shapes_parts.Polyline import Polyline
from Shapes_parts.Rectangle import Rectangle
