class ImageListStreamer(object,ISerializable,IDisposable):
 """ Provides the data portion of an System.Windows.Forms.ImageList. """
 def Dispose(self):
  """
  Dispose(self: ImageListStreamer)

   Releases all resources used by the current instance of the 

    System.Windows.Forms.ImageListStreamer class.
  """
  pass
 def GetObjectData(self,si,context):
  """
  GetObjectData(self: ImageListStreamer,si: SerializationInfo,context: StreamingContext)

   Populates a System.Runtime.Serialization.SerializationInfo with the data needed to serialize the 

    target object.

  

  

   si: The System.Runtime.Serialization.SerializationInfo to populate with data.

   context: The System.Runtime.Serialization.StreamingContext that is the destination for this serialization.
  """
  pass
 def __enter__(self,*args):
  """
  __enter__(self: IDisposable) -> object

  

   Provides the implementation of __enter__ for objects which implement IDisposable.
  """
  pass
 def __exit__(self,*args):
  """
  __exit__(self: IDisposable,exc_type: object,exc_value: object,exc_back: object)

   Provides the implementation of __exit__ for objects which implement IDisposable.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __reduce_ex__(self,*args):
  pass
 def __repr__(self,*args):
  """ __repr__(self: object) -> str """
  pass
