# encoding: utf-8
# module System.Windows.Media.Media3D.Converters calls itself Converters
# from PresentationCore,Version=4.0.0.0,Culture=neutral,PublicKeyToken=31bf3856ad364e35
# by generator 1.145
""" NamespaceTracker represent a CLS namespace. """
# no imports

# no functions
# classes

class Matrix3DValueSerializer(ValueSerializer):
 """
 Converts instances of System.String to and from instances of System.Windows.Media.Media3D.Matrix3D.

 

 Matrix3DValueSerializer()
 """
 def CanConvertFromString(self,value,context):
  """
  CanConvertFromString(self: Matrix3DValueSerializer,value: str,context: IValueSerializerContext) -> bool

  

   Determines if conversion from a given System.String to an instance of 

    System.Windows.Media.Media3D.Matrix3D is possible.

  

  

   value: String to evaluate for conversion.

   context: Context information used for conversion.

   Returns: true if the value can be converted; otherwise,false.
  """
  pass
 def CanConvertToString(self,value,context):
  """
  CanConvertToString(self: Matrix3DValueSerializer,value: object,context: IValueSerializerContext) -> bool

  

   Determines if an instance of System.Windows.Media.Media3D.Matrix3D can be converted to a 

    System.String.

  

  

   value: Instance of System.Windows.Media.Media3D.Matrix3D to evaluate for conversion.

   context: Context information used for conversion.

   Returns: true if value can be converted into a System.String; otherwise,false.
  """
  pass
 def ConvertFromString(self,value,context):
  """
  ConvertFromString(self: Matrix3DValueSerializer,value: str,context: IValueSerializerContext) -> object

  

   Converts a System.String into a System.Windows.Media.Media3D.Matrix3D.

  

   value: System.String value to convert into a System.Windows.Media.Media3D.Matrix3D.

   context: Context information used for conversion.

   Returns: A new instance of System.Windows.Media.Media3D.Matrix3D based on the supplied value.
  """
  pass
 def ConvertToString(self,value,context):
  """
  ConvertToString(self: Matrix3DValueSerializer,value: object,context: IValueSerializerContext) -> str

  

   Converts an instance of System.Windows.Media.Media3D.Matrix3D to a System.String.

  

   value: Instance of System.Windows.Media.Media3D.Matrix3D to evaluate for conversion.

   context: Context information used for conversion.

   Returns: A System.String representation of the supplied System.Windows.Media.Media3D.Matrix3D object.
  """
  pass

class Point3DCollectionValueSerializer(ValueSerializer):
 """
 Converts instances of System.String to and from instances of System.Windows.Media.Media3D.Point3DCollection.

 

 Point3DCollectionValueSerializer()
 """
 def CanConvertFromString(self,value,context):
  """
  CanConvertFromString(self: Point3DCollectionValueSerializer,value: str,context: IValueSerializerContext) -> bool

  

   Determines if conversion from a given System.String to an instance of 

    System.Windows.Media.Media3D.Point3DCollection is possible.

  

  

   value: String to evaluate for conversion.

   context: Context information used for conversion.

   Returns: true if the value can be converted; otherwise,false.
  """
  pass
 def CanConvertToString(self,value,context):
  """
  CanConvertToString(self: Point3DCollectionValueSerializer,value: object,context: IValueSerializerContext) -> bool

  

   Determines if an instance of System.Windows.Media.Media3D.Point3DCollection can be converted to 

    a System.String.

  

  

   value: Instance of System.Windows.Media.Media3D.Point3DCollection to evaluate for conversion.

   context: Context information used for conversion.

   Returns: true if value can be converted into a System.String; otherwise,false.
  """
  pass
 def ConvertFromString(self,value,context):
  """
  ConvertFromString(self: Point3DCollectionValueSerializer,value: str,context: IValueSerializerContext) -> object

  

   Converts a System.String into a System.Windows.Media.Media3D.Point3DCollection.

  

   value: System.String value to convert into a System.Windows.Media.Media3D.Point3DCollection.

   context: Context information used for conversion.

   Returns: A new instance of System.Windows.Media.Media3D.Point3DCollection based on the supplied value.
  """
  pass
 def ConvertToString(self,value,context):
  """
  ConvertToString(self: Point3DCollectionValueSerializer,value: object,context: IValueSerializerContext) -> str

  

   Converts an instance of System.Windows.Media.Media3D.Point3DCollection to a System.String.

  

   value: Instance of System.Windows.Media.Media3D.Point3DCollection to evaluate for conversion.

   context: Context information used for conversion.

   Returns: A System.String representation of the supplied System.Windows.Media.Media3D.Point3DCollection 

    object.
  """
  pass

class Point3DValueSerializer(ValueSerializer):
 """
 Converts instances of System.String to and from instances of System.Windows.Media.Media3D.Point3D.

 

 Point3DValueSerializer()
 """
 def CanConvertFromString(self,value,context):
  """
  CanConvertFromString(self: Point3DValueSerializer,value: str,context: IValueSerializerContext) -> bool

  

   Determines if conversion from a given System.String to an instance of 

    System.Windows.Media.Media3D.Point3D is possible.

  

  

   value: String to evaluate for conversion.

   context: Context information used for conversion.

   Returns: true if the value can be converted; otherwise,false.
  """
  pass
 def CanConvertToString(self,value,context):
  """
  CanConvertToString(self: Point3DValueSerializer,value: object,context: IValueSerializerContext) -> bool

  

   Determines if an instance of System.Windows.Media.Media3D.Point3D can be converted to a 

    System.String.

  

  

   value: Instance of System.Windows.Media.Media3D.Point3D to evaluate for conversion.

   context: Context information used for conversion.

   Returns: true if value can be converted into a System.String; otherwise,false.
  """
  pass
 def ConvertFromString(self,value,context):
  """
  ConvertFromString(self: Point3DValueSerializer,value: str,context: IValueSerializerContext) -> object

  

   Converts a System.String into a System.Windows.Media.Media3D.Point3D.

  

   value: System.String value to convert into a System.Windows.Media.Media3D.Point3D.

   context: Context information used for conversion.

   Returns: A new instance of System.Windows.Media.Media3D.Point3D based on the supplied value.
  """
  pass
 def ConvertToString(self,value,context):
  """
  ConvertToString(self: Point3DValueSerializer,value: object,context: IValueSerializerContext) -> str

  

   Converts an instance of System.Windows.Media.Media3D.Point3D to a System.String.

  

   value: Instance of System.Windows.Media.Media3D.Point3D to evaluate for conversion.

   context: Context information used for conversion.

   Returns: A System.String representation of the supplied System.Windows.Media.Media3D.Point3D object.
  """
  pass

class Point4DValueSerializer(ValueSerializer):
 """
 Converts instances of System.String to and from instances of System.Windows.Media.Media3D.Point4D.

 

 Point4DValueSerializer()
 """
 def CanConvertFromString(self,value,context):
  """
  CanConvertFromString(self: Point4DValueSerializer,value: str,context: IValueSerializerContext) -> bool

  

   Determines if conversion from a given System.String to an instance of 

    System.Windows.Media.Media3D.Point4D is possible.

  

  

   value: String to evaluate for conversion.

   context: Context information used for conversion.

   Returns: true if the value can be converted; otherwise,false.
  """
  pass
 def CanConvertToString(self,value,context):
  """
  CanConvertToString(self: Point4DValueSerializer,value: object,context: IValueSerializerContext) -> bool

  

   Determines if an instance of System.Windows.Media.Media3D.Point4D can be converted to a 

    System.String.

  

  

   value: Instance of System.Windows.Media.Media3D.Point4D to evaluate for conversion.

   context: Context information used for conversion.

   Returns: true if value can be converted into a System.String; otherwise,false.
  """
  pass
 def ConvertFromString(self,value,context):
  """
  ConvertFromString(self: Point4DValueSerializer,value: str,context: IValueSerializerContext) -> object

  

   Converts a System.String into a System.Windows.Media.Media3D.Point4D.

  

   value: System.String value to convert into a System.Windows.Media.Media3D.Point4D.

   context: Context information used for conversion.

   Returns: A new instance of System.Windows.Media.Media3D.Point4D based on the supplied value.
  """
  pass
 def ConvertToString(self,value,context):
  """
  ConvertToString(self: Point4DValueSerializer,value: object,context: IValueSerializerContext) -> str

  

   Converts an instance of System.Windows.Media.Media3D.Point4D to a System.String.

  

   value: Instance of System.Windows.Media.Media3D.Point4D to evaluate for conversion.

   context: Context information used for conversion.

   Returns: A System.String representation of the supplied System.Windows.Media.Media3D.Point4D object.
  """
  pass

class QuaternionValueSerializer(ValueSerializer):
 """
 Converts instances of System.String to and from instances of System.Windows.Media.Media3D.Quaternion.

 

 QuaternionValueSerializer()
 """
 def CanConvertFromString(self,value,context):
  """
  CanConvertFromString(self: QuaternionValueSerializer,value: str,context: IValueSerializerContext) -> bool

  

   Determines if conversion from a given System.String to an instance of 

    System.Windows.Media.Media3D.Quaternion is possible.

  

  

   value: String to evaluate for conversion.

   context: Context information used for conversion.

   Returns: true if the value can be converted; otherwise,false.
  """
  pass
 def CanConvertToString(self,value,context):
  """
  CanConvertToString(self: QuaternionValueSerializer,value: object,context: IValueSerializerContext) -> bool

  

   Determines if an instance of System.Windows.Media.Media3D.Quaternion can be converted to a 

    System.String.

  

  

   value: Instance of System.Windows.Media.Media3D.Quaternion to evaluate for conversion.

   context: Context information used for conversion.

   Returns: true if value can be converted into a System.String; otherwise,false.
  """
  pass
 def ConvertFromString(self,value,context):
  """
  ConvertFromString(self: QuaternionValueSerializer,value: str,context: IValueSerializerContext) -> object

  

   Converts a System.String into a System.Windows.Media.Media3D.Quaternion.

  

   value: System.String value to convert into a System.Windows.Media.Media3D.Quaternion.

   context: Context information used for conversion.

   Returns: A new instance of System.Windows.Media.Media3D.Quaternion based on the supplied value.
  """
  pass
 def ConvertToString(self,value,context):
  """
  ConvertToString(self: QuaternionValueSerializer,value: object,context: IValueSerializerContext) -> str

  

   Converts an instance of System.Windows.Media.Media3D.Quaternion to a System.String.

  

   value: Instance of System.Windows.Media.Media3D.Quaternion to evaluate for conversion.

   context: Context information used for conversion.

   Returns: A System.String representation of the supplied System.Windows.Media.Media3D.Quaternion object.
  """
  pass

class Rect3DValueSerializer(ValueSerializer):
 """
 Converts instances of System.String to and from instances of System.Windows.Media.Media3D.Rect3D.

 

 Rect3DValueSerializer()
 """
 def CanConvertFromString(self,value,context):
  """
  CanConvertFromString(self: Rect3DValueSerializer,value: str,context: IValueSerializerContext) -> bool

  

   Determines if conversion from a given System.String to an instance of 

    System.Windows.Media.Media3D.Rect3D is possible.

  

  

   value: String to evaluate for conversion.

   context: Context information used for conversion.

   Returns: true if the value can be converted; otherwise,false.
  """
  pass
 def CanConvertToString(self,value,context):
  """
  CanConvertToString(self: Rect3DValueSerializer,value: object,context: IValueSerializerContext) -> bool

  

   Determines if an instance of System.Windows.Media.Media3D.Rect3D can be converted to a 

    System.String.

  

  

   value: Instance of System.Windows.Media.Media3D.Rect3D to evaluate for conversion.

   context: Context information used for conversion.

   Returns: true if value can be converted into a System.String; otherwise,false.
  """
  pass
 def ConvertFromString(self,value,context):
  """
  ConvertFromString(self: Rect3DValueSerializer,value: str,context: IValueSerializerContext) -> object

  

   Converts a System.String into a System.Windows.Media.Media3D.Rect3D.

  

   value: System.String value to convert into a System.Windows.Media.Media3D.Rect3D.

   context: Context information used for conversion.

   Returns: A new instance of System.Windows.Media.Media3D.Rect3D based on the supplied value.
  """
  pass
 def ConvertToString(self,value,context):
  """
  ConvertToString(self: Rect3DValueSerializer,value: object,context: IValueSerializerContext) -> str

  

   Converts an instance of System.Windows.Media.Media3D.Rect3D to a System.String.

  

   value: Instance of System.Windows.Media.Media3D.Rect3D to evaluate for conversion.

   context: Context information used for conversion.

   Returns: A System.String representation of the supplied System.Windows.Media.Media3D.Rect3D object.
  """
  pass

class Size3DValueSerializer(ValueSerializer):
 """
 Converts instances of System.String to and from instances of System.Windows.Media.Media3D.Size3D.

 

 Size3DValueSerializer()
 """
 def CanConvertFromString(self,value,context):
  """
  CanConvertFromString(self: Size3DValueSerializer,value: str,context: IValueSerializerContext) -> bool

  

   Determines if conversion from a given System.String to an instance of 

    System.Windows.Media.Media3D.Size3D is possible.

  

  

   value: String to evaluate for conversion.

   context: Context information used for conversion.

   Returns: true if the value can be converted; otherwise,false.
  """
  pass
 def CanConvertToString(self,value,context):
  """
  CanConvertToString(self: Size3DValueSerializer,value: object,context: IValueSerializerContext) -> bool

  

   Determines if an instance of System.Windows.Media.Media3D.Size3D can be converted to a 

    System.String.

  

  

   value: Instance of System.Windows.Media.Media3D.Size3D to evaluate for conversion.

   context: Context information used for conversion.

   Returns: true if value can be converted into a System.String; otherwise,false.
  """
  pass
 def ConvertFromString(self,value,context):
  """
  ConvertFromString(self: Size3DValueSerializer,value: str,context: IValueSerializerContext) -> object

  

   Converts a System.String into a System.Windows.Media.Media3D.Size3D.

  

   value: System.String value to convert into a System.Windows.Media.Media3D.Size3D.

   context: Context information used for conversion.

   Returns: A new instance of System.Windows.Media.Media3D.Size3D based on the supplied value.
  """
  pass
 def ConvertToString(self,value,context):
  """
  ConvertToString(self: Size3DValueSerializer,value: object,context: IValueSerializerContext) -> str

  

   Converts an instance of System.Windows.Media.Media3D.Size3D to a System.String.

  

   value: Instance of System.Windows.Media.Media3D.Size3D to evaluate for conversion.

   context: Context information used for conversion.

   Returns: A System.String representation of the supplied System.Windows.Media.Media3D.Size3D object.
  """
  pass

class Vector3DCollectionValueSerializer(ValueSerializer):
 """
 Converts instances of System.String to and from instances of System.Windows.Media.Media3D.Vector3DCollection.

 

 Vector3DCollectionValueSerializer()
 """
 def CanConvertFromString(self,value,context):
  """
  CanConvertFromString(self: Vector3DCollectionValueSerializer,value: str,context: IValueSerializerContext) -> bool

  

   Determines if conversion from a given System.String to an instance of 

    System.Windows.Media.Media3D.Vector3DCollection is possible.

  

  

   value: String to evaluate for conversion.

   context: Context information used for conversion.

   Returns: true if the value can be converted; otherwise,false.
  """
  pass
 def CanConvertToString(self,value,context):
  """
  CanConvertToString(self: Vector3DCollectionValueSerializer,value: object,context: IValueSerializerContext) -> bool

  

   Determines if an instance of System.Windows.Media.Media3D.Vector3DCollection can be converted to 

    a System.String.

  

  

   value: Instance of System.Windows.Media.Media3D.Vector3DCollection to evaluate for conversion.

   context: Context information used for conversion.

   Returns: true if value can be converted into a System.String; otherwise,false.
  """
  pass
 def ConvertFromString(self,value,context):
  """
  ConvertFromString(self: Vector3DCollectionValueSerializer,value: str,context: IValueSerializerContext) -> object

  

   Converts a System.String into a System.Windows.Media.Media3D.Vector3DCollection.

  

   value: System.String value to convert into a System.Windows.Media.Media3D.Vector3DCollection.

   context: Context information used for conversion.

   Returns: A new instance of System.Windows.Media.Media3D.Vector3DCollection based on the supplied value.
  """
  pass
 def ConvertToString(self,value,context):
  """
  ConvertToString(self: Vector3DCollectionValueSerializer,value: object,context: IValueSerializerContext) -> str

  

   Converts an instance of System.Windows.Media.Media3D.Vector3DCollection to a System.String.

  

   value: Instance of System.Windows.Media.Media3D.Vector3DCollection to evaluate for conversion.

   context: Context information used for conversion.

   Returns: A System.String representation of the supplied System.Windows.Media.Media3D.Vector3DCollection 

    object.
  """
  pass

class Vector3DValueSerializer(ValueSerializer):
 """
 Converts instances of System.String to and from instances of System.Windows.Media.Media3D.Vector3D.

 

 Vector3DValueSerializer()
 """
 def CanConvertFromString(self,value,context):
  """
  CanConvertFromString(self: Vector3DValueSerializer,value: str,context: IValueSerializerContext) -> bool

  

   Determines if conversion from a given System.String to an instance of 

    System.Windows.Media.Media3D.Vector3D is possible.

  

  

   value: String to evaluate for conversion.

   context: Context information used for conversion.

   Returns: true if the value can be converted; otherwise,false.
  """
  pass
 def CanConvertToString(self,value,context):
  """
  CanConvertToString(self: Vector3DValueSerializer,value: object,context: IValueSerializerContext) -> bool

  

   Determines if an instance of System.Windows.Media.Media3D.Vector3D can be converted to a 

    System.String.

  

  

   value: Instance of System.Windows.Media.Media3D.Vector3D to evaluate for conversion.

   context: Context information used for conversion.

   Returns: true if value can be converted into a System.String; otherwise,false.
  """
  pass
 def ConvertFromString(self,value,context):
  """
  ConvertFromString(self: Vector3DValueSerializer,value: str,context: IValueSerializerContext) -> object

  

   Converts a System.String into a System.Windows.Media.Media3D.Vector3D.

  

   value: System.String value to convert into a System.Windows.Media.Media3D.Vector3D.

   context: Context information used for conversion.

   Returns: A new instance of System.Windows.Media.Media3D.Vector3D based on the supplied value.
  """
  pass
 def ConvertToString(self,value,context):
  """
  ConvertToString(self: Vector3DValueSerializer,value: object,context: IValueSerializerContext) -> str

  

   Converts an instance of System.Windows.Media.Media3D.Vector3D to a System.String.

  

   value: Instance of System.Windows.Media.Media3D.Vector3D to evaluate for conversion.

   context: Context information used for conversion.

   Returns: A System.String representation of the supplied System.Windows.Media.Media3D.Vector3D object.
  """
  pass

