from typing import Tuple, Set, Iterable, List


class DuctFittingAndAccessoryPressureDropUIDataItem:
    @property
    def IsValidObject(self) -> bool: ...
    def GetEntity(self) -> Entity: ...
    def SetEntity(self, entity: Entity) -> None: ...
    def GetDuctFittingAndAccessoryData(self) -> DuctFittingAndAccessoryData: ...
    def Dispose(self) -> None: ...


class DuctFittingAndAccessoryPressureDropUIData:
    @property
    def IsValidObject(self) -> bool: ...
    def GetUnits(self) -> Units: ...
    def GetUIDataItems(self) -> List[DuctFittingAndAccessoryPressureDropUIDataItem]: ...
    def Dispose(self) -> None: ...


class IDuctFittingAndAccessoryPressureDropUIServer:
    def GetDBServerId(self) -> Guid: ...
    def ShowSettings(self, data: DuctFittingAndAccessoryPressureDropUIData) -> bool: ...
