class WebRequestMethods(object):
 """ Container class for System.Net.WebRequestMethods.Ftp,System.Net.WebRequestMethods.File,and System.Net.WebRequestMethods.Http classes. This class cannot be inherited """
 File=None
 Ftp=None
 Http=None
 __all__=[
  'File',
  'Ftp',
  'Http',
 ]

