class AccessibleStates(Enum,IComparable,IFormattable,IConvertible):
 """
 Specifies values representing possible states for an accessible object.

 

 enum (flags) AccessibleStates,values: AlertHigh (268435456),AlertLow (67108864),AlertMedium (134217728),Animated (16384),Busy (2048),Checked (16),Collapsed (1024),Default (256),Expanded (512),ExtSelectable (33554432),Floating (4096),Focusable (1048576),Focused (4),HasPopup (1073741824),HotTracked (128),Indeterminate (32),Invisible (32768),Linked (4194304),Marqueed (8192),Mixed (32),Moveable (262144),MultiSelectable (16777216),None (0),Offscreen (65536),Pressed (8),Protected (536870912),ReadOnly (64),Selectable (2097152),Selected (2),SelfVoicing (524288),Sizeable (131072),Traversed (8388608),Unavailable (1),Valid (1073741823)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 AlertHigh=None
 AlertLow=None
 AlertMedium=None
 Animated=None
 Busy=None
 Checked=None
 Collapsed=None
 Default=None
 Expanded=None
 ExtSelectable=None
 Floating=None
 Focusable=None
 Focused=None
 HasPopup=None
 HotTracked=None
 Indeterminate=None
 Invisible=None
 Linked=None
 Marqueed=None
 Mixed=None
 Moveable=None
 MultiSelectable=None
 None=None
 Offscreen=None
 Pressed=None
 Protected=None
 ReadOnly=None
 Selectable=None
 Selected=None
 SelfVoicing=None
 Sizeable=None
 Traversed=None
 Unavailable=None
 Valid=None
 value__=None

