class HierarchicalVirtualizationHeaderDesiredSizes(object):
 """ HierarchicalVirtualizationHeaderDesiredSizes(logicalSize: Size,pixelSize: Size) """
 def Equals(self,*__args):
  """
  Equals(self: HierarchicalVirtualizationHeaderDesiredSizes,comparisonHeaderSizes: HierarchicalVirtualizationHeaderDesiredSizes) -> bool

  Equals(self: HierarchicalVirtualizationHeaderDesiredSizes,oCompare: object) -> bool
  """
  pass
 def GetHashCode(self):
  """ GetHashCode(self: HierarchicalVirtualizationHeaderDesiredSizes) -> int """
  pass
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==y """
  pass
 @staticmethod
 def __new__(self,logicalSize,pixelSize):
  """
  __new__(cls: type,logicalSize: Size,pixelSize: Size)

  __new__[HierarchicalVirtualizationHeaderDesiredSizes]() -> HierarchicalVirtualizationHeaderDesiredSizes
  """
  pass
 def __ne__(self,*args):
  pass
 LogicalSize=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: LogicalSize(self: HierarchicalVirtualizationHeaderDesiredSizes) -> Size



"""

 PixelSize=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: PixelSize(self: HierarchicalVirtualizationHeaderDesiredSizes) -> Size



"""


