class FileDialogCustomPlacesCollection(Collection[FileDialogCustomPlace],IList[FileDialogCustomPlace],ICollection[FileDialogCustomPlace],IEnumerable[FileDialogCustomPlace],IEnumerable,IList,ICollection,IReadOnlyList[FileDialogCustomPlace],IReadOnlyCollection[FileDialogCustomPlace]):
 """
 Represents a collection of Windows Vista�custom places for the System.Windows.Forms.FileDialog�class.

 

 FileDialogCustomPlacesCollection()
 """
 def Add(self,*__args):
  """
  Add(self: FileDialogCustomPlacesCollection,knownFolderGuid: Guid)

   Adds a custom place to the System.Windows.Forms.FileDialogCustomPlacesCollection collection.

  

   knownFolderGuid: A System.Guid that represents a Windows Vista Known Folder.

  Add(self: FileDialogCustomPlacesCollection,path: str)

   Adds a custom place to the System.Windows.Forms.FileDialogCustomPlacesCollection collection.

  

   path: A folder path to the custom place.
  """
  pass
 def ClearItems(self,*args):
  """
  ClearItems(self: Collection[FileDialogCustomPlace])

   Removes all elements from the System.Collections.ObjectModel.Collection.
  """
  pass
 def InsertItem(self,*args):
  """ InsertItem(self: Collection[FileDialogCustomPlace],index: int,item: FileDialogCustomPlace) """
  pass
 def RemoveItem(self,*args):
  """
  RemoveItem(self: Collection[FileDialogCustomPlace],index: int)

   Removes the element at the specified index of the System.Collections.ObjectModel.Collection.

  

   index: The zero-based index of the element to remove.
  """
  pass
 def SetItem(self,*args):
  """ SetItem(self: Collection[FileDialogCustomPlace],index: int,item: FileDialogCustomPlace) """
  pass
 def __add__(self,*args):
  """ x.__add__(y) <==> x+yx.__add__(y) <==> x+y """
  pass
 def __getitem__(self,*args):
  """ x.__getitem__(y) <==> x[y] """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __iter__(self,*args):
  """ __iter__(self: IEnumerable) -> object """
  pass
 def __setitem__(self,*args):
  """ x.__setitem__(i,y) <==> x[i]= """
  pass
 Items=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a System.Collections.Generic.IList wrapper around the System.Collections.ObjectModel.Collection.



"""


