class DiagnosticsConfigurationHandler(object,IConfigurationSectionHandler):
 """
 Handles the diagnostics section of configuration files.

 

 DiagnosticsConfigurationHandler()
 """
 def Create(self,parent,configContext,section):
  """
  Create(self: DiagnosticsConfigurationHandler,parent: object,configContext: object,section: XmlNode) -> object

  

   Parses the configuration settings for the <system.diagnostics> Element section of configuration 

    files.

  

  

   parent: The object inherited from the parent path

   configContext: Reserved. Used in ASP.NET to convey the virtual path of the configuration being evaluated.

   section: The root XML node at the section to handle.

   Returns: A new configuration object,in the form of a System.Collections.Hashtable.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __repr__(self,*args):
  """ __repr__(self: object) -> str """
  pass
