class IContainItemStorage:
 # no doc
 def Clear(self):
  """ Clear(self: IContainItemStorage) """
  pass
 def ClearItemValue(self,item,dp):
  """ ClearItemValue(self: IContainItemStorage,item: object,dp: DependencyProperty) """
  pass
 def ClearValue(self,dp):
  """ ClearValue(self: IContainItemStorage,dp: DependencyProperty) """
  pass
 def ReadItemValue(self,item,dp):
  """ ReadItemValue(self: IContainItemStorage,item: object,dp: DependencyProperty) -> object """
  pass
 def StoreItemValue(self,item,dp,value):
  """ StoreItemValue(self: IContainItemStorage,item: object,dp: DependencyProperty,value: object) """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
