class PlatformID(Enum,IComparable,IFormattable,IConvertible):
 """
 Identifies the operating system,or platform,supported by an assembly.

 

 enum PlatformID,values: MacOSX (6),Unix (4),Win32NT (2),Win32S (0),Win32Windows (1),WinCE (3),Xbox (5)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 MacOSX=None
 Unix=None
 value__=None
 Win32NT=None
 Win32S=None
 Win32Windows=None
 WinCE=None
 Xbox=None

