class ConsoleKey(Enum,IComparable,IFormattable,IConvertible):
 """
 Specifies the standard keys on a console.

 

 enum ConsoleKey,values: A (65),Add (107),Applications (93),Attention (246),B (66),Backspace (8),BrowserBack (166),BrowserFavorites (171),BrowserForward (167),BrowserHome (172),BrowserRefresh (168),BrowserSearch (170),BrowserStop (169),C (67),Clear (12),CrSel (247),D (68),D0 (48),D1 (49),D2 (50),D3 (51),D4 (52),D5 (53),D6 (54),D7 (55),D8 (56),D9 (57),Decimal (110),Delete (46),Divide (111),DownArrow (40),E (69),End (35),Enter (13),EraseEndOfFile (249),Escape (27),Execute (43),ExSel (248),F (70),F1 (112),F10 (121),F11 (122),F12 (123),F13 (124),F14 (125),F15 (126),F16 (127),F17 (128),F18 (129),F19 (130),F2 (113),F20 (131),F21 (132),F22 (133),F23 (134),F24 (135),F3 (114),F4 (115),F5 (116),F6 (117),F7 (118),F8 (119),F9 (120),G (71),H (72),Help (47),Home (36),I (73),Insert (45),J (74),K (75),L (76),LaunchApp1 (182),LaunchApp2 (183),LaunchMail (180),LaunchMediaSelect (181),LeftArrow (37),LeftWindows (91),M (77),MediaNext (176),MediaPlay (179),MediaPrevious (177),MediaStop (178),Multiply (106),N (78),NoName (252),NumPad0 (96),NumPad1 (97),NumPad2 (98),NumPad3 (99),NumPad4 (100),NumPad5 (101),NumPad6 (102),NumPad7 (103),NumPad8 (104),NumPad9 (105),O (79),Oem1 (186),Oem102 (226),Oem2 (191),Oem3 (192),Oem4 (219),Oem5 (220),Oem6 (221),Oem7 (222),Oem8 (223),OemClear (254),OemComma (188),OemMinus (189),OemPeriod (190),OemPlus (187),P (80),Pa1 (253),Packet (231),PageDown (34),PageUp (33),Pause (19),Play (250),Print (42),PrintScreen (44),Process (229),Q (81),R (82),RightArrow (39),RightWindows (92),S (83),Select (41),Separator (108),Sleep (95),Spacebar (32),Subtract (109),T (84),Tab (9),U (85),UpArrow (38),V (86),VolumeDown (174),VolumeMute (173),VolumeUp (175),W (87),X (88),Y (89),Z (90),Zoom (251)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 A=None
 Add=None
 Applications=None
 Attention=None
 B=None
 Backspace=None
 BrowserBack=None
 BrowserFavorites=None
 BrowserForward=None
 BrowserHome=None
 BrowserRefresh=None
 BrowserSearch=None
 BrowserStop=None
 C=None
 Clear=None
 CrSel=None
 D=None
 D0=None
 D1=None
 D2=None
 D3=None
 D4=None
 D5=None
 D6=None
 D7=None
 D8=None
 D9=None
 Decimal=None
 Delete=None
 Divide=None
 DownArrow=None
 E=None
 End=None
 Enter=None
 EraseEndOfFile=None
 Escape=None
 Execute=None
 ExSel=None
 F=None
 F1=None
 F10=None
 F11=None
 F12=None
 F13=None
 F14=None
 F15=None
 F16=None
 F17=None
 F18=None
 F19=None
 F2=None
 F20=None
 F21=None
 F22=None
 F23=None
 F24=None
 F3=None
 F4=None
 F5=None
 F6=None
 F7=None
 F8=None
 F9=None
 G=None
 H=None
 Help=None
 Home=None
 I=None
 Insert=None
 J=None
 K=None
 L=None
 LaunchApp1=None
 LaunchApp2=None
 LaunchMail=None
 LaunchMediaSelect=None
 LeftArrow=None
 LeftWindows=None
 M=None
 MediaNext=None
 MediaPlay=None
 MediaPrevious=None
 MediaStop=None
 Multiply=None
 N=None
 NoName=None
 NumPad0=None
 NumPad1=None
 NumPad2=None
 NumPad3=None
 NumPad4=None
 NumPad5=None
 NumPad6=None
 NumPad7=None
 NumPad8=None
 NumPad9=None
 O=None
 Oem1=None
 Oem102=None
 Oem2=None
 Oem3=None
 Oem4=None
 Oem5=None
 Oem6=None
 Oem7=None
 Oem8=None
 OemClear=None
 OemComma=None
 OemMinus=None
 OemPeriod=None
 OemPlus=None
 P=None
 Pa1=None
 Packet=None
 PageDown=None
 PageUp=None
 Pause=None
 Play=None
 Print=None
 PrintScreen=None
 Process=None
 Q=None
 R=None
 RightArrow=None
 RightWindows=None
 S=None
 Select=None
 Separator=None
 Sleep=None
 Spacebar=None
 Subtract=None
 T=None
 Tab=None
 U=None
 UpArrow=None
 V=None
 value__=None
 VolumeDown=None
 VolumeMute=None
 VolumeUp=None
 W=None
 X=None
 Y=None
 Z=None
 Zoom=None

