class INotifyPropertyChanging:
 """ Notifies clients that a property value is changing. """
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 PropertyChanging=None

