class ToolStripSystemRenderer(ToolStripRenderer):
 """
 Handles the painting functionality for System.Windows.Forms.ToolStrip objects,using system colors and a flat visual style.

 

 ToolStripSystemRenderer()
 """
