class RichTextBoxLanguageOptions(Enum,IComparable,IFormattable,IConvertible):
 """
 Provides System.Windows.Forms.RichTextBox settings for Input Method Editor (IME) and Asian language support.

 

 enum (flags) RichTextBoxLanguageOptions,values: AutoFont (2),AutoFontSizeAdjust (16),AutoKeyboard (1),DualFont (128),ImeAlwaysSendNotify (8),ImeCancelComplete (4),UIFonts (32)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 AutoFont=None
 AutoFontSizeAdjust=None
 AutoKeyboard=None
 DualFont=None
 ImeAlwaysSendNotify=None
 ImeCancelComplete=None
 UIFonts=None
 value__=None

