class DebuggerStepThroughAttribute(Attribute,_Attribute):
 """
 Instructs the debugger to step through the code instead of stepping into the code. This class cannot be inherited.

 

 DebuggerStepThroughAttribute()
 """
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __reduce_ex__(self,*args):
  pass
