class TYPEKIND(Enum,IComparable,IFormattable,IConvertible):
 """
 Use System.Runtime.InteropServices.ComTypes.TYPEKIND instead.

 

 enum TYPEKIND,values: TKIND_ALIAS (6),TKIND_COCLASS (5),TKIND_DISPATCH (4),TKIND_ENUM (0),TKIND_INTERFACE (3),TKIND_MAX (8),TKIND_MODULE (2),TKIND_RECORD (1),TKIND_UNION (7)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 TKIND_ALIAS=None
 TKIND_COCLASS=None
 TKIND_DISPATCH=None
 TKIND_ENUM=None
 TKIND_INTERFACE=None
 TKIND_MAX=None
 TKIND_MODULE=None
 TKIND_RECORD=None
 TKIND_UNION=None
 value__=None

