class SystemIcons(object):
 """ Each property of the System.Drawing.SystemIcons class is an System.Drawing.Icon object for Windows system-wide icons. This class cannot be inherited. """
 Application=None
 Asterisk=None
 Error=None
 Exclamation=None
 Hand=None
 Information=None
 Question=None
 Shield=None
 Warning=None
 WinLogo=None

