class ExceptionValidationRule(ValidationRule):
 """
 Represents a rule that checks for exceptions that are thrown during the update of the binding source property.

 

 ExceptionValidationRule()
 """
 def Validate(self,value,cultureInfo,owner=None):
  """
  Validate(self: ExceptionValidationRule,value: object,cultureInfo: CultureInfo) -> ValidationResult

  

   Performs validation checks on a value.

  

   value: The value (from the binding target) to check.

   cultureInfo: The culture to use in this rule.

   Returns: A System.Windows.Controls.ValidationResult object.
  """
  pass
