class ScrollChangedEventArgs(RoutedEventArgs):
 """ Describes a change in the scrolling state and contains the required arguments for a System.Windows.Controls.ScrollViewer.ScrollChanged event. """
 ExtentHeight=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the updated height of the System.Windows.Controls.ScrollViewer extent.



Get: ExtentHeight(self: ScrollChangedEventArgs) -> float



"""

 ExtentHeightChange=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value that indicates the change in height of the System.Windows.Controls.ScrollViewer extent.



Get: ExtentHeightChange(self: ScrollChangedEventArgs) -> float



"""

 ExtentWidth=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the updated width of the System.Windows.Controls.ScrollViewer extent.



Get: ExtentWidth(self: ScrollChangedEventArgs) -> float



"""

 ExtentWidthChange=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value that indicates the change in width of the System.Windows.Controls.ScrollViewer extent.



Get: ExtentWidthChange(self: ScrollChangedEventArgs) -> float



"""

 HorizontalChange=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value that indicates the change in horizontal offset for a System.Windows.Controls.ScrollViewer.



Get: HorizontalChange(self: ScrollChangedEventArgs) -> float



"""

 HorizontalOffset=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the updated horizontal offset value for a System.Windows.Controls.ScrollViewer.



Get: HorizontalOffset(self: ScrollChangedEventArgs) -> float



"""

 VerticalChange=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value that indicates the change in vertical offset of a System.Windows.Controls.ScrollViewer.



Get: VerticalChange(self: ScrollChangedEventArgs) -> float



"""

 VerticalOffset=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the updated value of the vertical offset for a System.Windows.Controls.ScrollViewer.



Get: VerticalOffset(self: ScrollChangedEventArgs) -> float



"""

 ViewportHeight=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the updated value of the viewport height for a System.Windows.Controls.ScrollViewer.



Get: ViewportHeight(self: ScrollChangedEventArgs) -> float



"""

 ViewportHeightChange=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value that indicates the change in value of the viewport height for a System.Windows.Controls.ScrollViewer.



Get: ViewportHeightChange(self: ScrollChangedEventArgs) -> float



"""

 ViewportWidth=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the updated value of the viewport width for a System.Windows.Controls.ScrollViewer.



Get: ViewportWidth(self: ScrollChangedEventArgs) -> float



"""

 ViewportWidthChange=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value that indicates the change in viewport width of a System.Windows.Controls.ScrollViewer.



Get: ViewportWidthChange(self: ScrollChangedEventArgs) -> float



"""


