class TableLayoutRowStyleCollection(TableLayoutStyleCollection,IList,ICollection,IEnumerable):
 """ A collection that stores System.Windows.Forms.RowStyle objects. """
 def Add(self,*__args):
  """
  Add(self: TableLayoutRowStyleCollection,rowStyle: RowStyle) -> int

  

   Adds a new System.Windows.Forms.RowStyle to the 

    System.Windows.Forms.TableLayoutRowStyleCollection.

  

  

   rowStyle: The System.Windows.Forms.RowStyle to add to the 

    System.Windows.Forms.TableLayoutRowStyleCollection.

  

   Returns: The position into which the new element was inserted.
  """
  pass
 def Contains(self,rowStyle):
  """
  Contains(self: TableLayoutRowStyleCollection,rowStyle: RowStyle) -> bool

  

   Determines whether the System.Windows.Forms.TableLayoutRowStyleCollection contains a specific 

    style.

  

  

   rowStyle: The System.Windows.Forms.RowStyle to locate in the 

    System.Windows.Forms.TableLayoutRowStyleCollection.

  

   Returns: true if the System.Windows.Forms.RowStyle is found in the 

    System.Windows.Forms.TableLayoutRowStyleCollection; otherwise,false.
  """
  pass
 def IndexOf(self,rowStyle):
  """
  IndexOf(self: TableLayoutRowStyleCollection,rowStyle: RowStyle) -> int

  

   Determines the index of a specific item in the 

    System.Windows.Forms.TableLayoutRowStyleCollection.

  

  

   rowStyle: The System.Windows.Forms.RowStyle to locate in the 

    System.Windows.Forms.TableLayoutRowStyleCollection.

  

   Returns: The index of rowStyle if found in the System.Windows.Forms.TableLayoutRowStyleCollection; 

    otherwise,-1.
  """
  pass
 def Insert(self,index,rowStyle):
  """
  Insert(self: TableLayoutRowStyleCollection,index: int,rowStyle: RowStyle)

   Inserts a System.Windows.Forms.RowStyle into the 

    System.Windows.Forms.TableLayoutRowStyleCollection at the specified position.

  

  

   index: The zero-based index at which the System.Windows.Forms.RowStyle should be inserted.

   rowStyle: The System.Windows.Forms.RowStyle to insert into the 

    System.Windows.Forms.TableLayoutRowStyleCollection. The value can be null.
  """
  pass
 def Remove(self,rowStyle):
  """
  Remove(self: TableLayoutRowStyleCollection,rowStyle: RowStyle)

   Removes the first occurrence of a specific object from the 

    System.Windows.Forms.TableLayoutRowStyleCollection.

  

  

   rowStyle: The System.Windows.Forms.RowStyle to remove from the 

    System.Windows.Forms.TableLayoutRowStyleCollection. The value can be null.
  """
  pass
 def __add__(self,*args):
  """ x.__add__(y) <==> x+y """
  pass
 def __getitem__(self,*args):
  """ x.__getitem__(y) <==> x[y] """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __iter__(self,*args):
  """ __iter__(self: IEnumerable) -> object """
  pass
 def __setitem__(self,*args):
  """ x.__setitem__(i,y) <==> x[i]= """
  pass
