class IComponentEditorPageSite:
 """ The site for a System.Windows.Forms.Design.ComponentEditorPage. """
 def GetControl(self):
  """
  GetControl(self: IComponentEditorPageSite) -> Control

  

   Returns the parent control for the page window.

   Returns: The parent control for the page window.
  """
  pass
 def SetDirty(self):
  """
  SetDirty(self: IComponentEditorPageSite)

   Notifies the site that the editor is in a modified state.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
