class IDataGridColumnStyleEditingNotificationService:
 """ Provides an editing notification interface. """
 def ColumnStartedEditing(self,editingControl):
  """
  ColumnStartedEditing(self: IDataGridColumnStyleEditingNotificationService,editingControl: Control)

   Informs the System.Windows.Forms.DataGrid that the user has begun editing the column.

  

   editingControl: The System.Windows.Forms.Control that is editing the column.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
