class HierarchicalVirtualizationItemDesiredSizes(object):
 """ HierarchicalVirtualizationItemDesiredSizes(logicalSize: Size,logicalSizeInViewport: Size,logicalSizeBeforeViewport: Size,logicalSizeAfterViewport: Size,pixelSize: Size,pixelSizeInViewport: Size,pixelSizeBeforeViewport: Size,pixelSizeAfterViewport: Size) """
 def Equals(self,*__args):
  """
  Equals(self: HierarchicalVirtualizationItemDesiredSizes,comparisonItemSizes: HierarchicalVirtualizationItemDesiredSizes) -> bool

  Equals(self: HierarchicalVirtualizationItemDesiredSizes,oCompare: object) -> bool
  """
  pass
 def GetHashCode(self):
  """ GetHashCode(self: HierarchicalVirtualizationItemDesiredSizes) -> int """
  pass
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==y """
  pass
 @staticmethod
 def __new__(self,logicalSize,logicalSizeInViewport,logicalSizeBeforeViewport,logicalSizeAfterViewport,pixelSize,pixelSizeInViewport,pixelSizeBeforeViewport,pixelSizeAfterViewport):
  """
  __new__(cls: type,logicalSize: Size,logicalSizeInViewport: Size,logicalSizeBeforeViewport: Size,logicalSizeAfterViewport: Size,pixelSize: Size,pixelSizeInViewport: Size,pixelSizeBeforeViewport: Size,pixelSizeAfterViewport: Size)

  __new__[HierarchicalVirtualizationItemDesiredSizes]() -> HierarchicalVirtualizationItemDesiredSizes
  """
  pass
 def __ne__(self,*args):
  pass
 LogicalSize=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: LogicalSize(self: HierarchicalVirtualizationItemDesiredSizes) -> Size



"""

 LogicalSizeAfterViewport=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: LogicalSizeAfterViewport(self: HierarchicalVirtualizationItemDesiredSizes) -> Size



"""

 LogicalSizeBeforeViewport=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: LogicalSizeBeforeViewport(self: HierarchicalVirtualizationItemDesiredSizes) -> Size



"""

 LogicalSizeInViewport=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: LogicalSizeInViewport(self: HierarchicalVirtualizationItemDesiredSizes) -> Size



"""

 PixelSize=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: PixelSize(self: HierarchicalVirtualizationItemDesiredSizes) -> Size



"""

 PixelSizeAfterViewport=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: PixelSizeAfterViewport(self: HierarchicalVirtualizationItemDesiredSizes) -> Size



"""

 PixelSizeBeforeViewport=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: PixelSizeBeforeViewport(self: HierarchicalVirtualizationItemDesiredSizes) -> Size



"""

 PixelSizeInViewport=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: PixelSizeInViewport(self: HierarchicalVirtualizationItemDesiredSizes) -> Size



"""


