class TraceOptions(Enum,IComparable,IFormattable,IConvertible):
 """
 Specifies trace data options to be written to the trace output.

 

 enum (flags) TraceOptions,values: Callstack (32),DateTime (2),LogicalOperationStack (1),None (0),ProcessId (8),ThreadId (16),Timestamp (4)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 Callstack=None
 DateTime=None
 LogicalOperationStack=None
 None=None
 ProcessId=None
 ThreadId=None
 Timestamp=None
 value__=None

