class STATSTG(object):
 """ Use System.Runtime.InteropServices.ComTypes.STATSTG instead. """
 atime=None
 cbSize=None
 clsid=None
 ctime=None
 grfLocksSupported=None
 grfMode=None
 grfStateBits=None
 mtime=None
 pwcsName=None
 reserved=None
 type=None

