class FormBorderStyle(Enum,IComparable,IFormattable,IConvertible):
 """
 Specifies the border styles for a form.

 

 enum FormBorderStyle,values: Fixed3D (2),FixedDialog (3),FixedSingle (1),FixedToolWindow (5),None (0),Sizable (4),SizableToolWindow (6)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 Fixed3D=None
 FixedDialog=None
 FixedSingle=None
 FixedToolWindow=None
 None=None
 Sizable=None
 SizableToolWindow=None
 value__=None

