class GlobalProxySelection(object):
 """
 Contains a global default proxy instance for all HTTP requests.

 

 GlobalProxySelection()
 """
 @staticmethod
 def GetEmptyWebProxy():
  """
  GetEmptyWebProxy() -> IWebProxy

  

   Returns an empty proxy instance.

   Returns: An System.Net.IWebProxy that contains no information.
  """
  pass
 Select=None

