class GCNotificationStatus(Enum,IComparable,IFormattable,IConvertible):
 """
 Provides information about the current registration for notification of the next full garbage collection.

 

 enum GCNotificationStatus,values: Canceled (2),Failed (1),NotApplicable (4),Succeeded (0),Timeout (3)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 Canceled=None
 Failed=None
 NotApplicable=None
 Succeeded=None
 Timeout=None
 value__=None

