class ContentAlignment(Enum,IComparable,IFormattable,IConvertible):
 """
 Specifies alignment of content on the drawing surface.

 

 enum ContentAlignment,values: BottomCenter (512),BottomLeft (256),BottomRight (1024),MiddleCenter (32),MiddleLeft (16),MiddleRight (64),TopCenter (2),TopLeft (1),TopRight (4)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 BottomCenter=None
 BottomLeft=None
 BottomRight=None
 MiddleCenter=None
 MiddleLeft=None
 MiddleRight=None
 TopCenter=None
 TopLeft=None
 TopRight=None
 value__=None

