class ItemsPanelTemplate(FrameworkTemplate,INameScope,ISealable,IHaveResources,IQueryAmbient):
 """
 Specifies the panel that the System.Windows.Controls.ItemsPresenter creates for the layout of the items of an System.Windows.Controls.ItemsControl.

 

 ItemsPanelTemplate()

 ItemsPanelTemplate(root: FrameworkElementFactory)
 """
 def ValidateTemplatedParent(self,*args):
  """
  ValidateTemplatedParent(self: ItemsPanelTemplate,templatedParent: FrameworkElement)

   Checks that the templated parent is a non-null System.Windows.Controls.ItemsPresenter object.

  

   templatedParent: The element this template is applied to. This must be an System.Windows.Controls.ItemsPresenter 

    object.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 @staticmethod
 def __new__(self,root=None):
  """
  __new__(cls: type)

  __new__(cls: type,root: FrameworkElementFactory)
  """
  pass
