class InputLanguageCollection(ReadOnlyCollectionBase,ICollection,IEnumerable):
 """ Stores System.Windows.Forms.InputLanguage objects. """
 def Contains(self,value):
  """
  Contains(self: InputLanguageCollection,value: InputLanguage) -> bool

  

   Gets a value indicating whether the System.Windows.Forms.InputLanguageCollection contains the 

    specified System.Windows.Forms.InputLanguage.

  

  

   value: The System.Windows.Forms.InputLanguage to locate.

   Returns: true if the System.Windows.Forms.InputLanguage is contained in the collection; otherwise,false.
  """
  pass
 def CopyTo(self,array,index):
  """
  CopyTo(self: InputLanguageCollection,array: Array[InputLanguage],index: int)

   Copies the System.Windows.Forms.InputLanguageCollection values to a one-dimensional System.Array 

    at the specified index.

  

  

   array: The one-dimensional array that is the destination of the values copied from 

    System.Windows.Forms.InputLanguageCollection.

  

   index: The index in array where copying begins.
  """
  pass
 def IndexOf(self,value):
  """
  IndexOf(self: InputLanguageCollection,value: InputLanguage) -> int

  

   Returns the index of an System.Windows.Forms.InputLanguage in the 

    System.Windows.Forms.InputLanguageCollection.

  

  

   value: The System.Windows.Forms.InputLanguage to locate.

   Returns: The index of the System.Windows.Forms.InputLanguage in the 

    System.Windows.Forms.InputLanguageCollection,if found; otherwise,-1.
  """
  pass
 def __getitem__(self,*args):
  """ x.__getitem__(y) <==> x[y] """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __iter__(self,*args):
  """ __iter__(self: IEnumerable) -> object """
  pass
 InnerList=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the list of elements contained in the System.Collections.ReadOnlyCollectionBase instance.



"""


