class IRevertibleChangeTracking(IChangeTracking):
 """ Provides support for rolling back the changes """
 def RejectChanges(self):
  """
  RejectChanges(self: IRevertibleChangeTracking)

    """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
