class HttpRequestHeader(Enum,IComparable,IFormattable,IConvertible):
 """
 The HTTP headers that may be specified in a client request.

 

 enum HttpRequestHeader,values: Accept (20),AcceptCharset (21),AcceptEncoding (22),AcceptLanguage (23),Allow (10),Authorization (24),CacheControl (0),Connection (1),ContentEncoding (13),ContentLanguage (14),ContentLength (11),ContentLocation (15),ContentMd5 (16),ContentRange (17),ContentType (12),Cookie (25),Date (2),Expect (26),Expires (18),From (27),Host (28),IfMatch (29),IfModifiedSince (30),IfNoneMatch (31),IfRange (32),IfUnmodifiedSince (33),KeepAlive (3),LastModified (19),MaxForwards (34),Pragma (4),ProxyAuthorization (35),Range (37),Referer (36),Te (38),Trailer (5),TransferEncoding (6),Translate (39),Upgrade (7),UserAgent (40),Via (8),Warning (9)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 Accept=None
 AcceptCharset=None
 AcceptEncoding=None
 AcceptLanguage=None
 Allow=None
 Authorization=None
 CacheControl=None
 Connection=None
 ContentEncoding=None
 ContentLanguage=None
 ContentLength=None
 ContentLocation=None
 ContentMd5=None
 ContentRange=None
 ContentType=None
 Cookie=None
 Date=None
 Expect=None
 Expires=None
 From=None
 Host=None
 IfMatch=None
 IfModifiedSince=None
 IfNoneMatch=None
 IfRange=None
 IfUnmodifiedSince=None
 KeepAlive=None
 LastModified=None
 MaxForwards=None
 Pragma=None
 ProxyAuthorization=None
 Range=None
 Referer=None
 Te=None
 Trailer=None
 TransferEncoding=None
 Translate=None
 Upgrade=None
 UserAgent=None
 value__=None
 Via=None
 Warning=None

