class ProfessionalColorTable(object):
 """
 Provides colors used for Microsoft Office display elements.

 

 ProfessionalColorTable()
 """
 ButtonCheckedGradientBegin=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the starting color of the gradient used when the button is checked.



Get: ButtonCheckedGradientBegin(self: ProfessionalColorTable) -> Color



"""

 ButtonCheckedGradientEnd=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the end color of the gradient used when the button is checked.



Get: ButtonCheckedGradientEnd(self: ProfessionalColorTable) -> Color



"""

 ButtonCheckedGradientMiddle=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the middle color of the gradient used when the button is checked.



Get: ButtonCheckedGradientMiddle(self: ProfessionalColorTable) -> Color



"""

 ButtonCheckedHighlight=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the solid color used when the button is checked.



Get: ButtonCheckedHighlight(self: ProfessionalColorTable) -> Color



"""

 ButtonCheckedHighlightBorder=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the border color to use with System.Windows.Forms.ProfessionalColorTable.ButtonCheckedHighlight.



Get: ButtonCheckedHighlightBorder(self: ProfessionalColorTable) -> Color



"""

 ButtonPressedBorder=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the border color to use with the System.Windows.Forms.ProfessionalColorTable.ButtonPressedGradientBegin,System.Windows.Forms.ProfessionalColorTable.ButtonPressedGradientMiddle,and System.Windows.Forms.ProfessionalColorTable.ButtonPressedGradientEnd colors.



Get: ButtonPressedBorder(self: ProfessionalColorTable) -> Color



"""

 ButtonPressedGradientBegin=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the starting color of the gradient used when the button is pressed.



Get: ButtonPressedGradientBegin(self: ProfessionalColorTable) -> Color



"""

 ButtonPressedGradientEnd=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the end color of the gradient used when the button is pressed.



Get: ButtonPressedGradientEnd(self: ProfessionalColorTable) -> Color



"""

 ButtonPressedGradientMiddle=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the middle color of the gradient used when the button is pressed.



Get: ButtonPressedGradientMiddle(self: ProfessionalColorTable) -> Color



"""

 ButtonPressedHighlight=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the solid color used when the button is pressed.



Get: ButtonPressedHighlight(self: ProfessionalColorTable) -> Color



"""

 ButtonPressedHighlightBorder=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the border color to use with System.Windows.Forms.ProfessionalColorTable.ButtonPressedHighlight.



Get: ButtonPressedHighlightBorder(self: ProfessionalColorTable) -> Color



"""

 ButtonSelectedBorder=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the border color to use with the System.Windows.Forms.ProfessionalColorTable.ButtonSelectedGradientBegin,System.Windows.Forms.ProfessionalColorTable.ButtonSelectedGradientMiddle,and System.Windows.Forms.ProfessionalColorTable.ButtonSelectedGradientEnd colors.



Get: ButtonSelectedBorder(self: ProfessionalColorTable) -> Color



"""

 ButtonSelectedGradientBegin=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the starting color of the gradient used when the button is selected.



Get: ButtonSelectedGradientBegin(self: ProfessionalColorTable) -> Color



"""

 ButtonSelectedGradientEnd=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the end color of the gradient used when the button is selected.



Get: ButtonSelectedGradientEnd(self: ProfessionalColorTable) -> Color



"""

 ButtonSelectedGradientMiddle=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the middle color of the gradient used when the button is selected.



Get: ButtonSelectedGradientMiddle(self: ProfessionalColorTable) -> Color



"""

 ButtonSelectedHighlight=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the solid color used when the button is selected.



Get: ButtonSelectedHighlight(self: ProfessionalColorTable) -> Color



"""

 ButtonSelectedHighlightBorder=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the border color to use with System.Windows.Forms.ProfessionalColorTable.ButtonSelectedHighlight.



Get: ButtonSelectedHighlightBorder(self: ProfessionalColorTable) -> Color



"""

 CheckBackground=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the solid color to use when the button is checked and gradients are being used.



Get: CheckBackground(self: ProfessionalColorTable) -> Color



"""

 CheckPressedBackground=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the solid color to use when the button is checked and selected and gradients are being used.



Get: CheckPressedBackground(self: ProfessionalColorTable) -> Color



"""

 CheckSelectedBackground=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the solid color to use when the button is checked and selected and gradients are being used.



Get: CheckSelectedBackground(self: ProfessionalColorTable) -> Color



"""

 GripDark=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the color to use for shadow effects on the grip (move handle).



Get: GripDark(self: ProfessionalColorTable) -> Color



"""

 GripLight=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the color to use for highlight effects on the grip (move handle).



Get: GripLight(self: ProfessionalColorTable) -> Color



"""

 ImageMarginGradientBegin=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the starting color of the gradient used in the image margin of a System.Windows.Forms.ToolStripDropDownMenu.



Get: ImageMarginGradientBegin(self: ProfessionalColorTable) -> Color



"""

 ImageMarginGradientEnd=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the end color of the gradient used in the image margin of a System.Windows.Forms.ToolStripDropDownMenu.



Get: ImageMarginGradientEnd(self: ProfessionalColorTable) -> Color



"""

 ImageMarginGradientMiddle=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the middle color of the gradient used in the image margin of a System.Windows.Forms.ToolStripDropDownMenu.



Get: ImageMarginGradientMiddle(self: ProfessionalColorTable) -> Color



"""

 ImageMarginRevealedGradientBegin=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the starting color of the gradient used in the image margin of a System.Windows.Forms.ToolStripDropDownMenu when an item is revealed.



Get: ImageMarginRevealedGradientBegin(self: ProfessionalColorTable) -> Color



"""

 ImageMarginRevealedGradientEnd=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the end color of the gradient used in the image margin of a System.Windows.Forms.ToolStripDropDownMenu when an item is revealed.



Get: ImageMarginRevealedGradientEnd(self: ProfessionalColorTable) -> Color



"""

 ImageMarginRevealedGradientMiddle=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the middle color of the gradient used in the image margin of a System.Windows.Forms.ToolStripDropDownMenu when an item is revealed.



Get: ImageMarginRevealedGradientMiddle(self: ProfessionalColorTable) -> Color



"""

 MenuBorder=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the color that is the border color to use on a System.Windows.Forms.MenuStrip.



Get: MenuBorder(self: ProfessionalColorTable) -> Color



"""

 MenuItemBorder=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the border color to use with a System.Windows.Forms.ToolStripMenuItem.



Get: MenuItemBorder(self: ProfessionalColorTable) -> Color



"""

 MenuItemPressedGradientBegin=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the starting color of the gradient used when a top-level System.Windows.Forms.ToolStripMenuItem is pressed.



Get: MenuItemPressedGradientBegin(self: ProfessionalColorTable) -> Color



"""

 MenuItemPressedGradientEnd=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the end color of the gradient used when a top-level System.Windows.Forms.ToolStripMenuItem is pressed.



Get: MenuItemPressedGradientEnd(self: ProfessionalColorTable) -> Color



"""

 MenuItemPressedGradientMiddle=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the middle color of the gradient used when a top-level System.Windows.Forms.ToolStripMenuItem is pressed.



Get: MenuItemPressedGradientMiddle(self: ProfessionalColorTable) -> Color



"""

 MenuItemSelected=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the solid color to use when a System.Windows.Forms.ToolStripMenuItem other than the top-level System.Windows.Forms.ToolStripMenuItem is selected.



Get: MenuItemSelected(self: ProfessionalColorTable) -> Color



"""

 MenuItemSelectedGradientBegin=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the starting color of the gradient used when the System.Windows.Forms.ToolStripMenuItem is selected.



Get: MenuItemSelectedGradientBegin(self: ProfessionalColorTable) -> Color



"""

 MenuItemSelectedGradientEnd=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the end color of the gradient used when the System.Windows.Forms.ToolStripMenuItem is selected.



Get: MenuItemSelectedGradientEnd(self: ProfessionalColorTable) -> Color



"""

 MenuStripGradientBegin=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the starting color of the gradient used in the System.Windows.Forms.MenuStrip.



Get: MenuStripGradientBegin(self: ProfessionalColorTable) -> Color



"""

 MenuStripGradientEnd=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the end color of the gradient used in the System.Windows.Forms.MenuStrip.



Get: MenuStripGradientEnd(self: ProfessionalColorTable) -> Color



"""

 OverflowButtonGradientBegin=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the starting color of the gradient used in the System.Windows.Forms.ToolStripOverflowButton.



Get: OverflowButtonGradientBegin(self: ProfessionalColorTable) -> Color



"""

 OverflowButtonGradientEnd=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the end color of the gradient used in the System.Windows.Forms.ToolStripOverflowButton.



Get: OverflowButtonGradientEnd(self: ProfessionalColorTable) -> Color



"""

 OverflowButtonGradientMiddle=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the middle color of the gradient used in the System.Windows.Forms.ToolStripOverflowButton.



Get: OverflowButtonGradientMiddle(self: ProfessionalColorTable) -> Color



"""

 RaftingContainerGradientBegin=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the starting color of the gradient used in the System.Windows.Forms.ToolStripContainer.



Get: RaftingContainerGradientBegin(self: ProfessionalColorTable) -> Color



"""

 RaftingContainerGradientEnd=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the end color of the gradient used in the System.Windows.Forms.ToolStripContainer.



Get: RaftingContainerGradientEnd(self: ProfessionalColorTable) -> Color



"""

 SeparatorDark=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the color to use to for shadow effects on the System.Windows.Forms.ToolStripSeparator.



Get: SeparatorDark(self: ProfessionalColorTable) -> Color



"""

 SeparatorLight=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the color to use to for highlight effects on the System.Windows.Forms.ToolStripSeparator.



Get: SeparatorLight(self: ProfessionalColorTable) -> Color



"""

 StatusStripGradientBegin=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the starting color of the gradient used on the System.Windows.Forms.StatusStrip.



Get: StatusStripGradientBegin(self: ProfessionalColorTable) -> Color



"""

 StatusStripGradientEnd=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the end color of the gradient used on the System.Windows.Forms.StatusStrip.



Get: StatusStripGradientEnd(self: ProfessionalColorTable) -> Color



"""

 ToolStripBorder=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the border color to use on the bottom edge of the System.Windows.Forms.ToolStrip.



Get: ToolStripBorder(self: ProfessionalColorTable) -> Color



"""

 ToolStripContentPanelGradientBegin=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the starting color of the gradient used in the System.Windows.Forms.ToolStripContentPanel.



Get: ToolStripContentPanelGradientBegin(self: ProfessionalColorTable) -> Color



"""

 ToolStripContentPanelGradientEnd=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the end color of the gradient used in the System.Windows.Forms.ToolStripContentPanel.



Get: ToolStripContentPanelGradientEnd(self: ProfessionalColorTable) -> Color



"""

 ToolStripDropDownBackground=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the solid background color of the System.Windows.Forms.ToolStripDropDown.



Get: ToolStripDropDownBackground(self: ProfessionalColorTable) -> Color



"""

 ToolStripGradientBegin=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the starting color of the gradient used in the System.Windows.Forms.ToolStrip background.



Get: ToolStripGradientBegin(self: ProfessionalColorTable) -> Color



"""

 ToolStripGradientEnd=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the end color of the gradient used in the System.Windows.Forms.ToolStrip background.



Get: ToolStripGradientEnd(self: ProfessionalColorTable) -> Color



"""

 ToolStripGradientMiddle=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the middle color of the gradient used in the System.Windows.Forms.ToolStrip background.



Get: ToolStripGradientMiddle(self: ProfessionalColorTable) -> Color



"""

 ToolStripPanelGradientBegin=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the starting color of the gradient used in the System.Windows.Forms.ToolStripPanel.



Get: ToolStripPanelGradientBegin(self: ProfessionalColorTable) -> Color



"""

 ToolStripPanelGradientEnd=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the end color of the gradient used in the System.Windows.Forms.ToolStripPanel.



Get: ToolStripPanelGradientEnd(self: ProfessionalColorTable) -> Color



"""

 UseSystemColors=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a value indicating whether to use System.Drawing.SystemColors rather than colors that match the current visual style.



Get: UseSystemColors(self: ProfessionalColorTable) -> bool



Set: UseSystemColors(self: ProfessionalColorTable)=value

"""


