class ComUnregisterFunctionAttribute(Attribute,_Attribute):
 """
 Specifies the method to call when you unregister an assembly for use from COM; this allows for the execution of user-written code during the unregistration process.

 

 ComUnregisterFunctionAttribute()
 """
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
