class AccessibleEvents(Enum,IComparable,IFormattable,IConvertible):
 """
 Specifies events that are reported by accessible applications.

 

 enum AccessibleEvents,values: AcceleratorChange (32786),Create (32768),DefaultActionChange (32785),DescriptionChange (32781),Destroy (32769),Focus (32773),HelpChange (32784),Hide (32771),LocationChange (32779),NameChange (32780),ParentChange (32783),Reorder (32772),Selection (32774),SelectionAdd (32775),SelectionRemove (32776),SelectionWithin (32777),Show (32770),StateChange (32778),SystemAlert (2),SystemCaptureEnd (9),SystemCaptureStart (8),SystemContextHelpEnd (13),SystemContextHelpStart (12),SystemDialogEnd (17),SystemDialogStart (16),SystemDragDropEnd (15),SystemDragDropStart (14),SystemForeground (3),SystemMenuEnd (5),SystemMenuPopupEnd (7),SystemMenuPopupStart (6),SystemMenuStart (4),SystemMinimizeEnd (23),SystemMinimizeStart (22),SystemMoveSizeEnd (11),SystemMoveSizeStart (10),SystemScrollingEnd (19),SystemScrollingStart (18),SystemSound (1),SystemSwitchEnd (21),SystemSwitchStart (20),ValueChange (32782)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 AcceleratorChange=None
 Create=None
 DefaultActionChange=None
 DescriptionChange=None
 Destroy=None
 Focus=None
 HelpChange=None
 Hide=None
 LocationChange=None
 NameChange=None
 ParentChange=None
 Reorder=None
 Selection=None
 SelectionAdd=None
 SelectionRemove=None
 SelectionWithin=None
 Show=None
 StateChange=None
 SystemAlert=None
 SystemCaptureEnd=None
 SystemCaptureStart=None
 SystemContextHelpEnd=None
 SystemContextHelpStart=None
 SystemDialogEnd=None
 SystemDialogStart=None
 SystemDragDropEnd=None
 SystemDragDropStart=None
 SystemForeground=None
 SystemMenuEnd=None
 SystemMenuPopupEnd=None
 SystemMenuPopupStart=None
 SystemMenuStart=None
 SystemMinimizeEnd=None
 SystemMinimizeStart=None
 SystemMoveSizeEnd=None
 SystemMoveSizeStart=None
 SystemScrollingEnd=None
 SystemScrollingStart=None
 SystemSound=None
 SystemSwitchEnd=None
 SystemSwitchStart=None
 ValueChange=None
 value__=None

