class Shortcut(Enum,IComparable,IFormattable,IConvertible):
 """
 Specifies shortcut keys that can be used by menu items.

 

 enum Shortcut,values: Alt0 (262192),Alt1 (262193),Alt2 (262194),Alt3 (262195),Alt4 (262196),Alt5 (262197),Alt6 (262198),Alt7 (262199),Alt8 (262200),Alt9 (262201),AltBksp (262152),AltDownArrow (262184),AltF1 (262256),AltF10 (262265),AltF11 (262266),AltF12 (262267),AltF2 (262257),AltF3 (262258),AltF4 (262259),AltF5 (262260),AltF6 (262261),AltF7 (262262),AltF8 (262263),AltF9 (262264),AltLeftArrow (262181),AltRightArrow (262183),AltUpArrow (262182),Ctrl0 (131120),Ctrl1 (131121),Ctrl2 (131122),Ctrl3 (131123),Ctrl4 (131124),Ctrl5 (131125),Ctrl6 (131126),Ctrl7 (131127),Ctrl8 (131128),Ctrl9 (131129),CtrlA (131137),CtrlB (131138),CtrlC (131139),CtrlD (131140),CtrlDel (131118),CtrlE (131141),CtrlF (131142),CtrlF1 (131184),CtrlF10 (131193),CtrlF11 (131194),CtrlF12 (131195),CtrlF2 (131185),CtrlF3 (131186),CtrlF4 (131187),CtrlF5 (131188),CtrlF6 (131189),CtrlF7 (131190),CtrlF8 (131191),CtrlF9 (131192),CtrlG (131143),CtrlH (131144),CtrlI (131145),CtrlIns (131117),CtrlJ (131146),CtrlK (131147),CtrlL (131148),CtrlM (131149),CtrlN (131150),CtrlO (131151),CtrlP (131152),CtrlQ (131153),CtrlR (131154),CtrlS (131155),CtrlShift0 (196656),CtrlShift1 (196657),CtrlShift2 (196658),CtrlShift3 (196659),CtrlShift4 (196660),CtrlShift5 (196661),CtrlShift6 (196662),CtrlShift7 (196663),CtrlShift8 (196664),CtrlShift9 (196665),CtrlShiftA (196673),CtrlShiftB (196674),CtrlShiftC (196675),CtrlShiftD (196676),CtrlShiftE (196677),CtrlShiftF (196678),CtrlShiftF1 (196720),CtrlShiftF10 (196729),CtrlShiftF11 (196730),CtrlShiftF12 (196731),CtrlShiftF2 (196721),CtrlShiftF3 (196722),CtrlShiftF4 (196723),CtrlShiftF5 (196724),CtrlShiftF6 (196725),CtrlShiftF7 (196726),CtrlShiftF8 (196727),CtrlShiftF9 (196728),CtrlShiftG (196679),CtrlShiftH (196680),CtrlShiftI (196681),CtrlShiftJ (196682),CtrlShiftK (196683),CtrlShiftL (196684),CtrlShiftM (196685),CtrlShiftN (196686),CtrlShiftO (196687),CtrlShiftP (196688),CtrlShiftQ (196689),CtrlShiftR (196690),CtrlShiftS (196691),CtrlShiftT (196692),CtrlShiftU (196693),CtrlShiftV (196694),CtrlShiftW (196695),CtrlShiftX (196696),CtrlShiftY (196697),CtrlShiftZ (196698),CtrlT (131156),CtrlU (131157),CtrlV (131158),CtrlW (131159),CtrlX (131160),CtrlY (131161),CtrlZ (131162),Del (46),F1 (112),F10 (121),F11 (122),F12 (123),F2 (113),F3 (114),F4 (115),F5 (116),F6 (117),F7 (118),F8 (119),F9 (120),Ins (45),None (0),ShiftDel (65582),ShiftF1 (65648),ShiftF10 (65657),ShiftF11 (65658),ShiftF12 (65659),ShiftF2 (65649),ShiftF3 (65650),ShiftF4 (65651),ShiftF5 (65652),ShiftF6 (65653),ShiftF7 (65654),ShiftF8 (65655),ShiftF9 (65656),ShiftIns (65581)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 Alt0=None
 Alt1=None
 Alt2=None
 Alt3=None
 Alt4=None
 Alt5=None
 Alt6=None
 Alt7=None
 Alt8=None
 Alt9=None
 AltBksp=None
 AltDownArrow=None
 AltF1=None
 AltF10=None
 AltF11=None
 AltF12=None
 AltF2=None
 AltF3=None
 AltF4=None
 AltF5=None
 AltF6=None
 AltF7=None
 AltF8=None
 AltF9=None
 AltLeftArrow=None
 AltRightArrow=None
 AltUpArrow=None
 Ctrl0=None
 Ctrl1=None
 Ctrl2=None
 Ctrl3=None
 Ctrl4=None
 Ctrl5=None
 Ctrl6=None
 Ctrl7=None
 Ctrl8=None
 Ctrl9=None
 CtrlA=None
 CtrlB=None
 CtrlC=None
 CtrlD=None
 CtrlDel=None
 CtrlE=None
 CtrlF=None
 CtrlF1=None
 CtrlF10=None
 CtrlF11=None
 CtrlF12=None
 CtrlF2=None
 CtrlF3=None
 CtrlF4=None
 CtrlF5=None
 CtrlF6=None
 CtrlF7=None
 CtrlF8=None
 CtrlF9=None
 CtrlG=None
 CtrlH=None
 CtrlI=None
 CtrlIns=None
 CtrlJ=None
 CtrlK=None
 CtrlL=None
 CtrlM=None
 CtrlN=None
 CtrlO=None
 CtrlP=None
 CtrlQ=None
 CtrlR=None
 CtrlS=None
 CtrlShift0=None
 CtrlShift1=None
 CtrlShift2=None
 CtrlShift3=None
 CtrlShift4=None
 CtrlShift5=None
 CtrlShift6=None
 CtrlShift7=None
 CtrlShift8=None
 CtrlShift9=None
 CtrlShiftA=None
 CtrlShiftB=None
 CtrlShiftC=None
 CtrlShiftD=None
 CtrlShiftE=None
 CtrlShiftF=None
 CtrlShiftF1=None
 CtrlShiftF10=None
 CtrlShiftF11=None
 CtrlShiftF12=None
 CtrlShiftF2=None
 CtrlShiftF3=None
 CtrlShiftF4=None
 CtrlShiftF5=None
 CtrlShiftF6=None
 CtrlShiftF7=None
 CtrlShiftF8=None
 CtrlShiftF9=None
 CtrlShiftG=None
 CtrlShiftH=None
 CtrlShiftI=None
 CtrlShiftJ=None
 CtrlShiftK=None
 CtrlShiftL=None
 CtrlShiftM=None
 CtrlShiftN=None
 CtrlShiftO=None
 CtrlShiftP=None
 CtrlShiftQ=None
 CtrlShiftR=None
 CtrlShiftS=None
 CtrlShiftT=None
 CtrlShiftU=None
 CtrlShiftV=None
 CtrlShiftW=None
 CtrlShiftX=None
 CtrlShiftY=None
 CtrlShiftZ=None
 CtrlT=None
 CtrlU=None
 CtrlV=None
 CtrlW=None
 CtrlX=None
 CtrlY=None
 CtrlZ=None
 Del=None
 F1=None
 F10=None
 F11=None
 F12=None
 F2=None
 F3=None
 F4=None
 F5=None
 F6=None
 F7=None
 F8=None
 F9=None
 Ins=None
 None=None
 ShiftDel=None
 ShiftF1=None
 ShiftF10=None
 ShiftF11=None
 ShiftF12=None
 ShiftF2=None
 ShiftF3=None
 ShiftF4=None
 ShiftF5=None
 ShiftF6=None
 ShiftF7=None
 ShiftF8=None
 ShiftF9=None
 ShiftIns=None
 value__=None

