class RegistrationClassContext(Enum,IComparable,IFormattable,IConvertible):
 """
 Specifies the set of execution contexts in which a class object will be made available for requests to construct instances.

 

 enum (flags) RegistrationClassContext,values: DisableActivateAsActivator (32768),EnableActivateAsActivator (65536),EnableCodeDownload (8192),FromDefaultContext (131072),InProcessHandler (2),InProcessHandler16 (32),InProcessServer (1),InProcessServer16 (8),LocalServer (4),NoCodeDownload (1024),NoCustomMarshal (4096),NoFailureLog (16384),RemoteServer (16),Reserved1 (64),Reserved2 (128),Reserved3 (256),Reserved4 (512),Reserved5 (2048)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 DisableActivateAsActivator=None
 EnableActivateAsActivator=None
 EnableCodeDownload=None
 FromDefaultContext=None
 InProcessHandler=None
 InProcessHandler16=None
 InProcessServer=None
 InProcessServer16=None
 LocalServer=None
 NoCodeDownload=None
 NoCustomMarshal=None
 NoFailureLog=None
 RemoteServer=None
 Reserved1=None
 Reserved2=None
 Reserved3=None
 Reserved4=None
 Reserved5=None
 value__=None

