class ScrollEventType(Enum,IComparable,IFormattable,IConvertible):
 """
 Specifies the type of action used to raise the System.Windows.Forms.ScrollBar.Scroll event.

 

 enum ScrollEventType,values: EndScroll (8),First (6),LargeDecrement (2),LargeIncrement (3),Last (7),SmallDecrement (0),SmallIncrement (1),ThumbPosition (4),ThumbTrack (5)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 EndScroll=None
 First=None
 LargeDecrement=None
 LargeIncrement=None
 Last=None
 SmallDecrement=None
 SmallIncrement=None
 ThumbPosition=None
 ThumbTrack=None
 value__=None

