class AllowReversePInvokeCallsAttribute(Attribute,_Attribute):
 """
 Allows an unmanaged method to call a managed method.

 

 AllowReversePInvokeCallsAttribute()
 """
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
