class ComRegisterFunctionAttribute(Attribute,_Attribute):
 """
 Specifies the method to call when you register an assembly for use from COM; this enables the execution of user-written code during the registration process.

 

 ComRegisterFunctionAttribute()
 """
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
