class GenericUriParser(UriParser):
 """
 A customizable parser for a hierarchical URI.

 

 GenericUriParser(options: GenericUriParserOptions)
 """
 @staticmethod
 def __new__(self,options):
  """ __new__(cls: type,options: GenericUriParserOptions) """
  pass
