# encoding: utf-8
# module System.Drawing calls itself Drawing
# from System.Drawing,Version=4.0.0.0,Culture=neutral,PublicKeyToken=b03f5f7f11d50a3a
# by generator 1.145
""" NamespaceTracker represent a CLS namespace. """
# no imports

# no functions
# classes
from __init___parts.Image import Image
from __init___parts.Bitmap import Bitmap
from __init___parts.BitmapSuffixInSameAssemblyAttribute import BitmapSuffixInSameAssemblyAttribute
from __init___parts.BitmapSuffixInSatelliteAssemblyAttribute import BitmapSuffixInSatelliteAssemblyAttribute
from __init___parts.Brush import Brush
from __init___parts.Brushes import Brushes
from __init___parts.BufferedGraphics import BufferedGraphics
from __init___parts.BufferedGraphicsContext import BufferedGraphicsContext
from __init___parts.BufferedGraphicsManager import BufferedGraphicsManager
from __init___parts.CharacterRange import CharacterRange
from __init___parts.Color import Color
from __init___parts.ColorConverter import ColorConverter
from __init___parts.ColorTranslator import ColorTranslator
from __init___parts.ContentAlignment import ContentAlignment
from __init___parts.CopyPixelOperation import CopyPixelOperation
from __init___parts.Font import Font
from __init___parts.FontConverter import FontConverter
from __init___parts.FontFamily import FontFamily
from __init___parts.FontStyle import FontStyle
from __init___parts.Graphics import Graphics
from __init___parts.GraphicsUnit import GraphicsUnit
from __init___parts.Icon import Icon
from __init___parts.IconConverter import IconConverter
from __init___parts.IDeviceContext import IDeviceContext
from __init___parts.ImageAnimator import ImageAnimator
from __init___parts.ImageConverter import ImageConverter
from __init___parts.ImageFormatConverter import ImageFormatConverter
from __init___parts.KnownColor import KnownColor
from __init___parts.Pen import Pen
from __init___parts.Pens import Pens
from __init___parts.Point import Point
from __init___parts.PointConverter import PointConverter
from __init___parts.PointF import PointF
from __init___parts.Rectangle import Rectangle
from __init___parts.RectangleConverter import RectangleConverter
from __init___parts.RectangleF import RectangleF
from __init___parts.Region import Region
from __init___parts.RotateFlipType import RotateFlipType
from __init___parts.Size import Size
from __init___parts.SizeConverter import SizeConverter
from __init___parts.SizeF import SizeF
from __init___parts.SizeFConverter import SizeFConverter
from __init___parts.SolidBrush import SolidBrush
from __init___parts.StringAlignment import StringAlignment
from __init___parts.StringDigitSubstitute import StringDigitSubstitute
from __init___parts.StringFormat import StringFormat
from __init___parts.StringFormatFlags import StringFormatFlags
from __init___parts.StringTrimming import StringTrimming
from __init___parts.StringUnit import StringUnit
from __init___parts.SystemBrushes import SystemBrushes
from __init___parts.SystemColors import SystemColors
from __init___parts.SystemFonts import SystemFonts
from __init___parts.SystemIcons import SystemIcons
from __init___parts.SystemPens import SystemPens
from __init___parts.TextureBrush import TextureBrush
from __init___parts.ToolboxBitmapAttribute import ToolboxBitmapAttribute
