class ErrorIconAlignment(Enum,IComparable,IFormattable,IConvertible):
 """
 Specifies constants indicating the locations that an error icon can appear in relation to the control with an error.

 

 enum ErrorIconAlignment,values: BottomLeft (4),BottomRight (5),MiddleLeft (2),MiddleRight (3),TopLeft (0),TopRight (1)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 BottomLeft=None
 BottomRight=None
 MiddleLeft=None
 MiddleRight=None
 TopLeft=None
 TopRight=None
 value__=None

