class MessageBoxIcon(Enum,IComparable,IFormattable,IConvertible):
 """
 Specifies constants defining which information to display.

 

 enum MessageBoxIcon,values: Asterisk (64),Error (16),Exclamation (48),Hand (16),Information (64),None (0),Question (32),Stop (16),Warning (48)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 Asterisk=None
 Error=None
 Exclamation=None
 Hand=None
 Information=None
 None=None
 Question=None
 Stop=None
 value__=None
 Warning=None

