class IEquatable:
 # no doc
 def Equals(self,other):
  """
  Equals(self: IEquatable[T],other: T) -> bool

  

   Indicates whether the current object is equal to another object of the same type.

  

   other: An object to compare with this object.

   Returns: true if the current object is equal to the other parameter; otherwise,false.
  """
  pass
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==y """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
