class TextFormatFlags(Enum,IComparable,IFormattable,IConvertible):
 """
 Specifies the display and layout information for text strings.

 

 enum (flags) TextFormatFlags,values: Bottom (8),Default (0),EndEllipsis (32768),ExpandTabs (64),ExternalLeading (512),GlyphOverhangPadding (0),HidePrefix (1048576),HorizontalCenter (1),Internal (4096),Left (0),LeftAndRightPadding (536870912),ModifyString (65536),NoClipping (256),NoFullWidthCharacterBreak (524288),NoPadding (268435456),NoPrefix (2048),PathEllipsis (16384),PrefixOnly (2097152),PreserveGraphicsClipping (16777216),PreserveGraphicsTranslateTransform (33554432),Right (2),RightToLeft (131072),SingleLine (32),TextBoxControl (8192),Top (0),VerticalCenter (4),WordBreak (16),WordEllipsis (262144)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 Bottom=None
 Default=None
 EndEllipsis=None
 ExpandTabs=None
 ExternalLeading=None
 GlyphOverhangPadding=None
 HidePrefix=None
 HorizontalCenter=None
 Internal=None
 Left=None
 LeftAndRightPadding=None
 ModifyString=None
 NoClipping=None
 NoFullWidthCharacterBreak=None
 NoPadding=None
 NoPrefix=None
 PathEllipsis=None
 PrefixOnly=None
 PreserveGraphicsClipping=None
 PreserveGraphicsTranslateTransform=None
 Right=None
 RightToLeft=None
 SingleLine=None
 TextBoxControl=None
 Top=None
 value__=None
 VerticalCenter=None
 WordBreak=None
 WordEllipsis=None

