"""pyRevit related links."""
from pyrevit.labs import Common

PYREVIT_LICENSE = Common.PyRevitLabsConsts.LicenseUrl
PYREVIT_CREDITS = Common.PyRevitLabsConsts.CreditsUrl
PYREVIT_WIKI = Common.PyRevitLabsConsts.WikiUrl
PYREVIT_TWITTER = "https://twitter.com/pyrevit"
PYREVIT_BLOG = Common.PyRevitLabsConsts.BlogsUrl
PYREVIT_DOCS = Common.PyRevitLabsConsts.DocsUrl
PYREVIT_GITHUB = Common.PyRevitLabsConsts.OriginalRepoBasePath
PYREVIT_GITHUBBRANCH = \
    Common.PyRevitLabsConsts.OriginalRepoBasePath + '/tree/{branch}'
PYREVIT_GITHUBMASTER_COMMIT = \
    Common.PyRevitLabsConsts.OriginalRepoBasePath + '/commits/master'
PYREVIT_GITHUBBRANCH_COMMIT = \
    Common.PyRevitLabsConsts.OriginalRepoBasePath + '/commits/{branch}'
PYREVIT_GITHUBISSUES = Common.PyRevitLabsConsts.IssuesUrl
PYREVIT_YOUTUBE = Common.PyRevitLabsConsts.YoutubeUrl
PYREVIT_SUPPORT = Common.PyRevitLabsConsts.SupportUrl
PYREVIT_RELEASENOTES = Common.PyRevitLabsConsts.ReleasesUrl
PROFILE_EIN = 'https://ein.sh'
