class PerformanceCounterType(Enum,IComparable,IFormattable,IConvertible):
 """
 Specifies the formula used to calculate the System.Diagnostics.PerformanceCounter.NextValue method for a System.Diagnostics.PerformanceCounter instance.

 

 enum PerformanceCounterType,values: AverageBase (1073939458),AverageCount64 (1073874176),AverageTimer32 (805438464),CounterDelta32 (4195328),CounterDelta64 (4195584),CounterMultiBase (1107494144),CounterMultiTimer (574686464),CounterMultiTimer100Ns (575735040),CounterMultiTimer100NsInverse (592512256),CounterMultiTimerInverse (591463680),CounterTimer (541132032),CounterTimerInverse (557909248),CountPerTimeInterval32 (4523008),CountPerTimeInterval64 (4523264),ElapsedTime (807666944),NumberOfItems32 (65536),NumberOfItems64 (65792),NumberOfItemsHEX32 (0),NumberOfItemsHEX64 (256),RateOfCountsPerSecond32 (272696320),RateOfCountsPerSecond64 (272696576),RawBase (1073939459),RawFraction (537003008),SampleBase (1073939457),SampleCounter (4260864),SampleFraction (549585920),Timer100Ns (542180608),Timer100NsInverse (558957824)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 AverageBase=None
 AverageCount64=None
 AverageTimer32=None
 CounterDelta32=None
 CounterDelta64=None
 CounterMultiBase=None
 CounterMultiTimer=None
 CounterMultiTimer100Ns=None
 CounterMultiTimer100NsInverse=None
 CounterMultiTimerInverse=None
 CounterTimer=None
 CounterTimerInverse=None
 CountPerTimeInterval32=None
 CountPerTimeInterval64=None
 ElapsedTime=None
 NumberOfItems32=None
 NumberOfItems64=None
 NumberOfItemsHEX32=None
 NumberOfItemsHEX64=None
 RateOfCountsPerSecond32=None
 RateOfCountsPerSecond64=None
 RawBase=None
 RawFraction=None
 SampleBase=None
 SampleCounter=None
 SampleFraction=None
 Timer100Ns=None
 Timer100NsInverse=None
 value__=None

