class HttpVersion(object):
 """
 Defines the HTTP version numbers that are supported by the System.Net.HttpWebRequest and System.Net.HttpWebResponse classes.

 

 HttpVersion()
 """
 Version10=None
 Version11=None

