class CopyPixelOperation(Enum,IComparable,IFormattable,IConvertible):
 """
 Determines how the source color in a copy pixel operation is combined with the destination color to result in a final color.

 

 enum CopyPixelOperation,values: Blackness (66),CaptureBlt (1073741824),DestinationInvert (5570569),MergeCopy (12583114),MergePaint (12255782),NoMirrorBitmap (-2147483648),NotSourceCopy (3342344),NotSourceErase (1114278),PatCopy (15728673),PatInvert (5898313),PatPaint (16452105),SourceAnd (8913094),SourceCopy (13369376),SourceErase (4457256),SourceInvert (6684742),SourcePaint (15597702),Whiteness (16711778)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 Blackness=None
 CaptureBlt=None
 DestinationInvert=None
 MergeCopy=None
 MergePaint=None
 NoMirrorBitmap=None
 NotSourceCopy=None
 NotSourceErase=None
 PatCopy=None
 PatInvert=None
 PatPaint=None
 SourceAnd=None
 SourceCopy=None
 SourceErase=None
 SourceInvert=None
 SourcePaint=None
 value__=None
 Whiteness=None

