class ItemContainerTemplateSelector(object):
 # no doc
 def SelectTemplate(self,item,parentItemsControl):
  """ SelectTemplate(self: ItemContainerTemplateSelector,item: object,parentItemsControl: ItemsControl) -> DataTemplate """
  pass
