class StringFormatFlags(Enum,IComparable,IFormattable,IConvertible):
 """
 Specifies the display and layout information for text strings.

 

 enum (flags) StringFormatFlags,values: DirectionRightToLeft (1),DirectionVertical (2),DisplayFormatControl (32),FitBlackBox (4),LineLimit (8192),MeasureTrailingSpaces (2048),NoClip (16384),NoFontFallback (1024),NoWrap (4096)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 DirectionRightToLeft=None
 DirectionVertical=None
 DisplayFormatControl=None
 FitBlackBox=None
 LineLimit=None
 MeasureTrailingSpaces=None
 NoClip=None
 NoFontFallback=None
 NoWrap=None
 value__=None

