# encoding: utf-8
# module System.ComponentModel calls itself ComponentModel
# from System,Version=4.0.0.0,Culture=neutral,PublicKeyToken=b77a5c561934e089
# by generator 1.145
""" NamespaceTracker represent a CLS namespace. """
# no imports

# no functions
# classes
from __init___parts.AddingNewEventArgs import AddingNewEventArgs
from __init___parts.AddingNewEventHandler import AddingNewEventHandler
from __init___parts.AmbientValueAttribute import AmbientValueAttribute
from __init___parts.TypeConverter import TypeConverter
from __init___parts.CollectionConverter import CollectionConverter
from __init___parts.ArrayConverter import ArrayConverter
from __init___parts.AsyncCompletedEventArgs import AsyncCompletedEventArgs
from __init___parts.AsyncCompletedEventHandler import AsyncCompletedEventHandler
from __init___parts.AsyncOperation import AsyncOperation
from __init___parts.AsyncOperationManager import AsyncOperationManager
from __init___parts.AttributeCollection import AttributeCollection
from __init___parts.AttributeProviderAttribute import AttributeProviderAttribute
from __init___parts.Component import Component
from __init___parts.BackgroundWorker import BackgroundWorker
from __init___parts.BaseNumberConverter import BaseNumberConverter
from __init___parts.BindableAttribute import BindableAttribute
from __init___parts.BindableSupport import BindableSupport
from __init___parts.BindingDirection import BindingDirection
from __init___parts.IBindingList import IBindingList
from __init___parts.ICancelAddNew import ICancelAddNew
from __init___parts.IRaiseItemChangedEvents import IRaiseItemChangedEvents
from __init___parts.BindingList import BindingList
from __init___parts.BooleanConverter import BooleanConverter
from __init___parts.BrowsableAttribute import BrowsableAttribute
from __init___parts.ByteConverter import ByteConverter
from __init___parts.CancelEventArgs import CancelEventArgs
from __init___parts.CancelEventHandler import CancelEventHandler
from __init___parts.CategoryAttribute import CategoryAttribute
from __init___parts.CharConverter import CharConverter
from __init___parts.CollectionChangeAction import CollectionChangeAction
from __init___parts.CollectionChangeEventArgs import CollectionChangeEventArgs
from __init___parts.CollectionChangeEventHandler import CollectionChangeEventHandler
from __init___parts.ComplexBindingPropertiesAttribute import ComplexBindingPropertiesAttribute
from __init___parts.ComponentCollection import ComponentCollection
from __init___parts.ReferenceConverter import ReferenceConverter
from __init___parts.ComponentConverter import ComponentConverter
from __init___parts.ComponentEditor import ComponentEditor
from __init___parts.ComponentResourceManager import ComponentResourceManager
from __init___parts.Container import Container
from __init___parts.ContainerFilterService import ContainerFilterService
from __init___parts.CultureInfoConverter import CultureInfoConverter
from __init___parts.CustomTypeDescriptor import CustomTypeDescriptor
from __init___parts.DataErrorsChangedEventArgs import DataErrorsChangedEventArgs
from __init___parts.DataObjectAttribute import DataObjectAttribute
from __init___parts.DataObjectFieldAttribute import DataObjectFieldAttribute
from __init___parts.DataObjectMethodAttribute import DataObjectMethodAttribute
from __init___parts.DataObjectMethodType import DataObjectMethodType
from __init___parts.DateTimeConverter import DateTimeConverter
from __init___parts.DateTimeOffsetConverter import DateTimeOffsetConverter
from __init___parts.DecimalConverter import DecimalConverter
from __init___parts.DefaultBindingPropertyAttribute import DefaultBindingPropertyAttribute
from __init___parts.DefaultEventAttribute import DefaultEventAttribute
from __init___parts.DefaultPropertyAttribute import DefaultPropertyAttribute
from __init___parts.DefaultValueAttribute import DefaultValueAttribute
from __init___parts.DescriptionAttribute import DescriptionAttribute
from __init___parts.DesignerAttribute import DesignerAttribute
from __init___parts.DesignerCategoryAttribute import DesignerCategoryAttribute
from __init___parts.DesignerSerializationVisibility import DesignerSerializationVisibility
from __init___parts.DesignerSerializationVisibilityAttribute import DesignerSerializationVisibilityAttribute
from __init___parts.DesignOnlyAttribute import DesignOnlyAttribute
from __init___parts.DesignTimeVisibleAttribute import DesignTimeVisibleAttribute
from __init___parts.DisplayNameAttribute import DisplayNameAttribute
from __init___parts.DoubleConverter import DoubleConverter
from __init___parts.DoWorkEventArgs import DoWorkEventArgs
from __init___parts.DoWorkEventHandler import DoWorkEventHandler
from __init___parts.EditorAttribute import EditorAttribute
from __init___parts.EditorBrowsableAttribute import EditorBrowsableAttribute
from __init___parts.EditorBrowsableState import EditorBrowsableState
from __init___parts.EnumConverter import EnumConverter
from __init___parts.MemberDescriptor import MemberDescriptor
from __init___parts.EventDescriptor import EventDescriptor
from __init___parts.EventDescriptorCollection import EventDescriptorCollection
from __init___parts.EventHandlerList import EventHandlerList
from __init___parts.ExpandableObjectConverter import ExpandableObjectConverter
from __init___parts.ExtenderProvidedPropertyAttribute import ExtenderProvidedPropertyAttribute
from __init___parts.GuidConverter import GuidConverter
from __init___parts.HandledEventArgs import HandledEventArgs
from __init___parts.HandledEventHandler import HandledEventHandler
from __init___parts.IBindingListView import IBindingListView
from __init___parts.IChangeTracking import IChangeTracking
from __init___parts.IComNativeDescriptorHandler import IComNativeDescriptorHandler
from __init___parts.IComponent import IComponent
from __init___parts.IContainer import IContainer
from __init___parts.ICustomTypeDescriptor import ICustomTypeDescriptor
from __init___parts.IDataErrorInfo import IDataErrorInfo
from __init___parts.IEditableObject import IEditableObject
from __init___parts.IExtenderProvider import IExtenderProvider
from __init___parts.IIntellisenseBuilder import IIntellisenseBuilder
from __init___parts.IListSource import IListSource
from __init___parts.ImmutableObjectAttribute import ImmutableObjectAttribute
from __init___parts.INestedContainer import INestedContainer
from __init___parts.ISite import ISite
from __init___parts.INestedSite import INestedSite
from __init___parts.InheritanceAttribute import InheritanceAttribute
from __init___parts.InheritanceLevel import InheritanceLevel
from __init___parts.InitializationEventAttribute import InitializationEventAttribute
from __init___parts.INotifyDataErrorInfo import INotifyDataErrorInfo
from __init___parts.INotifyPropertyChanged import INotifyPropertyChanged
from __init___parts.INotifyPropertyChanging import INotifyPropertyChanging
from __init___parts.InstallerTypeAttribute import InstallerTypeAttribute
from __init___parts.InstanceCreationEditor import InstanceCreationEditor
from __init___parts.Int16Converter import Int16Converter
from __init___parts.Int32Converter import Int32Converter
from __init___parts.Int64Converter import Int64Converter
from __init___parts.InvalidAsynchronousStateException import InvalidAsynchronousStateException
from __init___parts.InvalidEnumArgumentException import InvalidEnumArgumentException
from __init___parts.IRevertibleChangeTracking import IRevertibleChangeTracking
from __init___parts.ISupportInitialize import ISupportInitialize
from __init___parts.ISupportInitializeNotification import ISupportInitializeNotification
from __init___parts.ISynchronizeInvoke import ISynchronizeInvoke
from __init___parts.ITypeDescriptorContext import ITypeDescriptorContext
from __init___parts.ITypedList import ITypedList
from __init___parts.License import License
from __init___parts.LicenseContext import LicenseContext
from __init___parts.LicenseException import LicenseException
from __init___parts.LicenseManager import LicenseManager
from __init___parts.LicenseProvider import LicenseProvider
from __init___parts.LicenseProviderAttribute import LicenseProviderAttribute
from __init___parts.LicenseUsageMode import LicenseUsageMode
from __init___parts.LicFileLicenseProvider import LicFileLicenseProvider
from __init___parts.ListBindableAttribute import ListBindableAttribute
from __init___parts.ListChangedEventArgs import ListChangedEventArgs
from __init___parts.ListChangedEventHandler import ListChangedEventHandler
from __init___parts.ListChangedType import ListChangedType
from __init___parts.ListSortDescription import ListSortDescription
from __init___parts.ListSortDescriptionCollection import ListSortDescriptionCollection
from __init___parts.ListSortDirection import ListSortDirection
from __init___parts.LocalizableAttribute import LocalizableAttribute
from __init___parts.LookupBindingPropertiesAttribute import LookupBindingPropertiesAttribute
from __init___parts.MarshalByValueComponent import MarshalByValueComponent
from __init___parts.MaskedTextProvider import MaskedTextProvider
from __init___parts.MaskedTextResultHint import MaskedTextResultHint
from __init___parts.MergablePropertyAttribute import MergablePropertyAttribute
from __init___parts.MultilineStringConverter import MultilineStringConverter
from __init___parts.NestedContainer import NestedContainer
from __init___parts.NotifyParentPropertyAttribute import NotifyParentPropertyAttribute
from __init___parts.NullableConverter import NullableConverter
from __init___parts.ParenthesizePropertyNameAttribute import ParenthesizePropertyNameAttribute
from __init___parts.PasswordPropertyTextAttribute import PasswordPropertyTextAttribute
from __init___parts.ProgressChangedEventArgs import ProgressChangedEventArgs
from __init___parts.ProgressChangedEventHandler import ProgressChangedEventHandler
from __init___parts.PropertyChangedEventArgs import PropertyChangedEventArgs
from __init___parts.PropertyChangedEventHandler import PropertyChangedEventHandler
from __init___parts.PropertyChangingEventArgs import PropertyChangingEventArgs
from __init___parts.PropertyChangingEventHandler import PropertyChangingEventHandler
from __init___parts.PropertyDescriptor import PropertyDescriptor
from __init___parts.PropertyDescriptorCollection import PropertyDescriptorCollection
from __init___parts.PropertyTabAttribute import PropertyTabAttribute
from __init___parts.PropertyTabScope import PropertyTabScope
from __init___parts.ProvidePropertyAttribute import ProvidePropertyAttribute
from __init___parts.ReadOnlyAttribute import ReadOnlyAttribute
from __init___parts.RecommendedAsConfigurableAttribute import RecommendedAsConfigurableAttribute
from __init___parts.RefreshEventArgs import RefreshEventArgs
from __init___parts.RefreshEventHandler import RefreshEventHandler
from __init___parts.RefreshProperties import RefreshProperties
from __init___parts.RefreshPropertiesAttribute import RefreshPropertiesAttribute
from __init___parts.RunInstallerAttribute import RunInstallerAttribute
from __init___parts.RunWorkerCompletedEventArgs import RunWorkerCompletedEventArgs
from __init___parts.RunWorkerCompletedEventHandler import RunWorkerCompletedEventHandler
from __init___parts.SByteConverter import SByteConverter
from __init___parts.SettingsBindableAttribute import SettingsBindableAttribute
from __init___parts.SingleConverter import SingleConverter
from __init___parts.StringConverter import StringConverter
from __init___parts.SyntaxCheck import SyntaxCheck
from __init___parts.TimeSpanConverter import TimeSpanConverter
from __init___parts.ToolboxItemAttribute import ToolboxItemAttribute
from __init___parts.ToolboxItemFilterAttribute import ToolboxItemFilterAttribute
from __init___parts.ToolboxItemFilterType import ToolboxItemFilterType
from __init___parts.TypeConverterAttribute import TypeConverterAttribute
from __init___parts.TypeDescriptionProvider import TypeDescriptionProvider
from __init___parts.TypeDescriptionProviderAttribute import TypeDescriptionProviderAttribute
from __init___parts.TypeDescriptor import TypeDescriptor
from __init___parts.TypeListConverter import TypeListConverter
from __init___parts.UInt16Converter import UInt16Converter
from __init___parts.UInt32Converter import UInt32Converter
from __init___parts.UInt64Converter import UInt64Converter
from __init___parts.WarningException import WarningException
from __init___parts.Win32Exception import Win32Exception
