class OutAttribute(Attribute,_Attribute):
 """
 Indicates that data should be marshaled from callee back to caller.

 

 OutAttribute()
 """
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
