class ContainerFilterService(object):
 """ Provides a base class for the container filter service. """
 def FilterComponents(self,components):
  """
  FilterComponents(self: ContainerFilterService,components: ComponentCollection) -> ComponentCollection

  

   Filters the component collection.

  

   components: The component collection to filter.

   Returns: A System.ComponentModel.ComponentCollection that represents a modified collection.
  """
  pass
