# encoding: utf-8
# module System.Windows.Markup.Primitives calls itself Primitives
# from PresentationFramework,Version=4.0.0.0,Culture=neutral,PublicKeyToken=31bf3856ad364e35
# by generator 1.145
""" NamespaceTracker represent a CLS namespace. """
# no imports

# no functions
# classes

class MarkupWriter(object,IDisposable):
 """ Provides methods to write an object to XAML format. """
 def Dispose(self):
  """
  Dispose(self: MarkupWriter)

   Releases the resources used by the System.Windows.Markup.Primitives.MarkupWriter.
  """
  pass
 @staticmethod
 def GetMarkupObjectFor(instance,manager=None):
  """
  GetMarkupObjectFor(instance: object,manager: XamlDesignerSerializationManager) -> MarkupObject

  

   Creates an instance of a System.Windows.Markup.Primitives.MarkupObject from the specified object 

    and the specified serialization manager.

  

  

   instance: An object that will be the root of the serialized tree.

   manager: The serialization manager.

   Returns: A markup object that enables navigating through the tree of objects.

  GetMarkupObjectFor(instance: object) -> MarkupObject

  

   Creates an instance of a System.Windows.Markup.Primitives.MarkupObject from the specified object.

  

   instance: An object that will be the root of the serialized tree.

   Returns: A markup object that enables navigating through the tree of objects.
  """
  pass
 def __enter__(self,*args):
  """
  __enter__(self: IDisposable) -> object

  

   Provides the implementation of __enter__ for objects which implement IDisposable.
  """
  pass
 def __exit__(self,*args):
  """
  __exit__(self: IDisposable,exc_type: object,exc_value: object,exc_back: object)

   Provides the implementation of __exit__ for objects which implement IDisposable.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __repr__(self,*args):
  """ __repr__(self: object) -> str """
  pass

