class PlacementMode(Enum,IComparable,IFormattable,IConvertible):
 """
 Describes the placement of where a System.Windows.Controls.Primitives.Popup control appears on the screen.

 

 enum PlacementMode,values: Absolute (0),AbsolutePoint (5),Bottom (2),Center (3),Custom (11),Left (9),Mouse (7),MousePoint (8),Relative (1),RelativePoint (6),Right (4),Top (10)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 Absolute=None
 AbsolutePoint=None
 Bottom=None
 Center=None
 Custom=None
 Left=None
 Mouse=None
 MousePoint=None
 Relative=None
 RelativePoint=None
 Right=None
 Top=None
 value__=None

