# encoding: utf-8
# module System.Windows.Controls.Primitives calls itself Primitives
# from PresentationFramework,Version=4.0.0.0,Culture=neutral,PublicKeyToken=31bf3856ad364e35
# by generator 1.145
""" NamespaceTracker represent a CLS namespace. """
# no imports

# no functions
# classes
from Primitives_parts.AutoToolTipPlacement import AutoToolTipPlacement
from Primitives_parts.BulletDecorator import BulletDecorator
from Primitives_parts.ButtonBase import ButtonBase
from Primitives_parts.CalendarButton import CalendarButton
from Primitives_parts.CalendarDayButton import CalendarDayButton
from Primitives_parts.CalendarItem import CalendarItem
from Primitives_parts.CustomPopupPlacement import CustomPopupPlacement
from Primitives_parts.CustomPopupPlacementCallback import CustomPopupPlacementCallback
from Primitives_parts.IContainItemStorage import IContainItemStorage
from Primitives_parts.DataGridCellsPresenter import DataGridCellsPresenter
from Primitives_parts.DataGridColumnHeader import DataGridColumnHeader
from Primitives_parts.DataGridColumnHeadersPresenter import DataGridColumnHeadersPresenter
from Primitives_parts.DataGridDetailsPresenter import DataGridDetailsPresenter
from Primitives_parts.DataGridRowHeader import DataGridRowHeader
from Primitives_parts.IScrollInfo import IScrollInfo
from Primitives_parts.DataGridRowsPresenter import DataGridRowsPresenter
from Primitives_parts.TextBoxBase import TextBoxBase
from Primitives_parts.DatePickerTextBox import DatePickerTextBox
from Primitives_parts.DocumentPageView import DocumentPageView
from Primitives_parts.DocumentViewerBase import DocumentViewerBase
from Primitives_parts.DragCompletedEventArgs import DragCompletedEventArgs
from Primitives_parts.DragCompletedEventHandler import DragCompletedEventHandler
from Primitives_parts.DragDeltaEventArgs import DragDeltaEventArgs
from Primitives_parts.DragDeltaEventHandler import DragDeltaEventHandler
from Primitives_parts.DragStartedEventArgs import DragStartedEventArgs
from Primitives_parts.DragStartedEventHandler import DragStartedEventHandler
from Primitives_parts.GeneratorDirection import GeneratorDirection
from Primitives_parts.GeneratorPosition import GeneratorPosition
from Primitives_parts.GeneratorStatus import GeneratorStatus
from Primitives_parts.GridViewRowPresenterBase import GridViewRowPresenterBase
from Primitives_parts.IHierarchicalVirtualizationAndScrollInfo import IHierarchicalVirtualizationAndScrollInfo
from Primitives_parts.IItemContainerGenerator import IItemContainerGenerator
from Primitives_parts.IRecyclingItemContainerGenerator import IRecyclingItemContainerGenerator
from Primitives_parts.ItemsChangedEventArgs import ItemsChangedEventArgs
from Primitives_parts.ItemsChangedEventHandler import ItemsChangedEventHandler
from Primitives_parts.LayoutInformation import LayoutInformation
from Primitives_parts.MenuBase import MenuBase
from Primitives_parts.Selector import Selector
from Primitives_parts.MultiSelector import MultiSelector
from Primitives_parts.PlacementMode import PlacementMode
from Primitives_parts.Popup import Popup
from Primitives_parts.PopupAnimation import PopupAnimation
from Primitives_parts.PopupPrimaryAxis import PopupPrimaryAxis
from Primitives_parts.RangeBase import RangeBase
from Primitives_parts.RepeatButton import RepeatButton
from Primitives_parts.ResizeGrip import ResizeGrip
from Primitives_parts.ScrollBar import ScrollBar
from Primitives_parts.ScrollEventArgs import ScrollEventArgs
from Primitives_parts.ScrollEventHandler import ScrollEventHandler
from Primitives_parts.ScrollEventType import ScrollEventType
from Primitives_parts.SelectiveScrollingGrid import SelectiveScrollingGrid
from Primitives_parts.StatusBar import StatusBar
from Primitives_parts.StatusBarItem import StatusBarItem
from Primitives_parts.TabPanel import TabPanel
from Primitives_parts.Thumb import Thumb
from Primitives_parts.TickBar import TickBar
from Primitives_parts.TickBarPlacement import TickBarPlacement
from Primitives_parts.TickPlacement import TickPlacement
from Primitives_parts.ToggleButton import ToggleButton
from Primitives_parts.ToolBarOverflowPanel import ToolBarOverflowPanel
from Primitives_parts.ToolBarPanel import ToolBarPanel
from Primitives_parts.Track import Track
from Primitives_parts.UniformGrid import UniformGrid
