class TYPEFLAGS(Enum,IComparable,IFormattable,IConvertible):
 """
 Use System.Runtime.InteropServices.ComTypes.TYPEFLAGS instead.

 

 enum (flags) TYPEFLAGS,values: TYPEFLAG_FAGGREGATABLE (1024),TYPEFLAG_FAPPOBJECT (1),TYPEFLAG_FCANCREATE (2),TYPEFLAG_FCONTROL (32),TYPEFLAG_FDISPATCHABLE (4096),TYPEFLAG_FDUAL (64),TYPEFLAG_FHIDDEN (16),TYPEFLAG_FLICENSED (4),TYPEFLAG_FNONEXTENSIBLE (128),TYPEFLAG_FOLEAUTOMATION (256),TYPEFLAG_FPREDECLID (8),TYPEFLAG_FPROXY (16384),TYPEFLAG_FREPLACEABLE (2048),TYPEFLAG_FRESTRICTED (512),TYPEFLAG_FREVERSEBIND (8192)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 TYPEFLAG_FAGGREGATABLE=None
 TYPEFLAG_FAPPOBJECT=None
 TYPEFLAG_FCANCREATE=None
 TYPEFLAG_FCONTROL=None
 TYPEFLAG_FDISPATCHABLE=None
 TYPEFLAG_FDUAL=None
 TYPEFLAG_FHIDDEN=None
 TYPEFLAG_FLICENSED=None
 TYPEFLAG_FNONEXTENSIBLE=None
 TYPEFLAG_FOLEAUTOMATION=None
 TYPEFLAG_FPREDECLID=None
 TYPEFLAG_FPROXY=None
 TYPEFLAG_FREPLACEABLE=None
 TYPEFLAG_FRESTRICTED=None
 TYPEFLAG_FREVERSEBIND=None
 value__=None

