class IHierarchicalVirtualizationAndScrollInfo:
 # no doc
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 Constraints=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: Constraints(self: IHierarchicalVirtualizationAndScrollInfo) -> HierarchicalVirtualizationConstraints



Set: Constraints(self: IHierarchicalVirtualizationAndScrollInfo)=value

"""

 HeaderDesiredSizes=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: HeaderDesiredSizes(self: IHierarchicalVirtualizationAndScrollInfo) -> HierarchicalVirtualizationHeaderDesiredSizes



"""

 InBackgroundLayout=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: InBackgroundLayout(self: IHierarchicalVirtualizationAndScrollInfo) -> bool



Set: InBackgroundLayout(self: IHierarchicalVirtualizationAndScrollInfo)=value

"""

 ItemDesiredSizes=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: ItemDesiredSizes(self: IHierarchicalVirtualizationAndScrollInfo) -> HierarchicalVirtualizationItemDesiredSizes



Set: ItemDesiredSizes(self: IHierarchicalVirtualizationAndScrollInfo)=value

"""

 ItemsHost=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: ItemsHost(self: IHierarchicalVirtualizationAndScrollInfo) -> Panel



"""

 MustDisableVirtualization=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: MustDisableVirtualization(self: IHierarchicalVirtualizationAndScrollInfo) -> bool



Set: MustDisableVirtualization(self: IHierarchicalVirtualizationAndScrollInfo)=value

"""


