class TableLayoutColumnStyleCollection(TableLayoutStyleCollection,IList,ICollection,IEnumerable):
 """ A collection that stores System.Windows.Forms.ColumnStyle objects. """
 def Add(self,*__args):
  """
  Add(self: TableLayoutColumnStyleCollection,columnStyle: ColumnStyle) -> int

  

   Adds an item to the System.Windows.Forms.TableLayoutColumnStyleCollection.

  

   columnStyle: The System.Windows.Forms.ColumnStyle to add to the 

    System.Windows.Forms.TableLayoutColumnStyleCollection.

  

   Returns: The position into which the new element was inserted.
  """
  pass
 def Contains(self,columnStyle):
  """
  Contains(self: TableLayoutColumnStyleCollection,columnStyle: ColumnStyle) -> bool

  

   Determines whether the specified System.Windows.Forms.ColumnStyle is in the collection.

  

   columnStyle: The System.Windows.Forms.ColumnStyle to locate in the 

    System.Windows.Forms.TableLayoutColumnStyleCollection. The value can be null.

  

   Returns: true if the System.Windows.Forms.ColumnStyle is found in the 

    System.Windows.Forms.TableLayoutColumnStyleCollection; otherwise,false.
  """
  pass
 def IndexOf(self,columnStyle):
  """
  IndexOf(self: TableLayoutColumnStyleCollection,columnStyle: ColumnStyle) -> int

  

   Determines the index of a specific item in the 

    System.Windows.Forms.TableLayoutColumnStyleCollection.

  

  

   columnStyle: The System.Windows.Forms.ColumnStyle to locate in the 

    System.Windows.Forms.TableLayoutColumnStyleCollection.

  

   Returns: The index of columnStyle if found in the System.Windows.Forms.TableLayoutColumnStyleCollection; 

    otherwise,-1.
  """
  pass
 def Insert(self,index,columnStyle):
  """
  Insert(self: TableLayoutColumnStyleCollection,index: int,columnStyle: ColumnStyle)

   Inserts a System.Windows.Forms.ColumnStyle into the 

    System.Windows.Forms.TableLayoutColumnStyleCollection at the specified position.

  

  

   index: The zero-based index at which System.Windows.Forms.ColumnStyle should be inserted.

   columnStyle: The System.Windows.Forms.ColumnStyle to insert into the 

    System.Windows.Forms.TableLayoutColumnStyleCollection.
  """
  pass
 def Remove(self,columnStyle):
  """
  Remove(self: TableLayoutColumnStyleCollection,columnStyle: ColumnStyle)

   Removes the first occurrence of a specific System.Windows.Forms.ColumnStyle from the 

    System.Windows.Forms.TableLayoutColumnStyleCollection.

  

  

   columnStyle: The System.Windows.Forms.ColumnStyle to remove from the 

    System.Windows.Forms.TableLayoutColumnStyleCollection. The value can be null.
  """
  pass
 def __add__(self,*args):
  """ x.__add__(y) <==> x+y """
  pass
 def __getitem__(self,*args):
  """ x.__getitem__(y) <==> x[y] """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __iter__(self,*args):
  """ __iter__(self: IEnumerable) -> object """
  pass
 def __setitem__(self,*args):
  """ x.__setitem__(i,y) <==> x[i]= """
  pass
