class TableLayoutPanelGrowStyle(Enum,IComparable,IFormattable,IConvertible):
 """
 Specifies how a System.Windows.Forms.TableLayoutPanel will gain additional rows or columns after its existing cells are full.

 

 enum TableLayoutPanelGrowStyle,values: AddColumns (2),AddRows (1),FixedSize (0)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 AddColumns=None
 AddRows=None
 FixedSize=None
 value__=None

