class VarEnum(Enum,IComparable,IFormattable,IConvertible):
 """
 Indicates how to marshal the array elements when an array is marshaled from managed to unmanaged code as a System.Runtime.InteropServices.UnmanagedType.SafeArray.

 

 enum VarEnum,values: VT_ARRAY (8192),VT_BLOB (65),VT_BLOB_OBJECT (70),VT_BOOL (11),VT_BSTR (8),VT_BYREF (16384),VT_CARRAY (28),VT_CF (71),VT_CLSID (72),VT_CY (6),VT_DATE (7),VT_DECIMAL (14),VT_DISPATCH (9),VT_EMPTY (0),VT_ERROR (10),VT_FILETIME (64),VT_HRESULT (25),VT_I1 (16),VT_I2 (2),VT_I4 (3),VT_I8 (20),VT_INT (22),VT_LPSTR (30),VT_LPWSTR (31),VT_NULL (1),VT_PTR (26),VT_R4 (4),VT_R8 (5),VT_RECORD (36),VT_SAFEARRAY (27),VT_STORAGE (67),VT_STORED_OBJECT (69),VT_STREAM (66),VT_STREAMED_OBJECT (68),VT_UI1 (17),VT_UI2 (18),VT_UI4 (19),VT_UI8 (21),VT_UINT (23),VT_UNKNOWN (13),VT_USERDEFINED (29),VT_VARIANT (12),VT_VECTOR (4096),VT_VOID (24)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 value__=None
 VT_ARRAY=None
 VT_BLOB=None
 VT_BLOB_OBJECT=None
 VT_BOOL=None
 VT_BSTR=None
 VT_BYREF=None
 VT_CARRAY=None
 VT_CF=None
 VT_CLSID=None
 VT_CY=None
 VT_DATE=None
 VT_DECIMAL=None
 VT_DISPATCH=None
 VT_EMPTY=None
 VT_ERROR=None
 VT_FILETIME=None
 VT_HRESULT=None
 VT_I1=None
 VT_I2=None
 VT_I4=None
 VT_I8=None
 VT_INT=None
 VT_LPSTR=None
 VT_LPWSTR=None
 VT_NULL=None
 VT_PTR=None
 VT_R4=None
 VT_R8=None
 VT_RECORD=None
 VT_SAFEARRAY=None
 VT_STORAGE=None
 VT_STORED_OBJECT=None
 VT_STREAM=None
 VT_STREAMED_OBJECT=None
 VT_UI1=None
 VT_UI2=None
 VT_UI4=None
 VT_UI8=None
 VT_UINT=None
 VT_UNKNOWN=None
 VT_USERDEFINED=None
 VT_VARIANT=None
 VT_VECTOR=None
 VT_VOID=None

