class DataGridViewPaintParts(Enum,IComparable,IFormattable,IConvertible):
 """
 Defines values for specifying the parts of a System.Windows.Forms.DataGridViewCell that are to be painted.

 

 enum (flags) DataGridViewPaintParts,values: All (127),Background (1),Border (2),ContentBackground (4),ContentForeground (8),ErrorIcon (16),Focus (32),None (0),SelectionBackground (64)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 All=None
 Background=None
 Border=None
 ContentBackground=None
 ContentForeground=None
 ErrorIcon=None
 Focus=None
 None=None
 SelectionBackground=None
 value__=None

