class EXCEPINFO(object):
 """ Use System.Runtime.InteropServices.ComTypes.EXCEPINFO instead. """
 bstrDescription=None
 bstrHelpFile=None
 bstrSource=None
 dwHelpContext=None
 pfnDeferredFillIn=None
 pvReserved=None
 wCode=None
 wReserved=None

