class DataGridViewCellBorderStyle(Enum,IComparable,IFormattable,IConvertible):
 """
 Specifies the border styles that can be applied to the cells of a System.Windows.Forms.DataGridView control.

 

 enum DataGridViewCellBorderStyle,values: Custom (0),None (4),Raised (2),RaisedHorizontal (9),RaisedVertical (6),Single (1),SingleHorizontal (8),SingleVertical (5),Sunken (3),SunkenHorizontal (10),SunkenVertical (7)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 Custom=None
 None=None
 Raised=None
 RaisedHorizontal=None
 RaisedVertical=None
 Single=None
 SingleHorizontal=None
 SingleVertical=None
 Sunken=None
 SunkenHorizontal=None
 SunkenVertical=None
 value__=None

