class FileSystemRights(Enum,IComparable,IFormattable,IConvertible):
 """
 Defines the access rights to use when creating access and audit rules.

 

 enum (flags) FileSystemRights,values: AppendData (4),ChangePermissions (262144),CreateDirectories (4),CreateFiles (2),Delete (65536),DeleteSubdirectoriesAndFiles (64),ExecuteFile (32),FullControl (2032127),ListDirectory (1),Modify (197055),Read (131209),ReadAndExecute (131241),ReadAttributes (128),ReadData (1),ReadExtendedAttributes (8),ReadPermissions (131072),Synchronize (1048576),TakeOwnership (524288),Traverse (32),Write (278),WriteAttributes (256),WriteData (2),WriteExtendedAttributes (16)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 AppendData=None
 ChangePermissions=None
 CreateDirectories=None
 CreateFiles=None
 Delete=None
 DeleteSubdirectoriesAndFiles=None
 ExecuteFile=None
 FullControl=None
 ListDirectory=None
 Modify=None
 Read=None
 ReadAndExecute=None
 ReadAttributes=None
 ReadData=None
 ReadExtendedAttributes=None
 ReadPermissions=None
 Synchronize=None
 TakeOwnership=None
 Traverse=None
 value__=None
 Write=None
 WriteAttributes=None
 WriteData=None
 WriteExtendedAttributes=None

