class DataGridTextColumn(DataGridBoundColumn):
 """
 Represents a System.Windows.Controls.DataGrid column that hosts textual content in its cells.

 

 DataGridTextColumn()
 """
 DataGridOwner=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the System.Windows.Controls.DataGrid control that contains this column.



"""

 FontFamily=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the font family for the content of cells in the column.



Get: FontFamily(self: DataGridTextColumn) -> FontFamily



Set: FontFamily(self: DataGridTextColumn)=value

"""

 FontSize=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the font size for the content of cells in the column.



Get: FontSize(self: DataGridTextColumn) -> float



Set: FontSize(self: DataGridTextColumn)=value

"""

 FontStyle=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the font style for the content of cells in the column.



Get: FontStyle(self: DataGridTextColumn) -> FontStyle



Set: FontStyle(self: DataGridTextColumn)=value

"""

 FontWeight=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the font weight for the content of cells in the column.



Get: FontWeight(self: DataGridTextColumn) -> FontWeight



Set: FontWeight(self: DataGridTextColumn)=value

"""

 Foreground=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the System.Windows.Media.Brush that is used to paint the text contents of cells in the column.



Get: Foreground(self: DataGridTextColumn) -> Brush



Set: Foreground(self: DataGridTextColumn)=value

"""


 DefaultEditingElementStyle=None
 DefaultElementStyle=None
 FontFamilyProperty=None
 FontSizeProperty=None
 FontStyleProperty=None
 FontWeightProperty=None
 ForegroundProperty=None

