class UICues(Enum,IComparable,IFormattable,IConvertible):
 """
 Specifies the state of the user interface.

 

 enum (flags) UICues,values: Changed (12),ChangeFocus (4),ChangeKeyboard (8),None (0),ShowFocus (1),ShowKeyboard (2),Shown (3)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 Changed=None
 ChangeFocus=None
 ChangeKeyboard=None
 None=None
 ShowFocus=None
 ShowKeyboard=None
 Shown=None
 value__=None

