class BatteryChargeStatus(Enum,IComparable,IFormattable,IConvertible):
 """
 Defines identifiers that indicate the current battery charge level or charging state information.

 

 enum (flags) BatteryChargeStatus,values: Charging (8),Critical (4),High (1),Low (2),NoSystemBattery (128),Unknown (255)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 Charging=None
 Critical=None
 High=None
 Low=None
 NoSystemBattery=None
 Unknown=None
 value__=None

