class ContextStaticAttribute(Attribute,_Attribute):
 """
 Indicates that the value of a static field is unique for a particular context.

 

 ContextStaticAttribute()
 """
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __reduce_ex__(self,*args):
  pass
