class ImeMode(Enum,IComparable,IFormattable,IConvertible):
 """
 Specifies a value that determines the Input Method Editor (IME) status of an object when the object is selected.

 

 enum ImeMode,values: Alpha (8),AlphaFull (7),Close (11),Disable (3),Hangul (10),HangulFull (9),Hiragana (4),Inherit (-1),Katakana (5),KatakanaHalf (6),NoControl (0),Off (2),On (1),OnHalf (12)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 Alpha=None
 AlphaFull=None
 Close=None
 Disable=None
 Hangul=None
 HangulFull=None
 Hiragana=None
 Inherit=None
 Katakana=None
 KatakanaHalf=None
 NoControl=None
 Off=None
 On=None
 OnHalf=None
 value__=None

