class GenericUriParserOptions(Enum,IComparable,IFormattable,IConvertible):
 """
 Specifies options for a System.UriParser.

 

 enum (flags) GenericUriParserOptions,values: AllowEmptyAuthority (2),Default (0),DontCompressPath (128),DontConvertPathBackslashes (64),DontUnescapePathDotsAndSlashes (256),GenericAuthority (1),Idn (512),IriParsing (1024),NoFragment (32),NoPort (8),NoQuery (16),NoUserInfo (4)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 AllowEmptyAuthority=None
 Default=None
 DontCompressPath=None
 DontConvertPathBackslashes=None
 DontUnescapePathDotsAndSlashes=None
 GenericAuthority=None
 Idn=None
 IriParsing=None
 NoFragment=None
 NoPort=None
 NoQuery=None
 NoUserInfo=None
 value__=None

