class TableLayoutPanelCellBorderStyle(Enum,IComparable,IFormattable,IConvertible):
 """
 Specifies the border style of a cell in a table layout control.

 

 enum TableLayoutPanelCellBorderStyle,values: Inset (2),InsetDouble (3),None (0),Outset (4),OutsetDouble (5),OutsetPartial (6),Single (1)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 Inset=None
 InsetDouble=None
 None=None
 Outset=None
 OutsetDouble=None
 OutsetPartial=None
 Single=None
 value__=None

