class DESCKIND(Enum,IComparable,IFormattable,IConvertible):
 """
 Use System.Runtime.InteropServices.ComTypes.DESCKIND instead.

 

 enum DESCKIND,values: DESCKIND_FUNCDESC (1),DESCKIND_IMPLICITAPPOBJ (4),DESCKIND_MAX (5),DESCKIND_NONE (0),DESCKIND_TYPECOMP (3),DESCKIND_VARDESC (2)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 DESCKIND_FUNCDESC=None
 DESCKIND_IMPLICITAPPOBJ=None
 DESCKIND_MAX=None
 DESCKIND_NONE=None
 DESCKIND_TYPECOMP=None
 DESCKIND_VARDESC=None
 value__=None

