class VirtualizationCacheLengthConverter(TypeConverter):
 """ VirtualizationCacheLengthConverter() """
 def CanConvertFrom(self,*__args):
  """ CanConvertFrom(self: VirtualizationCacheLengthConverter,typeDescriptorContext: ITypeDescriptorContext,sourceType: Type) -> bool """
  pass
 def CanConvertTo(self,*__args):
  """ CanConvertTo(self: VirtualizationCacheLengthConverter,typeDescriptorContext: ITypeDescriptorContext,destinationType: Type) -> bool """
  pass
 def ConvertFrom(self,*__args):
  """ ConvertFrom(self: VirtualizationCacheLengthConverter,typeDescriptorContext: ITypeDescriptorContext,cultureInfo: CultureInfo,source: object) -> object """
  pass
 def ConvertTo(self,*__args):
  """ ConvertTo(self: VirtualizationCacheLengthConverter,typeDescriptorContext: ITypeDescriptorContext,cultureInfo: CultureInfo,value: object,destinationType: Type) -> object """
  pass
