class ContextMenuService(object):
 """ Provides the system implementation for displaying a System.Windows.Controls.ContextMenu. """
 @staticmethod
 def AddContextMenuClosingHandler(element,handler):
  """ AddContextMenuClosingHandler(element: DependencyObject,handler: ContextMenuEventHandler) """
  pass
 @staticmethod
 def AddContextMenuOpeningHandler(element,handler):
  """ AddContextMenuOpeningHandler(element: DependencyObject,handler: ContextMenuEventHandler) """
  pass
 @staticmethod
 def GetContextMenu(element):
  """
  GetContextMenu(element: DependencyObject) -> ContextMenu

  

   Gets the value of the System.Windows.Controls.ContextMenuService.ContextMenu property of the 

    specified object.

  

  

   element: Object to query concerning the System.Windows.FrameworkElement.ContextMenu property.

   Returns: Value of the System.Windows.Controls.ContextMenuService.ContextMenu property.
  """
  pass
 @staticmethod
 def GetHasDropShadow(element):
  """
  GetHasDropShadow(element: DependencyObject) -> bool

  

   Gets a value that indicates whether the System.Windows.Controls.ContextMenu has a drop shadow.

  

   element: Object to query concerning whether it has a drop shadow.

   Returns: A Boolean value,true if the System.Windows.Controls.ContextMenu has a drop shadow; false 

    otherwise.
  """
  pass
 @staticmethod
 def GetHorizontalOffset(element):
  """
  GetHorizontalOffset(element: DependencyObject) -> float

  

   Gets the value of the System.Windows.Controls.ContextMenuService.HorizontalOffset property of 

    the specified object.

  

  

   element: Object to query concerning the System.Windows.Controls.ContextMenuService.HorizontalOffset 

    property.

  

   Returns: Value of the System.Windows.Controls.ContextMenuService.HorizontalOffset property.
  """
  pass
 @staticmethod
 def GetIsEnabled(element):
  """
  GetIsEnabled(element: DependencyObject) -> bool

  

   Gets the value of the System.Windows.Controls.ContextMenuService.IsEnabled property of the 

    specified object.

  

  

   element: Object to query concerning the System.Windows.Controls.ContextMenuService.IsEnabled property.

   Returns: Value of the System.Windows.Controls.ContextMenuService.IsEnabled property.
  """
  pass
 @staticmethod
 def GetPlacement(element):
  """
  GetPlacement(element: DependencyObject) -> PlacementMode

  

   Gets the value of the System.Windows.Controls.ContextMenuService.Placement property of the 

    specified object.

  

  

   element: Object to query concerning the System.Windows.Controls.ContextMenuService.Placement  property.

   Returns: Value of the System.Windows.Controls.ContextMenuService.Placement property.
  """
  pass
 @staticmethod
 def GetPlacementRectangle(element):
  """
  GetPlacementRectangle(element: DependencyObject) -> Rect

  

   Gets the value of the System.Windows.Controls.ContextMenuService.PlacementRectangle property of 

    the specified object.

  

  

   element: Object to query concerning the System.Windows.Controls.ContextMenuService.PlacementRectangle 

    property.

  

   Returns: Value of the System.Windows.Controls.ContextMenuService.PlacementRectangle property.
  """
  pass
 @staticmethod
 def GetPlacementTarget(element):
  """
  GetPlacementTarget(element: DependencyObject) -> UIElement

  

   Gets the value of the System.Windows.Controls.ContextMenuService.PlacementTarget property of the 

    specified object.

  

  

   element: Object to query concerning the System.Windows.Controls.ContextMenuService.PlacementTarget 

    property.

  

   Returns: Value of the System.Windows.Controls.ContextMenuService.PlacementTarget property.
  """
  pass
 @staticmethod
 def GetShowOnDisabled(element):
  """
  GetShowOnDisabled(element: DependencyObject) -> bool

  

   Gets the value of the System.Windows.Controls.ContextMenuService.ShowOnDisabled property of the 

    specified object.

  

  

   element: Object to query concerning the System.Windows.Controls.ContextMenuService.ShowOnDisabled 

    property.

  

   Returns: Value of the System.Windows.Controls.ContextMenuService.ShowOnDisabled property.
  """
  pass
 @staticmethod
 def GetVerticalOffset(element):
  """
  GetVerticalOffset(element: DependencyObject) -> float

  

   Gets the value of the System.Windows.Controls.ContextMenuService.VerticalOffset property of the 

    specified object.

  

  

   element: Object to query concerning the System.Windows.Controls.ContextMenuService.VerticalOffset 

    property.

  

   Returns: Value of the System.Windows.Controls.ContextMenuService.VerticalOffset property.
  """
  pass
 @staticmethod
 def RemoveContextMenuClosingHandler(element,handler):
  """ RemoveContextMenuClosingHandler(element: DependencyObject,handler: ContextMenuEventHandler) """
  pass
 @staticmethod
 def RemoveContextMenuOpeningHandler(element,handler):
  """ RemoveContextMenuOpeningHandler(element: DependencyObject,handler: ContextMenuEventHandler) """
  pass
 @staticmethod
 def SetContextMenu(element,value):
  """
  SetContextMenu(element: DependencyObject,value: ContextMenu)

   Sets the value of the System.Windows.Controls.ContextMenuService.ContextMenu property of the 

    specified object.

  

  

   element: Object to set the property on.

   value: Value to set.
  """
  pass
 @staticmethod
 def SetHasDropShadow(element,value):
  """
  SetHasDropShadow(element: DependencyObject,value: bool)

   Sets a value that indicates whether the System.Windows.Controls.ContextMenu has a drop shadow.

  

   element: Object to set the property on.

   value: Boolean value to set,true if the System.Windows.Controls.ContextMenu has a drop shadow; false 

    otherwise.
  """
  pass
 @staticmethod
 def SetHorizontalOffset(element,value):
  """
  SetHorizontalOffset(element: DependencyObject,value: float)

   Sets the value of the System.Windows.Controls.ContextMenuService.HorizontalOffset property of 

    the specified object.

  

  

   element: Object to set the value on.

   value: Value to set.
  """
  pass
 @staticmethod
 def SetIsEnabled(element,value):
  """
  SetIsEnabled(element: DependencyObject,value: bool)

   Sets the value of the System.Windows.Controls.ContextMenuService.IsEnabled property of the 

    specified object.

  

  

   element: Object to set value on.

   value: Value to set.
  """
  pass
 @staticmethod
 def SetPlacement(element,value):
  """
  SetPlacement(element: DependencyObject,value: PlacementMode)

   Sets the value of the System.Windows.Controls.ContextMenuService.Placement  property of the 

    specified object.

  

  

   element: Object to set the value on.

   value: Value to set.
  """
  pass
 @staticmethod
 def SetPlacementRectangle(element,value):
  """
  SetPlacementRectangle(element: DependencyObject,value: Rect)

   Sets the value of the System.Windows.Controls.ContextMenuService.PlacementRectangle property of 

    the specified object.

  

  

   element: Object to set the value on.

   value: Value to set.
  """
  pass
 @staticmethod
 def SetPlacementTarget(element,value):
  """
  SetPlacementTarget(element: DependencyObject,value: UIElement)

   Sets the value of the System.Windows.Controls.ContextMenuService.PlacementTarget property of the 

    specified object.

  

  

   element: Object to set value on.

   value: Value to set.
  """
  pass
 @staticmethod
 def SetShowOnDisabled(element,value):
  """
  SetShowOnDisabled(element: DependencyObject,value: bool)

   Sets the value of the System.Windows.Controls.ContextMenuService.ShowOnDisabled property of the 

    specified object.

  

  

   element: Object to set value on.

   value: Value to set.
  """
  pass
 @staticmethod
 def SetVerticalOffset(element,value):
  """
  SetVerticalOffset(element: DependencyObject,value: float)

   Sets the value of the System.Windows.Controls.ContextMenuService.VerticalOffset property of the 

    specified object.

  

  

   element: Object to set value on.

   value: Value to set.
  """
  pass
 ContextMenuClosingEvent=None
 ContextMenuOpeningEvent=None
 ContextMenuProperty=None
 HasDropShadowProperty=None
 HorizontalOffsetProperty=None
 IsEnabledProperty=None
 PlacementProperty=None
 PlacementRectangleProperty=None
 PlacementTargetProperty=None
 ShowOnDisabledProperty=None
 VerticalOffsetProperty=None
 __all__=[
  'AddContextMenuClosingHandler',
  'AddContextMenuOpeningHandler',
  'ContextMenuClosingEvent',
  'ContextMenuOpeningEvent',
  'ContextMenuProperty',
  'GetContextMenu',
  'GetHasDropShadow',
  'GetHorizontalOffset',
  'GetIsEnabled',
  'GetPlacement',
  'GetPlacementRectangle',
  'GetPlacementTarget',
  'GetShowOnDisabled',
  'GetVerticalOffset',
  'HasDropShadowProperty',
  'HorizontalOffsetProperty',
  'IsEnabledProperty',
  'PlacementProperty',
  'PlacementRectangleProperty',
  'PlacementTargetProperty',
  'RemoveContextMenuClosingHandler',
  'RemoveContextMenuOpeningHandler',
  'SetContextMenu',
  'SetHasDropShadow',
  'SetHorizontalOffset',
  'SetIsEnabled',
  'SetPlacement',
  'SetPlacementRectangle',
  'SetPlacementTarget',
  'SetShowOnDisabled',
  'SetVerticalOffset',
  'ShowOnDisabledProperty',
  'VerticalOffsetProperty',
 ]

