# encoding: utf-8
# module System.Windows.Forms.VisualStyles calls itself VisualStyles
# from System.Windows.Forms,Version=4.0.0.0,Culture=neutral,PublicKeyToken=b77a5c561934e089
# by generator 1.145
""" NamespaceTracker represent a CLS namespace. """
# no imports

# no functions
# classes

class BackgroundType(Enum,IComparable,IFormattable,IConvertible):
 """
 Specifies the source of a visual style element's background.

 

 enum BackgroundType,values: BorderFill (1),ImageFile (0),None (2)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 BorderFill=None
 ImageFile=None
 None=None
 value__=None


class BooleanProperty(Enum,IComparable,IFormattable,IConvertible):
 """
 Identifies the Boolean properties of a visual style element.

 

 enum BooleanProperty,values: AlwaysShowSizingBar (2208),AutoSize (2202),BackgroundFill (2205),BorderOnly (2203),Composited (2204),GlyphOnly (2207),GlyphTransparent (2206),IntegralSizing (2211),MirrorImage (2209),SourceGrow (2212),SourceShrink (2213),Transparent (2201),UniformSizing (2210)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 AlwaysShowSizingBar=None
 AutoSize=None
 BackgroundFill=None
 BorderOnly=None
 Composited=None
 GlyphOnly=None
 GlyphTransparent=None
 IntegralSizing=None
 MirrorImage=None
 SourceGrow=None
 SourceShrink=None
 Transparent=None
 UniformSizing=None
 value__=None


class BorderType(Enum,IComparable,IFormattable,IConvertible):
 """
 Specifies the border type of a visual style element with a filled-border background.

 

 enum BorderType,values: Ellipse (2),Rectangle (0),RoundedRectangle (1)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 Ellipse=None
 Rectangle=None
 RoundedRectangle=None
 value__=None


class CheckBoxState(Enum,IComparable,IFormattable,IConvertible):
 """
 Specifies the visual state of a check box that is drawn with visual styles.

 

 enum CheckBoxState,values: CheckedDisabled (8),CheckedHot (6),CheckedNormal (5),CheckedPressed (7),MixedDisabled (12),MixedHot (10),MixedNormal (9),MixedPressed (11),UncheckedDisabled (4),UncheckedHot (2),UncheckedNormal (1),UncheckedPressed (3)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 CheckedDisabled=None
 CheckedHot=None
 CheckedNormal=None
 CheckedPressed=None
 MixedDisabled=None
 MixedHot=None
 MixedNormal=None
 MixedPressed=None
 UncheckedDisabled=None
 UncheckedHot=None
 UncheckedNormal=None
 UncheckedPressed=None
 value__=None


class ColorProperty(Enum,IComparable,IFormattable,IConvertible):
 """
 Identifies the color properties of a visual style element.

 

 enum ColorProperty,values: AccentColorHint (3823),BorderColor (3801),BorderColorHint (3822),EdgeDarkShadowColor (3807),EdgeFillColor (3808),EdgeHighlightColor (3805),EdgeLightColor (3804),EdgeShadowColor (3806),FillColor (3802),FillColorHint (3821),GlowColor (3816),GlyphTextColor (3819),GlyphTransparentColor (3820),GradientColor1 (3810),GradientColor2 (3811),GradientColor3 (3812),GradientColor4 (3813),GradientColor5 (3814),ShadowColor (3815),TextBorderColor (3817),TextColor (3803),TextShadowColor (3818),TransparentColor (3809)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 AccentColorHint=None
 BorderColor=None
 BorderColorHint=None
 EdgeDarkShadowColor=None
 EdgeFillColor=None
 EdgeHighlightColor=None
 EdgeLightColor=None
 EdgeShadowColor=None
 FillColor=None
 FillColorHint=None
 GlowColor=None
 GlyphTextColor=None
 GlyphTransparentColor=None
 GradientColor1=None
 GradientColor2=None
 GradientColor3=None
 GradientColor4=None
 GradientColor5=None
 ShadowColor=None
 TextBorderColor=None
 TextColor=None
 TextShadowColor=None
 TransparentColor=None
 value__=None


class ComboBoxState(Enum,IComparable,IFormattable,IConvertible):
 """
 Specifies the visual state of a combo box that is drawn with visual styles.

 

 enum ComboBoxState,values: Disabled (4),Hot (2),Normal (1),Pressed (3)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 Disabled=None
 Hot=None
 Normal=None
 Pressed=None
 value__=None


class ContentAlignment(Enum,IComparable,IFormattable,IConvertible):
 """
 Specifies how text is aligned in a window caption.

 

 enum ContentAlignment,values: Center (1),Left (0),Right (2)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 Center=None
 Left=None
 Right=None
 value__=None


class EdgeEffects(Enum,IComparable,IFormattable,IConvertible):
 """
 Specifies the visual effects that can be applied to the edges of a visual style element.

 

 enum (flags) EdgeEffects,values: FillInterior (2048),Flat (4096),Mono (32768),None (0),Soft (16384)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 FillInterior=None
 Flat=None
 Mono=None
 None=None
 Soft=None
 value__=None


class Edges(Enum,IComparable,IFormattable,IConvertible):
 """
 Specifies which edges of a visual style element to draw.

 

 enum (flags) Edges,values: Bottom (8),Diagonal (16),Left (1),Right (4),Top (2)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 Bottom=None
 Diagonal=None
 Left=None
 Right=None
 Top=None
 value__=None


class EdgeStyle(Enum,IComparable,IFormattable,IConvertible):
 """
 Specifies the styles that can be applied to the edges of a visual style element.

 

 enum EdgeStyle,values: Bump (9),Etched (6),Raised (5),Sunken (10)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 Bump=None
 Etched=None
 Raised=None
 Sunken=None
 value__=None


class EnumProperty(Enum,IComparable,IFormattable,IConvertible):
 """
 Identifies the enumerated type properties of a visual style element.

 

 enum EnumProperty,values: BackgroundType (4001),BorderType (4002),ContentAlignment (4006),FillType (4003),GlyphFontSizingType (4014),GlyphType (4012),HorizontalAlignment (4005),IconEffect (4009),ImageLayout (4011),ImageSelectType (4013),OffsetType (4008),SizingType (4004),TextShadowType (4010),TrueSizeScalingType (4015),VerticalAlignment (4007)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 BackgroundType=None
 BorderType=None
 ContentAlignment=None
 FillType=None
 GlyphFontSizingType=None
 GlyphType=None
 HorizontalAlignment=None
 IconEffect=None
 ImageLayout=None
 ImageSelectType=None
 OffsetType=None
 SizingType=None
 TextShadowType=None
 TrueSizeScalingType=None
 value__=None
 VerticalAlignment=None


class FilenameProperty(Enum,IComparable,IFormattable,IConvertible):
 """
 Identifies the names of the image files that are used to draw a visual style element.

 

 enum FilenameProperty,values: GlyphImageFile (3008),ImageFile (3001),ImageFile1 (3002),ImageFile2 (3003),ImageFile3 (3004),ImageFile4 (3005),ImageFile5 (3006),StockImageFile (3007)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 GlyphImageFile=None
 ImageFile=None
 ImageFile1=None
 ImageFile2=None
 ImageFile3=None
 ImageFile4=None
 ImageFile5=None
 StockImageFile=None
 value__=None


class FillType(Enum,IComparable,IFormattable,IConvertible):
 """
 Specifies the interior of visual style elements with a filled border background.

 

 enum FillType,values: HorizontalGradient (2),RadialGradient (3),Solid (0),TileImage (4),VerticalGradient (1)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 HorizontalGradient=None
 RadialGradient=None
 Solid=None
 TileImage=None
 value__=None
 VerticalGradient=None


class FontProperty(Enum,IComparable,IFormattable,IConvertible):
 """
 Identifies the font properties of a visual style element.

 

 enum FontProperty,values: GlyphFont (2601)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 GlyphFont=None
 value__=None


class GlyphFontSizingType(Enum,IComparable,IFormattable,IConvertible):
 """
 Specifies when the visual style selects a different glyph font size.

 

 enum GlyphFontSizingType,values: Dpi (2),None (0),Size (1)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 Dpi=None
 None=None
 Size=None
 value__=None


class GlyphType(Enum,IComparable,IFormattable,IConvertible):
 """
 Specifies the type of glyph for elements with a bitmap background.

 

 enum GlyphType,values: FontGlyph (2),ImageGlyph (1),None (0)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 FontGlyph=None
 ImageGlyph=None
 None=None
 value__=None


class GroupBoxState(Enum,IComparable,IFormattable,IConvertible):
 """
 Specifies the visual state of a group box that is drawn with visual styles.

 

 enum GroupBoxState,values: Disabled (2),Normal (1)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 Disabled=None
 Normal=None
 value__=None


class HitTestCode(Enum,IComparable,IFormattable,IConvertible):
 """
 Describes the location of a point in the background specified by a visual style.

 

 enum HitTestCode,values: Bottom (15),BottomLeft (16),BottomRight (17),Client (1),Left (10),Nowhere (0),Right (11),Top (12),TopLeft (13),TopRight (14)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 Bottom=None
 BottomLeft=None
 BottomRight=None
 Client=None
 Left=None
 Nowhere=None
 Right=None
 Top=None
 TopLeft=None
 TopRight=None
 value__=None


class HitTestOptions(Enum,IComparable,IFormattable,IConvertible):
 """
 Specifies the options that can be used when performing a hit test on the background specified by a visual style.

 

 enum (flags) HitTestOptions,values: BackgroundSegment (0),Caption (4),FixedBorder (2),ResizingBorder (240),ResizingBorderBottom (128),ResizingBorderLeft (16),ResizingBorderRight (64),ResizingBorderTop (32),SizingTemplate (256),SystemSizingMargins (512)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 BackgroundSegment=None
 Caption=None
 FixedBorder=None
 ResizingBorder=None
 ResizingBorderBottom=None
 ResizingBorderLeft=None
 ResizingBorderRight=None
 ResizingBorderTop=None
 SizingTemplate=None
 SystemSizingMargins=None
 value__=None


class HorizontalAlign(Enum,IComparable,IFormattable,IConvertible):
 """
 Specifies the horizontal alignment for visual style elements with a fixed size.

 

 enum HorizontalAlign,values: Center (1),Left (0),Right (2)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 Center=None
 Left=None
 Right=None
 value__=None


class IconEffect(Enum,IComparable,IFormattable,IConvertible):
 """
 Specifies the visual effect that the visual style will apply to an icon.

 

 enum IconEffect,values: Alpha (4),Glow (1),None (0),Pulse (3),Shadow (2)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 Alpha=None
 Glow=None
 None=None
 Pulse=None
 Shadow=None
 value__=None


class ImageOrientation(Enum,IComparable,IFormattable,IConvertible):
 """
 Specifies how multiple images are arranged in a single image file.

 

 enum ImageOrientation,values: Horizontal (1),Vertical (0)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 Horizontal=None
 value__=None
 Vertical=None


class ImageSelectType(Enum,IComparable,IFormattable,IConvertible):
 """
 Specifies when the visual style selects a different multiple-image file to draw an element.

 

 enum ImageSelectType,values: Dpi (2),None (0),Size (1)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 Dpi=None
 None=None
 Size=None
 value__=None


class IntegerProperty(Enum,IComparable,IFormattable,IConvertible):
 """
 Identifies the integer properties of a visual style element.

 

 enum IntegerProperty,values: AlphaLevel (2402),AlphaThreshold (2415),BorderSize (2403),GlyphIndex (2418),GradientRatio1 (2406),GradientRatio2 (2407),GradientRatio3 (2408),GradientRatio4 (2409),GradientRatio5 (2410),Height (2417),ImageCount (2401),MinDpi1 (2420),MinDpi2 (2421),MinDpi3 (2422),MinDpi4 (2423),MinDpi5 (2424),ProgressChunkSize (2411),ProgressSpaceSize (2412),RoundCornerHeight (2405),RoundCornerWidth (2404),Saturation (2413),TextBorderSize (2414),TrueSizeStretchMark (2419),Width (2416)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 AlphaLevel=None
 AlphaThreshold=None
 BorderSize=None
 GlyphIndex=None
 GradientRatio1=None
 GradientRatio2=None
 GradientRatio3=None
 GradientRatio4=None
 GradientRatio5=None
 Height=None
 ImageCount=None
 MinDpi1=None
 MinDpi2=None
 MinDpi3=None
 MinDpi4=None
 MinDpi5=None
 ProgressChunkSize=None
 ProgressSpaceSize=None
 RoundCornerHeight=None
 RoundCornerWidth=None
 Saturation=None
 TextBorderSize=None
 TrueSizeStretchMark=None
 value__=None
 Width=None


class MarginProperty(Enum,IComparable,IFormattable,IConvertible):
 """
 Identifies the margin properties of a visual style element.

 

 enum MarginProperty,values: CaptionMargins (3603),ContentMargins (3602),SizingMargins (3601)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 CaptionMargins=None
 ContentMargins=None
 SizingMargins=None
 value__=None


class OffsetType(Enum,IComparable,IFormattable,IConvertible):
 """
 Specifies where an offset is applied to a window element.

 

 enum OffsetType,values: AboveLastButton (12),BelowLastButton (13),BottomLeft (3),BottomMiddle (5),BottomRight (4),LeftOfCaption (8),LeftOfLastButton (10),MiddleLeft (6),MiddleRight (7),RightOfCaption (9),RightOfLastButton (11),TopLeft (0),TopMiddle (2),TopRight (1)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 AboveLastButton=None
 BelowLastButton=None
 BottomLeft=None
 BottomMiddle=None
 BottomRight=None
 LeftOfCaption=None
 LeftOfLastButton=None
 MiddleLeft=None
 MiddleRight=None
 RightOfCaption=None
 RightOfLastButton=None
 TopLeft=None
 TopMiddle=None
 TopRight=None
 value__=None


class PointProperty(Enum,IComparable,IFormattable,IConvertible):
 """
 Identifies the point properties of a visual style element.

 

 enum PointProperty,values: MinSize (3403),MinSize1 (3404),MinSize2 (3405),MinSize3 (3406),MinSize4 (3407),MinSize5 (3408),Offset (3401),TextShadowOffset (3402)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 MinSize=None
 MinSize1=None
 MinSize2=None
 MinSize3=None
 MinSize4=None
 MinSize5=None
 Offset=None
 TextShadowOffset=None
 value__=None


class PushButtonState(Enum,IComparable,IFormattable,IConvertible):
 """
 Specifies the visual state of a button that is drawn with visual styles.

 

 enum PushButtonState,values: Default (5),Disabled (4),Hot (2),Normal (1),Pressed (3)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 Default=None
 Disabled=None
 Hot=None
 Normal=None
 Pressed=None
 value__=None


class RadioButtonState(Enum,IComparable,IFormattable,IConvertible):
 """
 Specifies the visual state of an option button (also known as a radio button) that is drawn with visual styles.

 

 enum RadioButtonState,values: CheckedDisabled (8),CheckedHot (6),CheckedNormal (5),CheckedPressed (7),UncheckedDisabled (4),UncheckedHot (2),UncheckedNormal (1),UncheckedPressed (3)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 CheckedDisabled=None
 CheckedHot=None
 CheckedNormal=None
 CheckedPressed=None
 UncheckedDisabled=None
 UncheckedHot=None
 UncheckedNormal=None
 UncheckedPressed=None
 value__=None


class ScrollBarArrowButtonState(Enum,IComparable,IFormattable,IConvertible):
 """
 Specifies the visual state of a scroll arrow that is drawn with visual styles.

 

 enum ScrollBarArrowButtonState,values: DownDisabled (8),DownHot (6),DownNormal (5),DownPressed (7),LeftDisabled (12),LeftHot (10),LeftNormal (9),LeftPressed (11),RightDisabled (16),RightHot (14),RightNormal (13),RightPressed (15),UpDisabled (4),UpHot (2),UpNormal (1),UpPressed (3)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 DownDisabled=None
 DownHot=None
 DownNormal=None
 DownPressed=None
 LeftDisabled=None
 LeftHot=None
 LeftNormal=None
 LeftPressed=None
 RightDisabled=None
 RightHot=None
 RightNormal=None
 RightPressed=None
 UpDisabled=None
 UpHot=None
 UpNormal=None
 UpPressed=None
 value__=None


class ScrollBarSizeBoxState(Enum,IComparable,IFormattable,IConvertible):
 """
 Specifies the visual state of a scroll bar sizing handle that is drawn with visual styles.

 

 enum ScrollBarSizeBoxState,values: LeftAlign (2),RightAlign (1)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 LeftAlign=None
 RightAlign=None
 value__=None


class ScrollBarState(Enum,IComparable,IFormattable,IConvertible):
 """
 Specifies the visual state of a scroll bar that is drawn with visual styles.

 

 enum ScrollBarState,values: Disabled (4),Hot (2),Normal (1),Pressed (3)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 Disabled=None
 Hot=None
 Normal=None
 Pressed=None
 value__=None


class SizingType(Enum,IComparable,IFormattable,IConvertible):
 """
 Specifies how elements with a bitmap background will adjust to fill a bounds.

 

 enum SizingType,values: FixedSize (0),Stretch (1),Tile (2)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 FixedSize=None
 Stretch=None
 Tile=None
 value__=None


class StringProperty(Enum,IComparable,IFormattable,IConvertible):
 """
 Identifies the string properties of a visual style element.

 

 enum StringProperty,values: Text (3201)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 Text=None
 value__=None


class TabItemState(Enum,IComparable,IFormattable,IConvertible):
 """
 Specifies the visual state of a tab item that is drawn with visual styles.

 

 enum TabItemState,values: Disabled (4),Hot (2),Normal (1),Selected (3)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 Disabled=None
 Hot=None
 Normal=None
 Selected=None
 value__=None


class TextBoxState(Enum,IComparable,IFormattable,IConvertible):
 """
 Specifies the visual state of a text box that is drawn with visual styles.

 

 enum TextBoxState,values: Assist (7),Disabled (4),Hot (2),Normal (1),Readonly (6),Selected (3)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 Assist=None
 Disabled=None
 Hot=None
 Normal=None
 Readonly=None
 Selected=None
 value__=None


class TextMetrics(object):
 """ Provides basic information about the font specified by a visual style for a particular element. """
 Ascent=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the ascent of characters in the font.



Get: Ascent(self: TextMetrics) -> int



Set: Ascent(self: TextMetrics)=value

"""

 AverageCharWidth=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the average width of characters in the font.



Get: AverageCharWidth(self: TextMetrics) -> int



Set: AverageCharWidth(self: TextMetrics)=value

"""

 BreakChar=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the character used to define word breaks for text justification.



Get: BreakChar(self: TextMetrics) -> Char



Set: BreakChar(self: TextMetrics)=value

"""

 CharSet=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the character set of the font.



Get: CharSet(self: TextMetrics) -> TextMetricsCharacterSet



Set: CharSet(self: TextMetrics)=value

"""

 DefaultChar=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the character to be substituted for characters not in the font.



Get: DefaultChar(self: TextMetrics) -> Char



Set: DefaultChar(self: TextMetrics)=value

"""

 Descent=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the descent of characters in the font.



Get: Descent(self: TextMetrics) -> int



Set: Descent(self: TextMetrics)=value

"""

 DigitizedAspectX=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the horizontal aspect of the device for which the font was designed.



Get: DigitizedAspectX(self: TextMetrics) -> int



Set: DigitizedAspectX(self: TextMetrics)=value

"""

 DigitizedAspectY=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the vertical aspect of the device for which the font was designed.



Get: DigitizedAspectY(self: TextMetrics) -> int



Set: DigitizedAspectY(self: TextMetrics)=value

"""

 ExternalLeading=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the amount of extra leading that the application adds between rows.



Get: ExternalLeading(self: TextMetrics) -> int



Set: ExternalLeading(self: TextMetrics)=value

"""

 FirstChar=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the first character defined in the font.



Get: FirstChar(self: TextMetrics) -> Char



Set: FirstChar(self: TextMetrics)=value

"""

 Height=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the height of characters in the font.



Get: Height(self: TextMetrics) -> int



Set: Height(self: TextMetrics)=value

"""

 InternalLeading=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the amount of leading inside the bounds set by the System.Windows.Forms.VisualStyles.TextMetrics.Height property.



Get: InternalLeading(self: TextMetrics) -> int



Set: InternalLeading(self: TextMetrics)=value

"""

 Italic=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a value indicating whether the font is italic.



Get: Italic(self: TextMetrics) -> bool



Set: Italic(self: TextMetrics)=value

"""

 LastChar=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the last character defined in the font.



Get: LastChar(self: TextMetrics) -> Char



Set: LastChar(self: TextMetrics)=value

"""

 MaxCharWidth=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the width of the widest character in the font.



Get: MaxCharWidth(self: TextMetrics) -> int



Set: MaxCharWidth(self: TextMetrics)=value

"""

 Overhang=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the extra width per string that may be added to some synthesized fonts.



Get: Overhang(self: TextMetrics) -> int



Set: Overhang(self: TextMetrics)=value

"""

 PitchAndFamily=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets information about the pitch,technology,and family of a physical font.



Get: PitchAndFamily(self: TextMetrics) -> TextMetricsPitchAndFamilyValues



Set: PitchAndFamily(self: TextMetrics)=value

"""

 StruckOut=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a value indicating whether the font specifies a horizontal line through the characters.



Get: StruckOut(self: TextMetrics) -> bool



Set: StruckOut(self: TextMetrics)=value

"""

 Underlined=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a value indicating whether the font is underlined.



Get: Underlined(self: TextMetrics) -> bool



Set: Underlined(self: TextMetrics)=value

"""

 Weight=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the weight of the font.



Get: Weight(self: TextMetrics) -> int



Set: Weight(self: TextMetrics)=value

"""



class TextMetricsCharacterSet(Enum,IComparable,IFormattable,IConvertible):
 """
 Specifies the character set of the font specified by a visual style for a particular element.

 

 enum TextMetricsCharacterSet,values: Ansi (0),Arabic (178),Baltic (186),ChineseBig5 (136),Default (1),EastEurope (238),Gb2312 (134),Greek (161),Hangul (129),Hebrew (177),Johab (130),Mac (77),Oem (255),Russian (204),ShiftJis (128),Symbol (2),Thai (222),Turkish (162),Vietnamese (163)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 Ansi=None
 Arabic=None
 Baltic=None
 ChineseBig5=None
 Default=None
 EastEurope=None
 Gb2312=None
 Greek=None
 Hangul=None
 Hebrew=None
 Johab=None
 Mac=None
 Oem=None
 Russian=None
 ShiftJis=None
 Symbol=None
 Thai=None
 Turkish=None
 value__=None
 Vietnamese=None


class TextMetricsPitchAndFamilyValues(Enum,IComparable,IFormattable,IConvertible):
 """
 Specifies information about the pitch,technology,and family of the font specified by a visual style for a particular element.

 

 enum (flags) TextMetricsPitchAndFamilyValues,values: Device (8),FixedPitch (1),TrueType (4),Vector (2)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 Device=None
 FixedPitch=None
 TrueType=None
 value__=None
 Vector=None


class TextShadowType(Enum,IComparable,IFormattable,IConvertible):
 """
 Specifies the type of shadow to add to text.

 

 enum TextShadowType,values: Continuous (2),None (0),Single (1)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 Continuous=None
 None=None
 Single=None
 value__=None


class ThemeSizeType(Enum,IComparable,IFormattable,IConvertible):
 """
 Specifies the size of the visual style part to retrieve.

 

 enum ThemeSizeType,values: Draw (2),Minimum (0),True (1)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 Draw=None
 Minimum=None
 True=None
 value__=None


class ToolBarState(Enum,IComparable,IFormattable,IConvertible):
 """
 Specifies the visual state of a toolbar item that is drawn with visual styles.

 

 enum ToolBarState,values: Checked (5),Disabled (4),Hot (2),HotChecked (6),Normal (1),Pressed (3)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 Checked=None
 Disabled=None
 Hot=None
 HotChecked=None
 Normal=None
 Pressed=None
 value__=None


class TrackBarThumbState(Enum,IComparable,IFormattable,IConvertible):
 """
 Specifies the visual state of a track bar slider (also known as a thumb) that is drawn with visual styles.

 

 enum TrackBarThumbState,values: Disabled (5),Hot (2),Normal (1),Pressed (3)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 Disabled=None
 Hot=None
 Normal=None
 Pressed=None
 value__=None


class TrueSizeScalingType(Enum,IComparable,IFormattable,IConvertible):
 """
 Specifies the scaling type of a visual style element with a fixed size.

 

 enum TrueSizeScalingType,values: Dpi (2),None (0),Size (1)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 Dpi=None
 None=None
 Size=None
 value__=None


class VerticalAlignment(Enum,IComparable,IFormattable,IConvertible):
 """
 Specifies the vertical alignment for visual style elements with a fixed size.

 

 enum VerticalAlignment,values: Bottom (2),Center (1),Top (0)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 Bottom=None
 Center=None
 Top=None
 value__=None


class VisualStyleElement(object):
 """ Identifies a control or user interface (UI) element that is drawn with visual styles. """
 @staticmethod
 def CreateElement(className,part,state):
  """
  CreateElement(className: str,part: int,state: int) -> VisualStyleElement

  

   Creates a new visual style element from the specified class,part,and state values.

  

   className: A string that represents the class name of the visual style element to be created.

   part: A value that represents the part of the visual style element to be created.

   state: A value that represents the state of the visual style element to be created.

   Returns: A System.Windows.Forms.VisualStyles.VisualStyleElement with the 

    System.Windows.Forms.VisualStyles.VisualStyleElement.ClassName,

    System.Windows.Forms.VisualStyles.VisualStyleElement.Part,and 

    System.Windows.Forms.VisualStyles.VisualStyleElement.State properties initialized to the 

    className,part,and state parameters.
  """
  pass
 ClassName=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the class name of the visual style element that this System.Windows.Forms.VisualStyles.VisualStyleElement represents.



Get: ClassName(self: VisualStyleElement) -> str



"""

 Part=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value indicating the part of the visual style element that this System.Windows.Forms.VisualStyles.VisualStyleElement represents.



Get: Part(self: VisualStyleElement) -> int



"""

 State=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value indicating the state of the visual style element that this System.Windows.Forms.VisualStyles.VisualStyleElement represents.



Get: State(self: VisualStyleElement) -> int



"""


 Button=None
 ComboBox=None
 ExplorerBar=None
 Header=None
 ListView=None
 Menu=None
 MenuBand=None
 Page=None
 ProgressBar=None
 Rebar=None
 ScrollBar=None
 Spin=None
 StartPanel=None
 Status=None
 Tab=None
 TaskBand=None
 Taskbar=None
 TaskbarClock=None
 TextBox=None
 ToolBar=None
 ToolTip=None
 TrackBar=None
 TrayNotify=None
 TreeView=None
 Window=None


class VisualStyleInformation(object):
 """ Provides information about the current visual style of the operating system. """
 Author='MSX'
 ColorScheme='NormalColor'
 Company=''
 ControlHighlightHot=None
 Copyright=''
 Description=''
 DisplayName='Aero style'
 IsEnabledByUser=True
 IsSupportedByOS=True
 MinimumColorDepth=0
 Size='NormalSize'
 SupportsFlatMenus=False
 TextControlBorder=None
 Url=''
 Version=''
 __all__=[]


class VisualStyleRenderer(object):
 """
 Provides methods for drawing and getting information about a System.Windows.Forms.VisualStyles.VisualStyleElement. This class cannot be inherited.

 

 VisualStyleRenderer(element: VisualStyleElement)

 VisualStyleRenderer(className: str,part: int,state: int)
 """
 def DrawBackground(self,dc,bounds,clipRectangle=None):
  """
  DrawBackground(self: VisualStyleRenderer,dc: IDeviceContext,bounds: Rectangle,clipRectangle: Rectangle)

   Draws the background image of the current visual style element within the specified bounding 

    rectangle and clipped to the specified clipping rectangle.

  

  

   dc: The System.Drawing.IDeviceContext used to draw the background image.

   bounds: A System.Drawing.Rectangle in which the background image is drawn.

   clipRectangle: A System.Drawing.Rectangle that defines a clipping rectangle for the drawing operation.

  DrawBackground(self: VisualStyleRenderer,dc: IDeviceContext,bounds: Rectangle)

   Draws the background image of the current visual style element within the specified bounding 

    rectangle.

  

  

   dc: The System.Drawing.IDeviceContext used to draw the background image.

   bounds: A System.Drawing.Rectangle in which the background image is drawn.
  """
  pass
 def DrawEdge(self,dc,bounds,edges,style,effects):
  """
  DrawEdge(self: VisualStyleRenderer,dc: IDeviceContext,bounds: Rectangle,edges: Edges,style: EdgeStyle,effects: EdgeEffects) -> Rectangle

  

   Draws one or more edges of the specified bounding rectangle.

  

   dc: The System.Drawing.IDeviceContext used to draw the edges.

   bounds: The System.Drawing.Rectangle whose bounds define the edges to draw.

   edges: A bitwise combination of the System.Windows.Forms.VisualStyles.Edges values.

   style: A bitwise combination of the System.Windows.Forms.VisualStyles.EdgeStyle values.

   effects: A bitwise combination of the System.Windows.Forms.VisualStyles.EdgeEffects values.

   Returns: A System.Drawing.Rectangle that represents the interior of the bounds parameter,minus the edges 

    that were drawn.
  """
  pass
 def DrawImage(self,g,bounds,*__args):
  """
  DrawImage(self: VisualStyleRenderer,g: Graphics,bounds: Rectangle,imageList: ImageList,imageIndex: int)

   Draws the image from the specified System.Windows.Forms.ImageList within the specified bounds.

  

   g: The System.Drawing.Graphics used to draw the image.

   bounds: A System.Drawing.Rectangle in which the image is drawn.

   imageList: An System.Windows.Forms.ImageList that contains the System.Drawing.Image to draw.

   imageIndex: The index of the System.Drawing.Image within imageList to draw.

  DrawImage(self: VisualStyleRenderer,g: Graphics,bounds: Rectangle,image: Image)

   Draws the specified image within the specified bounds.

  

   g: The System.Drawing.Graphics used to draw the image.

   bounds: A System.Drawing.Rectangle in which the image is drawn.

   image: The System.Drawing.Image to draw.
  """
  pass
 def DrawParentBackground(self,dc,bounds,childControl):
  """
  DrawParentBackground(self: VisualStyleRenderer,dc: IDeviceContext,bounds: Rectangle,childControl: Control)

   Draws the background of a control's parent in the specified area.

  

   dc: The System.Drawing.IDeviceContext used to draw the background of the parent of childControl. 

    This object typically belongs to the child control.

  

   bounds: A System.Drawing.Rectangle in which to draw the parent control's background. This rectangle 

    

   childControl: The control whose parent's background will be drawn.
  """
  pass
 def DrawText(self,dc,bounds,textToDraw,drawDisabled=None,flags=None):
  """
  DrawText(self: VisualStyleRenderer,dc: IDeviceContext,bounds: Rectangle,textToDraw: str,drawDisabled: bool,flags: TextFormatFlags)

   Draws text in the specified bounding rectangle with the option of displaying disabled text and 

    applying other text formatting.

  

  

   dc: The System.Drawing.IDeviceContext used to draw the text.

   bounds: A System.Drawing.Rectangle in which to draw the text.

   textToDraw: The text to draw.

   drawDisabled: true to draw grayed-out text; otherwise,false.

   flags: A bitwise combination of the System.Windows.Forms.TextFormatFlags values.

  DrawText(self: VisualStyleRenderer,dc: IDeviceContext,bounds: Rectangle,textToDraw: str,drawDisabled: bool)

   Draws text in the specified bounds with the option of displaying disabled text.

  

   dc: The System.Drawing.IDeviceContext used to draw the text.

   bounds: A System.Drawing.Rectangle in which to draw the text.

   textToDraw: The text to draw.

   drawDisabled: true to draw grayed-out text; otherwise,false.

  DrawText(self: VisualStyleRenderer,dc: IDeviceContext,bounds: Rectangle,textToDraw: str)

   Draws text in the specified bounds using default formatting.

  

   dc: The System.Drawing.IDeviceContext used to draw the text.

   bounds: A System.Drawing.Rectangle in which to draw the text.

   textToDraw: The text to draw.
  """
  pass
 def GetBackgroundContentRectangle(self,dc,bounds):
  """
  GetBackgroundContentRectangle(self: VisualStyleRenderer,dc: IDeviceContext,bounds: Rectangle) -> Rectangle

  

   Returns the content area for the background of the current visual style element.

  

   dc: The System.Drawing.IDeviceContext this operation will use.

   bounds: A System.Drawing.Rectangle that contains the entire background area of the current visual style 

    element.

  

   Returns: A System.Drawing.Rectangle that contains the content area for the background of the current 

    visual style element.
  """
  pass
 def GetBackgroundExtent(self,dc,contentBounds):
  """
  GetBackgroundExtent(self: VisualStyleRenderer,dc: IDeviceContext,contentBounds: Rectangle) -> Rectangle

  

   Returns the entire background area for the current visual style element.

  

   dc: The System.Drawing.IDeviceContext this operation will use.

   contentBounds: A System.Drawing.Rectangle that contains the content area of the current visual style element.

   Returns: A System.Drawing.Rectangle that contains the entire background area of the current visual style 

    element.
  """
  pass
 def GetBackgroundRegion(self,dc,bounds):
  """
  GetBackgroundRegion(self: VisualStyleRenderer,dc: IDeviceContext,bounds: Rectangle) -> Region

  

   Returns the region for the background of the current visual style element.

  

   dc: The System.Drawing.IDeviceContext this operation will use.

   bounds: A System.Drawing.Rectangle that contains the entire background area of the current visual style 

    element.

  

   Returns: The System.Drawing.Region that contains the background of the current visual style element.
  """
  pass
 def GetBoolean(self,prop):
  """
  GetBoolean(self: VisualStyleRenderer,prop: BooleanProperty) -> bool

  

   Returns the value of the specified Boolean property for the current visual style element.

  

   prop: One of the System.Windows.Forms.VisualStyles.BooleanProperty values that specifies which 

    property value to retrieve for the current visual style element.

  

   Returns: true if the property specified by the prop parameter is true for the current visual style 

    element; otherwise,false.
  """
  pass
 def GetColor(self,prop):
  """
  GetColor(self: VisualStyleRenderer,prop: ColorProperty) -> Color

  

   Returns the value of the specified color property for the current visual style element.

  

   prop: One of the System.Windows.Forms.VisualStyles.ColorProperty values that specifies which property 

    value to retrieve for the current visual style element.

  

   Returns: A System.Drawing.Color that contains the value of the property specified by the prop parameter 

    for the current visual style element.
  """
  pass
 def GetEnumValue(self,prop):
  """
  GetEnumValue(self: VisualStyleRenderer,prop: EnumProperty) -> int

  

   Returns the value of the specified enumerated type property for the current visual style element.

  

   prop: One of the System.Windows.Forms.VisualStyles.EnumProperty values that specifies which property 

    value to retrieve for the current visual style element.

  

   Returns: The integer value of the property specified by the prop parameter for the current visual style 

    element.
  """
  pass
 def GetFilename(self,prop):
  """
  GetFilename(self: VisualStyleRenderer,prop: FilenameProperty) -> str

  

   Returns the value of the specified file name property for the current visual style element.

  

   prop: One of the System.Windows.Forms.VisualStyles.FilenameProperty values that specifies which 

    property value to retrieve for the current visual style element.

  

   Returns: A System.String that contains the value of the property specified by the prop parameter for the 

    current visual style element.
  """
  pass
 def GetFont(self,dc,prop):
  """
  GetFont(self: VisualStyleRenderer,dc: IDeviceContext,prop: FontProperty) -> Font

  

   Returns the value of the specified font property for the current visual style element.

  

   dc: The System.Drawing.IDeviceContext this operation will use.

   prop: One of the System.Windows.Forms.VisualStyles.FontProperty values that specifies which property 

    value to retrieve for the current visual style element.

  

   Returns: A System.Drawing.Font that contains the value of the property specified by the prop parameter 

    for the current visual style element.
  """
  pass
 def GetInteger(self,prop):
  """
  GetInteger(self: VisualStyleRenderer,prop: IntegerProperty) -> int

  

   Returns the value of the specified integer property for the current visual style element.

  

   prop: One of the System.Windows.Forms.VisualStyles.IntegerProperty values that specifies which 

    property value to retrieve for the current visual style element.

  

   Returns: The integer value of the property specified by the prop parameter for the current visual style 

    element.
  """
  pass
 def GetMargins(self,dc,prop):
  """
  GetMargins(self: VisualStyleRenderer,dc: IDeviceContext,prop: MarginProperty) -> Padding

  

   Returns the value of the specified margins property for the current visual style element.

  

   dc: The System.Drawing.IDeviceContext this operation will use.

   prop: One of the System.Windows.Forms.VisualStyles.MarginProperty values that specifies which property 

    value to retrieve for the current visual style element.

  

   Returns: A System.Windows.Forms.Padding that contains the value of the property specified by the prop 

    parameter for the current visual style element.
  """
  pass
 def GetPartSize(self,dc,*__args):
  """
  GetPartSize(self: VisualStyleRenderer,dc: IDeviceContext,bounds: Rectangle,type: ThemeSizeType) -> Size

  

   Returns the value of the specified size property of the current visual style part using the 

    specified drawing bounds.

  

  

   dc: The System.Drawing.IDeviceContext this operation will use.

   bounds: A System.Drawing.Rectangle that contains the area in which the part will be drawn.

   type: One of the System.Windows.Forms.VisualStyles.ThemeSizeType values that specifies which size 

    value to retrieve for the part.

  

   Returns: A System.Drawing.Size that contains the size specified by the type parameter for the current 

    visual style part.

  

  GetPartSize(self: VisualStyleRenderer,dc: IDeviceContext,type: ThemeSizeType) -> Size

  

   Returns the value of the specified size property of the current visual style part.

  

   dc: The System.Drawing.IDeviceContext this operation will use.

   type: One of the System.Windows.Forms.VisualStyles.ThemeSizeType values that specifies which size 

    value to retrieve for the part.

  

   Returns: A System.Drawing.Size that contains the size specified by the type parameter for the current 

    visual style part.
  """
  pass
 def GetPoint(self,prop):
  """
  GetPoint(self: VisualStyleRenderer,prop: PointProperty) -> Point

  

   Returns the value of the specified point property for the current visual style element.

  

   prop: One of the System.Windows.Forms.VisualStyles.PointProperty values that specifies which property 

    value to retrieve for the current visual style element.

  

   Returns: A System.Drawing.Point that contains the value of the property specified by the prop parameter 

    for the current visual style element.
  """
  pass
 def GetString(self,prop):
  """
  GetString(self: VisualStyleRenderer,prop: StringProperty) -> str

  

   Returns the value of the specified string property for the current visual style element.

  

   prop: One of the System.Windows.Forms.VisualStyles.StringProperty values that specifies which property 

    value to retrieve for the current visual style element.

  

   Returns: A System.String that contains the value of the property specified by the prop parameter for the 

    current visual style element.
  """
  pass
 def GetTextExtent(self,dc,*__args):
  """
  GetTextExtent(self: VisualStyleRenderer,dc: IDeviceContext,bounds: Rectangle,textToDraw: str,flags: TextFormatFlags) -> Rectangle

  

   Returns the size and location of the specified string when drawn with the font of the current 

    visual style element within the specified initial bounding rectangle.

  

  

   dc: The System.Drawing.IDeviceContext this operation will use.

   bounds: A System.Drawing.Rectangle used to control the flow and wrapping of the text.

   textToDraw: The string to measure.

   flags: A bitwise combination of the System.Windows.Forms.TextFormatFlags values.

   Returns: A System.Drawing.Rectangle that contains the area required to fit the rendered text.

  GetTextExtent(self: VisualStyleRenderer,dc: IDeviceContext,textToDraw: str,flags: TextFormatFlags) -> Rectangle

  

   Returns the size and location of the specified string when drawn with the font of the current 

    visual style element.

  

  

   dc: The System.Drawing.IDeviceContext this operation will use.

   textToDraw: The string to measure.

   flags: A bitwise combination of the System.Windows.Forms.TextFormatFlags values.

   Returns: A System.Drawing.Rectangle that contains the area required to fit the rendered text.
  """
  pass
 def GetTextMetrics(self,dc):
  """
  GetTextMetrics(self: VisualStyleRenderer,dc: IDeviceContext) -> TextMetrics

  

   Retrieves information about the font specified by the current visual style element.

  

   dc: The System.Drawing.IDeviceContext this operation will use.

   Returns: A System.Windows.Forms.VisualStyles.TextMetrics that provides information about the font 

    specified by the current visual style element.
  """
  pass
 def HitTestBackground(self,*__args):
  """
  HitTestBackground(self: VisualStyleRenderer,dc: IDeviceContext,backgroundRectangle: Rectangle,hRgn: IntPtr,pt: Point,options: HitTestOptions) -> HitTestCode

  

   Returns a hit test code indicating whether the point is contained in the background of the 

    current visual style element and within the specified region.

  

  

   dc: The System.Drawing.IDeviceContext this operation will use.

   backgroundRectangle: A System.Drawing.Rectangle that contains the background of the current visual style element.

   hRgn: A Windows handle to a System.Drawing.Region that specifies the bounds of the hit test area 

    within the background.

  

   pt: The System.Drawing.Point to test.

   options: A bitwise combination of the System.Windows.Forms.VisualStyles.HitTestOptions values.

   Returns: A System.Windows.Forms.VisualStyles.HitTestCode that describes where pt is located in the 

    background of the current visual style element.

  

  HitTestBackground(self: VisualStyleRenderer,g: Graphics,backgroundRectangle: Rectangle,region: Region,pt: Point,options: HitTestOptions) -> HitTestCode

  

   Returns a hit test code indicating whether the point is contained in the background of the 

    current visual style element and within the specified bounds.

  

  

   g: The System.Drawing.Graphics this operation will use.

   backgroundRectangle: A System.Drawing.Rectangle that contains the background of the current visual style element.

   region: A System.Drawing.Region that specifies the bounds of the hit test area within the background.

   pt: The System.Drawing.Point to test.

   options: A bitwise combination of the System.Windows.Forms.VisualStyles.HitTestOptions values.

   Returns: A System.Windows.Forms.VisualStyles.HitTestCode that describes where pt is located in the 

    background of the current visual style element,if at all.

  

  HitTestBackground(self: VisualStyleRenderer,dc: IDeviceContext,backgroundRectangle: Rectangle,pt: Point,options: HitTestOptions) -> HitTestCode

  

   Returns a hit test code indicating whether a point is contained in the background of the current 

    visual style element.

  

  

   dc: The System.Drawing.IDeviceContext this operation will use.

   backgroundRectangle: A System.Drawing.Rectangle that contains the background of the current visual style element.

   pt: The System.Drawing.Point to test.

   options: A bitwise combination of the System.Windows.Forms.VisualStyles.HitTestOptions values.

   Returns: A System.Windows.Forms.VisualStyles.HitTestCode that describes where pt is located in the 

    background of the current visual style element.
  """
  pass
 def IsBackgroundPartiallyTransparent(self):
  """
  IsBackgroundPartiallyTransparent(self: VisualStyleRenderer) -> bool

  

   Indicates whether the background of the current visual style element has any semitransparent or 

    alpha-blended pieces.

  

   Returns: true if the background of the current visual style element has any semitransparent or 

    alpha-blended pieces; otherwise,false.
  """
  pass
 @staticmethod
 def IsElementDefined(element):
  """
  IsElementDefined(element: VisualStyleElement) -> bool

  

   Determines whether the specified visual style element is defined by the current visual style.

  

   element: A System.Windows.Forms.VisualStyles.VisualStyleElement whose class and part combination will be 

    verified.

  

   Returns: true if the combination of the System.Windows.Forms.VisualStyles.VisualStyleElement.ClassName 

    and System.Windows.Forms.VisualStyles.VisualStyleElement.Part properties of element are defined; 

    otherwise,false.
  """
  pass
 def SetParameters(self,*__args):
  """
  SetParameters(self: VisualStyleRenderer,className: str,part: int,state: int)

   Sets this System.Windows.Forms.VisualStyles.VisualStyleRenderer to the visual style element 

    represented by the specified class,part,and state values.

  

  

   className: The new value of the System.Windows.Forms.VisualStyles.VisualStyleRenderer.Class property.

   part: The new value of the System.Windows.Forms.VisualStyles.VisualStyleRenderer.Part property.

   state: The new value of the System.Windows.Forms.VisualStyles.VisualStyleRenderer.State property.

  SetParameters(self: VisualStyleRenderer,element: VisualStyleElement)

   Sets this System.Windows.Forms.VisualStyles.VisualStyleRenderer to the visual style element 

    represented by the specified System.Windows.Forms.VisualStyles.VisualStyleElement.

  

  

   element: A System.Windows.Forms.VisualStyles.VisualStyleElement that specifies the new values of the 

    System.Windows.Forms.VisualStyles.VisualStyleRenderer.Class,

    System.Windows.Forms.VisualStyles.VisualStyleRenderer.Part,and 

    System.Windows.Forms.VisualStyles.VisualStyleRenderer.State properties.
  """
  pass
 @staticmethod
 def __new__(self,*__args):
  """
  __new__(cls: type,element: VisualStyleElement)

  __new__(cls: type,className: str,part: int,state: int)
  """
  pass
 Class=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the class name of the current visual style element.



Get: Class(self: VisualStyleRenderer) -> str



"""

 Handle=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a unique identifier for the current class of visual style elements.



Get: Handle(self: VisualStyleRenderer) -> IntPtr



"""

 LastHResult=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the last error code returned by the native visual styles (UxTheme) API methods encapsulated by the System.Windows.Forms.VisualStyles.VisualStyleRenderer class.



Get: LastHResult(self: VisualStyleRenderer) -> int



"""

 Part=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the part of the current visual style element.



Get: Part(self: VisualStyleRenderer) -> int



"""

 State=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the state of the current visual style element.



Get: State(self: VisualStyleRenderer) -> int



"""


 IsSupported=True


class VisualStyleState(Enum,IComparable,IFormattable,IConvertible):
 """
 Specifies how visual styles are applied to the current application.

 

 enum VisualStyleState,values: ClientAndNonClientAreasEnabled (3),ClientAreaEnabled (2),NonClientAreaEnabled (1),NoneEnabled (0)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 ClientAndNonClientAreasEnabled=None
 ClientAreaEnabled=None
 NonClientAreaEnabled=None
 NoneEnabled=None
 value__=None


