class ControlStyles(Enum,IComparable,IFormattable,IConvertible):
 """
 Specifies the style and behavior of a control.

 

 enum (flags) ControlStyles,values: AllPaintingInWmPaint (8192),CacheText (16384),ContainerControl (1),DoubleBuffer (65536),EnableNotifyMessage (32768),FixedHeight (64),FixedWidth (32),Opaque (4),OptimizedDoubleBuffer (131072),ResizeRedraw (16),Selectable (512),StandardClick (256),StandardDoubleClick (4096),SupportsTransparentBackColor (2048),UserMouse (1024),UserPaint (2),UseTextForAccessibility (262144)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 AllPaintingInWmPaint=None
 CacheText=None
 ContainerControl=None
 DoubleBuffer=None
 EnableNotifyMessage=None
 FixedHeight=None
 FixedWidth=None
 Opaque=None
 OptimizedDoubleBuffer=None
 ResizeRedraw=None
 Selectable=None
 StandardClick=None
 StandardDoubleClick=None
 SupportsTransparentBackColor=None
 UserMouse=None
 UserPaint=None
 UseTextForAccessibility=None
 value__=None

