class ToolTipService(object):
 """ Represents a service that provides properties and events to control the display and behavior of tooltips. """
 @staticmethod
 def AddToolTipClosingHandler(element,handler):
  """ AddToolTipClosingHandler(element: DependencyObject,handler: ToolTipEventHandler) """
  pass
 @staticmethod
 def AddToolTipOpeningHandler(element,handler):
  """ AddToolTipOpeningHandler(element: DependencyObject,handler: ToolTipEventHandler) """
  pass
 @staticmethod
 def GetBetweenShowDelay(element):
  """
  GetBetweenShowDelay(element: DependencyObject) -> int

  

   Gets the value of the System.Windows.Controls.ToolTipService.BetweenShowDelay�attached property 

    for an object.

  

  

   element: The object from which the property value is read.

   Returns: The object's System.Windows.Controls.ToolTipService.BetweenShowDelay property value.
  """
  pass
 @staticmethod
 def GetHasDropShadow(element):
  """
  GetHasDropShadow(element: DependencyObject) -> bool

  

   Gets the value of the System.Windows.Controls.ToolTipService.HasDropShadow�attached property for 

    an object.

  

  

   element: The object from which the property value is read.

   Returns: The object's System.Windows.Controls.ToolTipService.HasDropShadow property value.
  """
  pass
 @staticmethod
 def GetHorizontalOffset(element):
  """
  GetHorizontalOffset(element: DependencyObject) -> float

  

   Gets the value of the System.Windows.Controls.ToolTipService.HorizontalOffset�attached property 

    for an object.

  

  

   element: The object from which the property value is read.

   Returns: The object's System.Windows.Controls.ToolTipService.HorizontalOffset property value.
  """
  pass
 @staticmethod
 def GetInitialShowDelay(element):
  """
  GetInitialShowDelay(element: DependencyObject) -> int

  

   Gets the value of the System.Windows.Controls.ToolTipService.InitialShowDelay�attached property 

    for an object.

  

  

   element: The object from which the property value is read.

   Returns: The object's System.Windows.Controls.ToolTipService.InitialShowDelay property value.
  """
  pass
 @staticmethod
 def GetIsEnabled(element):
  """
  GetIsEnabled(element: DependencyObject) -> bool

  

   Gets the value of the System.Windows.Controls.ToolTipService.IsEnabled�attached property for an 

    object.

  

  

   element: The object from which the property value is read.

   Returns: The object's System.Windows.Controls.ToolTipService.IsEnabled property value.
  """
  pass
 @staticmethod
 def GetIsOpen(element):
  """
  GetIsOpen(element: DependencyObject) -> bool

  

   Gets the value of the System.Windows.Controls.ToolTipService.IsOpen�attached property for an 

    object.

  

  

   element: The object from which the property value is read.

   Returns: The object's System.Windows.Controls.ToolTipService.IsOpen property value.
  """
  pass
 @staticmethod
 def GetPlacement(element):
  """
  GetPlacement(element: DependencyObject) -> PlacementMode

  

   Gets the value of the System.Windows.Controls.ToolTipService.Placement�attached property for an 

    object.

  

  

   element: The object from which the property value is read.

   Returns: The object's System.Windows.Controls.ToolTipService.Placement property value.
  """
  pass
 @staticmethod
 def GetPlacementRectangle(element):
  """
  GetPlacementRectangle(element: DependencyObject) -> Rect

  

   Gets the value of the System.Windows.Controls.ToolTipService.PlacementRectangle�attached 

    property for an object.

  

  

   element: The object from which the property value is read.

   Returns: The object's System.Windows.Controls.ToolTipService.PlacementRectangle property value.
  """
  pass
 @staticmethod
 def GetPlacementTarget(element):
  """
  GetPlacementTarget(element: DependencyObject) -> UIElement

  

   Gets the value of the System.Windows.Controls.ToolTipService.PlacementTarget�attached property 

    for an object.

  

  

   element: The object from which the property value is read.

   Returns: The object's System.Windows.Controls.ToolTipService.PlacementTarget property value.
  """
  pass
 @staticmethod
 def GetShowDuration(element):
  """
  GetShowDuration(element: DependencyObject) -> int

  

   Gets the value of the System.Windows.Controls.ToolTipService.ShowDuration�attached property for 

    an object.

  

  

   element: The object from which the property value is read.

   Returns: The object's System.Windows.Controls.ToolTipService.ShowDuration property value.
  """
  pass
 @staticmethod
 def GetShowOnDisabled(element):
  """
  GetShowOnDisabled(element: DependencyObject) -> bool

  

   Gets the value of the System.Windows.Controls.ToolTipService.ShowOnDisabled�attached property 

    for an object.

  

  

   element: The object from which the property value is read.

   Returns: The object's System.Windows.Controls.ToolTipService.ShowOnDisabled property value.
  """
  pass
 @staticmethod
 def GetToolTip(element):
  """
  GetToolTip(element: DependencyObject) -> object

  

   Gets the value of the System.Windows.Controls.ToolTipService.ToolTip�attached property for an 

    object.

  

  

   element: The object from which the property value is read.

   Returns: The object's System.Windows.Controls.ToolTipService.ToolTip property value.
  """
  pass
 @staticmethod
 def GetVerticalOffset(element):
  """
  GetVerticalOffset(element: DependencyObject) -> float

  

   Gets the value of the System.Windows.Controls.ToolTipService.VerticalOffset�attached property 

    for an object.

  

  

   element: The object from which the property value is read.

   Returns: The object's System.Windows.Controls.ToolTipService.VerticalOffset property value.
  """
  pass
 @staticmethod
 def RemoveToolTipClosingHandler(element,handler):
  """ RemoveToolTipClosingHandler(element: DependencyObject,handler: ToolTipEventHandler) """
  pass
 @staticmethod
 def RemoveToolTipOpeningHandler(element,handler):
  """ RemoveToolTipOpeningHandler(element: DependencyObject,handler: ToolTipEventHandler) """
  pass
 @staticmethod
 def SetBetweenShowDelay(element,value):
  """
  SetBetweenShowDelay(element: DependencyObject,value: int)

   Sets the value of the System.Windows.Controls.ToolTipService.BetweenShowDelay�attached property 

    for an object.

  

  

   element: The object to which the attached property is written.

   value: The value to set.
  """
  pass
 @staticmethod
 def SetHasDropShadow(element,value):
  """
  SetHasDropShadow(element: DependencyObject,value: bool)

   Sets the value of the System.Windows.Controls.ToolTipService.HasDropShadow�attached property for 

    an object.

  

  

   element: The object to which the attached property is written.

   value: The value to set.
  """
  pass
 @staticmethod
 def SetHorizontalOffset(element,value):
  """
  SetHorizontalOffset(element: DependencyObject,value: float)

   Sets the value of the System.Windows.Controls.ToolTipService.HorizontalOffset�attached property 

    for an object.

  

  

   element: The object to which the attached property is written.

   value: The value to set.
  """
  pass
 @staticmethod
 def SetInitialShowDelay(element,value):
  """
  SetInitialShowDelay(element: DependencyObject,value: int)

   Sets the value of the System.Windows.Controls.ToolTipService.InitialShowDelay�attached property 

    for an object.

  

  

   element: The object to which the attached property is written.

   value: The value to set.
  """
  pass
 @staticmethod
 def SetIsEnabled(element,value):
  """
  SetIsEnabled(element: DependencyObject,value: bool)

   Sets the value of the System.Windows.Controls.ToolTipService.IsEnabled�attached property for an 

    object.

  

  

   element: The object to which the attached property is written.

   value: The value to set.
  """
  pass
 @staticmethod
 def SetPlacement(element,value):
  """
  SetPlacement(element: DependencyObject,value: PlacementMode)

   Sets the value of the System.Windows.Controls.ToolTipService.Placement�attached property for an 

    object.

  

  

   element: The object to which the attached property is written.

   value: The value to set.
  """
  pass
 @staticmethod
 def SetPlacementRectangle(element,value):
  """
  SetPlacementRectangle(element: DependencyObject,value: Rect)

   Sets the value of the System.Windows.Controls.ToolTipService.PlacementRectangle�attached 

    property for an object.

  

  

   element: The object to which the attached property is written.

   value: The value to set.
  """
  pass
 @staticmethod
 def SetPlacementTarget(element,value):
  """
  SetPlacementTarget(element: DependencyObject,value: UIElement)

   Sets the value of the System.Windows.Controls.ToolTipService.PlacementTarget�attached property 

    for an object.

  

  

   element: The object to which the attached property is written.

   value: The value to set.
  """
  pass
 @staticmethod
 def SetShowDuration(element,value):
  """
  SetShowDuration(element: DependencyObject,value: int)

   Sets the value of the System.Windows.Controls.ToolTipService.ShowDuration�attached property for 

    an object.

  

  

   element: The object to which the attached property is written.

   value: The value to set.
  """
  pass
 @staticmethod
 def SetShowOnDisabled(element,value):
  """
  SetShowOnDisabled(element: DependencyObject,value: bool)

   Sets the value of the System.Windows.Controls.ToolTipService.ShowOnDisabled�attached property 

    for an object.

  

  

   element: The object to which the attached property is written.

   value: The value to set.
  """
  pass
 @staticmethod
 def SetToolTip(element,value):
  """
  SetToolTip(element: DependencyObject,value: object)

   Sets the value of the System.Windows.Controls.ToolTipService.ToolTip�attached�property for an 

    object.

  

  

   element: The object to which the attached property is written.

   value: The value to set.
  """
  pass
 @staticmethod
 def SetVerticalOffset(element,value):
  """
  SetVerticalOffset(element: DependencyObject,value: float)

   Sets the value of the System.Windows.Controls.ToolTipService.VerticalOffset�attached property 

    for an object.

  

  

   element: The object to which the attached property is written.

   value: The desired value.
  """
  pass
 BetweenShowDelayProperty=None
 HasDropShadowProperty=None
 HorizontalOffsetProperty=None
 InitialShowDelayProperty=None
 IsEnabledProperty=None
 IsOpenProperty=None
 PlacementProperty=None
 PlacementRectangleProperty=None
 PlacementTargetProperty=None
 ShowDurationProperty=None
 ShowOnDisabledProperty=None
 ToolTipClosingEvent=None
 ToolTipOpeningEvent=None
 ToolTipProperty=None
 VerticalOffsetProperty=None
 __all__=[
  'AddToolTipClosingHandler',
  'AddToolTipOpeningHandler',
  'BetweenShowDelayProperty',
  'GetBetweenShowDelay',
  'GetHasDropShadow',
  'GetHorizontalOffset',
  'GetInitialShowDelay',
  'GetIsEnabled',
  'GetIsOpen',
  'GetPlacement',
  'GetPlacementRectangle',
  'GetPlacementTarget',
  'GetShowDuration',
  'GetShowOnDisabled',
  'GetToolTip',
  'GetVerticalOffset',
  'HasDropShadowProperty',
  'HorizontalOffsetProperty',
  'InitialShowDelayProperty',
  'IsEnabledProperty',
  'IsOpenProperty',
  'PlacementProperty',
  'PlacementRectangleProperty',
  'PlacementTargetProperty',
  'RemoveToolTipClosingHandler',
  'RemoveToolTipOpeningHandler',
  'SetBetweenShowDelay',
  'SetHasDropShadow',
  'SetHorizontalOffset',
  'SetInitialShowDelay',
  'SetIsEnabled',
  'SetPlacement',
  'SetPlacementRectangle',
  'SetPlacementTarget',
  'SetShowDuration',
  'SetShowOnDisabled',
  'SetToolTip',
  'SetVerticalOffset',
  'ShowDurationProperty',
  'ShowOnDisabledProperty',
  'ToolTipClosingEvent',
  'ToolTipOpeningEvent',
  'ToolTipProperty',
  'VerticalOffsetProperty',
 ]

