class ICommandExecutor:
 """ Defines a method that executes a certain action on the type that implements this interface. """
 def Execute(self):
  """
  Execute(self: ICommandExecutor)

   Performs a task that is determined by the type that implements this method.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
