# encoding: utf-8
# module System.Drawing.Configuration calls itself Configuration
# from System.Drawing,Version=4.0.0.0,Culture=neutral,PublicKeyToken=b03f5f7f11d50a3a
# by generator 1.145
""" NamespaceTracker represent a CLS namespace. """
# no imports

# no functions
# classes

class SystemDrawingSection(ConfigurationSection):
 """ SystemDrawingSection() """
 BitmapSuffix=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: BitmapSuffix(self: SystemDrawingSection) -> str



Set: BitmapSuffix(self: SystemDrawingSection)=value

"""

 ElementProperty=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the System.Configuration.ConfigurationElementProperty object that represents the System.Configuration.ConfigurationElement object itself.



"""

 EvaluationContext=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the System.Configuration.ContextInformation object for the System.Configuration.ConfigurationElement object.



"""

 HasContext=property(lambda self: object(),lambda self,v: None,lambda self: None)

 Properties=property(lambda self: object(),lambda self,v: None,lambda self: None)



