# encoding: utf-8
# module System.Windows.Converters calls itself Converters
# from WindowsBase,Version=4.0.0.0,Culture=neutral,PublicKeyToken=31bf3856ad364e35
# by generator 1.145
""" NamespaceTracker represent a CLS namespace. """
# no imports

# no functions
# classes

class Int32RectValueSerializer(ValueSerializer):
 """
 Converts instances of System.String to and from instances of System.Windows.Int32Rect.

 

 Int32RectValueSerializer()
 """
 def CanConvertFromString(self,value,context):
  """
  CanConvertFromString(self: Int32RectValueSerializer,value: str,context: IValueSerializerContext) -> bool

  

   Determines whether the specified System.String can be converted to an instance of 

    System.Windows.Int32Rect.

  

  

   value: String to evaluate for conversion.

   context: Context information that is used for conversion.

   Returns: Always returns true.
  """
  pass
 def CanConvertToString(self,value,context):
  """
  CanConvertToString(self: Int32RectValueSerializer,value: object,context: IValueSerializerContext) -> bool

  

   Determines whether the specified System.Windows.Int32Rect can be converted to a System.String.

  

   value: The object to evaluate for conversion.

   context: Context information that is used for conversion.

   Returns: true if value can be converted into a System.String; otherwise,false.
  """
  pass
 def ConvertFromString(self,value,context):
  """
  ConvertFromString(self: Int32RectValueSerializer,value: str,context: IValueSerializerContext) -> object

  

   Converts a System.String into a System.Windows.Int32Rect.

  

   value: The string to convert.

   context: Context information that is used for conversion.

   Returns: A new instance of System.Windows.Int32Rect based on the supplied value.
  """
  pass
 def ConvertToString(self,value,context):
  """
  ConvertToString(self: Int32RectValueSerializer,value: object,context: IValueSerializerContext) -> str

  

   Converts an instance of System.Windows.Int32Rect to a System.String.

  

   value: The object to convert into a string.

   context: Context information that is used for conversion.

   Returns: A string representation of the specified System.Windows.Int32Rect.
  """
  pass

class PointValueSerializer(ValueSerializer):
 """
 Converts instances of System.String to and from instances of System.Windows.Point.

 

 PointValueSerializer()
 """
 def CanConvertFromString(self,value,context):
  """
  CanConvertFromString(self: PointValueSerializer,value: str,context: IValueSerializerContext) -> bool

  

   Determines whether the specified System.String can be converted to an instance of 

    System.Windows.Point.

  

  

   value: String to evaluate for conversion.

   context: Context information that is used for conversion.

   Returns: Always returns true.
  """
  pass
 def CanConvertToString(self,value,context):
  """
  CanConvertToString(self: PointValueSerializer,value: object,context: IValueSerializerContext) -> bool

  

   Determines whether the specified System.Windows.Point can be converted to a System.String.

  

   value: The object to evaluate for conversion.

   context: Context information that is used for conversion.

   Returns: true if value can be converted into a System.String; otherwise,false.
  """
  pass
 def ConvertFromString(self,value,context):
  """
  ConvertFromString(self: PointValueSerializer,value: str,context: IValueSerializerContext) -> object

  

   Converts a System.String into a System.Windows.Point.

  

   value: The string to convert.

   context: Context information that is used for conversion.

   Returns: A new instance of System.Windows.Point based on the supplied value.
  """
  pass
 def ConvertToString(self,value,context):
  """
  ConvertToString(self: PointValueSerializer,value: object,context: IValueSerializerContext) -> str

  

   Converts an instance of System.Windows.Point to a System.String.

  

   value: The object to convert into a string.

   context: Context information that is used for conversion.

   Returns: A string representation of the specified System.Windows.Point.
  """
  pass

class RectValueSerializer(ValueSerializer):
 """
 Converts instances of System.String to and from instances of System.Windows.Rect.

 

 RectValueSerializer()
 """
 def CanConvertFromString(self,value,context):
  """
  CanConvertFromString(self: RectValueSerializer,value: str,context: IValueSerializerContext) -> bool

  

   Determines whether the specified System.String can be converted to an instance of 

    System.Windows.Rect.

  

  

   value: String to evaluate for conversion.

   context: Context information that is used for conversion.

   Returns: Always returns true.
  """
  pass
 def CanConvertToString(self,value,context):
  """
  CanConvertToString(self: RectValueSerializer,value: object,context: IValueSerializerContext) -> bool

  

   Determines whether the specified System.Windows.Rect can be converted to a System.String.

  

   value: The object to evaluate for conversion.

   context: Context information that is used for conversion.

   Returns: true if value can be converted into a System.String; otherwise,false.
  """
  pass
 def ConvertFromString(self,value,context):
  """
  ConvertFromString(self: RectValueSerializer,value: str,context: IValueSerializerContext) -> object

  

   Converts a System.String into a System.Windows.Rect.

  

   value: The string to convert.

   context: Context information that is used for conversion.

   Returns: A new instance of System.Windows.Rect based on the supplied value.
  """
  pass
 def ConvertToString(self,value,context):
  """
  ConvertToString(self: RectValueSerializer,value: object,context: IValueSerializerContext) -> str

  

   Converts an instance of System.Windows.Rect to a System.String.

  

   value: The object to convert into a string.

   context: Context information that is used for conversion.

   Returns: A string representation of the specified System.Windows.Rect.
  """
  pass

class SizeValueSerializer(ValueSerializer):
 """
 Converts instances of System.String to and from instances of System.Windows.Size.

 

 SizeValueSerializer()
 """
 def CanConvertFromString(self,value,context):
  """
  CanConvertFromString(self: SizeValueSerializer,value: str,context: IValueSerializerContext) -> bool

  

   Determines whether the specified System.String can be converted to an instance of 

    System.Windows.Size.

  

  

   value: String to evaluate for conversion.

   context: Context information that is used for conversion.

   Returns: Always returns true.
  """
  pass
 def CanConvertToString(self,value,context):
  """
  CanConvertToString(self: SizeValueSerializer,value: object,context: IValueSerializerContext) -> bool

  

   Determines whether the specified System.Windows.Size can be converted to a System.String.

  

   value: The object to evaluate for conversion.

   context: Context information that is used for conversion.

   Returns: true if value can be converted into a System.String; otherwise,false.
  """
  pass
 def ConvertFromString(self,value,context):
  """
  ConvertFromString(self: SizeValueSerializer,value: str,context: IValueSerializerContext) -> object

  

   Converts a System.String into a System.Windows.Size.

  

   value: The string to convert.

   context: Context information that is used for conversion.

   Returns: A new instance of System.Windows.Size based on the supplied value.
  """
  pass
 def ConvertToString(self,value,context):
  """
  ConvertToString(self: SizeValueSerializer,value: object,context: IValueSerializerContext) -> str

  

   Converts an instance of System.Windows.Size to a System.String.

  

   value: The object to convert into a string.

   context: Context information that is used for conversion.

   Returns: A string representation of the specified System.Windows.Size.
  """
  pass

class VectorValueSerializer(ValueSerializer):
 """
 Converts instances of System.String to and from instances of System.Windows.Vector.

 

 VectorValueSerializer()
 """
 def CanConvertFromString(self,value,context):
  """
  CanConvertFromString(self: VectorValueSerializer,value: str,context: IValueSerializerContext) -> bool

  

   Determines whether the specified System.String can be converted to an instance of 

    System.Windows.Vector.

  

  

   value: String to evaluate for conversion.

   context: Context information that is used for conversion.

   Returns: Always returns true.
  """
  pass
 def CanConvertToString(self,value,context):
  """
  CanConvertToString(self: VectorValueSerializer,value: object,context: IValueSerializerContext) -> bool

  

   Determines whether the specified System.Windows.Vector can be converted to a System.String.

  

   value: The object to evaluate for conversion.

   context: Context information that is used for conversion.

   Returns: true if value can be converted into a System.String; otherwise,false.
  """
  pass
 def ConvertFromString(self,value,context):
  """
  ConvertFromString(self: VectorValueSerializer,value: str,context: IValueSerializerContext) -> object

  

   Converts a System.String into a System.Windows.Vector.

  

   value: The string to convert.

   context: Context information that is used for conversion.

   Returns: A new instance of System.Windows.Vector based on the supplied value.
  """
  pass
 def ConvertToString(self,value,context):
  """
  ConvertToString(self: VectorValueSerializer,value: object,context: IValueSerializerContext) -> str

  

   Converts an instance of System.Windows.Vector to a System.String.

  

   value: The object to convert into a string.

   context: Context information that is used for conversion.

   Returns: A string representation of the specified System.Windows.Vector.
  """
  pass

