class PreserveSigAttribute(Attribute,_Attribute):
 """
 Indicates that the HRESULT or retval signature transformation that takes place during COM interop calls should be suppressed.

 

 PreserveSigAttribute()
 """
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
