class SystemPens(object):
 """ Each property of the System.Drawing.SystemPens class is a System.Drawing.Pen that is the color of a Windows display element and that has a width of 1 pixel. """
 @staticmethod
 def FromSystemColor(c):
  """
  FromSystemColor(c: Color) -> Pen

  

   Creates a System.Drawing.Pen from the specified System.Drawing.Color.

  

   c: The System.Drawing.Color for the new System.Drawing.Pen.

   Returns: The System.Drawing.Pen this method creates.
  """
  pass
 ActiveBorder=None
 ActiveCaption=None
 ActiveCaptionText=None
 AppWorkspace=None
 ButtonFace=None
 ButtonHighlight=None
 ButtonShadow=None
 Control=None
 ControlDark=None
 ControlDarkDark=None
 ControlLight=None
 ControlLightLight=None
 ControlText=None
 Desktop=None
 GradientActiveCaption=None
 GradientInactiveCaption=None
 GrayText=None
 Highlight=None
 HighlightText=None
 HotTrack=None
 InactiveBorder=None
 InactiveCaption=None
 InactiveCaptionText=None
 Info=None
 InfoText=None
 Menu=None
 MenuBar=None
 MenuHighlight=None
 MenuText=None
 ScrollBar=None
 Window=None
 WindowFrame=None
 WindowText=None

