class VARFLAGS(Enum,IComparable,IFormattable,IConvertible):
 """
 Use System.Runtime.InteropServices.ComTypes.VARFLAGS instead.

 

 enum (flags) VARFLAGS,values: VARFLAG_FBINDABLE (4),VARFLAG_FDEFAULTBIND (32),VARFLAG_FDEFAULTCOLLELEM (256),VARFLAG_FDISPLAYBIND (16),VARFLAG_FHIDDEN (64),VARFLAG_FIMMEDIATEBIND (4096),VARFLAG_FNONBROWSABLE (1024),VARFLAG_FREADONLY (1),VARFLAG_FREPLACEABLE (2048),VARFLAG_FREQUESTEDIT (8),VARFLAG_FRESTRICTED (128),VARFLAG_FSOURCE (2),VARFLAG_FUIDEFAULT (512)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 value__=None
 VARFLAG_FBINDABLE=None
 VARFLAG_FDEFAULTBIND=None
 VARFLAG_FDEFAULTCOLLELEM=None
 VARFLAG_FDISPLAYBIND=None
 VARFLAG_FHIDDEN=None
 VARFLAG_FIMMEDIATEBIND=None
 VARFLAG_FNONBROWSABLE=None
 VARFLAG_FREADONLY=None
 VARFLAG_FREPLACEABLE=None
 VARFLAG_FREQUESTEDIT=None
 VARFLAG_FRESTRICTED=None
 VARFLAG_FSOURCE=None
 VARFLAG_FUIDEFAULT=None

