class DebuggerStepperBoundaryAttribute(Attribute,_Attribute):
 """
 Indicates the code following the attribute is to be executed in run,not step,mode.

 

 DebuggerStepperBoundaryAttribute()
 """
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __reduce_ex__(self,*args):
  pass
