# encoding: utf-8
# module System.Windows calls itself Windows
# from System,Version=4.0.0.0,Culture=neutral,PublicKeyToken=b77a5c561934e089
# by generator 1.145
""" NamespaceTracker represent a CLS namespace. """
# no imports

# no functions
# no classes
# variables with complex values

