class Boolean(int):
 """ Represents a Boolean value. """
 @staticmethod
 def __new__(self,*args): #cannot find CLR constructor
  """
  __new__(cls: object,o: object) -> bool

  __new__(cls: object) -> object
  """
  pass
