# encoding: utf-8
# module System.IO calls itself IO
# from mscorlib,Version=4.0.0.0,Culture=neutral,PublicKeyToken=b77a5c561934e089,System,Version=4.0.0.0,Culture=neutral,PublicKeyToken=b77a5c561934e089
# by generator 1.145
""" NamespaceTracker represent a CLS namespace. """
# no imports

# no functions
# classes
from __init___parts.BinaryReader import BinaryReader
from __init___parts.BinaryWriter import BinaryWriter
from __init___parts.Stream import Stream
from __init___parts.BufferedStream import BufferedStream
from __init___parts.Directory import Directory
from __init___parts.FileSystemInfo import FileSystemInfo
from __init___parts.DirectoryInfo import DirectoryInfo
from __init___parts.IOException import IOException
from __init___parts.DirectoryNotFoundException import DirectoryNotFoundException
from __init___parts.DriveInfo import DriveInfo
from __init___parts.DriveNotFoundException import DriveNotFoundException
from __init___parts.DriveType import DriveType
from __init___parts.EndOfStreamException import EndOfStreamException
from __init___parts.ErrorEventArgs import ErrorEventArgs
from __init___parts.ErrorEventHandler import ErrorEventHandler
from __init___parts.File import File
from __init___parts.FileAccess import FileAccess
from __init___parts.FileAttributes import FileAttributes
from __init___parts.FileInfo import FileInfo
from __init___parts.FileLoadException import FileLoadException
from __init___parts.FileMode import FileMode
from __init___parts.FileNotFoundException import FileNotFoundException
from __init___parts.FileOptions import FileOptions
from __init___parts.FileShare import FileShare
from __init___parts.FileStream import FileStream
from __init___parts.FileSystemEventArgs import FileSystemEventArgs
from __init___parts.FileSystemEventHandler import FileSystemEventHandler
from __init___parts.FileSystemWatcher import FileSystemWatcher
from __init___parts.InternalBufferOverflowException import InternalBufferOverflowException
from __init___parts.InvalidDataException import InvalidDataException
from __init___parts.IODescriptionAttribute import IODescriptionAttribute
from __init___parts.MemoryStream import MemoryStream
from __init___parts.NotifyFilters import NotifyFilters
from __init___parts.Path import Path
from __init___parts.PathTooLongException import PathTooLongException
from __init___parts.RenamedEventArgs import RenamedEventArgs
from __init___parts.RenamedEventHandler import RenamedEventHandler
from __init___parts.SearchOption import SearchOption
from __init___parts.SeekOrigin import SeekOrigin
from __init___parts.TextReader import TextReader
from __init___parts.StreamReader import StreamReader
from __init___parts.TextWriter import TextWriter
from __init___parts.StreamWriter import StreamWriter
from __init___parts.StringReader import StringReader
from __init___parts.StringWriter import StringWriter
from __init___parts.UnmanagedMemoryAccessor import UnmanagedMemoryAccessor
from __init___parts.UnmanagedMemoryStream import UnmanagedMemoryStream
from __init___parts.WaitForChangedResult import WaitForChangedResult
from __init___parts.WatcherChangeTypes import WatcherChangeTypes
