class NotifyFilters(Enum,IComparable,IFormattable,IConvertible):
 """
 Specifies changes to watch for in a file or folder.

 

 enum (flags) NotifyFilters,values: Attributes (4),CreationTime (64),DirectoryName (2),FileName (1),LastAccess (32),LastWrite (16),Security (256),Size (8)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 Attributes=None
 CreationTime=None
 DirectoryName=None
 FileName=None
 LastAccess=None
 LastWrite=None
 Security=None
 Size=None
 value__=None

