class ItemContainerTemplateKey(TemplateKey,ISupportInitialize):
 """
 ItemContainerTemplateKey()

 ItemContainerTemplateKey(dataType: object)
 """
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 @staticmethod
 def __new__(self,dataType=None):
  """
  __new__(cls: type)

  __new__(cls: type,dataType: object)
  """
  pass
 def __str__(self,*args):
  pass
