class DebuggerNonUserCodeAttribute(Attribute,_Attribute):
 """
 Identifies a type or member that is not part of the user code for an application.

 

 DebuggerNonUserCodeAttribute()
 """
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __reduce_ex__(self,*args):
  pass
