class DriveType(Enum,IComparable,IFormattable,IConvertible):
 """
 Defines constants for drive types,including CDRom,Fixed,Network,NoRootDirectory,Ram,Removable,and Unknown.

 

 enum DriveType,values: CDRom (5),Fixed (3),Network (4),NoRootDirectory (1),Ram (6),Removable (2),Unknown (0)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 CDRom=None
 Fixed=None
 Network=None
 NoRootDirectory=None
 Ram=None
 Removable=None
 Unknown=None
 value__=None

