class ProfessionalColors(object):
 """ Provides System.Drawing.Color structures that are colors of a Windows display element. This class cannot be inherited. """
 ButtonCheckedGradientBegin=None
 ButtonCheckedGradientEnd=None
 ButtonCheckedGradientMiddle=None
 ButtonCheckedHighlight=None
 ButtonCheckedHighlightBorder=None
 ButtonPressedBorder=None
 ButtonPressedGradientBegin=None
 ButtonPressedGradientEnd=None
 ButtonPressedGradientMiddle=None
 ButtonPressedHighlight=None
 ButtonPressedHighlightBorder=None
 ButtonSelectedBorder=None
 ButtonSelectedGradientBegin=None
 ButtonSelectedGradientEnd=None
 ButtonSelectedGradientMiddle=None
 ButtonSelectedHighlight=None
 ButtonSelectedHighlightBorder=None
 CheckBackground=None
 CheckPressedBackground=None
 CheckSelectedBackground=None
 GripDark=None
 GripLight=None
 ImageMarginGradientBegin=None
 ImageMarginGradientEnd=None
 ImageMarginGradientMiddle=None
 ImageMarginRevealedGradientBegin=None
 ImageMarginRevealedGradientEnd=None
 ImageMarginRevealedGradientMiddle=None
 MenuBorder=None
 MenuItemBorder=None
 MenuItemPressedGradientBegin=None
 MenuItemPressedGradientEnd=None
 MenuItemPressedGradientMiddle=None
 MenuItemSelected=None
 MenuItemSelectedGradientBegin=None
 MenuItemSelectedGradientEnd=None
 MenuStripGradientBegin=None
 MenuStripGradientEnd=None
 OverflowButtonGradientBegin=None
 OverflowButtonGradientEnd=None
 OverflowButtonGradientMiddle=None
 RaftingContainerGradientBegin=None
 RaftingContainerGradientEnd=None
 SeparatorDark=None
 SeparatorLight=None
 StatusStripGradientBegin=None
 StatusStripGradientEnd=None
 ToolStripBorder=None
 ToolStripContentPanelGradientBegin=None
 ToolStripContentPanelGradientEnd=None
 ToolStripDropDownBackground=None
 ToolStripGradientBegin=None
 ToolStripGradientEnd=None
 ToolStripGradientMiddle=None
 ToolStripPanelGradientBegin=None
 ToolStripPanelGradientEnd=None

