class FlatButtonAppearance(object):
 """ Provides properties that specify the appearance of System.Windows.Forms.Button controls whose System.Windows.Forms.FlatStyle is System.Windows.Forms.FlatStyle.Flat. """
 BorderColor=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the color of the border around the button.



Get: BorderColor(self: FlatButtonAppearance) -> Color



Set: BorderColor(self: FlatButtonAppearance)=value

"""

 BorderSize=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a value that specifies the size,in pixels,of the border around the button.



Get: BorderSize(self: FlatButtonAppearance) -> int



Set: BorderSize(self: FlatButtonAppearance)=value

"""

 CheckedBackColor=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the color of the client area of the button when the button is checked and the mouse pointer is outside the bounds of the control.



Get: CheckedBackColor(self: FlatButtonAppearance) -> Color



Set: CheckedBackColor(self: FlatButtonAppearance)=value

"""

 MouseDownBackColor=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the color of the client area of the button when the mouse is pressed within the bounds of the control.



Get: MouseDownBackColor(self: FlatButtonAppearance) -> Color



Set: MouseDownBackColor(self: FlatButtonAppearance)=value

"""

 MouseOverBackColor=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the color of the client area of the button when the mouse pointer is within the bounds of the control.



Get: MouseOverBackColor(self: FlatButtonAppearance) -> Color



Set: MouseOverBackColor(self: FlatButtonAppearance)=value

"""


