# encoding: utf-8
# module System.Net calls itself Net
# from System,Version=4.0.0.0,Culture=neutral,PublicKeyToken=b77a5c561934e089
# by generator 1.145
""" NamespaceTracker represent a CLS namespace. """
# no imports

# no functions
# classes
from __init___parts.AuthenticationManager import AuthenticationManager
from __init___parts.AuthenticationSchemes import AuthenticationSchemes
from __init___parts.AuthenticationSchemeSelector import AuthenticationSchemeSelector
from __init___parts.Authorization import Authorization
from __init___parts.BindIPEndPoint import BindIPEndPoint
from __init___parts.Cookie import Cookie
from __init___parts.CookieCollection import CookieCollection
from __init___parts.CookieContainer import CookieContainer
from __init___parts.CookieException import CookieException
from __init___parts.CredentialCache import CredentialCache
from __init___parts.DecompressionMethods import DecompressionMethods
from __init___parts.Dns import Dns
from __init___parts.EndPoint import EndPoint
from __init___parts.DnsEndPoint import DnsEndPoint
from __init___parts.DnsPermission import DnsPermission
from __init___parts.DnsPermissionAttribute import DnsPermissionAttribute
from __init___parts.DownloadDataCompletedEventArgs import DownloadDataCompletedEventArgs
from __init___parts.DownloadDataCompletedEventHandler import DownloadDataCompletedEventHandler
from __init___parts.DownloadProgressChangedEventArgs import DownloadProgressChangedEventArgs
from __init___parts.DownloadProgressChangedEventHandler import DownloadProgressChangedEventHandler
from __init___parts.DownloadStringCompletedEventArgs import DownloadStringCompletedEventArgs
from __init___parts.DownloadStringCompletedEventHandler import DownloadStringCompletedEventHandler
from __init___parts.EndpointPermission import EndpointPermission
from __init___parts.WebRequest import WebRequest
from __init___parts.FileWebRequest import FileWebRequest
from __init___parts.WebResponse import WebResponse
from __init___parts.FileWebResponse import FileWebResponse
from __init___parts.FtpStatusCode import FtpStatusCode
from __init___parts.FtpWebRequest import FtpWebRequest
from __init___parts.FtpWebResponse import FtpWebResponse
from __init___parts.GlobalProxySelection import GlobalProxySelection
from __init___parts.HttpContinueDelegate import HttpContinueDelegate
from __init___parts.HttpListener import HttpListener
from __init___parts.HttpListenerBasicIdentity import HttpListenerBasicIdentity
from __init___parts.HttpListenerContext import HttpListenerContext
from __init___parts.HttpListenerException import HttpListenerException
from __init___parts.HttpListenerPrefixCollection import HttpListenerPrefixCollection
from __init___parts.HttpListenerRequest import HttpListenerRequest
from __init___parts.HttpListenerResponse import HttpListenerResponse
from __init___parts.HttpListenerTimeoutManager import HttpListenerTimeoutManager
from __init___parts.HttpRequestHeader import HttpRequestHeader
from __init___parts.HttpResponseHeader import HttpResponseHeader
from __init___parts.HttpStatusCode import HttpStatusCode
from __init___parts.HttpVersion import HttpVersion
from __init___parts.HttpWebRequest import HttpWebRequest
from __init___parts.HttpWebResponse import HttpWebResponse
from __init___parts.IAuthenticationModule import IAuthenticationModule
from __init___parts.ICertificatePolicy import ICertificatePolicy
from __init___parts.ICredentialPolicy import ICredentialPolicy
from __init___parts.ICredentials import ICredentials
from __init___parts.ICredentialsByHost import ICredentialsByHost
from __init___parts.IPAddress import IPAddress
from __init___parts.IPEndPoint import IPEndPoint
from __init___parts.IPHostEntry import IPHostEntry
from __init___parts.IWebProxy import IWebProxy
from __init___parts.IWebProxyScript import IWebProxyScript
from __init___parts.IWebRequestCreate import IWebRequestCreate
from __init___parts.NetworkAccess import NetworkAccess
from __init___parts.NetworkCredential import NetworkCredential
from __init___parts.OpenReadCompletedEventArgs import OpenReadCompletedEventArgs
from __init___parts.OpenReadCompletedEventHandler import OpenReadCompletedEventHandler
from __init___parts.OpenWriteCompletedEventArgs import OpenWriteCompletedEventArgs
from __init___parts.OpenWriteCompletedEventHandler import OpenWriteCompletedEventHandler
from __init___parts.ProtocolViolationException import ProtocolViolationException
from __init___parts.SecurityProtocolType import SecurityProtocolType
from __init___parts.ServicePoint import ServicePoint
from __init___parts.ServicePointManager import ServicePointManager
from __init___parts.SocketAddress import SocketAddress
from __init___parts.SocketPermission import SocketPermission
from __init___parts.SocketPermissionAttribute import SocketPermissionAttribute
from __init___parts.TransportContext import TransportContext
from __init___parts.TransportType import TransportType
from __init___parts.UploadDataCompletedEventArgs import UploadDataCompletedEventArgs
from __init___parts.UploadDataCompletedEventHandler import UploadDataCompletedEventHandler
from __init___parts.UploadFileCompletedEventArgs import UploadFileCompletedEventArgs
from __init___parts.UploadFileCompletedEventHandler import UploadFileCompletedEventHandler
from __init___parts.UploadProgressChangedEventArgs import UploadProgressChangedEventArgs
from __init___parts.UploadProgressChangedEventHandler import UploadProgressChangedEventHandler
from __init___parts.UploadStringCompletedEventArgs import UploadStringCompletedEventArgs
from __init___parts.UploadStringCompletedEventHandler import UploadStringCompletedEventHandler
from __init___parts.UploadValuesCompletedEventArgs import UploadValuesCompletedEventArgs
from __init___parts.UploadValuesCompletedEventHandler import UploadValuesCompletedEventHandler
from __init___parts.WebClient import WebClient
from __init___parts.WebException import WebException
from __init___parts.WebExceptionStatus import WebExceptionStatus
from __init___parts.WebHeaderCollection import WebHeaderCollection
from __init___parts.WebPermission import WebPermission
from __init___parts.WebPermissionAttribute import WebPermissionAttribute
from __init___parts.WebProxy import WebProxy
from __init___parts.WebRequestMethods import WebRequestMethods
from __init___parts.WebUtility import WebUtility
from __init___parts.WriteStreamClosedEventArgs import WriteStreamClosedEventArgs
from __init___parts.WriteStreamClosedEventHandler import WriteStreamClosedEventHandler
