class FUNCFLAGS(Enum,IComparable,IFormattable,IConvertible):
 """
 Use System.Runtime.InteropServices.ComTypes.FUNCFLAGS instead.

 

 enum (flags) FUNCFLAGS,values: FUNCFLAG_FBINDABLE (4),FUNCFLAG_FDEFAULTBIND (32),FUNCFLAG_FDEFAULTCOLLELEM (256),FUNCFLAG_FDISPLAYBIND (16),FUNCFLAG_FHIDDEN (64),FUNCFLAG_FIMMEDIATEBIND (4096),FUNCFLAG_FNONBROWSABLE (1024),FUNCFLAG_FREPLACEABLE (2048),FUNCFLAG_FREQUESTEDIT (8),FUNCFLAG_FRESTRICTED (1),FUNCFLAG_FSOURCE (2),FUNCFLAG_FUIDEFAULT (512),FUNCFLAG_FUSESGETLASTERROR (128)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 FUNCFLAG_FBINDABLE=None
 FUNCFLAG_FDEFAULTBIND=None
 FUNCFLAG_FDEFAULTCOLLELEM=None
 FUNCFLAG_FDISPLAYBIND=None
 FUNCFLAG_FHIDDEN=None
 FUNCFLAG_FIMMEDIATEBIND=None
 FUNCFLAG_FNONBROWSABLE=None
 FUNCFLAG_FREPLACEABLE=None
 FUNCFLAG_FREQUESTEDIT=None
 FUNCFLAG_FRESTRICTED=None
 FUNCFLAG_FSOURCE=None
 FUNCFLAG_FUIDEFAULT=None
 FUNCFLAG_FUSESGETLASTERROR=None
 value__=None

