class WebBrowserEncryptionLevel(Enum,IComparable,IFormattable,IConvertible):
 """
 Specifies constants that define the encryption methods used by documents displayed in the System.Windows.Forms.WebBrowser control.

 

 enum WebBrowserEncryptionLevel,values: Bit128 (6),Bit40 (3),Bit56 (4),Fortezza (5),Insecure (0),Mixed (1),Unknown (2)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 Bit128=None
 Bit40=None
 Bit56=None
 Fortezza=None
 Insecure=None
 Mixed=None
 Unknown=None
 value__=None

