class RotateFlipType(Enum,IComparable,IFormattable,IConvertible):
 """
 Specifies how much an image is rotated and the axis used to flip the image.

 

 enum RotateFlipType,values: Rotate180FlipNone (2),Rotate180FlipX (6),Rotate180FlipXY (0),Rotate180FlipY (4),Rotate270FlipNone (3),Rotate270FlipX (7),Rotate270FlipXY (1),Rotate270FlipY (5),Rotate90FlipNone (1),Rotate90FlipX (5),Rotate90FlipXY (3),Rotate90FlipY (7),RotateNoneFlipNone (0),RotateNoneFlipX (4),RotateNoneFlipXY (2),RotateNoneFlipY (6)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 Rotate180FlipNone=None
 Rotate180FlipX=None
 Rotate180FlipXY=None
 Rotate180FlipY=None
 Rotate270FlipNone=None
 Rotate270FlipX=None
 Rotate270FlipXY=None
 Rotate270FlipY=None
 Rotate90FlipNone=None
 Rotate90FlipX=None
 Rotate90FlipXY=None
 Rotate90FlipY=None
 RotateNoneFlipNone=None
 RotateNoneFlipX=None
 RotateNoneFlipXY=None
 RotateNoneFlipY=None
 value__=None

