class IProgress:
 # no doc
 def Report(self,value):
  """ Report(self: IProgress[T],value: T) """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
