class Double(object):
 """ Represents a double-precision floating-point number. """
 def as_integer_ratio(self,*args):
  """ as_integer_ratio(self: float) -> tuple """
  pass
 def conjugate(self,*args):
  """ conjugate(x: float) -> float """
  pass
 def fromhex(self,*args):
  """ fromhex(cls: type,self: str) -> object """
  pass
 def hex(self,*args):
  """ hex(self: float) -> str """
  pass
 def is_integer(self,*args):
  """ is_integer(self: float) -> bool """
  pass
 def __abs__(self,*args):
  """ x.__abs__() <==> abs(x) """
  pass
 def __add__(self,*args):
  """ x.__add__(y) <==> x+y """
  pass
 def __coerce__(self,*args):
  """ __coerce__(x: float,o: object) -> tuple """
  pass
 def __divmod__(self,*args):
  """ __divmod__(x: float,y: float) -> object """
  pass
 def __div__(self,*args):
  """ x.__div__(y) <==> x/y """
  pass
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __float__(self,*args):
  """ __float__(self: float) -> float """
  pass
 def __floordiv__(self,*args):
  """ x.__floordiv__(y) <==> x//y """
  pass
 def __getformat__(self,*args):
  """ __getformat__(typestr: str) -> str """
  pass
 def __getnewargs__(self,*args):
  """ __getnewargs__(self: float) -> object """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __int__(self,*args):
  """ __int__(d: float) -> object """
  pass
 def __le__(self,*args):
  pass
 def __long__(self,*args):
  """ __long__(self: float) -> long """
  pass
 def __lt__(self,*args):
  pass
 def __mod__(self,*args):
  """ x.__mod__(y) <==> x%y """
  pass
 def __mul__(self,*args):
  """ x.__mul__(y) <==> x*y """
  pass
 def __neg__(self,*args):
  """ x.__neg__() <==> -x """
  pass
 @staticmethod
 def __new__(self,*args): #cannot find CLR constructor
  """
  __new__(cls: type,s: IList[Byte]) -> object

  __new__(cls: type,x: object) -> object

  __new__(cls: type) -> object
  """
  pass
 def __ne__(self,*args):
  pass
 def __nonzero__(self,*args):
  """ __nonzero__(x: float) -> bool """
  pass
 def __pos__(self,*args):
  """ __pos__(x: float) -> float """
  pass
 def __pow__(self,*args):
  """ x.__pow__(y[,z]) <==> pow(x,y[,z]) """
  pass
 def __radd__(self,*args):
  """ __radd__(x: float,y: float) -> float """
  pass
 def __rdivmod__(self,*args):
  """ __rdivmod__(x: float,y: float) -> object """
  pass
 def __rdiv__(self,*args):
  """ __rdiv__(x: float,y: float) -> float """
  pass
 def __rfloordiv__(self,*args):
  """ __rfloordiv__(x: float,y: float) -> float """
  pass
 def __rmod__(self,*args):
  """ __rmod__(x: float,y: float) -> float """
  pass
 def __rmul__(self,*args):
  """ __rmul__(x: float,y: float) -> float """
  pass
 def __rpow__(self,*args):
  """ __rpow__(x: float,y: float) -> float """
  pass
 def __rsub__(self,*args):
  """ __rsub__(x: float,y: float) -> float """
  pass
 def __rtruediv__(self,*args):
  """ __rtruediv__(x: float,y: float) -> float """
  pass
 def __setformat__(self,*args):
  """ __setformat__(typestr: str,fmt: str) """
  pass
 def __sub__(self,*args):
  """ x.__sub__(y) <==> x-y """
  pass
 def __truediv__(self,*args):
  """ x.__truediv__(y) <==> x/y """
  pass
 def __trunc__(self,*args):
  """ __trunc__(x: float) -> object """
  pass
 imag=None
 real=None

