class PARAMFLAG(Enum,IComparable,IFormattable,IConvertible):
 """
 Use System.Runtime.InteropServices.ComTypes.PARAMFLAG instead.

 

 enum (flags) PARAMFLAG,values: PARAMFLAG_FHASCUSTDATA (64),PARAMFLAG_FHASDEFAULT (32),PARAMFLAG_FIN (1),PARAMFLAG_FLCID (4),PARAMFLAG_FOPT (16),PARAMFLAG_FOUT (2),PARAMFLAG_FRETVAL (8),PARAMFLAG_NONE (0)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 PARAMFLAG_FHASCUSTDATA=None
 PARAMFLAG_FHASDEFAULT=None
 PARAMFLAG_FIN=None
 PARAMFLAG_FLCID=None
 PARAMFLAG_FOPT=None
 PARAMFLAG_FOUT=None
 PARAMFLAG_FRETVAL=None
 PARAMFLAG_NONE=None
 value__=None

