class HierarchicalVirtualizationConstraints(object):
 """ HierarchicalVirtualizationConstraints(cacheLength: VirtualizationCacheLength,cacheLengthUnit: VirtualizationCacheLengthUnit,viewport: Rect) """
 def Equals(self,*__args):
  """
  Equals(self: HierarchicalVirtualizationConstraints,comparisonConstraints: HierarchicalVirtualizationConstraints) -> bool

  Equals(self: HierarchicalVirtualizationConstraints,oCompare: object) -> bool
  """
  pass
 def GetHashCode(self):
  """ GetHashCode(self: HierarchicalVirtualizationConstraints) -> int """
  pass
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==y """
  pass
 @staticmethod
 def __new__(self,cacheLength,cacheLengthUnit,viewport):
  """
  __new__(cls: type,cacheLength: VirtualizationCacheLength,cacheLengthUnit: VirtualizationCacheLengthUnit,viewport: Rect)

  __new__[HierarchicalVirtualizationConstraints]() -> HierarchicalVirtualizationConstraints
  """
  pass
 def __ne__(self,*args):
  pass
 CacheLength=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: CacheLength(self: HierarchicalVirtualizationConstraints) -> VirtualizationCacheLength



"""

 CacheLengthUnit=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: CacheLengthUnit(self: HierarchicalVirtualizationConstraints) -> VirtualizationCacheLengthUnit



"""

 Viewport=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: Viewport(self: HierarchicalVirtualizationConstraints) -> Rect



"""


