class DialogResult(Enum,IComparable,IFormattable,IConvertible):
 """
 Specifies identifiers to indicate the return value of a dialog box.

 

 enum DialogResult,values: Abort (3),Cancel (2),Ignore (5),No (7),None (0),OK (1),Retry (4),Yes (6)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 Abort=None
 Cancel=None
 Ignore=None
 No=None
 None=None
 OK=None
 Retry=None
 value__=None
 Yes=None

