# encoding: utf-8
# module System.Diagnostics calls itself Diagnostics
# from mscorlib,Version=4.0.0.0,Culture=neutral,PublicKeyToken=b77a5c561934e089,System,Version=4.0.0.0,Culture=neutral,PublicKeyToken=b77a5c561934e089
# by generator 1.145
""" NamespaceTracker represent a CLS namespace. """
# no imports

# no functions
# classes
from __init___parts.Switch import Switch
from __init___parts.BooleanSwitch import BooleanSwitch
from __init___parts.ConditionalAttribute import ConditionalAttribute
from __init___parts.TraceListener import TraceListener
from __init___parts.TextWriterTraceListener import TextWriterTraceListener
from __init___parts.ConsoleTraceListener import ConsoleTraceListener
from __init___parts.CorrelationManager import CorrelationManager
from __init___parts.CounterCreationData import CounterCreationData
from __init___parts.CounterCreationDataCollection import CounterCreationDataCollection
from __init___parts.CounterSample import CounterSample
from __init___parts.CounterSampleCalculator import CounterSampleCalculator
from __init___parts.DataReceivedEventArgs import DataReceivedEventArgs
from __init___parts.DataReceivedEventHandler import DataReceivedEventHandler
from __init___parts.Debug import Debug
from __init___parts.DebuggableAttribute import DebuggableAttribute
from __init___parts.Debugger import Debugger
from __init___parts.DebuggerBrowsableAttribute import DebuggerBrowsableAttribute
from __init___parts.DebuggerBrowsableState import DebuggerBrowsableState
from __init___parts.DebuggerDisplayAttribute import DebuggerDisplayAttribute
from __init___parts.DebuggerHiddenAttribute import DebuggerHiddenAttribute
from __init___parts.DebuggerNonUserCodeAttribute import DebuggerNonUserCodeAttribute
from __init___parts.DebuggerStepperBoundaryAttribute import DebuggerStepperBoundaryAttribute
from __init___parts.DebuggerStepThroughAttribute import DebuggerStepThroughAttribute
from __init___parts.DebuggerTypeProxyAttribute import DebuggerTypeProxyAttribute
from __init___parts.DebuggerVisualizerAttribute import DebuggerVisualizerAttribute
from __init___parts.DefaultTraceListener import DefaultTraceListener
from __init___parts.DelimitedListTraceListener import DelimitedListTraceListener
from __init___parts.DiagnosticsConfigurationHandler import DiagnosticsConfigurationHandler
from __init___parts.EntryWrittenEventArgs import EntryWrittenEventArgs
from __init___parts.EntryWrittenEventHandler import EntryWrittenEventHandler
from __init___parts.EventInstance import EventInstance
from __init___parts.EventLog import EventLog
from __init___parts.EventLogEntry import EventLogEntry
from __init___parts.EventLogEntryCollection import EventLogEntryCollection
from __init___parts.EventLogEntryType import EventLogEntryType
from __init___parts.EventLogPermission import EventLogPermission
from __init___parts.EventLogPermissionAccess import EventLogPermissionAccess
from __init___parts.EventLogPermissionAttribute import EventLogPermissionAttribute
from __init___parts.EventLogPermissionEntry import EventLogPermissionEntry
from __init___parts.EventLogPermissionEntryCollection import EventLogPermissionEntryCollection
from __init___parts.EventLogTraceListener import EventLogTraceListener
from __init___parts.EventSourceCreationData import EventSourceCreationData
from __init___parts.TraceFilter import TraceFilter
from __init___parts.EventTypeFilter import EventTypeFilter
from __init___parts.FileVersionInfo import FileVersionInfo
from __init___parts.ICollectData import ICollectData
from __init___parts.InstanceData import InstanceData
from __init___parts.InstanceDataCollection import InstanceDataCollection
from __init___parts.InstanceDataCollectionCollection import InstanceDataCollectionCollection
from __init___parts.MonitoringDescriptionAttribute import MonitoringDescriptionAttribute
from __init___parts.OverflowAction import OverflowAction
from __init___parts.PerformanceCounter import PerformanceCounter
from __init___parts.PerformanceCounterCategory import PerformanceCounterCategory
from __init___parts.PerformanceCounterCategoryType import PerformanceCounterCategoryType
from __init___parts.PerformanceCounterInstanceLifetime import PerformanceCounterInstanceLifetime
from __init___parts.PerformanceCounterManager import PerformanceCounterManager
from __init___parts.PerformanceCounterPermission import PerformanceCounterPermission
from __init___parts.PerformanceCounterPermissionAccess import PerformanceCounterPermissionAccess
from __init___parts.PerformanceCounterPermissionAttribute import PerformanceCounterPermissionAttribute
from __init___parts.PerformanceCounterPermissionEntry import PerformanceCounterPermissionEntry
from __init___parts.PerformanceCounterPermissionEntryCollection import PerformanceCounterPermissionEntryCollection
from __init___parts.PerformanceCounterType import PerformanceCounterType
from __init___parts.Process import Process
from __init___parts.ProcessModule import ProcessModule
from __init___parts.ProcessModuleCollection import ProcessModuleCollection
from __init___parts.ProcessPriorityClass import ProcessPriorityClass
from __init___parts.ProcessStartInfo import ProcessStartInfo
from __init___parts.ProcessThread import ProcessThread
from __init___parts.ProcessThreadCollection import ProcessThreadCollection
from __init___parts.ProcessWindowStyle import ProcessWindowStyle
from __init___parts.SourceFilter import SourceFilter
from __init___parts.SourceLevels import SourceLevels
from __init___parts.SourceSwitch import SourceSwitch
from __init___parts.StackFrame import StackFrame
from __init___parts.StackTrace import StackTrace
from __init___parts.Stopwatch import Stopwatch
from __init___parts.SwitchAttribute import SwitchAttribute
from __init___parts.SwitchLevelAttribute import SwitchLevelAttribute
from __init___parts.ThreadPriorityLevel import ThreadPriorityLevel
from __init___parts.ThreadState import ThreadState
from __init___parts.ThreadWaitReason import ThreadWaitReason
from __init___parts.Trace import Trace
from __init___parts.TraceEventCache import TraceEventCache
from __init___parts.TraceEventType import TraceEventType
from __init___parts.TraceLevel import TraceLevel
from __init___parts.TraceListenerCollection import TraceListenerCollection
from __init___parts.TraceOptions import TraceOptions
from __init___parts.TraceSource import TraceSource
from __init___parts.TraceSwitch import TraceSwitch
from __init___parts.XmlWriterTraceListener import XmlWriterTraceListener
