class DoubleConverter(BaseNumberConverter):
 """
 Provides a type converter to convert double-precision,floating point number objects to and from various other representations.

 

 DoubleConverter()
 """
