class HttpStatusCode(Enum,IComparable,IFormattable,IConvertible):
 """
 Contains the values of status codes defined for HTTP.

 

 enum HttpStatusCode,values: Accepted (202),Ambiguous (300),BadGateway (502),BadRequest (400),Conflict (409),Continue (100),Created (201),ExpectationFailed (417),Forbidden (403),Found (302),GatewayTimeout (504),Gone (410),HttpVersionNotSupported (505),InternalServerError (500),LengthRequired (411),MethodNotAllowed (405),Moved (301),MovedPermanently (301),MultipleChoices (300),NoContent (204),NonAuthoritativeInformation (203),NotAcceptable (406),NotFound (404),NotImplemented (501),NotModified (304),OK (200),PartialContent (206),PaymentRequired (402),PreconditionFailed (412),ProxyAuthenticationRequired (407),Redirect (302),RedirectKeepVerb (307),RedirectMethod (303),RequestedRangeNotSatisfiable (416),RequestEntityTooLarge (413),RequestTimeout (408),RequestUriTooLong (414),ResetContent (205),SeeOther (303),ServiceUnavailable (503),SwitchingProtocols (101),TemporaryRedirect (307),Unauthorized (401),UnsupportedMediaType (415),Unused (306),UpgradeRequired (426),UseProxy (305)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 Accepted=None
 Ambiguous=None
 BadGateway=None
 BadRequest=None
 Conflict=None
 Continue=None
 Created=None
 ExpectationFailed=None
 Forbidden=None
 Found=None
 GatewayTimeout=None
 Gone=None
 HttpVersionNotSupported=None
 InternalServerError=None
 LengthRequired=None
 MethodNotAllowed=None
 Moved=None
 MovedPermanently=None
 MultipleChoices=None
 NoContent=None
 NonAuthoritativeInformation=None
 NotAcceptable=None
 NotFound=None
 NotImplemented=None
 NotModified=None
 OK=None
 PartialContent=None
 PaymentRequired=None
 PreconditionFailed=None
 ProxyAuthenticationRequired=None
 Redirect=None
 RedirectKeepVerb=None
 RedirectMethod=None
 RequestedRangeNotSatisfiable=None
 RequestEntityTooLarge=None
 RequestTimeout=None
 RequestUriTooLong=None
 ResetContent=None
 SeeOther=None
 ServiceUnavailable=None
 SwitchingProtocols=None
 TemporaryRedirect=None
 Unauthorized=None
 UnsupportedMediaType=None
 Unused=None
 UpgradeRequired=None
 UseProxy=None
 value__=None

