class SerializableAttribute(Attribute,_Attribute):
 """
 Indicates that a class can be serialized. This class cannot be inherited.

 

 SerializableAttribute()
 """
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
