# encoding: utf-8
# module System.Windows.Automation.Peers calls itself Peers
# from PresentationCore,Version=4.0.0.0,Culture=neutral,PublicKeyToken=31bf3856ad364e35
# by generator 1.145
""" NamespaceTracker represent a CLS namespace. """
# no imports

# no functions
# classes

class AutomationControlType(Enum,IComparable,IFormattable,IConvertible):
 """
 Specifies the System.Windows.Automation.ControlType that is exposed to the UI Automation�client.

 

 enum AutomationControlType,values: Button (0),Calendar (1),CheckBox (2),ComboBox (3),Custom (25),DataGrid (28),DataItem (29),Document (30),Edit (4),Group (26),Header (34),HeaderItem (35),Hyperlink (5),Image (6),List (8),ListItem (7),Menu (9),MenuBar (10),MenuItem (11),Pane (33),ProgressBar (12),RadioButton (13),ScrollBar (14),Separator (38),Slider (15),Spinner (16),SplitButton (31),StatusBar (17),Tab (18),TabItem (19),Table (36),Text (20),Thumb (27),TitleBar (37),ToolBar (21),ToolTip (22),Tree (23),TreeItem (24),Window (32)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 Button=None
 Calendar=None
 CheckBox=None
 ComboBox=None
 Custom=None
 DataGrid=None
 DataItem=None
 Document=None
 Edit=None
 Group=None
 Header=None
 HeaderItem=None
 Hyperlink=None
 Image=None
 List=None
 ListItem=None
 Menu=None
 MenuBar=None
 MenuItem=None
 Pane=None
 ProgressBar=None
 RadioButton=None
 ScrollBar=None
 Separator=None
 Slider=None
 Spinner=None
 SplitButton=None
 StatusBar=None
 Tab=None
 TabItem=None
 Table=None
 Text=None
 Thumb=None
 TitleBar=None
 ToolBar=None
 ToolTip=None
 Tree=None
 TreeItem=None
 value__=None
 Window=None


class AutomationEvents(Enum,IComparable,IFormattable,IConvertible):
 """
 Specifies the event that is raised by the element through the associated System.Windows.Automation.Peers.AutomationPeer.

 

 enum AutomationEvents,values: AsyncContentLoaded (12),AutomationFocusChanged (4),InputDiscarded (17),InputReachedOtherElement (16),InputReachedTarget (15),InvokePatternOnInvoked (5),MenuClosed (3),MenuOpened (2),PropertyChanged (13),SelectionItemPatternOnElementAddedToSelection (6),SelectionItemPatternOnElementRemovedFromSelection (7),SelectionItemPatternOnElementSelected (8),SelectionPatternOnInvalidated (9),StructureChanged (14),TextPatternOnTextChanged (11),TextPatternOnTextSelectionChanged (10),ToolTipClosed (1),ToolTipOpened (0)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 AsyncContentLoaded=None
 AutomationFocusChanged=None
 InputDiscarded=None
 InputReachedOtherElement=None
 InputReachedTarget=None
 InvokePatternOnInvoked=None
 MenuClosed=None
 MenuOpened=None
 PropertyChanged=None
 SelectionItemPatternOnElementAddedToSelection=None
 SelectionItemPatternOnElementRemovedFromSelection=None
 SelectionItemPatternOnElementSelected=None
 SelectionPatternOnInvalidated=None
 StructureChanged=None
 TextPatternOnTextChanged=None
 TextPatternOnTextSelectionChanged=None
 ToolTipClosed=None
 ToolTipOpened=None
 value__=None


class AutomationOrientation(Enum,IComparable,IFormattable,IConvertible):
 """
 Specifies the direction in which a control can be laid out.

 

 enum AutomationOrientation,values: Horizontal (1),None (0),Vertical (2)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 Horizontal=None
 None=None
 value__=None
 Vertical=None


class AutomationPeer(DispatcherObject):
 """ Provides a base class that exposes an element to UI Automation. """
 def GetAcceleratorKey(self):
  """
  GetAcceleratorKey(self: AutomationPeer) -> str

  

   Gets the accelerator key combinations for the element that is associated with the UI Automation 

    peer.

  

   Returns: The accelerator key.
  """
  pass
 def GetAcceleratorKeyCore(self,*args):
  """
  GetAcceleratorKeyCore(self: AutomationPeer) -> str

  

   When overridden in a derived class,is called by 

    System.Windows.Automation.Peers.AutomationPeer.GetAcceleratorKey.

  

   Returns: The accelerator key.
  """
  pass
 def GetAccessKey(self):
  """
  GetAccessKey(self: AutomationPeer) -> str

  

   Gets the access key for the element that is associated with the automation peer.

   Returns: The string that contains the access key.
  """
  pass
 def GetAccessKeyCore(self,*args):
  """
  GetAccessKeyCore(self: AutomationPeer) -> str

  

   When overridden in a derived class,is called by 

    System.Windows.Automation.Peers.AutomationPeer.GetAccessKey.

  

   Returns: The string that contains the access key.
  """
  pass
 def GetAutomationControlType(self):
  """
  GetAutomationControlType(self: AutomationPeer) -> AutomationControlType

  

   Gets the control type for the element that is associated with the UI Automation peer.

   Returns: The control type.
  """
  pass
 def GetAutomationControlTypeCore(self,*args):
  """
  GetAutomationControlTypeCore(self: AutomationPeer) -> AutomationControlType

  

   When overridden in a derived class,is called by 

    System.Windows.Automation.Peers.AutomationPeer.GetAutomationControlType.

  

   Returns: The control type.
  """
  pass
 def GetAutomationId(self):
  """
  GetAutomationId(self: AutomationPeer) -> str

  

   Gets the System.Windows.Automation.AutomationProperties.AutomationId of the element that is 

    associated with the automation peer.

  

   Returns: The identifier.
  """
  pass
 def GetAutomationIdCore(self,*args):
  """
  GetAutomationIdCore(self: AutomationPeer) -> str

  

   When overridden in a derived class,is called by 

    System.Windows.Automation.Peers.AutomationPeer.GetAutomationId.

  

   Returns: The string that contains the identifier.
  """
  pass
 def GetBoundingRectangle(self):
  """
  GetBoundingRectangle(self: AutomationPeer) -> Rect

  

   Gets the System.Windows.Rect object that represents the screen coordinates of the element that 

    is associated with the automation peer.

  

   Returns: The bounding rectangle.
  """
  pass
 def GetBoundingRectangleCore(self,*args):
  """
  GetBoundingRectangleCore(self: AutomationPeer) -> Rect

  

   When overridden in a derived class,is called by 

    System.Windows.Automation.Peers.AutomationPeer.GetBoundingRectangle.

  

   Returns: The bounding rectangle.
  """
  pass
 def GetChildren(self):
  """
  GetChildren(self: AutomationPeer) -> List[AutomationPeer]

  

   Gets the collection of System.Windows.Automation.Peers.AutomationPeer.GetChildren elements that 

    are represented in the UI Automation tree as immediate child elements of the automation peer.

  

   Returns: The collection of child elements.
  """
  pass
 def GetChildrenCore(self,*args):
  """
  GetChildrenCore(self: AutomationPeer) -> List[AutomationPeer]

  

   When overridden in a derived class,is called by 

    System.Windows.Automation.Peers.AutomationPeer.GetChildren.

  

   Returns: The collection of child elements.
  """
  pass
 def GetClassName(self):
  """
  GetClassName(self: AutomationPeer) -> str

  

   Gets a name that is used with System.Windows.Automation.Peers.AutomationControlType,to 

    differentiate the control that is represented by this 

    System.Windows.Automation.Peers.AutomationPeer.

  

   Returns: The class name.
  """
  pass
 def GetClassNameCore(self,*args):
  """
  GetClassNameCore(self: AutomationPeer) -> str

  

   When overridden in a derived class,is called by 

    System.Windows.Automation.Peers.AutomationPeer.GetClassName.

  

   Returns: The class name.
  """
  pass
 def GetClickablePoint(self):
  """
  GetClickablePoint(self: AutomationPeer) -> Point

  

   Gets a System.Windows.Point on the element that is associated with the automation peer that 

    responds to a mouse click.

  

   Returns: A point in the clickable area of the element.
  """
  pass
 def GetClickablePointCore(self,*args):
  """
  GetClickablePointCore(self: AutomationPeer) -> Point

  

   When overridden in a derived class,is called by 

    System.Windows.Automation.Peers.AutomationPeer.GetClickablePoint.

  

   Returns: A point within the clickable area of the element.
  """
  pass
 def GetHelpText(self):
  """
  GetHelpText(self: AutomationPeer) -> str

  

   Gets text that describes the functionality of the control that is associated with the automation 

    peer.

  

   Returns: The help text.
  """
  pass
 def GetHelpTextCore(self,*args):
  """
  GetHelpTextCore(self: AutomationPeer) -> str

  

   When overridden in a derived class,is called by 

    System.Windows.Automation.Peers.AutomationPeer.GetHelpText.

  

   Returns: The help text.
  """
  pass
 def GetHostRawElementProviderCore(self,*args):
  """
  GetHostRawElementProviderCore(self: AutomationPeer) -> HostedWindowWrapper

  

   Tells UI Automation where in the UI Automation tree to place the hwnd being hosted by a Windows 

    Presentation Foundation (WPF) element.

  

   Returns: This method returns the hosted hwnd to UI Automation for controls that host hwnd objects.
  """
  pass
 def GetItemStatus(self):
  """
  GetItemStatus(self: AutomationPeer) -> str

  

   Gets text that conveys the visual status of the element that is associated with this automation 

    peer.

  

   Returns: The status.
  """
  pass
 def GetItemStatusCore(self,*args):
  """
  GetItemStatusCore(self: AutomationPeer) -> str

  

   When overridden in a derived class,is called by 

    System.Windows.Automation.Peers.AutomationPeer.GetItemStatus.

  

   Returns: The status.
  """
  pass
 def GetItemType(self):
  """
  GetItemType(self: AutomationPeer) -> str

  

   Gets a string that describes what kind of item an object represents.

   Returns: The kind of item.
  """
  pass
 def GetItemTypeCore(self,*args):
  """
  GetItemTypeCore(self: AutomationPeer) -> str

  

   When overridden in a derived class,is called by 

    System.Windows.Automation.Peers.AutomationPeer.GetItemType.

  

   Returns: The kind of item.
  """
  pass
 def GetLabeledBy(self):
  """
  GetLabeledBy(self: AutomationPeer) -> AutomationPeer

  

   Gets the System.Windows.Automation.Peers.AutomationPeer for the System.Windows.Controls.Label 

    that is targeted to the element.

  

   Returns: The System.Windows.Automation.Peers.LabelAutomationPeer for the element that is targeted by the 

    System.Windows.Controls.Label.
  """
  pass
 def GetLabeledByCore(self,*args):
  """
  GetLabeledByCore(self: AutomationPeer) -> AutomationPeer

  

   When overridden in a derived class,is called by 

    System.Windows.Automation.Peers.AutomationPeer.GetLabeledBy.

  

   Returns: The System.Windows.Automation.Peers.LabelAutomationPeer for the element that is targeted by the 

    System.Windows.Controls.Label.
  """
  pass
 def GetLocalizedControlType(self):
  """
  GetLocalizedControlType(self: AutomationPeer) -> str

  

   Gets a human-readable localized string that represents the 

    System.Windows.Automation.Peers.AutomationControlType value for the control that is associated 

    with this automation peer.

  

   Returns: The type of the control.
  """
  pass
 def GetLocalizedControlTypeCore(self,*args):
  """
  GetLocalizedControlTypeCore(self: AutomationPeer) -> str

  

   When overridden in a derived class,is called by 

    System.Windows.Automation.Peers.AutomationPeer.GetLocalizedControlType.

  

   Returns: The type of the control.
  """
  pass
 def GetName(self):
  """
  GetName(self: AutomationPeer) -> str

  

   Gets text that describes the element that is associated with this automation peer.

   Returns: The name.
  """
  pass
 def GetNameCore(self,*args):
  """
  GetNameCore(self: AutomationPeer) -> str

  

   When overridden in a derived class,is called by 

    System.Windows.Automation.Peers.AutomationPeer.GetName.

  

   Returns: The string that contains the label.
  """
  pass
 def GetOrientation(self):
  """
  GetOrientation(self: AutomationPeer) -> AutomationOrientation

  

   Gets a value that indicates the explicit control orientation,if any.

   Returns: The orientation of the control.
  """
  pass
 def GetOrientationCore(self,*args):
  """
  GetOrientationCore(self: AutomationPeer) -> AutomationOrientation

  

   When overridden in a derived class,is called by 

    System.Windows.Automation.Peers.AutomationPeer.GetOrientation.

  

   Returns: The orientation of the control.
  """
  pass
 def GetParent(self):
  """
  GetParent(self: AutomationPeer) -> AutomationPeer

  

   Gets the System.Windows.Automation.Peers.AutomationPeer that is the parent of this 

    System.Windows.Automation.Peers.AutomationPeer.

  

   Returns: The parent automation peer.
  """
  pass
 def GetPattern(self,patternInterface):
  """
  GetPattern(self: AutomationPeer,patternInterface: PatternInterface) -> object

  

   When overridden in a derived class,gets the control pattern that is associated with the 

    specified System.Windows.Automation.Peers.PatternInterface.

  

  

   patternInterface: A value from the System.Windows.Automation.Peers.PatternInterface enumeration.

   Returns: The object that implements the pattern interface; null if this peer does not support this 

    interface.
  """
  pass
 def GetPeerFromPoint(self,point):
  """ GetPeerFromPoint(self: AutomationPeer,point: Point) -> AutomationPeer """
  pass
 def GetPeerFromPointCore(self,*args):
  """ GetPeerFromPointCore(self: AutomationPeer,point: Point) -> AutomationPeer """
  pass
 def HasKeyboardFocus(self):
  """
  HasKeyboardFocus(self: AutomationPeer) -> bool

  

   Gets a value that indicates whether the element that is associated with this automation peer 

    currently has keyboard focus.

  

   Returns: true if the element has keyboard focus; otherwise,false.
  """
  pass
 def HasKeyboardFocusCore(self,*args):
  """
  HasKeyboardFocusCore(self: AutomationPeer) -> bool

  

   When overridden in a derived class,is called by 

    System.Windows.Automation.Peers.AutomationPeer.HasKeyboardFocus.

  

   Returns: true if the element has keyboard focus; otherwise,false.
  """
  pass
 def InvalidatePeer(self):
  """
  InvalidatePeer(self: AutomationPeer)

   Triggers recalculation of the main properties of the 

    System.Windows.Automation.Peers.AutomationPeer and raises the 

    System.ComponentModel.INotifyPropertyChanged.PropertyChanged notification to the Automation 

    Client if the properties changed.
  """
  pass
 def IsContentElement(self):
  """
  IsContentElement(self: AutomationPeer) -> bool

  

   Gets a value that indicates whether the element that is associated with this automation peer 

    contains data that is presented to the user.

  

   Returns: true if the element is a content element; otherwise,false.
  """
  pass
 def IsContentElementCore(self,*args):
  """
  IsContentElementCore(self: AutomationPeer) -> bool

  

   When overridden in a derived class,is called by 

    System.Windows.Automation.Peers.AutomationPeer.IsContentElement.

  

   Returns: true if the element is a content element; otherwise,false.
  """
  pass
 def IsControlElement(self):
  """
  IsControlElement(self: AutomationPeer) -> bool

  

   Gets a value that indicates whether the element is understood by the user as interactive or as 

    contributing to the logical structure of the control in the GUI.

  

   Returns: true if the element is a control; otherwise,false.
  """
  pass
 def IsControlElementCore(self,*args):
  """
  IsControlElementCore(self: AutomationPeer) -> bool

  

   When overridden in a derived class,is called by 

    System.Windows.Automation.Peers.AutomationPeer.IsControlElement.

  

   Returns: true if the element is a control; otherwise,false.
  """
  pass
 def IsEnabled(self):
  """
  IsEnabled(self: AutomationPeer) -> bool

  

   Gets a value that indicates whether the element associated with this automation peer supports 

    interaction.

  

   Returns: true if the element supports interaction; otherwise,false.
  """
  pass
 def IsEnabledCore(self,*args):
  """
  IsEnabledCore(self: AutomationPeer) -> bool

  

   When overridden in a derived class,is called by 

    System.Windows.Automation.Peers.AutomationPeer.IsEnabled.

  

   Returns: true if the automation peer can receive and send events; otherwise,false.
  """
  pass
 def IsKeyboardFocusable(self):
  """
  IsKeyboardFocusable(self: AutomationPeer) -> bool

  

   Gets a value that indicates whether the element can accept keyboard focus.

   Returns: true if the element can accept keyboard focus; otherwise,false.
  """
  pass
 def IsKeyboardFocusableCore(self,*args):
  """
  IsKeyboardFocusableCore(self: AutomationPeer) -> bool

  

   When overridden in a derived class,is called by 

    System.Windows.Automation.Peers.AutomationPeer.IsKeyboardFocusable.

  

   Returns: true if the element can accept keyboard focus; otherwise,false.
  """
  pass
 def IsOffscreen(self):
  """
  IsOffscreen(self: AutomationPeer) -> bool

  

   Gets a value that indicates whether an element is off the screen.

   Returns: true if the element is not on the screen; otherwise,false.
  """
  pass
 def IsOffscreenCore(self,*args):
  """
  IsOffscreenCore(self: AutomationPeer) -> bool

  

   When overridden in a derived class,is called by 

    System.Windows.Automation.Peers.AutomationPeer.IsOffscreen.

  

   Returns: true if the element is not on the screen; otherwise,false.
  """
  pass
 def IsPassword(self):
  """
  IsPassword(self: AutomationPeer) -> bool

  

   Gets a value that indicates whether the element contains sensitive content.

   Returns: true if the element contains sensitive content such as a password; otherwise,false.
  """
  pass
 def IsPasswordCore(self,*args):
  """
  IsPasswordCore(self: AutomationPeer) -> bool

  

   When overridden in a derived class,is called by 

    System.Windows.Automation.Peers.AutomationPeer.IsPassword.

  

   Returns: true if the element contains sensitive content; otherwise,false.
  """
  pass
 def IsRequiredForForm(self):
  """
  IsRequiredForForm(self: AutomationPeer) -> bool

  

   Gets a value that indicates whether the element that is associated with this peer must be 

    completed on a form.

  

   Returns: true if the element must be completed; otherwise,false.
  """
  pass
 def IsRequiredForFormCore(self,*args):
  """
  IsRequiredForFormCore(self: AutomationPeer) -> bool

  

   When overridden in a derived class,is called by 

    System.Windows.Automation.Peers.AutomationPeer.IsRequiredForForm.

  

   Returns: true if the element is must be completed; otherwise,false.
  """
  pass
 @staticmethod
 def ListenerExists(eventId):
  """
  ListenerExists(eventId: AutomationEvents) -> bool

  

   Gets a value that indicates whether UI Automation is listening for the specified event.

  

   eventId: One of the enumeration values.

   Returns: A boolean that indicates whether UI Automation is listening for the event.
  """
  pass
 def PeerFromProvider(self,*args):
  """
  PeerFromProvider(self: AutomationPeer,provider: IRawElementProviderSimple) -> AutomationPeer

  

   Gets an System.Windows.Automation.Peers.AutomationPeer for the specified 

    System.Windows.Automation.Provider.IRawElementProviderSimple proxy.

  

  

   provider: The class that implements System.Windows.Automation.Provider.IRawElementProviderSimple.

   Returns: The System.Windows.Automation.Peers.AutomationPeer.
  """
  pass
 def ProviderFromPeer(self,*args):
  """
  ProviderFromPeer(self: AutomationPeer,peer: AutomationPeer) -> IRawElementProviderSimple

  

   Gets the System.Windows.Automation.Provider.IRawElementProviderSimple for the specified 

    System.Windows.Automation.Peers.AutomationPeer.

  

  

   peer: The automation peer.

   Returns: The proxy.
  """
  pass
 def RaiseAsyncContentLoadedEvent(self,args):
  """
  RaiseAsyncContentLoadedEvent(self: AutomationPeer,args: AsyncContentLoadedEventArgs)

   Called by the System.Windows.Automation.Peers.AutomationPeer to raise the 

    System.Windows.Automation.AutomationElement.AsyncContentLoadedEvent event.

  

  

   args: The event data.
  """
  pass
 def RaiseAutomationEvent(self,eventId):
  """
  RaiseAutomationEvent(self: AutomationPeer,eventId: AutomationEvents)

   Raises an automation event.

  

   eventId: The event identifier.
  """
  pass
 def RaisePropertyChangedEvent(self,property,oldValue,newValue):
  """
  RaisePropertyChangedEvent(self: AutomationPeer,property: AutomationProperty,oldValue: object,newValue: object)

   Raises an event to notify the automation client of a changed property value.

  

   property: The property that changed.

   oldValue: The previous value of the property.

   newValue: The new value of the property.
  """
  pass
 def ResetChildrenCache(self):
  """
  ResetChildrenCache(self: AutomationPeer)

   Synchronously resets the tree of child elements by calling 

    System.Windows.Automation.Peers.AutomationPeer.GetChildrenCore.
  """
  pass
 def SetFocus(self):
  """
  SetFocus(self: AutomationPeer)

   Sets the keyboard focus on the element that is associated with this automation peer.
  """
  pass
 def SetFocusCore(self,*args):
  """
  SetFocusCore(self: AutomationPeer)

   When overridden in a derived class,is called by 

    System.Windows.Automation.Peers.AutomationPeer.SetFocus.
  """
  pass
 EventsSource=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets an System.Windows.Automation.Peers.AutomationPeer that is reported to the automation client as a source for all the events that come from this System.Windows.Automation.Peers.AutomationPeer.



Get: EventsSource(self: AutomationPeer) -> AutomationPeer



Set: EventsSource(self: AutomationPeer)=value

"""

 IsHwndHost=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value that indicates whether the element that is associated with this System.Windows.Automation.Peers.AutomationPeer hosts hwnds in Windows Presentation Foundation (WPF).



"""



class ContentElementAutomationPeer(AutomationPeer):
 """
 Exposes System.Windows.ContentElement types to UI Automation.

 

 ContentElementAutomationPeer(owner: ContentElement)
 """
 @staticmethod
 def CreatePeerForElement(element):
  """
  CreatePeerForElement(element: ContentElement) -> AutomationPeer

  

   Creates a System.Windows.Automation.Peers.ContentElementAutomationPeer for the specified 

    System.Windows.ContentElement.

  

  

   element: The System.Windows.ContentElement that is associated with this 

    System.Windows.Automation.Peers.ContentElementAutomationPeer.

  

   Returns: The System.Windows.Automation.Peers.ContentElementAutomationPeer for the specified 

    System.Windows.ContentElement.
  """
  pass
 @staticmethod
 def FromElement(element):
  """
  FromElement(element: ContentElement) -> AutomationPeer

  

   Gets the System.Windows.Automation.Peers.ContentElementAutomationPeer for the specified 

    System.Windows.ContentElement.

  

  

   element: The System.Windows.ContentElement that is associated with this 

    System.Windows.Automation.Peers.ContentElementAutomationPeer.

  

   Returns: The System.Windows.Automation.Peers.ContentElementAutomationPeer for the specified 

    System.Windows.ContentElement,or null if the 

    System.Windows.Automation.Peers.ContentElementAutomationPeer has not been created by the 

    System.Windows.Automation.Peers.ContentElementAutomationPeer.CreatePeerForElement(System.Windows.

    ContentElement) method.
  """
  pass
 def GetPattern(self,patternInterface):
  """
  GetPattern(self: ContentElementAutomationPeer,patternInterface: PatternInterface) -> object

  

   Gets the control pattern for the System.Windows.ContentElement that is associated with this 

    System.Windows.Automation.Peers.ContentElementAutomationPeer.

  

  

   patternInterface: One of the enumeration values.

   Returns: An object that implements the System.Windows.Automation.Provider.ISynchronizedInputProvider 

    interface if patternInterface is 

    System.Windows.Automation.Peers.PatternInterface.SynchronizedInput; otherwise,null.
  """
  pass
 @staticmethod
 def __new__(self,owner):
  """ __new__(cls: type,owner: ContentElement) """
  pass
 IsHwndHost=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value that indicates whether the element that is associated with this System.Windows.Automation.Peers.AutomationPeer hosts hwnds in Windows Presentation Foundation (WPF).



"""

 Owner=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the System.Windows.ContentElement that is associated with this System.Windows.Automation.Peers.ContentElementAutomationPeer.



Get: Owner(self: ContentElementAutomationPeer) -> ContentElement



"""



class UIElementAutomationPeer(AutomationPeer):
 """
 Exposes System.Windows.UIElement types to UI Automation.

 

 UIElementAutomationPeer(owner: UIElement)
 """
 @staticmethod
 def CreatePeerForElement(element):
  """
  CreatePeerForElement(element: UIElement) -> AutomationPeer

  

   Creates a System.Windows.Automation.Peers.UIElementAutomationPeer for the specified 

    System.Windows.UIElement.

  

  

   element: The System.Windows.UIElement that is associated with this 

    System.Windows.Automation.Peers.UIElementAutomationPeer.

  

   Returns: A System.Windows.Automation.Peers.UIElementAutomationPeer.
  """
  pass
 @staticmethod
 def FromElement(element):
  """
  FromElement(element: UIElement) -> AutomationPeer

  

   Gets the System.Windows.Automation.Peers.UIElementAutomationPeer for the specified 

    System.Windows.UIElement.

  

  

   element: The System.Windows.UIElement that is associated with this 

    System.Windows.Automation.Peers.UIElementAutomationPeer.

  

   Returns: The System.Windows.Automation.Peers.UIElementAutomationPeer; or null,if the 

    System.Windows.Automation.Peers.UIElementAutomationPeer was not created by the 

    System.Windows.Automation.Peers.UIElementAutomationPeer.CreatePeerForElement(System.Windows.UIEle

    ment) method.
  """
  pass
 def GetPattern(self,patternInterface):
  """
  GetPattern(self: UIElementAutomationPeer,patternInterface: PatternInterface) -> object

  

   Gets the control pattern for the System.Windows.UIElement that is associated with this 

    System.Windows.Automation.Peers.UIElementAutomationPeer.

  

  

   patternInterface: A value from the enumeration.

   Returns: An object that implements the System.Windows.Automation.Provider.ISynchronizedInputProvider 

    interface if patternInterface is 

    System.Windows.Automation.Peers.PatternInterface.SynchronizedInput; otherwise,null.
  """
  pass
 @staticmethod
 def __new__(self,owner):
  """ __new__(cls: type,owner: UIElement) """
  pass
 IsHwndHost=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value that indicates whether the element that is associated with this System.Windows.Automation.Peers.AutomationPeer hosts hwnds in Windows Presentation Foundation (WPF).



"""

 Owner=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the System.Windows.UIElement that is associated with this System.Windows.Automation.Peers.UIElementAutomationPeer.



Get: Owner(self: UIElementAutomationPeer) -> UIElement



"""



class GenericRootAutomationPeer(UIElementAutomationPeer):
 """
 Exposes System.Windows.Interop.HwndSource types to UI Automation.

 

 GenericRootAutomationPeer(owner: UIElement)
 """
 @staticmethod
 def __new__(self,owner):
  """ __new__(cls: type,owner: UIElement) """
  pass
 IsHwndHost=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value that indicates whether the element that is associated with this System.Windows.Automation.Peers.AutomationPeer hosts hwnds in Windows Presentation Foundation (WPF).



"""



class HostedWindowWrapper(object):
 """
 Exposes System.Windows.Interop.HwndHost types to UI Automation.

 

 HostedWindowWrapper(hwnd: IntPtr)
 """
 @staticmethod
 def __new__(self,hwnd):
  """ __new__(cls: type,hwnd: IntPtr) """
  pass

class PatternInterface(Enum,IComparable,IFormattable,IConvertible):
 """
 Specifies the control pattern that System.Windows.Automation.Peers.AutomationPeer.GetPattern(System.Windows.Automation.Peers.PatternInterface) returns.

 

 enum PatternInterface,values: Dock (12),ExpandCollapse (6),Grid (7),GridItem (8),Invoke (0),ItemContainer (18),MultipleView (9),RangeValue (3),Scroll (4),ScrollItem (5),Selection (1),SelectionItem (11),SynchronizedInput (20),Table (13),TableItem (14),Text (17),Toggle (15),Transform (16),Value (2),VirtualizedItem (19),Window (10)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 Dock=None
 ExpandCollapse=None
 Grid=None
 GridItem=None
 Invoke=None
 ItemContainer=None
 MultipleView=None
 RangeValue=None
 Scroll=None
 ScrollItem=None
 Selection=None
 SelectionItem=None
 SynchronizedInput=None
 Table=None
 TableItem=None
 Text=None
 Toggle=None
 Transform=None
 Value=None
 value__=None
 VirtualizedItem=None
 Window=None


class UIElement3DAutomationPeer(AutomationPeer):
 """
 Exposes System.Windows.UIElement3D types to UI Automation.

 

 UIElement3DAutomationPeer(owner: UIElement3D)
 """
 @staticmethod
 def CreatePeerForElement(element):
  """
  CreatePeerForElement(element: UIElement3D) -> AutomationPeer

  

   Creates a System.Windows.Automation.Peers.UIElement3DAutomationPeer for the specified 

    System.Windows.UIElement3D.

  

  

   element: The System.Windows.UIElement3D that is associated with this 

    System.Windows.Automation.Peers.UIElement3DAutomationPeer.

  

   Returns: A  System.Windows.Automation.Peers.UIElement3DAutomationPeer for the specified 

    System.Windows.UIElement3D.
  """
  pass
 @staticmethod
 def FromElement(element):
  """
  FromElement(element: UIElement3D) -> AutomationPeer

  

   Returns the System.Windows.Automation.Peers.UIElement3DAutomationPeer for the specified 

    System.Windows.UIElement3D.

  

  

   element: The System.Windows.UIElement3D that is associated with this 

    System.Windows.Automation.Peers.UIElement3DAutomationPeer.

  

   Returns: The System.Windows.Automation.Peers.UIElement3DAutomationPeer,or null if the 

    System.Windows.Automation.Peers.UIElement3DAutomationPeer was not created by the 

    System.Windows.Automation.Peers.UIElement3DAutomationPeer.CreatePeerForElement(System.Windows.UIE

    lement3D) method.
  """
  pass
 def GetPattern(self,patternInterface):
  """
  GetPattern(self: UIElement3DAutomationPeer,patternInterface: PatternInterface) -> object

  

   Returns the control pattern for the System.Windows.UIElement3D that is associated with this 

    System.Windows.Automation.Peers.UIElement3DAutomationPeer.

  

  

   patternInterface: One of the enumeration values.

   Returns: An object that implements the System.Windows.Automation.Provider.ISynchronizedInputProvider 

    interface if patternInterface is 

    System.Windows.Automation.Peers.PatternInterface.SynchronizedInput; otherwise,null.
  """
  pass
 @staticmethod
 def __new__(self,owner):
  """ __new__(cls: type,owner: UIElement3D) """
  pass
 IsHwndHost=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value that indicates whether the element that is associated with this System.Windows.Automation.Peers.AutomationPeer hosts hwnds in Windows Presentation Foundation (WPF).



"""

 Owner=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the System.Windows.UIElement3D that is associated with this System.Windows.Automation.Peers.UIElement3DAutomationPeer.



Get: Owner(self: UIElement3DAutomationPeer) -> UIElement3D



"""



