class FUNCDESC(object):
 """ Use System.Runtime.InteropServices.ComTypes.FUNCDESC instead. """
 callconv=None
 cParams=None
 cParamsOpt=None
 cScodes=None
 elemdescFunc=None
 funckind=None
 invkind=None
 lprgelemdescParam=None
 lprgscode=None
 memid=None
 oVft=None
 wFuncFlags=None

