# encoding: utf-8
# module System.Windows.Media.Animation calls itself Animation
# from PresentationCore,Version=4.0.0.0,Culture=neutral,PublicKeyToken=31bf3856ad364e35
# by generator 1.145
""" NamespaceTracker represent a CLS namespace. """
# no imports

# no functions
# classes
from Animation_parts.IAnimatable import IAnimatable
from Animation_parts.Animatable import Animatable
from Animation_parts.Clock import Clock
from Animation_parts.AnimationClock import AnimationClock
from Animation_parts.AnimationException import AnimationException
from Animation_parts.Timeline import Timeline
from Animation_parts.AnimationTimeline import AnimationTimeline
from Animation_parts.IEasingFunction import IEasingFunction
from Animation_parts.EasingFunctionBase import EasingFunctionBase
from Animation_parts.BackEase import BackEase
from Animation_parts.BooleanAnimationBase import BooleanAnimationBase
from Animation_parts.IKeyFrameAnimation import IKeyFrameAnimation
from Animation_parts.BooleanAnimationUsingKeyFrames import BooleanAnimationUsingKeyFrames
from Animation_parts.IKeyFrame import IKeyFrame
from Animation_parts.BooleanKeyFrame import BooleanKeyFrame
from Animation_parts.BooleanKeyFrameCollection import BooleanKeyFrameCollection
from Animation_parts.BounceEase import BounceEase
from Animation_parts.ByteAnimationBase import ByteAnimationBase
from Animation_parts.ByteAnimation import ByteAnimation
from Animation_parts.ByteAnimationUsingKeyFrames import ByteAnimationUsingKeyFrames
from Animation_parts.ByteKeyFrame import ByteKeyFrame
from Animation_parts.ByteKeyFrameCollection import ByteKeyFrameCollection
from Animation_parts.CharAnimationBase import CharAnimationBase
from Animation_parts.CharAnimationUsingKeyFrames import CharAnimationUsingKeyFrames
from Animation_parts.CharKeyFrame import CharKeyFrame
from Animation_parts.CharKeyFrameCollection import CharKeyFrameCollection
from Animation_parts.CircleEase import CircleEase
from Animation_parts.ClockCollection import ClockCollection
from Animation_parts.ClockController import ClockController
from Animation_parts.ClockGroup import ClockGroup
from Animation_parts.ClockState import ClockState
from Animation_parts.ColorAnimationBase import ColorAnimationBase
from Animation_parts.ColorAnimation import ColorAnimation
from Animation_parts.ColorAnimationUsingKeyFrames import ColorAnimationUsingKeyFrames
from Animation_parts.ColorKeyFrame import ColorKeyFrame
from Animation_parts.ColorKeyFrameCollection import ColorKeyFrameCollection
from Animation_parts.CubicEase import CubicEase
from Animation_parts.DecimalAnimationBase import DecimalAnimationBase
from Animation_parts.DecimalAnimation import DecimalAnimation
from Animation_parts.DecimalAnimationUsingKeyFrames import DecimalAnimationUsingKeyFrames
from Animation_parts.DecimalKeyFrame import DecimalKeyFrame
from Animation_parts.DecimalKeyFrameCollection import DecimalKeyFrameCollection
from Animation_parts.DiscreteBooleanKeyFrame import DiscreteBooleanKeyFrame
from Animation_parts.DiscreteByteKeyFrame import DiscreteByteKeyFrame
from Animation_parts.DiscreteCharKeyFrame import DiscreteCharKeyFrame
from Animation_parts.DiscreteColorKeyFrame import DiscreteColorKeyFrame
from Animation_parts.DiscreteDecimalKeyFrame import DiscreteDecimalKeyFrame
from Animation_parts.DoubleKeyFrame import DoubleKeyFrame
from Animation_parts.DiscreteDoubleKeyFrame import DiscreteDoubleKeyFrame
from Animation_parts.Int16KeyFrame import Int16KeyFrame
from Animation_parts.DiscreteInt16KeyFrame import DiscreteInt16KeyFrame
from Animation_parts.Int32KeyFrame import Int32KeyFrame
from Animation_parts.DiscreteInt32KeyFrame import DiscreteInt32KeyFrame
from Animation_parts.Int64KeyFrame import Int64KeyFrame
from Animation_parts.DiscreteInt64KeyFrame import DiscreteInt64KeyFrame
from Animation_parts.MatrixKeyFrame import MatrixKeyFrame
from Animation_parts.DiscreteMatrixKeyFrame import DiscreteMatrixKeyFrame
from Animation_parts.ObjectKeyFrame import ObjectKeyFrame
from Animation_parts.DiscreteObjectKeyFrame import DiscreteObjectKeyFrame
from Animation_parts.Point3DKeyFrame import Point3DKeyFrame
from Animation_parts.DiscretePoint3DKeyFrame import DiscretePoint3DKeyFrame
from Animation_parts.PointKeyFrame import PointKeyFrame
from Animation_parts.DiscretePointKeyFrame import DiscretePointKeyFrame
from Animation_parts.QuaternionKeyFrame import QuaternionKeyFrame
from Animation_parts.DiscreteQuaternionKeyFrame import DiscreteQuaternionKeyFrame
from Animation_parts.RectKeyFrame import RectKeyFrame
from Animation_parts.DiscreteRectKeyFrame import DiscreteRectKeyFrame
from Animation_parts.Rotation3DKeyFrame import Rotation3DKeyFrame
from Animation_parts.DiscreteRotation3DKeyFrame import DiscreteRotation3DKeyFrame
from Animation_parts.SingleKeyFrame import SingleKeyFrame
from Animation_parts.DiscreteSingleKeyFrame import DiscreteSingleKeyFrame
from Animation_parts.SizeKeyFrame import SizeKeyFrame
from Animation_parts.DiscreteSizeKeyFrame import DiscreteSizeKeyFrame
from Animation_parts.StringKeyFrame import StringKeyFrame
from Animation_parts.DiscreteStringKeyFrame import DiscreteStringKeyFrame
from Animation_parts.Vector3DKeyFrame import Vector3DKeyFrame
from Animation_parts.DiscreteVector3DKeyFrame import DiscreteVector3DKeyFrame
from Animation_parts.VectorKeyFrame import VectorKeyFrame
from Animation_parts.DiscreteVectorKeyFrame import DiscreteVectorKeyFrame
from Animation_parts.DoubleAnimationBase import DoubleAnimationBase
from Animation_parts.DoubleAnimation import DoubleAnimation
from Animation_parts.DoubleAnimationUsingKeyFrames import DoubleAnimationUsingKeyFrames
from Animation_parts.DoubleAnimationUsingPath import DoubleAnimationUsingPath
from Animation_parts.DoubleKeyFrameCollection import DoubleKeyFrameCollection
from Animation_parts.EasingByteKeyFrame import EasingByteKeyFrame
from Animation_parts.EasingColorKeyFrame import EasingColorKeyFrame
from Animation_parts.EasingDecimalKeyFrame import EasingDecimalKeyFrame
from Animation_parts.EasingDoubleKeyFrame import EasingDoubleKeyFrame
from Animation_parts.EasingInt16KeyFrame import EasingInt16KeyFrame
from Animation_parts.EasingInt32KeyFrame import EasingInt32KeyFrame
from Animation_parts.EasingInt64KeyFrame import EasingInt64KeyFrame
from Animation_parts.EasingMode import EasingMode
from Animation_parts.EasingPoint3DKeyFrame import EasingPoint3DKeyFrame
from Animation_parts.EasingPointKeyFrame import EasingPointKeyFrame
from Animation_parts.EasingQuaternionKeyFrame import EasingQuaternionKeyFrame
from Animation_parts.EasingRectKeyFrame import EasingRectKeyFrame
from Animation_parts.EasingRotation3DKeyFrame import EasingRotation3DKeyFrame
from Animation_parts.EasingSingleKeyFrame import EasingSingleKeyFrame
from Animation_parts.EasingSizeKeyFrame import EasingSizeKeyFrame
from Animation_parts.EasingVector3DKeyFrame import EasingVector3DKeyFrame
from Animation_parts.EasingVectorKeyFrame import EasingVectorKeyFrame
from Animation_parts.ElasticEase import ElasticEase
from Animation_parts.ExponentialEase import ExponentialEase
from Animation_parts.FillBehavior import FillBehavior
from Animation_parts.HandoffBehavior import HandoffBehavior
from Animation_parts.Int16AnimationBase import Int16AnimationBase
from Animation_parts.Int16Animation import Int16Animation
from Animation_parts.Int16AnimationUsingKeyFrames import Int16AnimationUsingKeyFrames
from Animation_parts.Int16KeyFrameCollection import Int16KeyFrameCollection
from Animation_parts.Int32AnimationBase import Int32AnimationBase
from Animation_parts.Int32Animation import Int32Animation
from Animation_parts.Int32AnimationUsingKeyFrames import Int32AnimationUsingKeyFrames
from Animation_parts.Int32KeyFrameCollection import Int32KeyFrameCollection
from Animation_parts.Int64AnimationBase import Int64AnimationBase
from Animation_parts.Int64Animation import Int64Animation
from Animation_parts.Int64AnimationUsingKeyFrames import Int64AnimationUsingKeyFrames
from Animation_parts.Int64KeyFrameCollection import Int64KeyFrameCollection
from Animation_parts.KeySpline import KeySpline
from Animation_parts.KeyTime import KeyTime
from Animation_parts.KeyTimeType import KeyTimeType
from Animation_parts.LinearByteKeyFrame import LinearByteKeyFrame
from Animation_parts.LinearColorKeyFrame import LinearColorKeyFrame
from Animation_parts.LinearDecimalKeyFrame import LinearDecimalKeyFrame
from Animation_parts.LinearDoubleKeyFrame import LinearDoubleKeyFrame
from Animation_parts.LinearInt16KeyFrame import LinearInt16KeyFrame
from Animation_parts.LinearInt32KeyFrame import LinearInt32KeyFrame
from Animation_parts.LinearInt64KeyFrame import LinearInt64KeyFrame
from Animation_parts.LinearPoint3DKeyFrame import LinearPoint3DKeyFrame
from Animation_parts.LinearPointKeyFrame import LinearPointKeyFrame
from Animation_parts.LinearQuaternionKeyFrame import LinearQuaternionKeyFrame
from Animation_parts.LinearRectKeyFrame import LinearRectKeyFrame
from Animation_parts.LinearRotation3DKeyFrame import LinearRotation3DKeyFrame
from Animation_parts.LinearSingleKeyFrame import LinearSingleKeyFrame
from Animation_parts.LinearSizeKeyFrame import LinearSizeKeyFrame
from Animation_parts.LinearVector3DKeyFrame import LinearVector3DKeyFrame
from Animation_parts.LinearVectorKeyFrame import LinearVectorKeyFrame
from Animation_parts.MatrixAnimationBase import MatrixAnimationBase
from Animation_parts.MatrixAnimationUsingKeyFrames import MatrixAnimationUsingKeyFrames
from Animation_parts.MatrixAnimationUsingPath import MatrixAnimationUsingPath
from Animation_parts.MatrixKeyFrameCollection import MatrixKeyFrameCollection
from Animation_parts.ObjectAnimationBase import ObjectAnimationBase
from Animation_parts.ObjectAnimationUsingKeyFrames import ObjectAnimationUsingKeyFrames
from Animation_parts.ObjectKeyFrameCollection import ObjectKeyFrameCollection
from Animation_parts.TimelineGroup import TimelineGroup
from Animation_parts.ParallelTimeline import ParallelTimeline
from Animation_parts.PathAnimationSource import PathAnimationSource
from Animation_parts.Point3DAnimationBase import Point3DAnimationBase
from Animation_parts.Point3DAnimation import Point3DAnimation
from Animation_parts.Point3DAnimationUsingKeyFrames import Point3DAnimationUsingKeyFrames
from Animation_parts.Point3DKeyFrameCollection import Point3DKeyFrameCollection
from Animation_parts.PointAnimationBase import PointAnimationBase
from Animation_parts.PointAnimation import PointAnimation
from Animation_parts.PointAnimationUsingKeyFrames import PointAnimationUsingKeyFrames
from Animation_parts.PointAnimationUsingPath import PointAnimationUsingPath
from Animation_parts.PointKeyFrameCollection import PointKeyFrameCollection
from Animation_parts.PowerEase import PowerEase
from Animation_parts.QuadraticEase import QuadraticEase
from Animation_parts.QuarticEase import QuarticEase
from Animation_parts.QuaternionAnimationBase import QuaternionAnimationBase
from Animation_parts.QuaternionAnimation import QuaternionAnimation
from Animation_parts.QuaternionAnimationUsingKeyFrames import QuaternionAnimationUsingKeyFrames
from Animation_parts.QuaternionKeyFrameCollection import QuaternionKeyFrameCollection
from Animation_parts.QuinticEase import QuinticEase
from Animation_parts.RectAnimationBase import RectAnimationBase
from Animation_parts.RectAnimation import RectAnimation
from Animation_parts.RectAnimationUsingKeyFrames import RectAnimationUsingKeyFrames
from Animation_parts.RectKeyFrameCollection import RectKeyFrameCollection
from Animation_parts.RepeatBehavior import RepeatBehavior
from Animation_parts.RepeatBehaviorConverter import RepeatBehaviorConverter
from Animation_parts.Rotation3DAnimationBase import Rotation3DAnimationBase
from Animation_parts.Rotation3DAnimation import Rotation3DAnimation
from Animation_parts.Rotation3DAnimationUsingKeyFrames import Rotation3DAnimationUsingKeyFrames
from Animation_parts.Rotation3DKeyFrameCollection import Rotation3DKeyFrameCollection
from Animation_parts.SineEase import SineEase
from Animation_parts.SingleAnimationBase import SingleAnimationBase
from Animation_parts.SingleAnimation import SingleAnimation
from Animation_parts.SingleAnimationUsingKeyFrames import SingleAnimationUsingKeyFrames
from Animation_parts.SingleKeyFrameCollection import SingleKeyFrameCollection
from Animation_parts.SizeAnimationBase import SizeAnimationBase
from Animation_parts.SizeAnimation import SizeAnimation
from Animation_parts.SizeAnimationUsingKeyFrames import SizeAnimationUsingKeyFrames
from Animation_parts.SizeKeyFrameCollection import SizeKeyFrameCollection
from Animation_parts.SlipBehavior import SlipBehavior
from Animation_parts.SplineByteKeyFrame import SplineByteKeyFrame
from Animation_parts.SplineColorKeyFrame import SplineColorKeyFrame
from Animation_parts.SplineDecimalKeyFrame import SplineDecimalKeyFrame
from Animation_parts.SplineDoubleKeyFrame import SplineDoubleKeyFrame
from Animation_parts.SplineInt16KeyFrame import SplineInt16KeyFrame
from Animation_parts.SplineInt32KeyFrame import SplineInt32KeyFrame
from Animation_parts.SplineInt64KeyFrame import SplineInt64KeyFrame
from Animation_parts.SplinePoint3DKeyFrame import SplinePoint3DKeyFrame
from Animation_parts.SplinePointKeyFrame import SplinePointKeyFrame
from Animation_parts.SplineQuaternionKeyFrame import SplineQuaternionKeyFrame
from Animation_parts.SplineRectKeyFrame import SplineRectKeyFrame
from Animation_parts.SplineRotation3DKeyFrame import SplineRotation3DKeyFrame
from Animation_parts.SplineSingleKeyFrame import SplineSingleKeyFrame
from Animation_parts.SplineSizeKeyFrame import SplineSizeKeyFrame
from Animation_parts.SplineVector3DKeyFrame import SplineVector3DKeyFrame
from Animation_parts.SplineVectorKeyFrame import SplineVectorKeyFrame
from Animation_parts.StringAnimationBase import StringAnimationBase
from Animation_parts.StringAnimationUsingKeyFrames import StringAnimationUsingKeyFrames
from Animation_parts.StringKeyFrameCollection import StringKeyFrameCollection
from Animation_parts.TimelineCollection import TimelineCollection
from Animation_parts.TimeSeekOrigin import TimeSeekOrigin
from Animation_parts.Vector3DAnimationBase import Vector3DAnimationBase
from Animation_parts.Vector3DAnimation import Vector3DAnimation
from Animation_parts.Vector3DAnimationUsingKeyFrames import Vector3DAnimationUsingKeyFrames
from Animation_parts.Vector3DKeyFrameCollection import Vector3DKeyFrameCollection
from Animation_parts.VectorAnimationBase import VectorAnimationBase
from Animation_parts.VectorAnimation import VectorAnimation
from Animation_parts.VectorAnimationUsingKeyFrames import VectorAnimationUsingKeyFrames
from Animation_parts.VectorKeyFrameCollection import VectorKeyFrameCollection
