class MessageBoxButtons(Enum,IComparable,IFormattable,IConvertible):
 """
 Specifies constants defining which buttons to display on a System.Windows.Forms.MessageBox.

 

 enum MessageBoxButtons,values: AbortRetryIgnore (2),OK (0),OKCancel (1),RetryCancel (5),YesNo (4),YesNoCancel (3)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 AbortRetryIgnore=None
 OK=None
 OKCancel=None
 RetryCancel=None
 value__=None
 YesNo=None
 YesNoCancel=None

