class UriComponents(Enum,IComparable,IFormattable,IConvertible):
 """
 Specifies the parts of a System.Uri.

 

 enum (flags) UriComponents,values: AbsoluteUri (127),Fragment (64),Host (4),HostAndPort (132),HttpRequestUrl (61),KeepDelimiter (1073741824),NormalizedHost (256),Path (16),PathAndQuery (48),Port (8),Query (32),Scheme (1),SchemeAndServer (13),SerializationInfoString (-2147483648),StrongAuthority (134),StrongPort (128),UserInfo (2)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 AbsoluteUri=None
 Fragment=None
 Host=None
 HostAndPort=None
 HttpRequestUrl=None
 KeepDelimiter=None
 NormalizedHost=None
 Path=None
 PathAndQuery=None
 Port=None
 Query=None
 Scheme=None
 SchemeAndServer=None
 SerializationInfoString=None
 StrongAuthority=None
 StrongPort=None
 UserInfo=None
 value__=None

