class PerformanceCounterManager(object,ICollectData):
 """
 Prepares performance data for the performance.dll the system loads when working with performance counters.

 

 PerformanceCounterManager()
 """
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __repr__(self,*args):
  """ __repr__(self: object) -> str """
  pass
