class ListViewItemStates(Enum,IComparable,IFormattable,IConvertible):
 """
 Defines constants that represent the possible states of a System.Windows.Forms.ListViewItem.

 

 enum (flags) ListViewItemStates,values: Checked (8),Default (32),Focused (16),Grayed (2),Hot (64),Indeterminate (256),Marked (128),Selected (1),ShowKeyboardCues (512)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 Checked=None
 Default=None
 Focused=None
 Grayed=None
 Hot=None
 Indeterminate=None
 Marked=None
 Selected=None
 ShowKeyboardCues=None
 value__=None

