class TypeLibImporterFlags(Enum,IComparable,IFormattable,IConvertible):
 """
 Indicates how an assembly should be produced.

 

 enum (flags) TypeLibImporterFlags,values: ImportAsAgnostic (2048),ImportAsArm (16384),ImportAsItanium (1024),ImportAsX64 (512),ImportAsX86 (256),NoDefineVersionResource (8192),None (0),PreventClassMembers (16),PrimaryInteropAssembly (1),ReflectionOnlyLoading (4096),SafeArrayAsSystemArray (4),SerializableValueClasses (32),TransformDispRetVals (8),UnsafeInterfaces (2)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 ImportAsAgnostic=None
 ImportAsArm=None
 ImportAsItanium=None
 ImportAsX64=None
 ImportAsX86=None
 NoDefineVersionResource=None
 None=None
 PreventClassMembers=None
 PrimaryInteropAssembly=None
 ReflectionOnlyLoading=None
 SafeArrayAsSystemArray=None
 SerializableValueClasses=None
 TransformDispRetVals=None
 UnsafeInterfaces=None
 value__=None

