class TableLayoutStyle(object):
 """ Implements the basic functionality that represents the appearance and behavior of a table layout. """
 SizeType=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a flag indicating how a row or column should be sized relative to its containing table.



Get: SizeType(self: TableLayoutStyle) -> SizeType



Set: SizeType(self: TableLayoutStyle)=value

"""


