class AccessibleRole(Enum,IComparable,IFormattable,IConvertible):
 """
 Specifies values representing possible roles for an accessible object.

 

 enum AccessibleRole,values: Alert (8),Animation (54),Application (14),Border (19),ButtonDropDown (56),ButtonDropDownGrid (58),ButtonMenu (57),Caret (7),Cell (29),Character (32),Chart (17),CheckButton (44),Client (10),Clock (61),Column (27),ColumnHeader (25),ComboBox (46),Cursor (6),Default (-1),Diagram (53),Dial (49),Dialog (18),Document (15),DropList (47),Equation (55),Graphic (40),Grip (4),Grouping (20),HelpBalloon (31),HotkeyField (50),Indicator (39),IpAddress (63),Link (30),List (33),ListItem (34),MenuBar (2),MenuItem (12),MenuPopup (11),None (0),Outline (35),OutlineButton (64),OutlineItem (36),PageTab (37),PageTabList (60),Pane (16),ProgressBar (48),PropertyPage (38),PushButton (43),RadioButton (45),Row (28),RowHeader (26),ScrollBar (3),Separator (21),Slider (51),Sound (5),SpinButton (52),SplitButton (62),StaticText (41),StatusBar (23),Table (24),Text (42),TitleBar (1),ToolBar (22),ToolTip (13),WhiteSpace (59),Window (9)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 Alert=None
 Animation=None
 Application=None
 Border=None
 ButtonDropDown=None
 ButtonDropDownGrid=None
 ButtonMenu=None
 Caret=None
 Cell=None
 Character=None
 Chart=None
 CheckButton=None
 Client=None
 Clock=None
 Column=None
 ColumnHeader=None
 ComboBox=None
 Cursor=None
 Default=None
 Diagram=None
 Dial=None
 Dialog=None
 Document=None
 DropList=None
 Equation=None
 Graphic=None
 Grip=None
 Grouping=None
 HelpBalloon=None
 HotkeyField=None
 Indicator=None
 IpAddress=None
 Link=None
 List=None
 ListItem=None
 MenuBar=None
 MenuItem=None
 MenuPopup=None
 None=None
 Outline=None
 OutlineButton=None
 OutlineItem=None
 PageTab=None
 PageTabList=None
 Pane=None
 ProgressBar=None
 PropertyPage=None
 PushButton=None
 RadioButton=None
 Row=None
 RowHeader=None
 ScrollBar=None
 Separator=None
 Slider=None
 Sound=None
 SpinButton=None
 SplitButton=None
 StaticText=None
 StatusBar=None
 Table=None
 Text=None
 TitleBar=None
 ToolBar=None
 ToolTip=None
 value__=None
 WhiteSpace=None
 Window=None

