class GridTablesFactory(object):
 """ Provides the System.Windows.Forms.GridTablesFactory.CreateGridTables(System.Windows.Forms.DataGridTableStyle,System.Object,System.String,System.Windows.Forms.BindingContext) method. """
 @staticmethod
 def CreateGridTables(gridTable,dataSource,dataMember,bindingManager):
  """
  CreateGridTables(gridTable: DataGridTableStyle,dataSource: object,dataMember: str,bindingManager: BindingContext) -> Array[DataGridTableStyle]

  

   Returns the specified System.Windows.Forms.DataGridColumnStyle.DataGridTableStyle in a 

    one-element array.

  

  

   gridTable: A System.Windows.Forms.DataGridTableStyle.

   dataSource: An System.Object.

   dataMember: A System.String.

   bindingManager: A System.Windows.Forms.BindingContext.

   Returns: An array of System.Windows.Forms.DataGridTableStyle objects.
  """
  pass
