class UnmanagedType(Enum,IComparable,IFormattable,IConvertible):
 """
 Identifies how to marshal parameters or fields to unmanaged code.

 

 enum UnmanagedType,values: AnsiBStr (35),AsAny (40),Bool (2),BStr (19),ByValArray (30),ByValTStr (23),Currency (15),CustomMarshaler (44),Error (45),FunctionPtr (38),HString (47),I1 (3),I2 (5),I4 (7),I8 (9),IDispatch (26),IInspectable (46),Interface (28),IUnknown (25),LPArray (42),LPStr (20),LPStruct (43),LPTStr (22),LPUTF8Str (48),LPWStr (21),R4 (11),R8 (12),SafeArray (29),Struct (27),SysInt (31),SysUInt (32),TBStr (36),U1 (4),U2 (6),U4 (8),U8 (10),VariantBool (37),VBByRefStr (34)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 AnsiBStr=None
 AsAny=None
 Bool=None
 BStr=None
 ByValArray=None
 ByValTStr=None
 Currency=None
 CustomMarshaler=None
 Error=None
 FunctionPtr=None
 HString=None
 I1=None
 I2=None
 I4=None
 I8=None
 IDispatch=None
 IInspectable=None
 Interface=None
 IUnknown=None
 LPArray=None
 LPStr=None
 LPStruct=None
 LPTStr=None
 LPUTF8Str=None
 LPWStr=None
 R4=None
 R8=None
 SafeArray=None
 Struct=None
 SysInt=None
 SysUInt=None
 TBStr=None
 U1=None
 U2=None
 U4=None
 U8=None
 value__=None
 VariantBool=None
 VBByRefStr=None

