class TraceLevel(Enum,IComparable,IFormattable,IConvertible):
 """
 Specifies what messages to output for the System.Diagnostics.Debug,System.Diagnostics.Trace and System.Diagnostics.TraceSwitch classes.

 

 enum TraceLevel,values: Error (1),Info (3),Off (0),Verbose (4),Warning (2)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 Error=None
 Info=None
 Off=None
 value__=None
 Verbose=None
 Warning=None

