class SystemInformation(object):
 """ Provides information about the current system environment. """
 @staticmethod
 def GetBorderSizeForDpi(dpi):
  """ GetBorderSizeForDpi(dpi: int) -> Size """
  pass
 @staticmethod
 def GetHorizontalScrollBarHeightForDpi(dpi):
  """ GetHorizontalScrollBarHeightForDpi(dpi: int) -> int """
  pass
 @staticmethod
 def GetMenuFontForDpi(dpi):
  """ GetMenuFontForDpi(dpi: int) -> Font """
  pass
 @staticmethod
 def GetVerticalScrollBarWidthForDpi(dpi):
  """ GetVerticalScrollBarWidthForDpi(dpi: int) -> int """
  pass
 ActiveWindowTrackingDelay=0
 ArrangeDirection=None
 ArrangeStartingPosition=None
 BootMode=None
 Border3DSize=None
 BorderMultiplierFactor=1
 BorderSize=None
 CaptionButtonSize=None
 CaptionHeight=23
 CaretBlinkTime=530
 CaretWidth=1
 ComputerName='STUDIO-SSD'
 CursorSize=None
 DbcsEnabled=False
 DebugOS=False
 DoubleClickSize=None
 DoubleClickTime=500
 DragFullWindows=True
 DragSize=None
 FixedFrameBorderSize=None
 FontSmoothingContrast=1200
 FontSmoothingType=2
 FrameBorderSize=None
 HighContrast=False
 HorizontalFocusThickness=1
 HorizontalResizeBorderThickness=8
 HorizontalScrollBarArrowWidth=17
 HorizontalScrollBarHeight=17
 HorizontalScrollBarThumbWidth=17
 IconHorizontalSpacing=75
 IconSize=None
 IconSpacingSize=None
 IconVerticalSpacing=75
 IsActiveWindowTrackingEnabled=False
 IsComboBoxAnimationEnabled=True
 IsDropShadowEnabled=True
 IsFlatMenuEnabled=True
 IsFontSmoothingEnabled=True
 IsHotTrackingEnabled=True
 IsIconTitleWrappingEnabled=True
 IsKeyboardPreferred=False
 IsListBoxSmoothScrollingEnabled=True
 IsMenuAnimationEnabled=True
 IsMenuFadeEnabled=True
 IsMinimizeRestoreAnimationEnabled=False
 IsSelectionFadeEnabled=True
 IsSnapToDefaultEnabled=False
 IsTitleBarGradientEnabled=True
 IsToolTipAnimationEnabled=True
 KanjiWindowHeight=0
 KeyboardDelay=1
 KeyboardSpeed=31
 MaxWindowTrackSize=None
 MenuAccessKeysUnderlined=False
 MenuBarButtonSize=None
 MenuButtonSize=None
 MenuCheckSize=None
 MenuFont=None
 MenuHeight=20
 MenuShowDelay=400
 MidEastEnabled=False
 MinimizedWindowSize=None
 MinimizedWindowSpacingSize=None
 MinimumWindowSize=None
 MinWindowTrackSize=None
 MonitorCount=2
 MonitorsSameDisplayFormat=True
 MouseButtons=8
 MouseButtonsSwapped=False
 MouseHoverSize=None
 MouseHoverTime=400
 MousePresent=True
 MouseSpeed=10
 MouseWheelPresent=True
 MouseWheelScrollDelta=120
 MouseWheelScrollLines=3
 NativeMouseWheelSupport=True
 Network=True
 PenWindows=False
 PopupMenuAlignment=None
 PowerStatus=None
 PrimaryMonitorMaximizedWindowSize=None
 PrimaryMonitorSize=None
 RightAlignedMenus=False
 ScreenOrientation=None
 Secure=False
 ShowSounds=False
 SizingBorderWidth=5
 SmallCaptionButtonSize=None
 SmallIconSize=None
 TerminalServerSession=False
 ToolWindowCaptionButtonSize=None
 ToolWindowCaptionHeight=23
 UIEffectsEnabled=True
 UserDomainName='STUDIO-SSD'
 UserInteractive=True
 UserName='gtalarico'
 VerticalFocusThickness=1
 VerticalResizeBorderThickness=8
 VerticalScrollBarArrowHeight=17
 VerticalScrollBarThumbHeight=17
 VerticalScrollBarWidth=17
 VirtualScreen=None
 WorkingArea=None

