class SecurityProtocolType(Enum,IComparable,IFormattable,IConvertible):
 """
 Specifies the security protocols that are supported by the Schannel security package.

 

 enum (flags) SecurityProtocolType,values: Ssl3 (48),SystemDefault (0),Tls (192),Tls11 (768),Tls12 (3072)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 Ssl3=None
 SystemDefault=None
 Tls=None
 Tls11=None
 Tls12=None
 value__=None

