class HttpListenerTimeoutManager(object):
 # no doc
 DrainEntityBody=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: DrainEntityBody(self: HttpListenerTimeoutManager) -> TimeSpan



Set: DrainEntityBody(self: HttpListenerTimeoutManager)=value

"""

 EntityBody=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: EntityBody(self: HttpListenerTimeoutManager) -> TimeSpan



Set: EntityBody(self: HttpListenerTimeoutManager)=value

"""

 HeaderWait=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: HeaderWait(self: HttpListenerTimeoutManager) -> TimeSpan



Set: HeaderWait(self: HttpListenerTimeoutManager)=value

"""

 IdleConnection=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: IdleConnection(self: HttpListenerTimeoutManager) -> TimeSpan



Set: IdleConnection(self: HttpListenerTimeoutManager)=value

"""

 MinSendBytesPerSecond=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: MinSendBytesPerSecond(self: HttpListenerTimeoutManager) -> Int64



Set: MinSendBytesPerSecond(self: HttpListenerTimeoutManager)=value

"""

 RequestQueue=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: RequestQueue(self: HttpListenerTimeoutManager) -> TimeSpan



Set: RequestQueue(self: HttpListenerTimeoutManager)=value

"""


