class HelpNavigator(Enum,IComparable,IFormattable,IConvertible):
 """
 Specifies constants indicating which elements of the Help file to display.

 

 enum HelpNavigator,values: AssociateIndex (-2147483643),Find (-2147483644),Index (-2147483645),KeywordIndex (-2147483642),TableOfContents (-2147483646),Topic (-2147483647),TopicId (-2147483641)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 AssociateIndex=None
 Find=None
 Index=None
 KeywordIndex=None
 TableOfContents=None
 Topic=None
 TopicId=None
 value__=None

