class Border3DStyle(Enum,IComparable,IFormattable,IConvertible):
 """
 Specifies the style of a three-dimensional border.

 

 enum Border3DStyle,values: Adjust (8192),Bump (9),Etched (6),Flat (16394),Raised (5),RaisedInner (4),RaisedOuter (1),Sunken (10),SunkenInner (8),SunkenOuter (2)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 Adjust=None
 Bump=None
 Etched=None
 Flat=None
 Raised=None
 RaisedInner=None
 RaisedOuter=None
 Sunken=None
 SunkenInner=None
 SunkenOuter=None
 value__=None

