class MTAThreadAttribute(Attribute,_Attribute):
 """
 Indicates that the COM threading model for an application is multithreaded apartment (MTA).

 

 MTAThreadAttribute()
 """
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
