class DefaultDllImportSearchPathsAttribute(Attribute,_Attribute):
 """ DefaultDllImportSearchPathsAttribute(paths: DllImportSearchPath) """
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 @staticmethod
 def __new__(self,paths):
  """ __new__(cls: type,paths: DllImportSearchPath) """
  pass
 Paths=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: Paths(self: DefaultDllImportSearchPathsAttribute) -> DllImportSearchPath



"""


