class KnownColor(Enum,IComparable,IFormattable,IConvertible):
 """
 Specifies the known system colors.

 

 enum KnownColor,values: ActiveBorder (1),ActiveCaption (2),ActiveCaptionText (3),AliceBlue (28),AntiqueWhite (29),AppWorkspace (4),Aqua (30),Aquamarine (31),Azure (32),Beige (33),Bisque (34),Black (35),BlanchedAlmond (36),Blue (37),BlueViolet (38),Brown (39),BurlyWood (40),ButtonFace (168),ButtonHighlight (169),ButtonShadow (170),CadetBlue (41),Chartreuse (42),Chocolate (43),Control (5),ControlDark (6),ControlDarkDark (7),ControlLight (8),ControlLightLight (9),ControlText (10),Coral (44),CornflowerBlue (45),Cornsilk (46),Crimson (47),Cyan (48),DarkBlue (49),DarkCyan (50),DarkGoldenrod (51),DarkGray (52),DarkGreen (53),DarkKhaki (54),DarkMagenta (55),DarkOliveGreen (56),DarkOrange (57),DarkOrchid (58),DarkRed (59),DarkSalmon (60),DarkSeaGreen (61),DarkSlateBlue (62),DarkSlateGray (63),DarkTurquoise (64),DarkViolet (65),DeepPink (66),DeepSkyBlue (67),Desktop (11),DimGray (68),DodgerBlue (69),Firebrick (70),FloralWhite (71),ForestGreen (72),Fuchsia (73),Gainsboro (74),GhostWhite (75),Gold (76),Goldenrod (77),GradientActiveCaption (171),GradientInactiveCaption (172),Gray (78),GrayText (12),Green (79),GreenYellow (80),Highlight (13),HighlightText (14),Honeydew (81),HotPink (82),HotTrack (15),InactiveBorder (16),InactiveCaption (17),InactiveCaptionText (18),IndianRed (83),Indigo (84),Info (19),InfoText (20),Ivory (85),Khaki (86),Lavender (87),LavenderBlush (88),LawnGreen (89),LemonChiffon (90),LightBlue (91),LightCoral (92),LightCyan (93),LightGoldenrodYellow (94),LightGray (95),LightGreen (96),LightPink (97),LightSalmon (98),LightSeaGreen (99),LightSkyBlue (100),LightSlateGray (101),LightSteelBlue (102),LightYellow (103),Lime (104),LimeGreen (105),Linen (106),Magenta (107),Maroon (108),MediumAquamarine (109),MediumBlue (110),MediumOrchid (111),MediumPurple (112),MediumSeaGreen (113),MediumSlateBlue (114),MediumSpringGreen (115),MediumTurquoise (116),MediumVioletRed (117),Menu (21),MenuBar (173),MenuHighlight (174),MenuText (22),MidnightBlue (118),MintCream (119),MistyRose (120),Moccasin (121),NavajoWhite (122),Navy (123),OldLace (124),Olive (125),OliveDrab (126),Orange (127),OrangeRed (128),Orchid (129),PaleGoldenrod (130),PaleGreen (131),PaleTurquoise (132),PaleVioletRed (133),PapayaWhip (134),PeachPuff (135),Peru (136),Pink (137),Plum (138),PowderBlue (139),Purple (140),Red (141),RosyBrown (142),RoyalBlue (143),SaddleBrown (144),Salmon (145),SandyBrown (146),ScrollBar (23),SeaGreen (147),SeaShell (148),Sienna (149),Silver (150),SkyBlue (151),SlateBlue (152),SlateGray (153),Snow (154),SpringGreen (155),SteelBlue (156),Tan (157),Teal (158),Thistle (159),Tomato (160),Transparent (27),Turquoise (161),Violet (162),Wheat (163),White (164),WhiteSmoke (165),Window (24),WindowFrame (25),WindowText (26),Yellow (166),YellowGreen (167)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 ActiveBorder=None
 ActiveCaption=None
 ActiveCaptionText=None
 AliceBlue=None
 AntiqueWhite=None
 AppWorkspace=None
 Aqua=None
 Aquamarine=None
 Azure=None
 Beige=None
 Bisque=None
 Black=None
 BlanchedAlmond=None
 Blue=None
 BlueViolet=None
 Brown=None
 BurlyWood=None
 ButtonFace=None
 ButtonHighlight=None
 ButtonShadow=None
 CadetBlue=None
 Chartreuse=None
 Chocolate=None
 Control=None
 ControlDark=None
 ControlDarkDark=None
 ControlLight=None
 ControlLightLight=None
 ControlText=None
 Coral=None
 CornflowerBlue=None
 Cornsilk=None
 Crimson=None
 Cyan=None
 DarkBlue=None
 DarkCyan=None
 DarkGoldenrod=None
 DarkGray=None
 DarkGreen=None
 DarkKhaki=None
 DarkMagenta=None
 DarkOliveGreen=None
 DarkOrange=None
 DarkOrchid=None
 DarkRed=None
 DarkSalmon=None
 DarkSeaGreen=None
 DarkSlateBlue=None
 DarkSlateGray=None
 DarkTurquoise=None
 DarkViolet=None
 DeepPink=None
 DeepSkyBlue=None
 Desktop=None
 DimGray=None
 DodgerBlue=None
 Firebrick=None
 FloralWhite=None
 ForestGreen=None
 Fuchsia=None
 Gainsboro=None
 GhostWhite=None
 Gold=None
 Goldenrod=None
 GradientActiveCaption=None
 GradientInactiveCaption=None
 Gray=None
 GrayText=None
 Green=None
 GreenYellow=None
 Highlight=None
 HighlightText=None
 Honeydew=None
 HotPink=None
 HotTrack=None
 InactiveBorder=None
 InactiveCaption=None
 InactiveCaptionText=None
 IndianRed=None
 Indigo=None
 Info=None
 InfoText=None
 Ivory=None
 Khaki=None
 Lavender=None
 LavenderBlush=None
 LawnGreen=None
 LemonChiffon=None
 LightBlue=None
 LightCoral=None
 LightCyan=None
 LightGoldenrodYellow=None
 LightGray=None
 LightGreen=None
 LightPink=None
 LightSalmon=None
 LightSeaGreen=None
 LightSkyBlue=None
 LightSlateGray=None
 LightSteelBlue=None
 LightYellow=None
 Lime=None
 LimeGreen=None
 Linen=None
 Magenta=None
 Maroon=None
 MediumAquamarine=None
 MediumBlue=None
 MediumOrchid=None
 MediumPurple=None
 MediumSeaGreen=None
 MediumSlateBlue=None
 MediumSpringGreen=None
 MediumTurquoise=None
 MediumVioletRed=None
 Menu=None
 MenuBar=None
 MenuHighlight=None
 MenuText=None
 MidnightBlue=None
 MintCream=None
 MistyRose=None
 Moccasin=None
 NavajoWhite=None
 Navy=None
 OldLace=None
 Olive=None
 OliveDrab=None
 Orange=None
 OrangeRed=None
 Orchid=None
 PaleGoldenrod=None
 PaleGreen=None
 PaleTurquoise=None
 PaleVioletRed=None
 PapayaWhip=None
 PeachPuff=None
 Peru=None
 Pink=None
 Plum=None
 PowderBlue=None
 Purple=None
 Red=None
 RosyBrown=None
 RoyalBlue=None
 SaddleBrown=None
 Salmon=None
 SandyBrown=None
 ScrollBar=None
 SeaGreen=None
 SeaShell=None
 Sienna=None
 Silver=None
 SkyBlue=None
 SlateBlue=None
 SlateGray=None
 Snow=None
 SpringGreen=None
 SteelBlue=None
 Tan=None
 Teal=None
 Thistle=None
 Tomato=None
 Transparent=None
 Turquoise=None
 value__=None
 Violet=None
 Wheat=None
 White=None
 WhiteSmoke=None
 Window=None
 WindowFrame=None
 WindowText=None
 Yellow=None
 YellowGreen=None

