class TypeLibFuncFlags(Enum,IComparable,IFormattable,IConvertible):
 """
 Describes the original settings of the FUNCFLAGS in the COM type library from where this method was imported.

 

 enum (flags) TypeLibFuncFlags,values: FBindable (4),FDefaultBind (32),FDefaultCollelem (256),FDisplayBind (16),FHidden (64),FImmediateBind (4096),FNonBrowsable (1024),FReplaceable (2048),FRequestEdit (8),FRestricted (1),FSource (2),FUiDefault (512),FUsesGetLastError (128)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 FBindable=None
 FDefaultBind=None
 FDefaultCollelem=None
 FDisplayBind=None
 FHidden=None
 FImmediateBind=None
 FNonBrowsable=None
 FReplaceable=None
 FRequestEdit=None
 FRestricted=None
 FSource=None
 FUiDefault=None
 FUsesGetLastError=None
 value__=None

