class TYPEATTR(object):
 """ Use System.Runtime.InteropServices.ComTypes.TYPEATTR instead. """
 cbAlignment=None
 cbSizeInstance=None
 cbSizeVft=None
 cFuncs=None
 cImplTypes=None
 cVars=None
 dwReserved=None
 guid=None
 idldescType=None
 lcid=None
 lpstrSchema=None
 MEMBER_ID_NIL=-1
 memidConstructor=None
 memidDestructor=None
 tdescAlias=None
 typekind=None
 wMajorVerNum=None
 wMinorVerNum=None
 wTypeFlags=None

