class TransportType(Enum,IComparable,IFormattable,IConvertible):
 """
 Defines transport types for the System.Net.SocketPermission and System.Net.Sockets.Socket classes.

 

 enum TransportType,values: All (3),Connectionless (1),ConnectionOriented (2),Tcp (2),Udp (1)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 All=None
 Connectionless=None
 ConnectionOriented=None
 Tcp=None
 Udp=None
 value__=None

