class Cursors(object):
 """ Provides a collection of System.Windows.Forms.Cursor objects for use by a Windows Forms application. """
 AppStarting=None
 Arrow=None
 Cross=None
 Default=None
 Hand=None
 Help=None
 HSplit=None
 IBeam=None
 No=None
 NoMove2D=None
 NoMoveHoriz=None
 NoMoveVert=None
 PanEast=None
 PanNE=None
 PanNorth=None
 PanNW=None
 PanSE=None
 PanSouth=None
 PanSW=None
 PanWest=None
 SizeAll=None
 SizeNESW=None
 SizeNS=None
 SizeNWSE=None
 SizeWE=None
 UpArrow=None
 VSplit=None
 WaitCursor=None

