class MaskedTextResultHint(Enum,IComparable,IFormattable,IConvertible):
 """
 Specifies values that succinctly describe the results of a masked text parsing operation.

 

 enum MaskedTextResultHint,values: AlphanumericCharacterExpected (-2),AsciiCharacterExpected (-1),CharacterEscaped (1),DigitExpected (-3),InvalidInput (-51),LetterExpected (-4),NoEffect (2),NonEditPosition (-54),PositionOutOfRange (-55),PromptCharNotAllowed (-52),SideEffect (3),SignedDigitExpected (-5),Success (4),UnavailableEditPosition (-53),Unknown (0)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 AlphanumericCharacterExpected=None
 AsciiCharacterExpected=None
 CharacterEscaped=None
 DigitExpected=None
 InvalidInput=None
 LetterExpected=None
 NoEffect=None
 NonEditPosition=None
 PositionOutOfRange=None
 PromptCharNotAllowed=None
 SideEffect=None
 SignedDigitExpected=None
 Success=None
 UnavailableEditPosition=None
 Unknown=None
 value__=None

