class DataGridViewCellStyleScopes(Enum,IComparable,IFormattable,IConvertible):
 """
 Specifies the System.Windows.Forms.DataGridView entity that owns the cell style that was changed.

 

 enum (flags) DataGridViewCellStyleScopes,values: AlternatingRows (128),Cell (1),Column (2),ColumnHeaders (16),DataGridView (8),None (0),Row (4),RowHeaders (32),Rows (64)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 AlternatingRows=None
 Cell=None
 Column=None
 ColumnHeaders=None
 DataGridView=None
 None=None
 Row=None
 RowHeaders=None
 Rows=None
 value__=None

