class HttpResponseHeader(Enum,IComparable,IFormattable,IConvertible):
 """
 The HTTP headers that can be specified in a server response.

 

 enum HttpResponseHeader,values: AcceptRanges (20),Age (21),Allow (10),CacheControl (0),Connection (1),ContentEncoding (13),ContentLanguage (14),ContentLength (11),ContentLocation (15),ContentMd5 (16),ContentRange (17),ContentType (12),Date (2),ETag (22),Expires (18),KeepAlive (3),LastModified (19),Location (23),Pragma (4),ProxyAuthenticate (24),RetryAfter (25),Server (26),SetCookie (27),Trailer (5),TransferEncoding (6),Upgrade (7),Vary (28),Via (8),Warning (9),WwwAuthenticate (29)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 AcceptRanges=None
 Age=None
 Allow=None
 CacheControl=None
 Connection=None
 ContentEncoding=None
 ContentLanguage=None
 ContentLength=None
 ContentLocation=None
 ContentMd5=None
 ContentRange=None
 ContentType=None
 Date=None
 ETag=None
 Expires=None
 KeepAlive=None
 LastModified=None
 Location=None
 Pragma=None
 ProxyAuthenticate=None
 RetryAfter=None
 Server=None
 SetCookie=None
 Trailer=None
 TransferEncoding=None
 Upgrade=None
 value__=None
 Vary=None
 Via=None
 Warning=None
 WwwAuthenticate=None

