class DrawItemState(Enum,IComparable,IFormattable,IConvertible):
 """
 Specifies the state of an item that is being drawn.

 

 enum (flags) DrawItemState,values: Checked (8),ComboBoxEdit (4096),Default (32),Disabled (4),Focus (16),Grayed (2),HotLight (64),Inactive (128),NoAccelerator (256),NoFocusRect (512),None (0),Selected (1)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 Checked=None
 ComboBoxEdit=None
 Default=None
 Disabled=None
 Focus=None
 Grayed=None
 HotLight=None
 Inactive=None
 NoAccelerator=None
 NoFocusRect=None
 None=None
 Selected=None
 value__=None

