class DataGridViewDataErrorContexts(Enum,IComparable,IFormattable,IConvertible):
 """
 Represents the state of a data-bound System.Windows.Forms.DataGridView control when a data error occurred.

 

 enum (flags) DataGridViewDataErrorContexts,values: ClipboardContent (16384),Commit (512),CurrentCellChange (4096),Display (2),Formatting (1),InitialValueRestoration (1024),LeaveControl (2048),Parsing (256),PreferredSize (4),RowDeletion (8),Scroll (8192)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 ClipboardContent=None
 Commit=None
 CurrentCellChange=None
 Display=None
 Formatting=None
 InitialValueRestoration=None
 LeaveControl=None
 Parsing=None
 PreferredSize=None
 RowDeletion=None
 Scroll=None
 value__=None

