class NotifyDataErrorValidationRule(ValidationRule):
 """ NotifyDataErrorValidationRule() """
 def Validate(self,value,cultureInfo,owner=None):
  """ Validate(self: NotifyDataErrorValidationRule,value: object,cultureInfo: CultureInfo) -> ValidationResult """
  pass
