class ControlFlags(Enum,IComparable,IFormattable,IConvertible):
 """
 These flags affect the security descriptor behavior.

 

 enum (flags) ControlFlags,values: DiscretionaryAclAutoInherited (1024),DiscretionaryAclAutoInheritRequired (256),DiscretionaryAclDefaulted (8),DiscretionaryAclPresent (4),DiscretionaryAclProtected (4096),DiscretionaryAclUntrusted (64),GroupDefaulted (2),None (0),OwnerDefaulted (1),RMControlValid (16384),SelfRelative (32768),ServerSecurity (128),SystemAclAutoInherited (2048),SystemAclAutoInheritRequired (512),SystemAclDefaulted (32),SystemAclPresent (16),SystemAclProtected (8192)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 DiscretionaryAclAutoInherited=None
 DiscretionaryAclAutoInheritRequired=None
 DiscretionaryAclDefaulted=None
 DiscretionaryAclPresent=None
 DiscretionaryAclProtected=None
 DiscretionaryAclUntrusted=None
 GroupDefaulted=None
 None=None
 OwnerDefaulted=None
 RMControlValid=None
 SelfRelative=None
 ServerSecurity=None
 SystemAclAutoInherited=None
 SystemAclAutoInheritRequired=None
 SystemAclDefaulted=None
 SystemAclPresent=None
 SystemAclProtected=None
 value__=None

