class FileMode(Enum,IComparable,IFormattable,IConvertible):
 """
 Specifies how the operating system should open a file.

 

 enum FileMode,values: Append (6),Create (2),CreateNew (1),Open (3),OpenOrCreate (4),Truncate (5)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 Append=None
 Create=None
 CreateNew=None
 Open=None
 OpenOrCreate=None
 Truncate=None
 value__=None

