class DataGridSortingEventArgs(DataGridColumnEventArgs):
 """
 Provides data for the System.Windows.Controls.DataGrid.Sorting event.

 

 DataGridSortingEventArgs(column: DataGridColumn)
 """
 @staticmethod
 def __new__(self,column):
  """ __new__(cls: type,column: DataGridColumn) """
  pass
 Handled=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a value that specifies whether the routed event is handled.



Get: Handled(self: DataGridSortingEventArgs) -> bool



Set: Handled(self: DataGridSortingEventArgs)=value

"""


