class IFileReaderService:
 """ Defines a method that opens a file from the current directory. """
 def OpenFileFromSource(self,relativePath):
  """
  OpenFileFromSource(self: IFileReaderService,relativePath: str) -> Stream

  

   Opens a file from the current directory.

  

   relativePath: The file to open.

   Returns: A stream of the specified file.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
