class InkCanvasStrokeErasingEventArgs(CancelEventArgs):
 """ Provides data for the System.Windows.Controls.InkCanvas.StrokeErasing event. """
 Stroke=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the stroke that is about to be erased.



Get: Stroke(self: InkCanvasStrokeErasingEventArgs) -> Stroke



"""


