class AmbientProperties(object):
 """
 Provides ambient property values to top-level controls.

 

 AmbientProperties()
 """
 BackColor=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the ambient background color of an object.



Get: BackColor(self: AmbientProperties) -> Color



Set: BackColor(self: AmbientProperties)=value

"""

 Cursor=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the ambient cursor of an object.



Get: Cursor(self: AmbientProperties) -> Cursor



Set: Cursor(self: AmbientProperties)=value

"""

 Font=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the ambient font of an object.



Get: Font(self: AmbientProperties) -> Font



Set: Font(self: AmbientProperties)=value

"""

 ForeColor=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the ambient foreground color of an object.



Get: ForeColor(self: AmbientProperties) -> Color



Set: ForeColor(self: AmbientProperties)=value

"""


