from typing import Tuple, Set, Iterable, List


class SteelElementProperties(APIObject):
    @property
    def UniqueID(self) -> Guid: ...
    @property
    def IsValidObject(self) -> bool: ...
    def GetSteelElementProperties(pElement: Element) -> SteelElementProperties: ...
    def GetFabricationUniqueID(aDoc: Document, reference: Reference) -> Guid: ...
    def GetReference(aDoc: Document, guid: Guid) -> Reference: ...
    def AddFabricationInformationForRevitElements(aDoc: Document, elementIds: List[ElementId]) -> List[ElementId]: ...
