class CALLCONV(Enum,IComparable,IFormattable,IConvertible):
 """
 Use System.Runtime.InteropServices.ComTypes.CALLCONV instead.

 

 enum CALLCONV,values: CC_CDECL (1),CC_MACPASCAL (3),CC_MAX (9),CC_MPWCDECL (7),CC_MPWPASCAL (8),CC_MSCPASCAL (2),CC_PASCAL (2),CC_RESERVED (5),CC_STDCALL (4),CC_SYSCALL (6)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 CC_CDECL=None
 CC_MACPASCAL=None
 CC_MAX=None
 CC_MPWCDECL=None
 CC_MPWPASCAL=None
 CC_MSCPASCAL=None
 CC_PASCAL=None
 CC_RESERVED=None
 CC_STDCALL=None
 CC_SYSCALL=None
 value__=None

