class IEasingFunction:
 """ Defines the basic functionality of an easing function. """
 def Ease(self,normalizedTime):
  """
  Ease(self: IEasingFunction,normalizedTime: float) -> float

  

   Transforms normalized time to control the pace of an animation.

  

   normalizedTime: Normalized time (progress) of the animation.

   Returns: The transformed progress.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
