from typing import Tuple, Set, Iterable, List


class PolymeshFacet:
    def __init__(self, v1: int, v2: int, v3: int): ...
    @property
    def V1(self) -> int: ...
    @property
    def V2(self) -> int: ...
    @property
    def V3(self) -> int: ...
    def GetVertices(self) -> List[int]: ...
    @property
    def IsValidObject(self) -> bool: ...
    def ToString(self) -> str: ...


class APIObject:
    @property
    def IsReadOnly(self) -> bool: ...
    def Dispose(self) -> None: ...


class ElementId:
    @overload
    def __init__(self, parameterId: BuiltInParameter): ...
    @overload
    def __init__(self, categoryId: BuiltInCategory): ...
    @overload
    def __init__(self, id: int): ...
    @property
    def IntegerValue(self) -> int: ...
    def ToString(self) -> str: ...
    def Equals(self, obj: Object) -> bool: ...
    def GetHashCode(self) -> int: ...
    @property
    def InvalidElementId() -> ElementId: ...
    def Compare(self, id: ElementId) -> int: ...
    def op_Equality(first: ElementId, second: ElementId) -> bool: ...
    def op_Inequality(first: ElementId, second: ElementId) -> bool: ...
    def op_LessThan(elementId1: ElementId, elementId2: ElementId) -> bool: ...
    def op_GreaterThan(elementId1: ElementId, elementId2: ElementId) -> bool: ...
    def op_LessThanOrEqual(elementId1: ElementId, elementId2: ElementId) -> bool: ...
    def op_GreaterThanOrEqual(elementId1: ElementId, elementId2: ElementId) -> bool: ...


class Element:
    @property
    def Name(self) -> str: ...
    @Name.setter
    def Name(self, name: str) -> None: ...
    @property
    def Category(self) -> Category: ...
    @property
    def Parameter(self, parameterId: BuiltInParameter) -> Parameter: ...
    @property
    def Parameter(self, definition: Definition) -> Parameter: ...
    @property
    def Parameter(self, guid: Guid) -> Parameter: ...
    @property
    def Parameters(self) -> ParameterSet: ...
    @property
    def ParametersMap(self) -> ParameterMap: ...
    @property
    def Location(self) -> Location: ...
    @property
    def Document(self) -> Document: ...
    @property
    def DesignOption(self) -> DesignOption: ...
    @property
    def Geometry(self, options: Options) -> GeometryElement: ...
    @property
    def BoundingBox(self, A_0: View) -> BoundingBoxXYZ: ...
    def IsHidden(self, pView: View) -> bool: ...
    def CanBeHidden(self, pView: View) -> bool: ...
    @overload
    def GetChangeTypeParameter(parameterId: ElementId) -> ChangeType: ...
    @overload
    def GetChangeTypeParameter(param: Parameter) -> ChangeType: ...
    def GetOrderedParameters(self) -> List[Parameter]: ...
    def GetParameters(self, name: str) -> List[Parameter]: ...
    def LookupParameter(self, name: str) -> Parameter: ...
    @property
    def Pinned(self) -> bool: ...
    @Pinned.setter
    def Pinned(self, lock: bool) -> None: ...
    @property
    def WorksetId(self) -> WorksetId: ...
    @property
    def VersionGuid(self) -> Guid: ...
    @property
    def GroupId(self) -> ElementId: ...
    @property
    def Id(self) -> ElementId: ...
    @property
    def IsTransient(self) -> bool: ...
    @property
    def UniqueId(self) -> str: ...
    @property
    def LevelId(self) -> ElementId: ...
    @property
    def AssemblyInstanceId(self) -> ElementId: ...
    @property
    def ViewSpecific(self) -> bool: ...
    @property
    def OwnerViewId(self) -> ElementId: ...
    @property
    def CreatedPhaseId(self) -> ElementId: ...
    @CreatedPhaseId.setter
    def CreatedPhaseId(self, createdPhaseId: ElementId) -> None: ...
    @property
    def DemolishedPhaseId(self) -> ElementId: ...
    @DemolishedPhaseId.setter
    def DemolishedPhaseId(self, demolishedPhaseId: ElementId) -> None: ...
    @property
    def IsValidObject(self) -> bool: ...
    def CanBeLocked(self) -> bool: ...
    def GetPhaseStatus(self, phaseId: ElementId) -> ElementOnPhaseStatus: ...
    def GetTypeId(self) -> ElementId: ...
    def GetGeneratingElementIds(self, geometryObject: GeometryObject) -> ICollection: ...
    @overload
    def CanHaveTypeAssigned(document: Document, elementIds: ICollection) -> bool: ...
    @overload
    def CanHaveTypeAssigned(self) -> bool: ...
    @overload
    def IsValidType(document: Document, elementIds: ICollection, typeId: ElementId) -> bool: ...
    @overload
    def IsValidType(self, typeId: ElementId) -> bool: ...
    @overload
    def GetValidTypes(document: Document, elementIds: ICollection) -> ICollection: ...
    @overload
    def GetValidTypes(self) -> ICollection: ...
    @overload
    def ChangeTypeId(document: Document, elementIds: ICollection, typeId: ElementId) -> IDictionary: ...
    @overload
    def ChangeTypeId(self, typeId: ElementId) -> ElementId: ...
    def GetSubelements(self) -> List[Subelement]: ...
    def DeleteSubelement(self, subelem: Subelement) -> bool: ...
    def DeleteSubelements(self, subelems: List[Subelement]) -> bool: ...
    def CanDeleteSubelement(self, subelem: Subelement) -> bool: ...
    def GetDependentElements(self, filter: ElementFilter) -> List[ElementId]: ...
    def GetGeometryObjectFromReference(self, reference: Reference) -> GeometryObject: ...
    def IsExternalFileReference(self) -> bool: ...
    def GetExternalFileReference(self) -> ExternalFileReference: ...
    def RefersToExternalResourceReferences(self) -> bool: ...
    def GetExternalResourceReferences(self) -> IDictionary: ...
    def RefersToExternalResourceReference(self, resourceType: ExternalResourceType) -> bool: ...
    def GetExternalResourceReference(self, resourceType: ExternalResourceType) -> ExternalResourceReference: ...
    def GetMaterialIds(self, returnPaintMaterials: bool) -> ICollection: ...
    def GetMaterialArea(self, materialId: ElementId, usePaintMaterial: bool) -> float: ...
    def GetMaterialVolume(self, materialId: ElementId) -> float: ...
    def GetParameterFormatOptions(self, parameterId: ElementId) -> FormatOptions: ...
    def GetChangeTypeElementDeletion() -> ChangeType: ...
    def GetChangeTypeElementAddition() -> ChangeType: ...
    def GetChangeTypeGeometry() -> ChangeType: ...
    def GetChangeTypeAny() -> ChangeType: ...
    def CanHaveAnalyticalModel(self) -> bool: ...
    def GetAnalyticalModel(self) -> AnalyticalModel: ...
    def GetAnalyticalModelId(self) -> ElementId: ...
    def IsMonitoringLinkElement(self) -> bool: ...
    def IsMonitoringLocalElement(self) -> bool: ...
    def GetMonitoredLinkElementIds(self) -> List[ElementId]: ...
    def GetMonitoredLocalElementIds(self) -> List[ElementId]: ...
    def HasPhases(self) -> bool: ...
    def ArePhasesModifiable(self) -> bool: ...
    def IsPhaseCreatedValid(self, createdPhaseId: ElementId) -> bool: ...
    def IsPhaseDemolishedValid(self, demolishedPhaseId: ElementId) -> bool: ...
    def GetEntitySchemaGuids(self) -> List[Guid]: ...
    def GetEntity(self, schema: Schema) -> Entity: ...
    def SetEntity(self, entity: Entity) -> None: ...
    def DeleteEntity(self, schema: Schema) -> bool: ...
    def Dispose(self) -> None: ...


class WorksetPreview:
    @property
    def Id(self) -> WorksetId: ...
    @property
    def UniqueId(self) -> Guid: ...
    @property
    def Name(self) -> str: ...
    @property
    def Owner(self) -> str: ...
    @property
    def IsDefaultWorkset(self) -> bool: ...
    @property
    def IsValidObject(self) -> bool: ...
    def Dispose(self) -> None: ...


class Workset(WorksetPreview):
    @property
    def Kind(self) -> WorksetKind: ...
    @property
    def IsOpen(self) -> bool: ...
    @property
    def IsEditable(self) -> bool: ...
    @property
    def IsVisibleByDefault(self) -> bool: ...
    def Create(document: Document, name: str) -> Workset: ...


class XYZ:
    @overload
    def __init__(self, x: float, y: float, z: float): ...
    @overload
    def __init__(self): ...
    @property
    def X(self) -> float: ...
    @property
    def Y(self) -> float: ...
    @property
    def Z(self) -> float: ...
    @property
    def Item(self, idx: int) -> float: ...
    @property
    def Zero() -> XYZ: ...
    @property
    def BasisX() -> XYZ: ...
    @property
    def BasisY() -> XYZ: ...
    @property
    def BasisZ() -> XYZ: ...
    def IsZeroLength(self) -> bool: ...
    def IsUnitLength(self) -> bool: ...
    def IsWithinLengthLimits(point: XYZ) -> bool: ...
    def Normalize(self) -> XYZ: ...
    def GetLength(self) -> float: ...
    def op_Addition(left: XYZ, right: XYZ) -> XYZ: ...
    def op_UnaryNegation(source: XYZ) -> XYZ: ...
    def op_Subtraction(left: XYZ, right: XYZ) -> XYZ: ...
    @overload
    def op_Multiply(left: XYZ, value: float) -> XYZ: ...
    @overload
    def op_Multiply(value: float, right: XYZ) -> XYZ: ...
    def op_Division(left: XYZ, value: float) -> XYZ: ...
    def DotProduct(self, source: XYZ) -> float: ...
    def CrossProduct(self, source: XYZ) -> XYZ: ...
    def TripleProduct(self, middle: XYZ, right: XYZ) -> float: ...
    def Add(self, source: XYZ) -> XYZ: ...
    def Subtract(self, source: XYZ) -> XYZ: ...
    def Negate(self) -> XYZ: ...
    def Multiply(self, value: float) -> XYZ: ...
    def Divide(self, value: float) -> XYZ: ...
    @overload
    def IsAlmostEqualTo(self, source: XYZ, tolerance: float) -> bool: ...
    @overload
    def IsAlmostEqualTo(self, source: XYZ) -> bool: ...
    def DistanceTo(self, source: XYZ) -> float: ...
    def AngleTo(self, source: XYZ) -> float: ...
    def AngleOnPlaneTo(self, right: XYZ, normal: XYZ) -> float: ...
    def ToString(self) -> str: ...


class UV:
    @overload
    def __init__(self, u: float, v: float): ...
    @overload
    def __init__(self): ...
    @property
    def U(self) -> float: ...
    @property
    def V(self) -> float: ...
    @property
    def Item(self, idx: int) -> float: ...
    @property
    def Zero() -> UV: ...
    @property
    def BasisU() -> UV: ...
    @property
    def BasisV() -> UV: ...
    def Normalize(self) -> UV: ...
    def GetLength(self) -> float: ...
    def IsZeroLength(self) -> bool: ...
    def IsUnitLength(self) -> bool: ...
    def op_Addition(left: UV, right: UV) -> UV: ...
    def op_UnaryNegation(source: UV) -> UV: ...
    def op_Subtraction(left: UV, right: UV) -> UV: ...
    @overload
    def op_Multiply(left: UV, value: float) -> UV: ...
    @overload
    def op_Multiply(value: float, right: UV) -> UV: ...
    def op_Division(left: UV, value: float) -> UV: ...
    def DotProduct(self, source: UV) -> float: ...
    def CrossProduct(self, source: UV) -> float: ...
    def Add(self, source: UV) -> UV: ...
    def Subtract(self, source: UV) -> UV: ...
    def Negate(self) -> UV: ...
    def Multiply(self, value: float) -> UV: ...
    def Divide(self, value: float) -> UV: ...
    @overload
    def IsAlmostEqualTo(self, source: UV, tolerance: float) -> bool: ...
    @overload
    def IsAlmostEqualTo(self, source: UV) -> bool: ...
    def DistanceTo(self, source: UV) -> float: ...
    def AngleTo(self, source: UV) -> float: ...
    def ToString(self) -> str: ...


class BoundingBoxUV:
    @overload
    def __init__(self, min_u: float, min_v: float, max_u: float, max_v: float): ...
    @overload
    def __init__(self): ...
    @property
    def IsSet(self) -> bool: ...
    @property
    def Min(self) -> UV: ...
    @Min.setter
    def Min(self, min: UV) -> None: ...
    @property
    def Max(self) -> UV: ...
    @Max.setter
    def Max(self, max: UV) -> None: ...
    @property
    def Bounds(self, idx: int) -> UV: ...
    def Dispose(self) -> None: ...


class BaseArray(Element):
    @property
    def NumMembers(self) -> int: ...
    @NumMembers.setter
    def NumMembers(self, value: int) -> None: ...
    def GetOriginalMemberIds(self) -> ICollection: ...
    def GetCopiedMemberIds(self) -> ICollection: ...
    @Name.setter
    def Name(self, name: str) -> None: ...
    @property
    def Label(self) -> FamilyParameter: ...
    @Label.setter
    def Label(self, familyParameter: FamilyParameter) -> None: ...


class View(Element):
    def SetFilterVisibility(self, filterElementId: ElementId, visibility: bool) -> None: ...
    def GetIsFilterEnabled(self, filterElementId: ElementId) -> bool: ...
    def SetIsFilterEnabled(self, filterElementId: ElementId, enable: bool) -> None: ...
    def IsFilterApplied(self, filterElementId: ElementId) -> bool: ...
    def AreGraphicsOverridesAllowed(self) -> bool: ...
    def GetElementOverrides(self, elementId: ElementId) -> OverrideGraphicSettings: ...
    def SetElementOverrides(self, elementId: ElementId, overrideGraphicSettings: OverrideGraphicSettings) -> None: ...
    def GetBackground(self) -> ViewDisplayBackground: ...
    def SetBackground(self, background: ViewDisplayBackground) -> None: ...
    def GetSketchyLines(self) -> ViewDisplaySketchyLines: ...
    def SetSketchyLines(self, sketchyLines: ViewDisplaySketchyLines) -> None: ...
    def GetDepthCueing(self) -> ViewDisplayDepthCueing: ...
    def SetDepthCueing(self, depthCueing: ViewDisplayDepthCueing) -> None: ...
    def GetViewDisplayModel(self) -> ViewDisplayModel: ...
    def SetViewDisplayModel(self, viewDisplayModel: ViewDisplayModel) -> None: ...
    def GetPointCloudOverrides(self) -> PointCloudOverrides: ...
    def GetDirectContext3DHandleOverrides(self) -> DirectContext3DHandleOverrides: ...
    def GetTemplateParameterIds(self) -> List[ElementId]: ...
    def GetNonControlledTemplateParameterIds(self) -> ICollection: ...
    def SetNonControlledTemplateParameterIds(self, newSet: ICollection) -> None: ...
    def ApplyViewTemplateParameters(self, otherView: View) -> None: ...
    def IsValidViewTemplate(self, templateId: ElementId) -> bool: ...
    def IsViewValidForTemplateCreation(self) -> bool: ...
    def CreateViewTemplate(self) -> View: ...
    @property
    def Outline(self) -> BoundingBoxUV: ...
    @property
    def ViewType(self) -> ViewType: ...
    @property
    def CropBox(self) -> BoundingBoxXYZ: ...
    @CropBox.setter
    def CropBox(self, cropBox: BoundingBoxXYZ) -> None: ...
    @property
    def Origin(self) -> XYZ: ...
    @property
    def Scale(self) -> int: ...
    @Scale.setter
    def Scale(self, scale: int) -> None: ...
    @property
    def ViewDirection(self) -> XYZ: ...
    @property
    def RightDirection(self) -> XYZ: ...
    @property
    def UpDirection(self) -> XYZ: ...
    @property
    def CanBePrinted(self) -> bool: ...
    @property
    def IsTemplate(self) -> bool: ...
    @overload
    def Print(self, viewTemplate: View) -> None: ...
    @overload
    def Print(self) -> None: ...
    @overload
    def Print(self, viewTemplate: View, useCurrentPrintSettings: bool) -> None: ...
    @overload
    def Print(self, useCurrentPrintSettings: bool) -> None: ...
    @property
    def GenLevel(self) -> Level: ...
    @property
    def CropBoxActive(self) -> bool: ...
    @CropBoxActive.setter
    def CropBoxActive(self, active: bool) -> None: ...
    @property
    def CropBoxVisible(self) -> bool: ...
    @CropBoxVisible.setter
    def CropBoxVisible(self, visible: bool) -> None: ...
    def HideElements(self, elementIdSet: ICollection) -> None: ...
    def UnhideElements(self, elementIdSet: ICollection) -> None: ...
    @property
    def SketchPlane(self) -> SketchPlane: ...
    @SketchPlane.setter
    def SketchPlane(self, sketchPlane: SketchPlane) -> None: ...
    @property
    def SunAndShadowSettings(self) -> SunAndShadowSettings: ...
    def ShowActiveWorkPlane(self) -> None: ...
    def HideActiveWorkPlane(self) -> None: ...
    @property
    def AssociatedAssemblyInstanceId(self) -> ElementId: ...
    @property
    def IsAssemblyView(self) -> bool: ...
    @property
    def Title(self) -> str: ...
    @property
    def PartsVisibility(self) -> PartsVisibility: ...
    @PartsVisibility.setter
    def PartsVisibility(self, partsVisibility: PartsVisibility) -> None: ...
    @property
    def DetailLevel(self) -> ViewDetailLevel: ...
    @DetailLevel.setter
    def DetailLevel(self, detailLevel: ViewDetailLevel) -> None: ...
    @property
    def AreModelCategoriesHidden(self) -> bool: ...
    @AreModelCategoriesHidden.setter
    def AreModelCategoriesHidden(self, hidden: bool) -> None: ...
    @property
    def AreAnnotationCategoriesHidden(self) -> bool: ...
    @AreAnnotationCategoriesHidden.setter
    def AreAnnotationCategoriesHidden(self, hidden: bool) -> None: ...
    @property
    def AreAnalyticalModelCategoriesHidden(self) -> bool: ...
    @AreAnalyticalModelCategoriesHidden.setter
    def AreAnalyticalModelCategoriesHidden(self, hidden: bool) -> None: ...
    @property
    def AreImportCategoriesHidden(self) -> bool: ...
    @AreImportCategoriesHidden.setter
    def AreImportCategoriesHidden(self, hidden: bool) -> None: ...
    @property
    def ArePointCloudsHidden(self) -> bool: ...
    @ArePointCloudsHidden.setter
    def ArePointCloudsHidden(self, hidden: bool) -> None: ...
    @property
    def AreCoordinationModelHandlesHidden(self) -> bool: ...
    @AreCoordinationModelHandlesHidden.setter
    def AreCoordinationModelHandlesHidden(self, hidden: bool) -> None: ...
    @property
    def AnalysisDisplayStyleId(self) -> ElementId: ...
    @AnalysisDisplayStyleId.setter
    def AnalysisDisplayStyleId(self, value: ElementId) -> None: ...
    @property
    def TemporaryViewModes(self) -> TemporaryViewModes: ...
    @property
    def RevealConstraintsMode(self) -> bool: ...
    @RevealConstraintsMode.setter
    def RevealConstraintsMode(self, revealConstraintsModeEnabled: bool) -> None: ...
    @property
    def DisplayStyle(self) -> DisplayStyle: ...
    @DisplayStyle.setter
    def DisplayStyle(self, displayStyle: DisplayStyle) -> None: ...
    @property
    def Discipline(self) -> ViewDiscipline: ...
    @Discipline.setter
    def Discipline(self, viewDiscipline: ViewDiscipline) -> None: ...
    @property
    def ShadowIntensity(self) -> int: ...
    @ShadowIntensity.setter
    def ShadowIntensity(self, intensity: int) -> None: ...
    @property
    def SunlightIntensity(self) -> int: ...
    @SunlightIntensity.setter
    def SunlightIntensity(self, intensity: int) -> None: ...
    @property
    def ViewTemplateId(self) -> ElementId: ...
    @ViewTemplateId.setter
    def ViewTemplateId(self, val: ElementId) -> None: ...
    def GetCropRegionShapeManager(self) -> ViewCropRegionShapeManager: ...
    def GetCropRegionShapeManagerForReferenceCallout(doc: Document, callout: ElementId) -> ViewCropRegionShapeManager: ...
    def GetReferenceCallouts(self) -> ICollection: ...
    def GetReferenceSections(self) -> ICollection: ...
    def GetReferenceElevations(self) -> ICollection: ...
    def Duplicate(self, duplicateOption: ViewDuplicateOption) -> ElementId: ...
    def ConvertToIndependent(self) -> None: ...
    def CanViewBeDuplicated(self, duplicateOption: ViewDuplicateOption) -> bool: ...
    def IsElementVisibleInTemporaryViewMode(self, mode: TemporaryViewMode, id: ElementId) -> bool: ...
    def GetWorksetVisibility(self, worksetId: WorksetId) -> WorksetVisibility: ...
    def SetWorksetVisibility(self, worksetId: WorksetId, visible: WorksetVisibility) -> None: ...
    def IsWorksetVisible(self, worksetId: WorksetId) -> bool: ...
    def IsInTemporaryViewMode(self, mode: TemporaryViewMode) -> bool: ...
    def DisableTemporaryViewMode(self, mode: TemporaryViewMode) -> None: ...
    def EnableRevealHiddenMode(self) -> None: ...
    def CanEnableTemporaryViewPropertiesMode(self) -> bool: ...
    def EnableTemporaryViewPropertiesMode(self, viewTemplateId: ElementId) -> bool: ...
    def GetTemporaryViewPropertiesId(self) -> ElementId: ...
    def IsTemporaryViewPropertiesModeEnabled(self) -> bool: ...
    def GetTemporaryViewPropertiesName(self) -> str: ...
    def HideElementTemporary(self, elementId: ElementId) -> None: ...
    def HideElementsTemporary(self, elementIdSet: ICollection) -> None: ...
    def CanCategoryBeHiddenTemporary(self, elementId: ElementId) -> bool: ...
    def HideCategoryTemporary(self, elementId: ElementId) -> None: ...
    def HideCategoriesTemporary(self, elementIds: ICollection) -> None: ...
    def IsolateElementsTemporary(self, elementIds: ICollection) -> None: ...
    def IsolateElementTemporary(self, elementId: ElementId) -> None: ...
    def IsolateCategoryTemporary(self, elementId: ElementId) -> None: ...
    def IsolateCategoriesTemporary(self, elementIds: ICollection) -> None: ...
    def CanCategoryBeHidden(self, elementId: ElementId) -> bool: ...
    def SetCategoryHidden(self, categoryId: ElementId, hide: bool) -> None: ...
    def GetCategoryHidden(self, categoryId: ElementId) -> bool: ...
    def ConvertTemporaryHideIsolateToPermanent(self) -> None: ...
    def IsTemporaryHideIsolateActive(self) -> bool: ...
    def SetWorksharingDisplayMode(self, displayMode: WorksharingDisplayMode) -> None: ...
    def GetWorksharingDisplayMode(self) -> WorksharingDisplayMode: ...
    def SupportsWorksharingDisplayMode(self, mode: WorksharingDisplayMode) -> bool: ...
    def CanModifyDetailLevel(self) -> bool: ...
    def HasDetailLevel(self) -> bool: ...
    def AllowsAnalysisDisplay(self) -> bool: ...
    def IsValidViewScale(viewScale: int) -> bool: ...
    def SupportsRevealConstraints(self) -> bool: ...
    def CanModifyDisplayStyle(self) -> bool: ...
    def HasDisplayStyle(self) -> bool: ...
    def CanUseDepthCueing(self) -> bool: ...
    def CanUseTemporaryVisibilityModes(self) -> bool: ...
    def HasViewDiscipline(self) -> bool: ...
    def CanModifyViewDiscipline(self) -> bool: ...
    def GetPrimaryViewId(self) -> ElementId: ...
    def GetDependentViewIds(self) -> ICollection: ...
    def SetCategoryOverrides(self, categoryId: ElementId, overrideGraphicSettings: OverrideGraphicSettings) -> None: ...
    def GetCategoryOverrides(self, categoryId: ElementId) -> OverrideGraphicSettings: ...
    def IsCategoryOverridable(self, categoryId: ElementId) -> bool: ...
    def GetFilters(self) -> ICollection: ...
    def GetOrderedFilters(self) -> List[ElementId]: ...
    def GetFilterOverrides(self, filterElementId: ElementId) -> OverrideGraphicSettings: ...
    def SetFilterOverrides(self, filterElementId: ElementId, overrideGraphicSettings: OverrideGraphicSettings) -> None: ...
    def AddFilter(self, filterElementId: ElementId) -> None: ...
    def RemoveFilter(self, filterElementId: ElementId) -> None: ...
    def GetFilterVisibility(self, filterElementId: ElementId) -> bool: ...


class Control(Element):
    @property
    def Shape(self) -> ControlShape: ...
    @property
    def Origin(self) -> XYZ: ...
    @property
    def View(self) -> View: ...


class Family(Element):
    @property
    def IsConceptualMassFamily(self) -> bool: ...
    @property
    def IsCurtainPanelFamily(self) -> bool: ...
    @property
    def CurtainPanelTilePattern(self) -> TilePatternsBuiltIn: ...
    @property
    def CurtainPanelHorizontalSpacing(self) -> float: ...
    @CurtainPanelHorizontalSpacing.setter
    def CurtainPanelHorizontalSpacing(self, A_0: float) -> None: ...
    @property
    def CurtainPanelVerticalSpacing(self) -> float: ...
    @CurtainPanelVerticalSpacing.setter
    def CurtainPanelVerticalSpacing(self, A_0: float) -> None: ...
    @property
    def ShowSpatialElementCalculationPoint(self) -> bool: ...
    @ShowSpatialElementCalculationPoint.setter
    def ShowSpatialElementCalculationPoint(self, A_0: bool) -> None: ...
    def ExtractPartAtom(self, xmlFilePath: str) -> None: ...
    @property
    def FamilyCategory(self) -> Category: ...
    @FamilyCategory.setter
    def FamilyCategory(self, category: Category) -> None: ...
    @property
    def IsInPlace(self) -> bool: ...
    @property
    def IsEditable(self) -> bool: ...
    @property
    def StructuralMaterialType(self) -> StructuralMaterialType: ...
    @property
    def StructuralSectionShape(self) -> StructuralSectionShape: ...
    @StructuralSectionShape.setter
    def StructuralSectionShape(self, shape: StructuralSectionShape) -> None: ...
    @property
    def StructuralFamilyNameKey(self) -> str: ...
    @StructuralFamilyNameKey.setter
    def StructuralFamilyNameKey(self, key: str) -> None: ...
    @property
    def StructuralCodeName(self) -> str: ...
    @StructuralCodeName.setter
    def StructuralCodeName(self, name: str) -> None: ...
    @property
    def FamilyCategoryId(self) -> ElementId: ...
    @FamilyCategoryId.setter
    def FamilyCategoryId(self, categoryId: ElementId) -> None: ...
    @property
    def IsOwnerFamily(self) -> bool: ...
    @property
    def FamilyPlacementType(self) -> FamilyPlacementType: ...
    @property
    def IsUserCreated(self) -> bool: ...
    @property
    def IsParametric(self) -> bool: ...
    def CanHaveStructuralSection(self) -> bool: ...
    def IsAppropriateCategoryId(self, categoryId: ElementId) -> bool: ...
    def GetFamilySymbolIds(self) -> ISet: ...
    def GetFamilyTypeParameterValues(self, parameterId: ElementId) -> ISet: ...
    def HasLargeSketches(self) -> bool: ...
    def CanLoadFamilies(document: Document) -> bool: ...


class Color(APIObject):
    def __init__(self, red: Byte, green: Byte, blue: Byte): ...
    @property
    def Red(self) -> Byte: ...
    @Red.setter
    def Red(self, red: Byte) -> None: ...
    @property
    def Green(self) -> Byte: ...
    @Green.setter
    def Green(self, green: Byte) -> None: ...
    @property
    def Blue(self) -> Byte: ...
    @Blue.setter
    def Blue(self, blue: Byte) -> None: ...
    @property
    def IsValid(self) -> bool: ...
    @property
    def InvalidColorValue() -> Color: ...


class ElementType(Element):
    @Name.setter
    def Name(self, name: str) -> None: ...
    def GetPreviewImage(self, size: Size) -> Bitmap: ...
    @property
    def CanBeCopied(self) -> bool: ...
    @property
    def CanBeRenamed(self) -> bool: ...
    @property
    def CanBeDeleted(self) -> bool: ...
    @property
    def FamilyName(self) -> str: ...
    def IsSimilarType(self, typeId: ElementId) -> bool: ...
    def GetSimilarTypes(self) -> ICollection: ...
    def Duplicate(self, name: str) -> ElementType: ...
    def IsValidDefaultFamilyType(self, familyCategoryId: ElementId) -> bool: ...


class MEPSystemType(ElementType):
    @property
    def Abbreviation(self) -> str: ...
    @Abbreviation.setter
    def Abbreviation(self, abbreviation: str) -> None: ...
    @property
    def SystemClassification(self) -> MEPSystemClassification: ...
    @property
    def LineWeight(self) -> int: ...
    @LineWeight.setter
    def LineWeight(self, lineWeight: int) -> None: ...
    @property
    def LineColor(self) -> Color: ...
    @LineColor.setter
    def LineColor(self, lineColor: Color) -> None: ...
    @property
    def LinePatternId(self) -> ElementId: ...
    @LinePatternId.setter
    def LinePatternId(self, linePatternId: ElementId) -> None: ...
    @property
    def FillColor(self) -> Color: ...
    @FillColor.setter
    def FillColor(self, lineColor: Color) -> None: ...
    @property
    def FillPatternId(self) -> ElementId: ...
    @FillPatternId.setter
    def FillPatternId(self, fillPatternId: ElementId) -> None: ...
    @property
    def FillVisible(self) -> bool: ...
    @FillVisible.setter
    def FillVisible(self, fillVisible: bool) -> None: ...
    @property
    def MaterialId(self) -> ElementId: ...
    @MaterialId.setter
    def MaterialId(self, materialId: ElementId) -> None: ...
    @property
    def CalculationLevel(self) -> SystemCalculationLevel: ...
    @CalculationLevel.setter
    def CalculationLevel(self, kLevel: SystemCalculationLevel) -> None: ...


class CombinableElement(Element):
    @property
    def Combinations(self) -> GeomCombinationSet: ...


class GenericForm(CombinableElement):
    @property
    def Visible(self) -> bool: ...
    @property
    def IsSolid(self) -> bool: ...
    @Name.setter
    def Name(self, name: str) -> None: ...
    def GetVisibility(self) -> FamilyElementVisibility: ...
    def SetVisibility(self, visibility: FamilyElementVisibility) -> None: ...
    @property
    def Subcategory(self) -> Category: ...
    @Subcategory.setter
    def Subcategory(self, subcategory: Category) -> None: ...


class Sweep(GenericForm):
    @property
    def ProfileSketch(self) -> Sketch: ...
    @property
    def ProfileSymbol(self) -> FamilySymbolProfile: ...
    @property
    def PathSketch(self) -> Sketch: ...
    @property
    def Path3d(self) -> Path3d: ...
    @property
    def IsTrajectorySegmentationEnabled(self) -> bool: ...
    @IsTrajectorySegmentationEnabled.setter
    def IsTrajectorySegmentationEnabled(self, enable: bool) -> None: ...
    @property
    def MaxSegmentAngle(self) -> float: ...
    @MaxSegmentAngle.setter
    def MaxSegmentAngle(self, maxSegAngle: float) -> None: ...


class ForgeTypeId:
    @overload
    def __init__(self, typeId: str): ...
    @overload
    def __init__(self): ...
    def Equals(self, other: Object) -> bool: ...
    def op_Equality(lhs: ForgeTypeId, rhs: ForgeTypeId) -> bool: ...
    def GetHashCode(self) -> int: ...
    @property
    def TypeId(self) -> str: ...
    @TypeId.setter
    def TypeId(self, typeId: str) -> None: ...
    @property
    def IsValidObject(self) -> bool: ...
    def Empty(self) -> bool: ...
    def Clear(self) -> ForgeTypeId: ...
    def NameEquals(self, other: ForgeTypeId) -> bool: ...
    def StrictlyEquals(self, other: ForgeTypeId) -> bool: ...
    def Dispose(self) -> None: ...


class FamilyParameter(APIObject):
    @property
    def Definition(self) -> Definition: ...
    @property
    def StorageType(self) -> StorageType: ...
    @property
    def IsInstance(self) -> bool: ...
    @property
    def IsReporting(self) -> bool: ...
    @property
    def IsDeterminedByFormula(self) -> bool: ...
    @property
    def CanAssignFormula(self) -> bool: ...
    @property
    def Formula(self) -> str: ...
    @property
    def DisplayUnitType(self) -> DisplayUnitType: ...
    def GetUnitTypeId(self) -> ForgeTypeId: ...
    @property
    def AssociatedParameters(self) -> ParameterSet: ...
    @property
    def Id(self) -> ElementId: ...
    @property
    def GUID(self) -> Guid: ...
    @property
    def IsShared(self) -> bool: ...
    @property
    def IsReadOnly(self) -> bool: ...
    @property
    def UserModifiable(self) -> bool: ...


class FamilyParameterSet(APIObject):
    def __init__(self): ...
    def Clear(self) -> None: ...
    @property
    def Size(self) -> int: ...
    @property
    def IsEmpty(self) -> bool: ...
    def ForwardIterator(self) -> FamilyParameterSetIterator: ...
    def ReverseIterator(self) -> FamilyParameterSetIterator: ...
    def GetEnumerator(self) -> IEnumerator: ...
    def Contains(self, item: FamilyParameter) -> bool: ...
    def Insert(self, item: FamilyParameter) -> bool: ...
    def Erase(self, item: FamilyParameter) -> int: ...


class FamilyParameterSetIterator(APIObject):
    def __init__(self): ...
    @property
    def Current(self) -> Object: ...
    def MoveNext(self) -> bool: ...
    def Reset(self) -> None: ...


class PrintSetup(APIObject):
    @property
    def CurrentPrintSetting(self) -> IPrintSetting: ...
    @CurrentPrintSetting.setter
    def CurrentPrintSetting(self, pps: IPrintSetting) -> None: ...
    @property
    def InSession(self) -> InSessionPrintSetting: ...
    def Save(self) -> bool: ...
    def SaveAs(self, newName: str) -> bool: ...
    def Rename(self, newName: str) -> bool: ...
    def Delete(self) -> bool: ...
    def Revert(self) -> None: ...


class PrintManager(APIObject):
    @property
    def PrinterName(self) -> str: ...
    @property
    def PrintSetup(self) -> PrintSetup: ...
    @property
    def ViewSheetSetting(self) -> ViewSheetSetting: ...
    @property
    def PrintToFile(self) -> bool: ...
    @PrintToFile.setter
    def PrintToFile(self, bPrntToFile: bool) -> None: ...
    @property
    def CombinedFile(self) -> bool: ...
    @CombinedFile.setter
    def CombinedFile(self, isCombinedFile: bool) -> None: ...
    @property
    def PrintToFileName(self) -> str: ...
    @PrintToFileName.setter
    def PrintToFileName(self, fileName: str) -> None: ...
    @property
    def PrintRange(self) -> PrintRange: ...
    @PrintRange.setter
    def PrintRange(self, pr: PrintRange) -> None: ...
    @property
    def CopyNumber(self) -> int: ...
    @CopyNumber.setter
    def CopyNumber(self, cn: int) -> None: ...
    @property
    def PrintOrderReverse(self) -> bool: ...
    @PrintOrderReverse.setter
    def PrintOrderReverse(self, por: bool) -> None: ...
    @property
    def Collate(self) -> bool: ...
    @Collate.setter
    def Collate(self, por: bool) -> None: ...
    @property
    def IsVirtual(self) -> VirtualPrinterType: ...
    @property
    def PaperSizes(self) -> PaperSizeSet: ...
    @property
    def PaperSources(self) -> PaperSourceSet: ...
    def SelectNewPrintDriver(self, strPrinterName: str) -> None: ...
    @overload
    def SubmitPrint(self, view: View) -> bool: ...
    @overload
    def SubmitPrint(self) -> bool: ...
    def Apply(self) -> None: ...


class SweepProfile(APIObject):


class CurveLoopsProfile(SweepProfile):
    @property
    def Profile(self) -> CurveArrArray: ...
    @Profile.setter
    def Profile(self, curveLoops: CurveArrArray) -> None: ...


class FamilySymbolProfile(SweepProfile):
    @property
    def Profile(self) -> FamilySymbol: ...
    @Profile.setter
    def Profile(self, familySymbol: FamilySymbol) -> None: ...
    @property
    def XOffset(self) -> float: ...
    @XOffset.setter
    def XOffset(self, xOffset: float) -> None: ...
    @property
    def YOffset(self) -> float: ...
    @YOffset.setter
    def YOffset(self, yOffset: float) -> None: ...
    @property
    def Angle(self) -> float: ...
    @Angle.setter
    def Angle(self, angle: float) -> None: ...
    @property
    def IsFlipped(self) -> bool: ...
    @IsFlipped.setter
    def IsFlipped(self, isFlipped: bool) -> None: ...


class Document:
    def ExportImage(self, options: ImageExportOptions) -> None: ...
    @overload
    def Link(self, file: str, options: DWFImportOptions) -> List[ElementId]: ...
    @overload
    def Link(self, file: str, options: DGNImportOptions, pDBView: View) -> Tuple[bool, ElementId]: ...
    @overload
    def Link(self, file: str, options: SKPImportOptions, pDBView: View) -> ElementId: ...
    @overload
    def Link(self, file: str, options: SATImportOptions, pDBView: View) -> ElementId: ...
    @overload
    def Link(self, file: str, options: DWGImportOptions, pDBView: View) -> Tuple[bool, ElementId]: ...
    def SaveToProjectAsImage(self, options: ImageExportOptions) -> ElementId: ...
    def UnpostFailure(self, messageKey: FailureMessageKey) -> None: ...
    def PostFailure(self, failure: FailureMessage) -> FailureMessageKey: ...
    def GetWarnings(self) -> List[FailureMessage]: ...
    def GetWorksharingCentralModelPath(self) -> ModelPath: ...
    def GetCloudModelPath(self) -> ModelPath: ...
    def GetDefaultElementTypeId(self, defaultTypeId: ElementTypeGroup) -> ElementId: ...
    def SetDefaultElementTypeId(self, defaultTypeId: ElementTypeGroup, typeId: ElementId) -> None: ...
    def IsDefaultElementTypeIdValid(self, defaultTypeId: ElementTypeGroup, typeId: ElementId) -> bool: ...
    def GetDefaultFamilyTypeId(self, familyCategoryId: ElementId) -> ElementId: ...
    def SetDefaultFamilyTypeId(self, familyCategoryId: ElementId, familyTypeId: ElementId) -> None: ...
    def IsDefaultFamilyTypeIdValid(self, familyCategoryId: ElementId, familyTypeId: ElementId) -> bool: ...
    def GetDocumentPreviewSettings(self) -> DocumentPreviewSettings: ...
    def MakeTransientElements(self, maker: ITransientElementMaker) -> None: ...
    @overload
    def GetElement(self, id: ElementId) -> Element: ...
    @overload
    def GetElement(self, uniqueId: str) -> Element: ...
    @overload
    def GetElement(self, reference: Reference) -> Element: ...
    @overload
    def GetSubelement(self, id: ElementId, subId: int) -> Subelement: ...
    @overload
    def GetSubelement(self, uniqueId: str) -> Subelement: ...
    @overload
    def GetSubelement(self, reference: Reference) -> Subelement: ...
    def ReloadLatest(self, reloadOptions: ReloadLatestOptions) -> None: ...
    def HasAllChangesFromCentral(self) -> bool: ...
    def SynchronizeWithCentral(self, transactOptions: TransactWithCentralOptions, syncOptions: SynchronizeWithCentralOptions) -> None: ...
    def IsPainted(self, elementId: ElementId, face: Face) -> bool: ...
    def GetPaintedMaterial(self, elementId: ElementId, face: Face) -> ElementId: ...
    def RemovePaint(self, elementId: ElementId, face: Face) -> None: ...
    @overload
    def Delete(self, elementIds: ICollection) -> ICollection: ...
    @overload
    def Delete(self, elementId: ElementId) -> ICollection: ...
    def GetDocumentVersion(doc: Document) -> DocumentVersion: ...
    def AcquireCoordinates(self, linkInstanceId: ElementId) -> None: ...
    def PublishCoordinates(self, locationId: LinkElementId) -> None: ...
    def ResetSharedCoordinates(self) -> None: ...
    def IsBackgroundCalculationInProgress(self) -> bool: ...
    def EraseSchemaAndAllEntities(self, schema: Schema) -> None: ...
    def add_DocumentSaving(self, handler: EventHandler) -> None: ...
    def remove_DocumentSaving(self, handler: EventHandler) -> None: ...
    def add_DocumentSaved(self, handler: EventHandler) -> None: ...
    def remove_DocumentSaved(self, handler: EventHandler) -> None: ...
    def add_DocumentSavingAs(self, handler: EventHandler) -> None: ...
    def remove_DocumentSavingAs(self, handler: EventHandler) -> None: ...
    def add_DocumentSavedAs(self, handler: EventHandler) -> None: ...
    def remove_DocumentSavedAs(self, handler: EventHandler) -> None: ...
    def add_DocumentPrinting(self, handler: EventHandler) -> None: ...
    def remove_DocumentPrinting(self, handler: EventHandler) -> None: ...
    def add_DocumentPrinted(self, handler: EventHandler) -> None: ...
    def remove_DocumentPrinted(self, handler: EventHandler) -> None: ...
    def add_ViewPrinting(self, handler: EventHandler) -> None: ...
    def remove_ViewPrinting(self, handler: EventHandler) -> None: ...
    def add_ViewPrinted(self, handler: EventHandler) -> None: ...
    def remove_ViewPrinted(self, handler: EventHandler) -> None: ...
    def add_DocumentClosing(self, handler: EventHandler) -> None: ...
    def remove_DocumentClosing(self, handler: EventHandler) -> None: ...
    def Dispose(self) -> None: ...
    def Equals(self, obj: Object) -> bool: ...
    def GetHashCode(self) -> int: ...
    @property
    def TypeOfStorage(self, A_0: BuiltInParameter) -> StorageType: ...
    @property
    def Settings(self) -> Settings: ...
    @property
    def DisplayUnitSystem(self) -> DisplayUnit: ...
    @property
    def ParameterBindings(self) -> BindingMap: ...
    @property
    def MullionTypes(self) -> MullionTypeSet: ...
    @property
    def PanelTypes(self) -> PanelTypeSet: ...
    @property
    def Phases(self) -> PhaseArray: ...
    @property
    def ReactionsAreUpToDate(self) -> bool: ...
    @property
    def ProjectInformation(self) -> ProjectInfo: ...
    @overload
    def LoadFamily(self, targetDocument: Document, familyLoadOptions: IFamilyLoadOptions) -> Family: ...
    @overload
    def LoadFamily(self, targetDocument: Document) -> Family: ...
    @overload
    def LoadFamily(self, filename: str, familyLoadOptions: IFamilyLoadOptions) -> Tuple[bool, Family]: ...
    @overload
    def LoadFamily(self, filename: str) -> Tuple[bool, Family]: ...
    @overload
    def LoadFamily(self, filename: str) -> bool: ...
    def EditFamily(self, loadedFamily: Family) -> Document: ...
    @overload
    def LoadFamilySymbol(self, filename: str, name: str, familyLoadOptions: IFamilyLoadOptions) -> Tuple[bool, FamilySymbol]: ...
    @overload
    def LoadFamilySymbol(self, filename: str, name: str) -> Tuple[bool, FamilySymbol]: ...
    @overload
    def LoadFamilySymbol(self, filename: str, name: str) -> bool: ...
    @overload
    def Print(self, views: ViewSet, viewTemplate: View, useCurrentPrintSettings: bool) -> None: ...
    @overload
    def Print(self, views: ViewSet, viewTemplate: View) -> None: ...
    @overload
    def Print(self, views: ViewSet, useCurrentPrintSettings: bool) -> None: ...
    @overload
    def Print(self, views: ViewSet) -> None: ...
    @property
    def PlanTopology(self, level: Level, phase: Phase) -> PlanTopology: ...
    @property
    def PlanTopology(self, level: Level) -> PlanTopology: ...
    @property
    def PlanTopologies(self, phase: Phase) -> PlanTopologySet: ...
    @property
    def PlanTopologies(self) -> PlanTopologySet: ...
    @overload
    def Close(self) -> bool: ...
    @overload
    def Close(self, saveModified: bool) -> bool: ...
    @overload
    def Export(self, folder: str, name: str, options: GBXMLExportOptions) -> bool: ...
    @overload
    def Export(self, folder: str, name: str, options: MassGBXMLExportOptions) -> None: ...
    @overload
    def Export(self, folder: str, name: str, options: NavisworksExportOptions) -> None: ...
    @overload
    def Export(self, folder: str, name: str, options: STLExportOptions) -> bool: ...
    @overload
    def Export(self, folder: str, name: str, options: IFCExportOptions) -> bool: ...
    @overload
    def Export(self, folder: str, name: str, views: ICollection, options: SATExportOptions) -> bool: ...
    @overload
    def Export(self, folder: str, name: str, views: ICollection, options: DGNExportOptions) -> bool: ...
    @overload
    def Export(self, folder: str, name: str, views: ICollection, options: DXFExportOptions) -> bool: ...
    @overload
    def Export(self, folder: str, name: str, views: ICollection, options: DWGExportOptions) -> bool: ...
    @overload
    def Export(self, folder: str, name: str, views: ViewSet, options: FBXExportOptions) -> bool: ...
    @overload
    def Export(self, folder: str, name: str, views: ViewSet, options: DWFXExportOptions) -> bool: ...
    @overload
    def Export(self, folder: str, name: str, views: ViewSet, options: DWFExportOptions) -> bool: ...
    @overload
    def Import(self, file: str, options: DGNImportOptions, pDBView: View) -> Tuple[bool, ElementId]: ...
    @overload
    def Import(self, file: str, options: SKPImportOptions, pDBView: View) -> ElementId: ...
    @overload
    def Import(self, file: str, options: SATImportOptions, pDBView: View) -> ElementId: ...
    @overload
    def Import(self, file: str, options: DWGImportOptions, pDBView: View) -> Tuple[bool, ElementId]: ...
    @overload
    def Import(self, file: str, options: GBXMLImportOptions) -> bool: ...
    @property
    def Create(self) -> Document: ...
    @property
    def FamilyCreate(self) -> FamilyItemFactory: ...
    @property
    def FamilyManager(self) -> FamilyManager: ...
    @property
    def ActiveView(self) -> View: ...
    @property
    def ProjectLocations(self) -> ProjectLocationSet: ...
    @property
    def ActiveProjectLocation(self) -> ProjectLocation: ...
    @ActiveProjectLocation.setter
    def ActiveProjectLocation(self, value: ProjectLocation) -> None: ...
    @property
    def SiteLocation(self) -> SiteLocation: ...
    @property
    def PrintManager(self) -> PrintManager: ...
    def GetPrintSettingIds(self) -> ICollection: ...
    @overload
    def GetRoomAtPoint(self, point: XYZ) -> Room: ...
    @overload
    def GetRoomAtPoint(self, point: XYZ, phase: Phase) -> Room: ...
    @overload
    def GetSpaceAtPoint(self, point: XYZ) -> Space: ...
    @overload
    def GetSpaceAtPoint(self, point: XYZ, phase: Phase) -> Space: ...
    @property
    def IsFamilyDocument(self) -> bool: ...
    @property
    def OwnerFamily(self) -> Family: ...
    def CombineElements(self, members: CombinableElementArray) -> GeomCombination: ...
    def SeparateElements(self, members: CombinableElementArray) -> None: ...
    @property
    def Application(self) -> Application: ...
    def ConvertModelToDetailCurves(self, view: View, modelCurves: ModelCurveArray) -> DetailCurveArray: ...
    def ConvertDetailToModelCurves(self, view: View, detailCurves: DetailCurveArray) -> ModelCurveArray: ...
    def ConvertModelToSymbolicCurves(self, view: View, modelCurves: ModelCurveArray) -> SymbolicCurveArray: ...
    def ConvertSymbolicToModelCurves(self, view: View, symbolicCurve: SymbolicCurveArray) -> ModelCurveArray: ...
    def Regenerate(self) -> None: ...
    def AutoJoinElements(self) -> None: ...
    @overload
    def Paint(self, elementId: ElementId, face: Face, materialId: ElementId) -> None: ...
    @overload
    def Paint(self, elementId: ElementId, face: Face, familyParameter: FamilyParameter) -> None: ...
    @property
    def PathName(self) -> str: ...
    @property
    def Title(self) -> str: ...
    @property
    def IsModifiable(self) -> bool: ...
    @property
    def IsModified(self) -> bool: ...
    @property
    def IsReadOnly(self) -> bool: ...
    @property
    def IsReadOnlyFile(self) -> bool: ...
    @property
    def IsLinked(self) -> bool: ...
    @property
    def IsWorkshared(self) -> bool: ...
    @property
    def IsDetached(self) -> bool: ...
    @property
    def IsModelInCloud(self) -> bool: ...
    @property
    def WorksharingCentralGUID(self) -> Guid: ...
    @property
    def MassDisplayTemporaryOverride(self) -> MassDisplayTemporaryOverrideType: ...
    @MassDisplayTemporaryOverride.setter
    def MassDisplayTemporaryOverride(self, displayType: MassDisplayTemporaryOverrideType) -> None: ...
    @property
    def IsValidObject(self) -> bool: ...
    def GetWorksetTable(self) -> WorksetTable: ...
    def GetUnits(self) -> Units: ...
    def SetUnits(self, units: Units) -> None: ...
    def CanEnableCloudWorksharing(self) -> bool: ...
    def CanEnableWorksharing(self) -> bool: ...
    def EnableWorksharing(self, worksetNameGridLevel: str, worksetName: str) -> None: ...
    def GetWorksetId(self, id: ElementId) -> WorksetId: ...
    @overload
    def Save(self, options: SaveOptions) -> None: ...
    @overload
    def Save(self) -> None: ...
    @overload
    def SaveAs(self, path: ModelPath, options: SaveAsOptions) -> None: ...
    @overload
    def SaveAs(self, filepath: str, options: SaveAsOptions) -> None: ...
    @overload
    def SaveAs(self, filepath: str) -> None: ...
    def SaveCloudModel(self) -> None: ...
    @overload
    def SaveAsCloudModel(self, folderId: str, modelName: str) -> None: ...
    @overload
    def SaveAsCloudModel(self, accountId: Guid, projectId: Guid, folderId: str, modelName: str) -> None: ...
    def EnableCloudWorksharing(self) -> None: ...


class AddInId:
    def __init__(self, val: Guid): ...
    def GetAddInNameFromDocument(self, aDoc: Document) -> str: ...
    @property
    def IsValidObject(self) -> bool: ...
    def GetGUID(self) -> Guid: ...
    def GetAddInName(self) -> str: ...
    def Dispose(self) -> None: ...


class LayerModifier:
    @overload
    def __init__(self, modifierType: ModifierType, separator: str): ...
    @overload
    def __init__(self): ...
    @property
    def ModifierType(self) -> ModifierType: ...
    @ModifierType.setter
    def ModifierType(self, modifierType: ModifierType) -> None: ...
    @property
    def Separator(self) -> str: ...
    @Separator.setter
    def Separator(self, separator: str) -> None: ...
    @property
    def IsValidObject(self) -> bool: ...
    def Dispose(self) -> None: ...


class ExportLayerKey:
    @overload
    def __init__(self, categoryName: str, subCategoryName: str, num: SpecialType): ...
    @overload
    def __init__(self): ...
    @property
    def CategoryName(self) -> str: ...
    @CategoryName.setter
    def CategoryName(self, categoryName: str) -> None: ...
    @property
    def SubCategoryName(self) -> str: ...
    @SubCategoryName.setter
    def SubCategoryName(self, subCategoryName: str) -> None: ...
    @property
    def SpecialType(self) -> SpecialType: ...
    @SpecialType.setter
    def SpecialType(self, specialType: SpecialType) -> None: ...
    @property
    def IsValidObject(self) -> bool: ...
    def Dispose(self) -> None: ...


class ExportLayerInfo:
    def __init__(self): ...
    @property
    def CategoryType(self) -> LayerCategoryType: ...
    @CategoryType.setter
    def CategoryType(self, categoryType: LayerCategoryType) -> None: ...
    @property
    def ColorName(self) -> str: ...
    @ColorName.setter
    def ColorName(self, colorName: str) -> None: ...
    @property
    def LayerName(self) -> str: ...
    @LayerName.setter
    def LayerName(self, layerName: str) -> None: ...
    @property
    def CutLayerName(self) -> str: ...
    @CutLayerName.setter
    def CutLayerName(self, cutLayerName: str) -> None: ...
    @property
    def ColorNumber(self) -> int: ...
    @ColorNumber.setter
    def ColorNumber(self, colorNumber: int) -> None: ...
    @property
    def CutColorNumber(self) -> int: ...
    @CutColorNumber.setter
    def CutColorNumber(self, cutColorNumber: int) -> None: ...
    @property
    def IsValidObject(self) -> bool: ...
    def AddLayerModifier(self, layerModifier: LayerModifier) -> None: ...
    def AddCutLayerModifier(self, layerModifier: LayerModifier) -> None: ...
    def RemoveLayerModifier(self, layerModifier: LayerModifier) -> None: ...
    def RemoveCutLayerModifier(self, layerModifier: LayerModifier) -> None: ...
    def ClearLayerModifiers(self) -> None: ...
    def ClearCutLayerModifiers(self) -> None: ...
    def GetLayerModifiers(self) -> List[LayerModifier]: ...
    def GetCutLayerModifiers(self) -> List[LayerModifier]: ...
    def SetLayerModifiers(self, layermodifiers: List[LayerModifier]) -> None: ...
    def SetCutLayerModifiers(self, cutLayermodifiers: List[LayerModifier]) -> None: ...
    def Dispose(self) -> None: ...


class ExportLayerTableIterator:
    @property
    def IsValidObject(self) -> bool: ...
    def MoveNext(self) -> bool: ...
    def IsDone(self) -> bool: ...
    def Reset(self) -> None: ...
    @property
    def Current(self) -> KeyValuePair: ...
    def Dispose(self) -> None: ...


class ExportLayerTable:
    def __init__(self): ...
    def GetLayerTableIterator(self) -> ExportLayerTableIterator: ...
    @property
    def Item(self, layerKey: ExportLayerKey) -> ExportLayerInfo: ...
    @Item.setter
    def Item(self, LayerKey: ExportLayerKey, LayerInfo: ExportLayerInfo) -> None: ...
    def GetAvaliableLayerModifierTypes(document: Document, exportLayerKey: ExportLayerKey) -> List[ModifierType]: ...
    @property
    def Count(self) -> int: ...
    @property
    def IsValidObject(self) -> bool: ...
    def ContainsKey(self, exportlayerKey: ExportLayerKey) -> bool: ...
    def GetExportLayerInfo(self, exportLayerKey: ExportLayerKey) -> ExportLayerInfo: ...
    def GetKeys(self) -> List[ExportLayerKey]: ...
    def GetValues(self) -> List[ExportLayerInfo]: ...
    def Add(self, exportLayerKey: ExportLayerKey, exportLayerInfo: ExportLayerInfo) -> None: ...
    def Remove(self, exportLayerKey: ExportLayerKey) -> None: ...
    def Clear(self) -> None: ...
    def GetEnumerator(self) -> IEnumerator: ...
    def Dispose(self) -> None: ...


class ElementTypeGroup:
    RailingsTypeForStairs = 0
    RailingsTypeForRamps = 1
    WallType = 2
    RoofType = 3
    FloorType = 4
    FootingSlabType = 5
    CeilingType = 6
    StairsBySketchType = 7
    GridType = 8
    LevelType = 9
    LinearDimensionType = 10
    SpotElevationType = 11
    TextNoteType = 12
    TagNoteType = 13
    ModelTextType = 14
    CorniceType = 16
    RevealType = 17
    ViewportType = 19
    ReferenceViewerType = 21
    CalloutType = 22
    RampType = 28
    StairsRailingType = 30
    ModelGroupType = 32
    DetailGroupType = 33
    AttachedDetailGroupType = 34
    FilledRegionType = 35
    RadialDimensionType = 36
    AngularDimensionType = 37
    ArcLengthDimensionType = 38
    BuildingPadType = 43
    DecalType = 45
    ContourLabelingType = 46
    RoofSoffitType = 47
    FasciaType = 48
    GutterType = 49
    EdgeSlabType = 50
    RepeatingDetailType = 53
    BeamSystemType = 54
    CurtainSystemType = 58
    ViewType3D = 62
    ViewTypeWalkthrough = 63
    ViewTypeRendering = 64
    ViewTypeSchedule = 65
    ViewTypeLegend = 66
    ViewTypeCostReport = 67
    ViewTypeSheet = 68
    ViewTypeDrafting = 69
    ViewTypeStructuralPlan = 70
    ViewTypeFloorPlan = 71
    ViewTypeCeilingPlan = 72
    ViewTypeSection = 73
    ViewTypeDetailView = 74
    ViewTypeElevation = 75
    ViewTypeStructuralElevation = 76
    ViewTypeLoadsReport = 78
    ViewTypePressureLossReport = 79
    ViewTypePanelSchedule = 80
    AreaLoadType = 82
    LineLoadType = 83
    PointLoadType = 84
    RebarBarType = 85
    AreaReinforcementType = 87
    PathReinforcementType = 88
    FabricAreaType = 90
    FabricSheetType = 91
    DuctType = 97
    FlexDuctType = 98
    PipeType = 100
    FlexPipeType = 101
    WireType = 102
    SpotCoordinateType = 106
    ViewTypeGraphScheduleColumn = 107
    SpotSlopeType = 108
    WallFoundationType = 109
    PipeInsulationType = 119
    DuctInsulationType = 120
    DuctLiningType = 121
    CableTrayType = 122
    ConduitType = 123
    DiameterDimensionType = 126
    StairsType = 127
    AnalyticalLinkType = 136
    MultiReferenceAnnotationType = 140
    ColorFillType = 143
    RebarContainerType = 144
    StructuralConnectionHandlerType = 145
    EndTreatmentType = 146
    ViewTypeSystemsAnalysisReport = 150
    AlignmentStationLabelType = 151


class MassDisplayTemporaryOverrideType:
    ShowMassByViewSettings = 0
    ShowMassFormAndFloors = 1
    ShowMassSurfaceTypes = 2
    ShowMassZonesAndShades = 3


class TemporaryViewMode:
    RevealHiddenElements = 1
    TemporaryHideIsolate = 2
    WorksharingDisplay = 3
    TemporaryViewProperties = 4
    ExplodedView = 6
    RevealConstraints = 7
    PreviewFamilyVisibility = 8


class UnderlayOrientation:
    LookingDown = 0
    LookingUp = 1


class DisplayStyle:
    Undefined = 0
    Wireframe = 1
    HLR = 2
    Shading = 3
    ShadingWithEdges = 4
    Rendering = 5
    Realistic = 6
    FlatColors = 7
    RealisticWithEdges = 8


class ElementOnPhaseStatus:
    #None = 0
    Past = 1
    Existing = 2
    Demolished = 3
    New = 4
    Temporary = 5
    Future = 6


class BuiltInParameter:
    VOID_CUTS_GEOMETRY = -1155218
    REBAR_HOOK_ROTATION_AT_END_SCHEDULES_TAGS_FILTERS = -1155217
    REBAR_HOOK_ROTATION_AT_START_SCHEDULES_TAGS_FILTERS = -1155216
    REBAR_HOOK_LENGTH_OVERRIDE = -1155215
    INFRASTRUCTURE_ALIGNMENT_NAME = -1155214
    INFRASTRUCTURE_ALIGNMENT_DESCRIPTION = -1155213
    INFRASTRUCTURE_ALIGNMENT_DISPLAYED_START_STATION = -1155212
    INFRASTRUCTURE_ALIGNMENT_DISPLAYED_END_STATION = -1155211
    ASSEMBLY_PRECAST_FREEZE = -1155210
    REBAR_HOOK_ROTATION_AT_END = -1155206
    REBAR_HOOK_ROTATION_AT_START = -1155205
    REBAR_SHAPE_HOOK_ROTATION_AT_END = -1155204
    REBAR_SHAPE_HOOK_ROTATION_AT_START = -1155203
    PATH_OF_TRAVEL_FROM_ROOM = -1155202
    PATH_OF_TRAVEL_TO_ROOM = -1155201
    RBS_ELEC_NUMBER_OF_CIRCUITS = -1155150
    STEEL_ELEM_PROFILE_VOLUME = -1155148
    STEEL_ELEM_PROFILE_LENGTH = -1155147
    STEEL_ELEM_PROFILE_TYPE = -1155146
    RBS_ELEC_EDIT_CIRCUIT_NAMING_SETTINGS_PARAM = -1155145
    STEEL_ELEM_PLATE_JUSTIFICATION = -1155144
    STEEL_ELEM_PLATE_PAINT_AREA = -1155143
    STEEL_ELEM_PLATE_EXACT_WEIGHT = -1155142
    STEEL_ELEM_PLATE_WEIGHT = -1155141
    STEEL_ELEM_PLATE_VOLUME = -1155140
    STEEL_ELEM_PLATE_AREA = -1155139
    STEEL_ELEM_PLATE_WIDTH = -1155138
    STEEL_ELEM_PLATE_LENGTH = -1155137
    STEEL_ELEM_PLATE_TYPE = -1155136
    STEEL_ELEM_BOLT_TOTAL_WEIGHT = -1155135
    STEEL_ELEM_SHEARSTUD_TOTAL_WEIGHT = -1155134
    STEEL_ELEM_ANCHOR_TOTAL_WEIGHT = -1155132
    STEEL_ELEM_ANCHOR_ORIENTATION = -1155130
    STEEL_ELEM_CUT_LENGTH = -1155128
    STEEL_ELEM_EXACT_WEIGHT = -1155127
    STEEL_ELEM_PAINT_AREA = -1155125
    STEEL_ELEM_WEIGHT = -1155124
    PATH_OF_TRAVEL_SPEED = -1155123
    STEEL_ELEM_BOLT_LOCATION = -1155122
    STEEL_ELEM_BOLT_FINISH_CALCULATION_AT_GAP = -1155121
    STEEL_ELEM_BOLT_INVERTED = -1155120
    STEEL_ELEM_BOLT_GRIP_LENGTH_INCREASE = -1155119
    STEEL_ELEM_BOLT_GRIP_LENGTH = -1155118
    STEEL_ELEM_BOLT_LENGTH = -1155117
    GENERIC_ZONE_NAME = -1155116
    RBS_PIPE_BOTTOM_ELEVATION = -1155115
    RBS_PIPE_TOP_ELEVATION = -1155114
    RBS_ELEC_PANEL_FEED_THRU_LUGS_CURRENT_PHASEC = -1155113
    RBS_ELEC_PANEL_FEED_THRU_LUGS_CURRENT_PHASEB = -1155112
    RBS_ELEC_PANEL_FEED_THRU_LUGS_CURRENT_PHASEA = -1155111
    RBS_ELEC_PANEL_FEED_THRU_LUGS_APPARENT_LOAD_PHASEC = -1155110
    RBS_ELEC_PANEL_FEED_THRU_LUGS_APPARENT_LOAD_PHASEB = -1155109
    RBS_ELEC_PANEL_FEED_THRU_LUGS_APPARENT_LOAD_PHASEA = -1155108
    RBS_ELEC_PANEL_BRANCH_CIRCUIT_CURRENT_PHASEC = -1155107
    RBS_ELEC_PANEL_BRANCH_CIRCUIT_CURRENT_PHASEB = -1155106
    RBS_ELEC_PANEL_BRANCH_CIRCUIT_CURRENT_PHASEA = -1155105
    RBS_ELEC_PANEL_BRANCH_CIRCUIT_APPARENT_LOAD_PHASEC = -1155104
    RBS_ELEC_PANEL_BRANCH_CIRCUIT_APPARENT_LOAD_PHASEB = -1155103
    RBS_ELEC_PANEL_BRANCH_CIRCUIT_APPARENT_LOAD_PHASEA = -1155102
    STEEL_ELEM_HOLE_DEFINITION = -1155101
    RBS_ELEC_PANEL_FEED_THRU_LUGS_PARAM = -1155100
    RBS_ELEC_CIRCUIT_NUMBERING_TYPE = -1155099
    TAG_ON_PLACEMENT_UI = -1155096
    ROUTE_ANALYSIS_SETTINGS_PARAM = -1155095
    PATH_OF_TRAVEL_VIEW_NAME = -1155094
    PATH_OF_TRAVEL_LEVEL_NAME = -1155093
    STRUCTURAL_CONNECTION_OVERRIDE_TYPE = -1155092
    STRUCTURAL_CONNECTION_EDIT_TYPE = -1155091
    PATH_OF_TRAVEL_TIME = -1155090
    STEEL_ELEM_ZCLIP_TYPE = -1155087
    STEEL_ELEM_COPE_AROUND_AXIS = -1155086
    STEEL_ELEM_COPE_AXIS_ANGLE = -1155085
    STEEL_ELEM_COPE_Z_ANGLE = -1155084
    STEEL_ELEM_COPE_X_ANGLE = -1155083
    STEEL_ELEM_COPE_DISTANCE_AXIS = -1155082
    STEEL_ELEM_COPE_WIDTHX = -1155081
    STEEL_ELEM_Y_DISTANCE = -1155080
    STEEL_ELEM_X_DISTANCE = -1155079
    STEEL_ELEM_CUT_TYPE = -1155078
    STEEL_ELEM_PLATE_SHORTEN_CUTSTRAIGHT = -1155077
    STEEL_ELEM_PLATE_SHORTEN_SUCTION = -1155076
    STEEL_ELEM_PLATE_SHORTEN_ANGLE = -1155075
    STEEL_ELEM_WELD_PREFIX = -1155074
    STEEL_ELEM_WELD_TEXT_MODULE = -1155073
    STEEL_ELEM_HOLE_DEPTH_OF_BOLT_HEAD = -1155072
    STEEL_ELEM_HOLE_TAPPING = -1155071
    STEEL_ELEM_HOLE_BACK_TAPER_THREAD = -1155070
    STEEL_ELEM_HOLE_TAPPING_HOLE = -1155069
    STEEL_ELEM_HOLE_HEAD_DIAMETER = -1155068
    STEEL_ELEM_HOLE_ANGLE = -1155067
    STEEL_ELEM_HOLE_ALPHA = -1155066
    STEEL_ELEM_HOLE_DEPTH = -1155065
    STEEL_ELEM_HOLE_SLOT_DIRECTION = -1155064
    STEEL_ELEM_HOLE_SLOT_LENGTH = -1155063
    STEEL_ELEM_HOLE_TYPE = -1155062
    STEEL_ELEM_HOLE_DIAMETER = -1155061
    STEEL_ELEM_PATTERN_NUMBER = -1155060
    STEEL_ELEM_PATTERN_RADIUS = -1155059
    STEEL_ELEM_PATTERN_EDGE_DISTANCE_Y = -1155058
    STEEL_ELEM_PATTERN_EDGE_DISTANCE_X = -1155057
    STEEL_ELEM_PATTERN_INTERMEDIATE_DISTANCE_Y = -1155056
    STEEL_ELEM_PATTERN_INTERMEDIATE_DISTANCE_X = -1155055
    STEEL_ELEM_PATTERN_TOTAL_WIDTH = -1155054
    STEEL_ELEM_PATTERN_TOTAL_LENGTH = -1155053
    STEEL_ELEM_PATTERN_NUMBER_Y = -1155052
    STEEL_ELEM_PATTERN_NUMBER_X = -1155051
    STEEL_ELEM_WELD_DOUBLE_PREPDEPTH = -1155050
    STEEL_ELEM_WELD_DOUBLE_EFFECTIVETHROAT = -1155049
    STEEL_ELEM_WELD_DOUBLE_ROOTOPENING = -1155048
    STEEL_ELEM_WELD_DOUBLE_WELDPREP = -1155047
    STEEL_ELEM_WELD_DOUBLE_SURFACESHAPE = -1155046
    STEEL_ELEM_WELD_DOUBLE_TEXT = -1155045
    STEEL_ELEM_WELD_DOUBLE_THICKNESS = -1155044
    STEEL_ELEM_WELD_DOUBLE_TYPE = -1155043
    STEEL_ELEM_WELD_MAIN_PREPDEPTH = -1155042
    STEEL_ELEM_WELD_MAIN_EFFECTIVETHROAT = -1155041
    STEEL_ELEM_WELD_MAIN_ROOTOPENING = -1155040
    STEEL_ELEM_WELD_MAIN_WELDPREP = -1155039
    STEEL_ELEM_WELD_MAIN_SURFACESHAPE = -1155038
    STEEL_ELEM_WELD_MAIN_TEXT = -1155037
    STEEL_ELEM_WELD_PITCH = -1155036
    STEEL_ELEM_WELD_CONTINUOUS = -1155035
    STEEL_ELEM_WELD_LOCATION = -1155034
    STEEL_ELEM_WELD_LENGTH = -1155033
    STEEL_ELEM_WELD_MAIN_THICKNESS = -1155032
    STEEL_ELEM_WELD_MAIN_TYPE = -1155031
    STEEL_ELEM_PARAM_BORINGOUT = -1155029
    STEEL_ELEM_PARAM_RADIUS = -1155028
    STEEL_ELEM_CONTOUR_SIDE2DIST = -1155027
    STEEL_ELEM_CONTOUR_SIDE1DIST = -1155026
    STEEL_ELEM_CONTOUR_GAP_WIDTH = -1155023
    STEEL_ELEM_SHORTEN_ANGLEZ = -1155022
    STEEL_ELEM_SHORTEN_ANGLEY = -1155021
    STEEL_ELEM_SHORTEN_REFLENGTH = -1155020
    STEEL_ELEM_SHEARSTUD_LENGTH = -1155019
    STEEL_ELEM_BOLT_COATING = -1155018
    STEEL_ELEM_ANCHOR_LENGTH = -1155017
    STEEL_ELEM_SHEARSTUD_DIAMETER = -1155016
    STEEL_ELEM_SHEARSTUD_GRADE = -1155015
    STEEL_ELEM_SHEARSTUD_STANDARD = -1155014
    STEEL_ELEM_ANCHOR_DIAMETER = -1155013
    STEEL_ELEM_ANCHOR_ASSEMBLY = -1155012
    STEEL_ELEM_ANCHOR_GRADE = -1155011
    STEEL_ELEM_ANCHOR_STANDARD = -1155010
    STEEL_ELEM_COATING = -1155009
    STEEL_ELEM_BOLT_DIAMETER = -1155008
    STEEL_ELEM_BOLT_ASSEMBLY = -1155007
    STEEL_ELEM_BOLT_GRADE = -1155006
    STEEL_ELEM_BOLT_STANDARD = -1155005
    STEEL_ELEM_PLATE_THICKNESS = -1155003
    REBAR_WORKSHOP_INSTRUCTIONS = -1154695
    REBAR_GEOMETRY_TYPE = -1154694
    BASEPOINT_LATITUDE_PARAM = -1154693
    BASEPOINT_LONGITUDE_PARAM = -1154692
    REBAR_FREE_FORM_HOOK_END_PLANE_ANGLE = -1154691
    REBAR_FREE_FORM_HOOK_START_PLANE_ANGLE = -1154690
    ROOM_OUTDOOR_AIRFLOW_PARAM = -1154689
    ROOM_OUTDOOR_AIRFLOW_STANDARD_PARAM = -1154687
    DIRECTCONTEXT3D_SOURCE_ID = -1154686
    DIRECTCONTEXT3D_APPLICATION_ID = -1154685
    DIRECTCONTEXT3D_LOADED = -1154677
    DIRECTCONTEXT3D_SERVER_ID = -1154676
    DIRECTCONTEXT3D_NAME = -1154675
    ROOM_AIR_CHANGES_PER_HOUR_PARAM = -1154671
    ROOM_OUTDOOR_AIR_PER_AREA_PARAM = -1154668
    ROOM_OUTDOOR_AIR_PER_PERSON_PARAM = -1154665
    ROOM_OUTDOOR_AIR_INFO_PARAM = -1154662
    REBAR_INTERNAL_MULTIPLANAR_ARC_CONNECTOR = -1154659
    REBAR_SHAPE_ENDTREATMENT_END_TYPE = -1154658
    REBAR_SHAPE_ENDTREATMENT_START_TYPE = -1154657
    REBAR_ELEM_ENDTREATMENT_END = -1154656
    REBAR_ELEM_ENDTREATMENT_START = -1154655
    END_TREATMENT = -1154654
    COUPLER_COUPLED_ENDTREATMENT = -1154653
    COUPLER_MAIN_ENDTREATMENT = -1154652
    COUPLER_WIDTH = -1154651
    COUPLER_MARK = -1154649
    FAMILY_FREEINST_DEFAULT_ELEVATION = -1154647
    COUPLER_COUPLED_ENGAGEMENT = -1154646
    COUPLER_MAIN_ENGAGEMENT = -1154645
    COUPLER_LENGTH = -1154644
    COUPLER_WEIGHT = -1154643
    COUPLER_NUMBER = -1154642
    COUPLER_QUANTITY = -1154641
    COUPLER_COUPLED_BAR_SIZE = -1154640
    COUPLER_MAIN_BAR_SIZE = -1154639
    COUPLER_CODE = -1154638
    MULTISTORY_STAIRS_ACTUAL_TREAD_DEPTH = -1154634
    MULTISTORY_STAIRS_REF_LEVEL = -1154630
    REBAR_ELEM_HOST_MARK = -1154619
    REBAR_SHAPE_IMAGE = -1154618
    FABRIC_NUMBER = -1154617
    REBAR_NUMBER = -1154616
    GRAPHIC_DISPLAY_OPTIONS_SKETCHY_LINES = -1154615
    NUMBER_PARTITION_PARAM = -1154614
    VIEW_SHOW_HIDDEN_LINES = -1154613
    MEP_ZONE_EQUIPMENT_DRAW_VENTILATION = -1153528
    MEP_VRF_LOOP = -1153527
    MEP_REHEAT_HOTWATER_LOOP = -1153526
    MEP_ZONE_EQUIPMENT = -1153519
    MEP_ANALYTICAL_EQUIPMENT_NAME = -1153518
    MEP_ZONE_HOTWATER_LOOP = -1153517
    MEP_ZONE_AIR_LOOP = -1153516
    MEP_REHEAT_COIL_TYPE = -1153514
    MEP_ZONE_EQUIPMENT_BEHAVIOR = -1153513
    MEP_ZONE_EQUIPMENT_TYPE = -1153512
    MEP_AIRLOOP_FANTYPE = -1153511
    MEP_CHILLED_WATER_LOOP = -1153510
    MEP_COOLING_COIL_TYPE = -1153509
    MEP_HEATING_HOTWATER_LOOP = -1153508
    MEP_HEATING_COIL_TYPE = -1153507
    MEP_PREHEAT_HOTWATER_LOOP = -1153506
    MEP_AIRLOOP_PREHEAT_COILTYPE = -1153505
    MEP_AIRLOOP_HEATEXCHANGER_TYPE = -1153504
    MEP_CONDENSER_WATER_LOOP = -1153503
    MEP_WATERLOOP_CHILLERTYPE = -1153502
    MEP_WATERLOOP_TYPE = -1153501
    MEP_ANALYTICAL_LOOP_NAME = -1153500
    SYSTEM_EQUIPMENT_SETS = -1153115
    MEP_IGNORE_FLOW_ANALYSIS = -1153114
    MEP_ANALYTICAL_LOOP_BOUNDARY_PARAM = -1153113
    MECHANICAL_EQUIPMENT_SET_ID_PARAM = -1153112
    MECHANICAL_EQUIPMENT_SET_NAME = -1153111
    MECHANICAL_EQUIPMENT_SET_ON_STANDBY = -1153110
    MECHANICAL_EQUIPMENT_SET_ON_DUTY = -1153109
    MEP_ANALYTICAL_CRITICALPATH_PARAM = -1153106
    MEP_ANALYTICAL_PIPE_DESIGNFLOW = -1153105
    MEP_EQUIPMENT_CALC_PIPINGPRESSUREDROP_PARAM = -1153104
    MEP_EQUIPMENT_CALC_PIPINGFLOW_PARAM = -1153103
    MEP_EQUIPMENT_CLASSIFICATION = -1153100
    STRUCTURAL_CONNECTION_INPUT_ELEMENTS = -1153004
    STRUCTURAL_CONNECTION_NOBLE_STATUS = -1153003
    STRUCTURAL_CONNECTION_CODE_CHECKING_STATUS = -1153002
    STRUCTURAL_CONNECTION_APPROVAL_STATUS = -1153001
    STRUCTURAL_CONNECTION_MODIFY_CONNECTION_PARAMETERS = -1153000
    STRUCTURAL_CONNECTION_SYMBOL = -1152999
    ALL_MODEL_IMAGE = -1152385
    ALL_MODEL_TYPE_IMAGE = -1152384
    STRUCT_FRAM_JOIN_STATUS = -1152383
    REFERENCED_VIEW = -1152380
    ENERGY_ANALYSIS_ADVANCED_OPTIONS = -1152379
    RBS_ENERGY_ANALYSIS_MODE = -1152378
    RBS_ENERGY_ANALYSIS_BUILDING_ENVELOPE_ANALYTICAL_SURFACE_IDENTIFICATION_RESOLUTION = -1152377
    RBS_ENERGY_ANALYSIS_BUILDING_ENVELOPE_ANALYTICAL_SPACE_IDENTIFICATION_RESOLUTION = -1152376
    FAMILY_ROUNDCONNECTOR_DIMENSIONTYPE = -1152375
    FAM_PROFILE_DEFINITION = -1152374
    END_Z_OFFSET_VALUE = -1152373
    END_Z_JUSTIFICATION = -1152372
    END_Y_OFFSET_VALUE = -1152371
    END_Y_JUSTIFICATION = -1152370
    START_Z_OFFSET_VALUE = -1152369
    START_Z_JUSTIFICATION = -1152368
    START_Y_OFFSET_VALUE = -1152367
    START_Y_JUSTIFICATION = -1152366
    Z_OFFSET_VALUE = -1152365
    Z_JUSTIFICATION = -1152364
    Y_OFFSET_VALUE = -1152363
    Y_JUSTIFICATION = -1152362
    YZ_JUSTIFICATION = -1152361
    END_JOIN_CUTBACK = -1152360
    START_JOIN_CUTBACK = -1152359
    END_EXTENSION = -1152358
    START_EXTENSION = -1152357
    DIVISION_SKETCH_CURVE_DIVISION_PARAMS_OVERRIDE_PARAM = -1152356
    DIVISION_SKETCH_CURVE_EXTENTD_TO_SILH_PARAM = -1152352
    DIVISION_RULE_PARAM = -1152351
    PATTERN_MIRROR_FOR_DIVISION_RULE = -1152350
    ALL_GRID_ROTATION_FOR_DIVISION_RULE = -1152349
    PATTERN_INDENT_2_FOR_DIVISION_RULE = -1152348
    PATTERN_INDENT_1_FOR_DIVISION_RULE = -1152347
    DIVISION_PATTERN = -1152346
    DPART_SHAPE_MODIFIED = -1152345
    DPART_EXCLUDED = -1152344
    ANALYTICAL_MODEL_MANUALLY_ADJUSTED = -1152343
    PROPERTY_SET_KEYWORDS = -1152342
    MATERIAL_ASSET_PARAM_SOURCE_URL = -1152341
    MATERIAL_ASSET_PARAM_SOURCE = -1152340
    MATERIAL_ASSET_PARAM_EXTERNAL_MATERIAL_ID = -1152339
    MATERIAL_ASSET_PARAM_COMMON_SHARED_ASSET = -1152338
    MATERIAL_ASSET_PARAM_ASSET_LIB_ID = -1152337
    DPART_BASE_LEVEL_BY_ORIGINAL = -1152336
    DPART_BASE_LEVEL = -1152335
    POINT_ADAPTIVE_NUM_PARAM = -1152334
    POINT_ADAPTIVE_SHOW_NUMBER = -1152333
    POINT_ADAPTIVE_CONSTRAINED = -1152332
    POINT_ADAPTIVE_ORIENTATION_TYPE = -1152331
    THERMAL_MATERIAL_PARAM_ELECTRICAL_RESISTIVITY = -1152330
    THERMAL_MATERIAL_PARAM_REFLECTIVITY = -1152329
    THERMAL_MATERIAL_PARAM_POROSITY = -1152328
    THERMAL_MATERIAL_PARAM_PERMEABILITY = -1152327
    THERMAL_MATERIAL_PARAM_TRANSMITS_LIGHT = -1152326
    THERMAL_MATERIAL_PARAM_VAPOR_PRESSURE = -1152325
    THERMAL_MATERIAL_PARAM_SPECIFIC_HEAT_OF_VAPORIZATION = -1152324
    THERMAL_MATERIAL_PARAM_LIQUID_VISCOSITY = -1152323
    THERMAL_MATERIAL_PARAM_COMPRESSIBILITY = -1152322
    THERMAL_MATERIAL_PARAM_GAS_VISCOSITY = -1152321
    THERMAL_MATERIAL_PARAM_EMISSIVITY = -1152320
    PHY_MATERIAL_PARAM_WOOD_CONSTRUCTION = -1152319
    PHY_MATERIAL_PARAM_FIVEPERCENT_MODULUS_OF_ELACTICITY = -1152318
    PHY_MATERIAL_PARAM_AVERAGE_MODULUS = -1152317
    PHY_MATERIAL_PARAM_TENSION_PERPENDICULAR = -1152316
    PHY_MATERIAL_PARAM_TENSION_PARALLEL = -1152315
    PHY_MATERIAL_PARAM_STRUCTURAL_THERMAL_TREATED = -1152314
    PHY_MATERIAL_PARAM_STRUCTURAL_DENSITY = -1152313
    PHY_MATERIAL_PARAM_STRUCTURAL_SPECIFIC_HEAT = -1152312
    PHY_MATERIAL_PARAM_THERMAL_CONDUCTIVITY_Z = -1152311
    PHY_MATERIAL_PARAM_THERMAL_CONDUCTIVITY_Y = -1152310
    PHY_MATERIAL_PARAM_THERMAL_CONDUCTIVITY_X = -1152309
    PHY_MATERIAL_PARAM_THERMAL_CONDUCTIVITY = -1152308
    PHY_MATERIAL_PARAM_EXP_COEFF_2 = -1152307
    PHY_MATERIAL_PARAM_EXP_COEFF_1 = -1152306
    PHY_MATERIAL_PARAM_SHEAR_MOD_12 = -1152305
    PHY_MATERIAL_PARAM_POISSON_MOD_23 = -1152304
    PHY_MATERIAL_PARAM_POISSON_MOD_12 = -1152303
    PHY_MATERIAL_PARAM_YOUNG_MOD_2 = -1152302
    PHY_MATERIAL_PARAM_YOUNG_MOD_1 = -1152301
    STAIRS_RAILING_PLACEMENT_OFFSET = -1152300
    STAIRS_TRISERTYPE_RISER_IS_SLANTED = -1152177
    STAIRS_TRISERTYPE_RISER = -1152176
    STAIRS_TRISERTYPE_NOSING_PLACEMENT = -1152175
    STAIRS_TRISERTYPE_RISER_PROFILE = -1152174
    TERMINATION_EXTENSION_LENGTH = -1152167
    SUPPORT_HEIGHT = -1152166
    SUPPORT_HAND_CLEARANCE = -1152165
    STAIRS_TRISERTYPE_TREAD_PROFILE = -1152164
    STAIRS_TRISERTYPE_RISER_MATERIAL = -1152163
    STAIRS_TRISERTYPE_TREAD_MATERIAL = -1152162
    STAIRS_TRISERTYPE_RISER_TREAD_CONNECTION = -1152161
    STAIRS_TRISERTYPE_RISER_THICKNESS = -1152160
    STAIRS_TRISERTYPE_RISER_STYLE = -1152159
    STAIRS_TRISERTYPE_BACK_NOSING = -1152158
    STAIRS_TRISERTYPE_LEFT_NOSING = -1152157
    STAIRS_TRISERTYPE_RIGHT_NOSING = -1152156
    STAIRS_TRISERTYPE_FRONT_NOSING = -1152155
    STAIRS_TRISERTYPE_NOSING_LENGTH = -1152154
    STAIRS_TRISERTYPE_NOSING_PROFILE = -1152153
    STAIRS_TRISERTYPE_TREAD_THICKNESS = -1152152
    STAIRS_TRISERTYPE_TREAD = -1152151
    STAIRS_TRISER_RISER_MARK = -1152105
    STAIRS_TRISER_TREAD_MARK = -1152104
    STAIRS_TRISER_RISER_NUMBER = -1152103
    STAIRS_TRISER_TREAD_NUMBER = -1152102
    STAIRS_TRISER_IS_TYPE_OVERRIDDEN = -1152101
    STAIRS_WINDERPATTERN_NUMBER_OF_STRAIGHT_STEPS_AT_END = -1151908
    STAIRS_WINDERPATTERN_NUMBER_OF_STRAIGHT_STEPS_AT_BEGIN = -1151907
    STAIRS_WINDERPATTERN_RADIUS_INTERIOR = -1151906
    STAIRS_WINDERPATTERN_FILLET_INSIDE_CORNER = -1151905
    STAIRS_WINDERPATTERN_STAIR_PATH_OFFSET = -1151904
    STAIRS_WINDERPATTERN_MINIMUM_WIDTH_INSIDE_WALKLINE = -1151903
    STAIRS_WINDERPATTERN_MINIMUM_WIDTH_CORNER = -1151902
    STAIRS_WINDERPATTERN_WINDER_STYLE = -1151901
    STAIRS_SUPPORTTYPE_FLIP_SECTION_PROFILE = -1151811
    STAIRS_SUPPORTTYPE_STRUCTURAL_DEPTH_ON_LANDING = -1151810
    STAIRS_SUPPORTTYPE_STRUCTURAL_DEPTH_ON_RUN = -1151809
    STAIRS_SUPPORTTYPE_MATERIAL = -1151808
    STAIRS_SUPPORTTYPE_WIDTH = -1151807
    STAIRS_SUPPORTTYPE_TOTAL_DEPTH = -1151806
    STAIRS_SUPPORTTYPE_STRUCTURAL_DEPTH = -1151805
    STAIRS_SUPPORTTYPE_UNDERSIDE_SURFACE = -1151804
    STAIRS_SUPPORTTYPE_TOPSIDE_SURFACE = -1151803
    STAIRS_SUPPORTTYPE_SECTION_PROFILE = -1151801
    STAIRS_SUPPORT_LANDINGSUPPORT_TYPE = -1151710
    STAIRS_SUPPORT_OVERRIDDEN = -1151709
    STAIRS_SUPPORT_TRIM_SUPPORT_UPPER = -1151708
    STAIRS_SUPPORT_UPPER_END_CUT = -1151706
    STAIRS_SUPPORT_LOWER_END_CUT = -1151705
    STAIRS_SUPPORT_VERTICAL_OFFSET = -1151702
    STAIRS_SUPPORT_HORIZONTAL_OFFSET = -1151701
    STAIRS_LANDINGTYPE_LANDING_MATERIAL = -1151606
    STAIRS_LANDINGTYPE_TREADRISER_TYPE = -1151605
    STAIRS_LANDINGTYPE_USE_SAME_TRISER_AS_RUN = -1151604
    STAIRS_LANDINGTYPE_THICKNESS = -1151603
    STAIRS_LANDINGTYPE_STRUCTURE = -1151602
    STAIRS_LANDINGTYPE_HAS_MONOLITHIC_SUPPORT = -1151601
    STAIRS_LANDING_OVERRIDDEN = -1151508
    STAIRS_LANDING_THICKNESS = -1151507
    STAIRS_LANDING_STRUCTURAL = -1151502
    STAIRS_LANDING_BASE_ELEVATION = -1151501
    STAIRS_RUNTYPE_RUN_MATERIAL = -1151406
    STAIRS_RUNTYPE_TOTAL_DEPTH = -1151405
    STAIRS_RUNTYPE_STRUCTURAL_DEPTH = -1151404
    STAIRS_RUNTYPE_STRUCTURE = -1151403
    STAIRS_RUNTYPE_UNDERSIDE_SURFACE_TYPE = -1151402
    STAIRS_RUNTYPE_HAS_MONOLITHIC_SUPPORT = -1151401
    STAIRS_RUN_EXTEND_BELOW_TREAD_BASE = -1151323
    STAIRS_RUN_CCW = -1151322
    STAIRS_RUN_CREATE_AUTO_LANDING = -1151321
    STAIRS_RUN_WINDER_END_WITH_STRAIGHT = -1151320
    STAIRS_RUN_WINDER_BEGIN_WITH_STRAIGHT = -1151319
    STAIRS_RUN_LOCATIONPATH_JUSTFICATION = -1151318
    STAIRS_RUN_END_WITH_RISER = -1151317
    STAIRS_RUN_BEGIN_WITH_RISER = -1151316
    STAIRS_RUN_OVERRIDDEN = -1151315
    STAIRS_RUN_STRUCTURAL = -1151314
    STAIRS_RUN_CENTER_MARK_VISIBLE = -1151313
    STAIRS_RUN_ACTUAL_RUN_WIDTH = -1151309
    STAIRS_RUN_ACTUAL_TREAD_DEPTH = -1151308
    STAIRS_RUN_ACTUAL_RISER_HEIGHT = -1151307
    STAIRS_RUN_ACTUAL_NUMBER_OF_TREADS = -1151306
    STAIRS_RUN_ACTUAL_NUMBER_OF_RISERS = -1151305
    STAIRS_RUN_EXTEND_BELOW_RISER_BASE = -1151304
    STAIRS_RUN_HEIGHT = -1151303
    STAIRS_RUN_TOP_ELEVATION = -1151302
    STAIRS_RUN_BOTTOM_ELEVATION = -1151301
    STAIRSTYPE_HAS_INTERMEDIATE_SUPPORT = -1151237
    STAIRSTYPE_LEFT_SUPPORT_LATERAL_OFFSET = -1151236
    STAIRSTYPE_RIGHT_SUPPORT_LATERAL_OFFSET = -1151235
    STAIRSTYPE_CUTMARK_TYPE = -1151234
    STAIRSTYPE_CONSTRUCTION_METHOD = -1151233
    STAIRSTYPE_HAS_RIGHT_SUPPORT = -1151232
    STAIRSTYPE_HAS_LEFT_SUPPORT = -1151231
    STAIRSTYPE_NOTCH_WIDTH = -1151230
    STAIRSTYPE_NOTCH_VERTICAL_GAP = -1151229
    STAIRSTYPE_NOTCH_HORIZONTAL_GAP = -1151228
    STAIRSTYPE_NOTCH_CUSTOM_WIDTH = -1151227
    STAIRSTYPE_NOTCH_THICKNESS = -1151226
    STAIRSTYPE_NOTCH_EXTENSION = -1151225
    STAIRSTYPE_GEOMUNJOINED_END_CUT_STYLE = -1151224
    STAIRSTYPE_CALC_RULE_TARGET_RESULT = -1151223
    STAIRSTYPE_CALC_RULE_MIN_RESULT = -1151222
    STAIRSTYPE_CALC_RULE_MAX_RESULT = -1151221
    STAIRSTYPE_CALC_RULE_TREAD_MULTIPLIER = -1151220
    STAIRSTYPE_CALC_RULE_RISER_MULTIPLIER = -1151219
    STAIRSTYPE_IS_ASSEMBLED_STAIRS = -1151218
    STAIRSTYPE_NUMBER_OF_INTERMEDIATE_SUPPORTS = -1151217
    STAIRSTYPE_MINIMUM_RUN_WIDTH = -1151216
    STAIRSTYPE_WINDER_STEP_FRONT_MEASUREMENT = -1151215
    STAIRSTYPE_SHOW_UPDOWN = -1151214
    STAIRSTYPE_SHOW_STAIR_PATH = -1151213
    STAIRSTYPE_SHOW_CUTLINE = -1151212
    STAIRSTYPE_INTERMEDIATE_SUPPORT_TYPE = -1151211
    STAIRSTYPE_LEFT_SIDE_SUPPORT_TYPE = -1151210
    STAIRSTYPE_RIGHT_SIDE_SUPPORT_TYPE = -1151209
    STAIRSTYPE_LANDING_TYPE = -1151208
    STAIRSTYPE_RUN_TYPE = -1151207
    STAIRSTYPE_CALCULATION_RULES = -1151206
    STAIRSTYPE_MINIMUM_TREAD_WIDTH_INSIDE_BOUNDARY = -1151205
    STAIRSTYPE_MINIMUM_TREAD_DEPTH = -1151204
    STAIRSTYPE_MAXIMUM_RISER_HEIGHT = -1151203
    STAIRS_TRISER_NUMBER_BASE_INDEX = -1151154
    STAIRS_DBG_SHOW_ANNOTATION_CUT_MARK = -1151153
    STAIRS_DBG_SHOW_MONOLITHIC_SUPPORT_CORSE_GEOM = -1151152
    STAIRS_DBG_SHOW_TRISER_CORSE_GEOM = -1151151
    STAIRS_DBG_SHOW_RUN_CORSE_GEOM = -1151150
    STAIRS_DBG_SHOW_MONOLITHIC_SUPPORT_GEOM = -1151149
    STAIRS_DBG_SHOW_TRISER_GEOM = -1151148
    STAIRS_DBG_SHOW_RUN_GEOM = -1151147
    STAIRS_DBG_SHOW_SUPPORT_PATH = -1151146
    STAIRS_DBG_SHOW_BOUNDARY_3D = -1151145
    STAIRS_DBG_SHOW_BOUNDARY_2D = -1151144
    STAIRS_DBG_SHOW_LANDING_PATH = -1151143
    STAIRS_DBG_SHOW_LANDING_BOUNDARY = -1151142
    STAIRS_DBG_SHOW_RUN_OUTLINE_FOR_PLAN = -1151141
    STAIRS_DBG_SHOW_RUN_NOSING = -1151140
    STAIRS_DBG_SHOW_RUN_RISER = -1151139
    STAIRS_DBG_SHOW_RUN_PATH_3D = -1151138
    STAIRS_DBG_SHOW_RUN_PATH_2D = -1151137
    STAIRS_DBG_SHOW_RIGHT_RUN_BOUNDARY_3D = -1151136
    STAIRS_DBG_SHOW_LEFT_RUN_BOUNDARY_3D = -1151135
    STAIRS_DBG_SHOW_RIGHT_RUN_BOUNDARY_2D = -1151134
    STAIRS_DBG_SHOW_LEFT_RUN_BOUNDARY_2D = -1151133
    STAIRS_DBG_SHOW_LANDING_FACES = -1151132
    STAIRS_DBG_SHOW_TREAD_FACES = -1151131
    STAIRS_ENABLE_CALCULATION_RULE_CHECKING = -1151118
    STAIRS_MIN_AUTOMATIC_LANDING_DEPTH = -1151117
    STAIRS_RUN_WIDTH_MEASUREMENT = -1151116
    STAIRS_TOTAL_NUMBER_OF_TREADS = -1151113
    STAIRS_TOTAL_NUMBER_OF_RISERS = -1151112
    STAIRS_ACTUAL_NUMBER_OF_RISERS = -1151111
    STAIRS_DESIRED_NUMBER_OF_RISERS = -1151110
    STAIRS_MULTISTORY_UP_TO_LEVEL = -1151106
    STAIRS_STAIRS_HEIGHT = -1151105
    STAIRS_TOP_LEVEL = -1151103
    STAIRS_BASE_LEVEL = -1151101
    PART_MAKER_DIVISION_PROFILE_OFFSET = -1150624
    DIVISION_PROFILE_WIDTH = -1150623
    PART_MAKER_SPLITTER_PROFILE_EDGE_MATCH = -1150622
    PART_MAKER_SPLITTER_PROFILE_FLIP_ALONG = -1150605
    PART_MAKER_SPLITTER_PROFILE_FLIP_ACROSS = -1150604
    PART_MAKER_SPLITTER_PROFILE = -1150603
    FAMILY_KEYWORD_PROTECTED = -1150602
    PARTMAKER_PARAM_DIVISION_GAP = -1150601
    POINTCLOUDINSTANCE_NAME = -1150600
    ANALYTICAL_MODEL_ROTATION = -1150501
    POINTCLOUDTYPE_SCALE = -1150500
    PROPERTY_SET_DESCRIPTION = -1150481
    PROPERTY_SET_MATERIAL_ASPECT = -1150480
    RBS_DUCT_PIPE_SYSTEM_ABBREVIATION_PARAM = -1150468
    PHY_MATERIAL_PROPERTIES = -1150467
    PROPERTY_SET_NAME = -1150466
    PHY_MATERIAL_PARAM_SUBCLASS = -1150465
    PHY_MATERIAL_PARAM_CLASS = -1150464
    ANALYTICAL_MODEL_PERIMETER = -1150463
    ANALYTICAL_MODEL_AREA = -1150462
    ANALYTICAL_MODEL_LENGTH = -1150461
    SHEET_ASSEMBLY_KEYNOTE = -1150460
    SHEET_ASSEMBLY_ASSEMBLY_DESCRIPTION = -1150459
    SHEET_ASSEMBLY_COST = -1150458
    SHEET_ASSEMBLY_TYPE_MARK = -1150457
    SHEET_ASSEMBLY_ASSEMBLY_CODE = -1150456
    SHEET_ASSEMBLY_DESCRIPTION = -1150455
    SHEET_ASSEMBLY_URL = -1150454
    SHEET_ASSEMBLY_TYPE_COMMENTS = -1150453
    SHEET_ASSEMBLY_MANUFACTURER = -1150452
    SHEET_ASSEMBLY_MODEL = -1150451
    SHEET_ASSEMBLY_NAME = -1150450
    RBS_REFERENCE_FREESIZE = -1150435
    RBS_REFERENCE_OVERALLSIZE = -1150434
    RBS_REFERENCE_LINING_THICKNESS = -1150433
    RBS_REFERENCE_LINING_TYPE = -1150432
    RBS_REFERENCE_INSULATION_THICKNESS = -1150431
    RBS_REFERENCE_INSULATION_TYPE = -1150430
    RBS_PIPE_CALCULATED_SIZE = -1150427
    RBS_DUCT_CALCULATED_SIZE = -1150426
    RBS_INSULATION_LINING_VOLUME = -1150425
    ASSEMBLY_NAME = -1150420
    RBS_COMPONENT_CLASSIFICATION_PARAM = -1150412
    RBS_SYSTEM_RISEDROP_PARAM = -1150411
    RBS_SYSTEM_RISEDROP_2LINEDROPSYMBOL_PARAM = -1150410
    RBS_SYSTEM_RISEDROP_2LINERISESYMBOL_PARAM = -1150409
    RBS_SYSTEM_RISEDROP_1LINEDROPSYMBOL_PARAM = -1150408
    RBS_SYSTEM_RISEDROP_1LINERISESYMBOL_PARAM = -1150407
    RBS_SYSTEM_RISEDROP_1LINETEEUPSYMBOL_PARAM = -1150406
    RBS_SYSTEM_RISEDROP_1LINETEEDOWNSYMBOL_PARAM = -1150405
    ASSEMBLY_NAMING_CATEGORY = -1150403
    RAILING_SYSTEM_HAS_TOP_RAIL = -1150380
    CONTINUOUSRAIL_JOIN_TYPE_PARAM = -1150373
    CONTINUOUSRAIL_PLUS_TREAD_DEPTH_PARAM = -1150361
    CONTINUOUSRAIL_LENGTH_PARAM = -1150360
    HANDRAIL_SUPPORTS_JUSTIFICATION_PARAM = -1150355
    HANDRAIL_SUPPORTS_NUMBER_PARAM = -1150354
    HANDRAIL_SUPPORTS_SPACING_PARAM = -1150353
    HANDRAIL_SUPPORTS_LAYOUT_PARAM = -1150352
    HANDRAIL_SUPPORTS_TYPE_PARAM = -1150351
    CONTINUOUSRAIL_END_EXTENSION_LENGTH_PARAM = -1150350
    CONTINUOUSRAIL_END_TERMINATION_ATTACHMENT_PARAM = -1150349
    CONTINUOUSRAIL_EXTENSION_LENGTH_PARAM = -1150348
    CONTINUOUSRAIL_BEGINNING_TERMINATION_ATTACHMENT_PARAM = -1150347
    CONTINUOUSRAIL_END_TERMINATION_TYPE_PARAM = -1150346
    CONTINUOUSRAIL_BEGINNING_TERMINATION_TYPE_PARAM = -1150345
    CONTINUOUSRAIL_MATERIALS_PARAM = -1150344
    CONTINUOUSRAIL_TRANSITION_TYPE_PARAM = -1150343
    HANDRAIL_HAND_CLEARANCE_PARAM = -1150342
    HANDRAIL_PROJECTION_PARAM = -1150341
    HANDRAIL_HEIGHT_PARAM = -1150340
    CONTINUOUSRAIL_PROFILE_TYPE_PARAM = -1150339
    CONTINUOUSRAIL_FILLET_RADIUS_PARAM = -1150338
    CONTINUOUSRAIL_DEFAULT_JOIN_TYPE_PARAM = -1150337
    RAILING_SYSTEM_SECONDARY_HANDRAILS_LATTERAL_OFFSET = -1150336
    RAILING_SYSTEM_SECONDARY_HANDRAILS_HEIGHT_PARAM = -1150335
    RAILING_SYSTEM_SECONDARY_HANDRAILS_POSITION_PARAM = -1150334
    RAILING_SYSTEM_SECONDARY_HANDRAILS_TYPES_PARAM = -1150333
    RAILING_SYSTEM_HANDRAILS_LATTERAL_OFFSET = -1150332
    RAILING_SYSTEM_HANDRAILS_HEIGHT_PARAM = -1150331
    RAILING_SYSTEM_HANDRAILS_POSITION_PARAM = -1150330
    RAILING_SYSTEM_HANDRAILS_TYPES_PARAM = -1150329
    RAILING_SYSTEM_TOP_RAIL_HEIGHT_PARAM = -1150328
    RAILING_SYSTEM_TOP_RAIL_TYPES_PARAM = -1150327
    POINT_ELEMENT_ROTATION_ANGLE = -1150322
    FLEXIBLE_INSTANCE_FLIP = -1150321
    POINT_FLEXIBLE_ORIENTATION_TYPE = -1150320
    DEFAULT_CONSTRUCTION_MASS_FLOOR = -1150310
    DEFAULT_CONSTRUCTION_MASS_OPENING = -1150309
    DEFAULT_CONSTRUCTION_MASS_SKYLIGHT = -1150307
    DEFAULT_CONSTRUCTION_MASS_GLAZING = -1150306
    DEFAULT_CONSTRUCTION_EXT_WALL_UNDERGROUND = -1150305
    DEFAULT_CONSTRUCTION_MASS_SLAB = -1150304
    DEFAULT_CONSTRUCTION_MASS_SHADE = -1150303
    DEFAULT_CONSTRUCTION_MASS_ROOF = -1150302
    DEFAULT_CONSTRUCTION_MASS_INTERIOR_WALL = -1150301
    DEFAULT_CONSTRUCTION_MASS_EXTERIOR_WALL = -1150300
    ENERGY_ANALYSIS_SPACE_BOUNDING_PARAM = -1150236
    ENERGY_ANALYSIS_HORIZONTAL_VOID_THRESHOLD = -1150235
    ENERGY_ANALYSIS_VERTICAL_VOID_THRESHOLD = -1150234
    RBS_ENERGY_ANALYSIS_BUILDING_ENVELOPE_ANALYTICAL_GRID_CELL_SIZE = -1150233
    RBS_ENERGY_ANALYSIS_BUILDING_ENVELOPE_DETERMINATION_PARAM = -1150232
    LEADER_RIGHT_ATTACHMENT = -1150231
    LEADER_LEFT_ATTACHMENT = -1150230
    POINT_ELEMENT_MEASURE_FROM = -1150227
    POINT_ELEMENT_ANGLE = -1150226
    POINT_ELEMENT_CHORD_LENGTH = -1150225
    POINT_ELEMENT_NORMALIZED_SEGMENT_LENGTH = -1150224
    POINT_ELEMENT_SEGMENT_LENGTH = -1150223
    POINT_ELEMENT_NORMALIZED_CURVE_PARAMATER = -1150222
    POINT_ELEMENT_NON_NORMALIZED_CURVE_PARAMATER = -1150221
    POINT_ELEMENT_MEASUREMENT_TYPE = -1150220
    STRUCTURAL_BEAM_END_ATTACHMENT_REFCOLUMN_END = -1150219
    STRUCTURAL_BEAM_START_ATTACHMENT_REFCOLUMN_END = -1150218
    STRUCTURAL_BEAM_END_ATTACHMENT_DISTANCE = -1150217
    STRUCTURAL_BEAM_START_ATTACHMENT_DISTANCE = -1150216
    STRUCTURAL_BEAM_END_ATTACHMENT_TYPE = -1150215
    STRUCTURAL_BEAM_START_ATTACHMENT_TYPE = -1150214
    TEXT_BOX_VISIBILITY = -1150213
    CURVE_BY_POINTS_PROJECTION_TYPE = -1150212
    FOLLOW_SURFACE = -1150211
    RBS_ENERGY_ANALYSIS_INCLUDE_THERMAL_PROPERTIES = -1150210
    POINT_FLEXIBLE_NUM_PARAM = -1150209
    FRAMING_LENGTH_ROUNDOFF = -1150208
    SLANTED_COLUMN_BASE_EXTENSION = -1150207
    SLANTED_COLUMN_TOP_EXTENSION = -1150206
    SLANTED_COLUMN_BASE_CUT_STYLE = -1150205
    SLANTED_COLUMN_TOP_CUT_STYLE = -1150204
    RBS_BUILDING_USELOADCREDITS = -1150203
    TILE_PATTERN_FAMREF_COMPONENT_EXTENTS = -1150202
    TILE_PATTERN_GRID_CELLS_Y = -1150201
    TILE_PATTERN_GRID_CELLS_X = -1150200
    TILE_PATTERN_GRID_UNIT_Y = -1150199
    TILE_PATTERN_GRID_UNIT_X = -1150198
    POINT_ELEMENT_SHOW_NORMAL_PLANE_ONLY = -1150197
    LEVEL_IS_GROUND_PLANE = -1150195
    BASEPOINT_ANGLETON_PARAM = -1150194
    BASEPOINT_ELEVATION_PARAM = -1150193
    BASEPOINT_EASTWEST_PARAM = -1150192
    BASEPOINT_NORTHSOUTH_PARAM = -1150191
    SLANTED_COLUMN_GEOMETRY_TREATMENT_BASE = -1150190
    SLANTED_COLUMN_GEOMETRY_TREATMENT_TOP = -1150189
    ROOM_PLENUM_LIGHTING_PARAM = -1150188
    STRUCTURAL_ATTACHMENT_TOP_REFERENCEDEND = -1150183
    STRUCTURAL_ATTACHMENT_TOP_RATIO = -1150182
    STRUCTURAL_ATTACHMENT_TOP_DISTANCE = -1150181
    STRUCTURAL_ATTACHMENT_TOP_TYPE = -1150180
    STRUCTURAL_ATTACHMENT_BASE_REFERENCEDEND = -1150179
    STRUCTURAL_ATTACHMENT_BASE_RATIO = -1150178
    STRUCTURAL_ATTACHMENT_BASE_DISTANCE = -1150177
    STRUCTURAL_ATTACHMENT_BASE_TYPE = -1150176
    INSTANCE_MOVE_BASE_WITH_GRIDS = -1150173
    INSTANCE_MOVE_TOP_WITH_GRIDS = -1150172
    SLANTED_COLUMN_TYPE_PARAM = -1150171
    VIEW_SLANTED_COLUMN_SYMBOL_OFFSET = -1150170
    POINT_ELEMENT_MIRRORED = -1150169
    POINT_ELEMENT_ZFLIPPED = -1150168
    POINT_ELEMENT_HOSTED_ON_FACE_V_PARAM = -1150167
    POINT_ELEMENT_HOSTED_ON_FACE_U_PARAM = -1150166
    LOCKED_END_OFFSET = -1150165
    LOCKED_START_OFFSET = -1150164
    LOCKED_BASE_OFFSET = -1150163
    LOCKED_TOP_OFFSET = -1150162
    RBS_PROJECT_REPORTTYPE_PARAM = -1150161
    RBS_BUILDING_CONSTRUCTIONCLASS = -1150160
    CONNECTOR_UTILITY_PARAM = -1150159
    POINT_FLEXIBLE_SHOW_NUMBER = -1150158
    POINT_FLEXIBLE_CONSTRAINED = -1150157
    POINT_NAME_PARAM = -1150156
    POINT_ADAPTIVE_TYPE_PARAM = -1150155
    SPOT_DIM_STYLE_SLOPE_UNITS = -1150154
    POINT_ELEMENT_DRIVING = -1150153
    SPOT_SLOPE_LEADER_LENGTH = -1150152
    SPOT_SLOPE_SUFFIX = -1150151
    SPOT_SLOPE_PREFIX = -1150150
    POINT_VISIBILITY_PARAM = -1150149
    POINT_ELEMENT_SHOW_PLANES = -1150148
    CURVE_IS_REFERENCE_LINE = -1150147
    POINT_ELEMENT_HOSTED_PARAM = -1150146
    POINT_ELEMENT_DRIVEN = -1150145
    POINT_ELEMENT_OFFSET = -1150144
    SPOT_DIM_STYLE_SLOPE_UNITS_ALT = -1150143
    FBX_LIGHT_PHOTOMETRIC_FILE_CACHE = -1150142
    FBX_LIGHT_PHOTOMETRICS_FAM = -1150141
    FAMILY_CURVE_ATTACHMENT_PROPORTION = -1150140
    FBX_LIGHT_LOSS_FACTOR_CTRL = -1150139
    FBX_LIGHT_INITIAL_COLOR_CTRL = -1150138
    FBX_LIGHT_LOSS_FACTOR_METHOD = -1150137
    FBX_LIGHT_INITIAL_COLOR_NAME = -1150134
    FBX_LIGHT_AT_A_DISTANCE = -1150133
    FBX_LIGHT_INITIAL_INTENSITY_INPUT_METHOD = -1150132
    FBX_LIGHT_SOURCE_LENGTH = -1150131
    FBX_LIGHT_SOURCE_DIAMETER = -1150130
    FBX_LIGHT_EMIT_CIRCLE_DIAMETER = -1150129
    FBX_LIGHT_EMIT_RECTANGLE_LENGTH = -1150128
    FBX_LIGHT_EMIT_RECTANGLE_WIDTH = -1150127
    FBX_LIGHT_EMIT_LINE_LENGTH = -1150126
    FBX_LIGHT_EMIT_SHAPE_VISIBLE = -1150118
    FBX_LIGHT_DIMMING_LIGHT_COLOR = -1150117
    FBX_LIGHT_LUMENAIRE_DIRT = -1150115
    FBX_LIGHT_LAMP_LUMEN_DEPR = -1150114
    FBX_LIGHT_SURFACE_LOSS = -1150113
    FBX_LIGHT_LAMP_TILT_LOSS = -1150112
    FBX_LIGHT_VOLTAGE_LOSS = -1150110
    FBX_LIGHT_TEMPERATURE_LOSS = -1150109
    FBX_LIGHT_COLOR_FILTER = -1150108
    FBX_LIGHT_INITIAL_COLOR_TEMPERATURE = -1150107
    FBX_LIGHT_ILLUMINANCE = -1150106
    FBX_LIGHT_LIMUNOUS_INTENSITY = -1150105
    FBX_LIGHT_EFFICACY = -1150104
    FBX_LIGHT_WATTAGE = -1150103
    FBX_LIGHT_INITIAL_INTENSITY = -1150102
    FBX_LIGHT_PHOTOMETRICS = -1150101
    FBX_ASSET_TYPE = -1150100
    DIVIDED_SURFACE_GRID_OPTION_PARAM_2 = -1150086
    DIVIDED_SURFACE_GRID_OPTION_PARAM_1 = -1150085
    DIVIDED_SURFACE_DISPLAY_DISCARDEDDIVISIONLINES = -1150084
    DIVIDED_SURFACE_COMPONENT_TRIM_TYPE = -1150083
    DIVIDED_SURFACE_PATTERN_MIRROR = -1150082
    DIVIDED_SURFACE_RULE_2_SUSPENSION = -1150081
    DIVIDED_SURFACE_RULE_1_SUSPENSION = -1150080
    DIVIDED_SURFACE_DISPLAY_COMPONENTS = -1150079
    DIVIDED_SURFACE_PATTERN_FILL_MATERIAL = -1150078
    DIVIDED_SURFACE_DISPLAY_PATTERN_FILL = -1150077
    DIVIDED_SURFACE_PATTERN_LINES_STYLE = -1150076
    DIVIDED_SURFACE_DISPLAY_PATTERN_LINES = -1150075
    DIVIDED_SURFACE_GRIDLINES_STYLE = -1150074
    DIVIDED_SURFACE_DISPLAY_GRIDLINES = -1150073
    DIVIDED_SURFACE_DISPLAY_NODES = -1150072
    DIVIDED_SURFACE_ORIGINAL_SURFACE_MATERIAL = -1150071
    DIVIDED_SURFACE_DISPLAY_ORIGINAL_SURFACE = -1150070
    DIVIDED_SURFACE_DISPLAY_SURFACE_OPTION = -1150069
    DIVIDED_SURFACE_ALL_GRID_ROTATION = -1150068
    DIVIDED_SURFACE_TILE_BORDER = -1150067
    DIVIDED_SURFACE_ALL_POINTS = -1150062
    DIVIDED_SURFACE_PATTERN = -1150061
    DIVIDED_SURFACE_PATTERN_FLIP = -1150060
    DIVIDED_SURFACE_PATTERN_ROTATION_ANGLE = -1150059
    DIVIDED_SURFACE_PATTERN_INDENT_2 = -1150058
    DIVIDED_SURFACE_PATTERN_INDENT_1 = -1150057
    DIVIDED_SURFACE_COVER_FACE_COMPLETELY = -1150056
    DIVIDED_SURFACE_OFFSET_FROM_SURFACE = -1150055
    DIVIDED_SURFACE_TOTAL_EDGE_LENGTH = -1150054
    DIVIDED_SURFACE_EDGE_NUMBER = -1150053
    DIVIDED_SURFACE_POINT_NUMBER = -1150052
    DIVIDED_SURFACE_FACET_NUMBER = -1150051
    DIVIDED_SURFACE_SURFACE_AREA = -1150050
    RBS_ELEC_ROOM_LIGHTING_CALC_LUMINAIREPLANE = -1144331
    LAYOUTNODE_CURVETYPE_PARAM = -1142000
    FABRICATION_PART_PAT_NO = -1141014
    FABRICATION_END_SIZE = -1141013
    FABRICATION_BRA_SIZE = -1141012
    FABRICATION_SEC_SIZE = -1141011
    FABRICATION_PRI_SIZE = -1141010
    FABRICATION_CHANGE_SERVICE_PARAM = -1141009
    FABRICATION_SET_UP_DOWN_TAG_FROM_BOTTOM = -1141008
    FABRICATION_INSULATION_MATERIAL_FINISH = -1141007
    DISPLACED_ELEMENT_DISPLACEMENT_Z = -1141006
    DISPLACED_ELEMENT_DISPLACEMENT_Y = -1141005
    DISPLACED_ELEMENT_DISPLACEMENT_X = -1141004
    DISPLACEMENT_PATH_STYLE = -1141003
    DISPLACEMENT_PATH_DEPTH = -1141002
    REFERENCE_VIEWER_UI_TARGET_VIEW = -1141001
    REFERENCE_VIEWER_UI_TARGET_FILTER = -1141000
    FABRICATION_FITTING_DESCRIPTION = -1140999
    FABRICATION_DOUBLEWALL_MATERIAL_ABBREVIATION = -1140998
    FABRICATION_MATERIAL_ABBREVIATION = -1140997
    FABRICATION_INSULATION_SPECIFICATION_ABBREVIATION = -1140996
    FABRICATION_INSULATION_ABBREVIATION = -1140995
    FABRICATION_SPECIFICATION_ABBREVIATION = -1140994
    FABRICATION_PIPE_INVERT_ELEVATION = -1140993
    FABRICATION_BOTTOM_ELEVATION_INCLUDE_INSULATION_OF_PART = -1140992
    FABRICATION_BOTTOM_ELEVATION_OF_PART = -1140991
    FABRICATION_TOP_ELEVATION_INCLUDE_INSULATION_OF_PART = -1140990
    FABRICATION_TOP_ELEVATION_OF_PART = -1140989
    FABRICATION_CENTERLINE_ELEVATION_OF_PART = -1140988
    FABRICATION_SPOT_BOTTOM_ELEVATION_INCLUDE_INSULATION_OF_PART = -1140987
    FABRICATION_SPOT_BOTTOM_ELEVATION_OF_PART = -1140986
    FABRICATION_SPOT_TOP_ELEVATION_INCLUDE_INSULATION_OF_PART = -1140985
    FABRICATION_SPOT_TOP_ELEVATION_OF_PART = -1140984
    FABRICATION_PART_DOUBLEWALL_MATERIAL_AREA = -1140983
    FABRICATION_SET_UP_DOWN_TAG = -1140982
    FABRICATION_PART_SHEETMETAL_AREA = -1140981
    FABRICATION_SERVICE_ABBREVIATION = -1140979
    FABRICATION_PART_MATERIAL_THICKNESS = -1140978
    FABRICATION_PART_NOTES = -1140977
    FABRICATION_PART_LINING_AREA = -1140976
    FABRICATION_PART_ITEM_NUMBER = -1140975
    FABRICATION_PART_INSULATION_AREA = -1140974
    FABRICATION_SERVICE_NAME = -1140973
    FABRICATION_PART_DOUBLEWALL_MATERIAL_THICKNESS = -1140972
    FABRICATION_PART_DOUBLEWALL_MATERIAL = -1140971
    FABRICATION_PART_CUT_TYPE = -1140970
    FABRICATION_PART_BOUGHT_OUT = -1140969
    FABRICATION_PART_ALIAS = -1140968
    FABRICATION_ROUTING_SOLUTIONS_UI_PARAM = -1140967
    FABRICATION_PRODUCT_CODE = -1140966
    FABRICATION_PART_TAKEOFF_DIALOG_PARAM = -1140965
    FABRICATION_PART_DEPTH_OUT_OPTION = -1140957
    FABRICATION_PART_WIDTH_OUT_OPTION = -1140956
    FABRICATION_PART_DIAMETER_OUT_OPTION = -1140955
    FABRICATION_PART_DIAMETER_IN_OPTION = -1140952
    FABRICATION_PART_DEPTH_IN_OPTION = -1140951
    FABRICATION_PART_WIDTH_IN_OPTION = -1140950
    FABRICATION_PART_ANGLE_OPTION = -1140949
    FABRICATION_PART_LENGTH_OPTION = -1140948
    FABRICATION_INSULATION_SPEC = -1140947
    FABRICATION_PART_LENGTH = -1140944
    FABRICATION_PRODUCT_ENTRY = -1140943
    FABRICATION_PART_DEPTH_OUT = -1140935
    FABRICATION_PART_WIDTH_OUT = -1140934
    FABRICATION_PART_DIAMETER_OUT = -1140933
    FABRICATION_PART_DEPTH_IN = -1140930
    FABRICATION_PART_WIDTH_IN = -1140929
    FABRICATION_END_OFFSET_PARAM = -1140925
    FABRICATION_START_OFFSET_PARAM = -1140924
    FABRICATION_SLOPE_PARAM = -1140923
    FABRICATION_RELATIVE_FILENAME = -1140921
    FABRICATION_VENDOR = -1140920
    FABRICATION_BOTTOM_OF_PART = -1140919
    FABRICATION_TOP_OF_PART = -1140918
    FABRICATION_OFFSET_PARAM = -1140917
    FABRICATION_LEVEL_PARAM = -1140916
    FABRICATION_SPECIFICATION = -1140915
    FABRICATION_VENDOR_CODE = -1140914
    FABRICATION_PART_WEIGHT = -1140913
    FABRICATION_PART_DIAMETER_IN = -1140912
    FABRICATION_PART_ANGLE = -1140911
    FABRICATION_PRODUCT_DATA_INSTALL_TYPE = -1140910
    FABRICATION_PART_MATERIAL = -1140909
    FABRICATION_PRODUCT_DATA_OEM = -1140908
    FABRICATION_PRODUCT_DATA_PRODUCT = -1140907
    FABRICATION_PRODUCT_DATA_ITEM_DESCRIPTION = -1140906
    FABRICATION_PRODUCT_DATA_SIZE_DESCRIPTION = -1140905
    FABRICATION_PRODUCT_DATA_MATERIAL_DESCRIPTION = -1140904
    FABRICATION_PRODUCT_DATA_SPECIFICATION = -1140903
    FABRICATION_PRODUCT_DATA_LONG_DESCRIPTION = -1140902
    FABRICATION_PRODUCT_DATA_RANGE = -1140901
    FABRICATION_PRODUCT_DATA_FINISH_DESCRIPTION = -1140900
    TRUSS_FAMILY_BOTTOM_CHORD_STRUCTURAL_TYPES_PARAM = -1140766
    TRUSS_FAMILY_BOTTOM_CHORD_ANGLE_PARAM = -1140764
    TRUSS_FAMILY_BOTTOM_CHORD_VERTICAL_PROJECTION_PARAM = -1140763
    TRUSS_FAMILY_BOTTOM_CHORD_START_RELEASE_TYPE = -1140762
    TRUSS_FAMILY_BOTTOM_CHORD_END_RELEASE_TYPE = -1140761
    REFERENCE_OTHER_VIEW_UI_REF_VIEW = -1140759
    REFERENCE_OTHER_VIEW_UI_TOGGLE = -1140758
    JOIST_SYSTEM_ELEM_TAG_NEW_MEMBERS_VIEW = -1140757
    REFERENCE_VIEWER_ATTR_TAG = -1140756
    REFERENCE_VIEWER_TARGET_VIEW = -1140755
    MATCHLINE_BOTTOM_PLANE = -1140754
    MATCHLINE_TOP_PLANE = -1140753
    MATCHLINE_BOTTOM_OFFSET = -1140752
    MATCHLINE_TOP_OFFSET = -1140751
    TRUSS_FAMILY_TOP_CHORD_STRUCTURAL_TYPES_PARAM = -1140746
    TRUSS_FAMILY_TOP_CHORD_ANGLE_PARAM = -1140744
    TRUSS_FAMILY_TOP_CHORD_VERTICAL_PROJECTION_PARAM = -1140743
    TRUSS_FAMILY_TOP_CHORD_START_RELEASE_TYPE = -1140742
    TRUSS_FAMILY_TOP_CHORD_END_RELEASE_TYPE = -1140741
    TRUSS_FAMILY_DIAG_WEB_STRUCTURAL_TYPES_PARAM = -1140736
    TRUSS_FAMILY_DIAG_WEB_ANGLE_PARAM = -1140734
    TRUSS_FAMILY_DIAG_WEB_START_RELEASE_TYPE = -1140732
    TRUSS_FAMILY_DIAG_WEB_END_RELEASE_TYPE = -1140731
    TRUSS_FAMILY_VERT_WEB_STRUCTURAL_TYPES_PARAM = -1140726
    TRUSS_FAMILY_VERT_WEB_ANGLE_PARAM = -1140724
    TRUSS_FAMILY_VERT_WEB_START_RELEASE_TYPE = -1140722
    TRUSS_FAMILY_VERT_WEB_END_RELEASE_TYPE = -1140721
    TRUSS_ELEMENT_TAG_NEW_MEMBERS_VIEW = -1140718
    TRUSS_NON_BEARING_OFFSET_PARAM = -1140717
    TRUSS_BEARING_CHORD_TOP_BOTTOM_PARAM = -1140716
    TRUSS_ELEMENT_SPAN_PARAM = -1140715
    TRUSS_ELEMENT_STICK_JUST_PARAM = -1140714
    TRUSS_FAMILY_WEBS_HAVE_SYMBOLIC_CUTBACK_PARAM = -1140713
    TRUSS_HEIGHT = -1140712
    TRUSS_FAMILY_TRANSFORMATION_PARAM = -1140711
    TRUSS_ELEMENT_ROTATE_CHORDS_WITH_TRUSS = -1140710
    TRUSS_ELEMENT_REFERENCE_LEVEL_PARAM = -1140709
    TRUSS_ELEMENT_END1_ELEVATION = -1140708
    TRUSS_ELEMENT_END0_ELEVATION = -1140707
    TRUSS_ELEMENT_BEARING_JUST_PARAM = -1140706
    TRUSS_ELEMENT_CREATE_BOTTOM_PARAM = -1140705
    TRUSS_ELEMENT_CREATE_TOP_PARAM = -1140704
    TRUSS_ELEMENT_ANGLE_PARAM = -1140703
    TRUSS_ELEMENT_CLASS_PARAM = -1140702
    TRUSS_LENGTH = -1140700
    BOUNDARY_PARAM_PRESET_AREA = -1140635
    BOUNDARY_PARAM_PRESET_LINEAR = -1140634
    BOUNDARY_PARAM_PRESET = -1140633
    BOUNDARY_Z_TRANSLATION_SPRING = -1140532
    BOUNDARY_Z_TRANSLATION_FIXED = -1140531
    BOUNDARY_Z_ROTATION_SPRING = -1140530
    BOUNDARY_Z_ROTATION_FIXED = -1140529
    BOUNDARY_Y_TRANSLATION_SPRING = -1140528
    BOUNDARY_Y_TRANSLATION_FIXED = -1140527
    BOUNDARY_Y_ROTATION_SPRING = -1140526
    BOUNDARY_Y_ROTATION_FIXED = -1140525
    BOUNDARY_X_TRANSLATION_SPRING = -1140524
    BOUNDARY_X_TRANSLATION_FIXED = -1140523
    BOUNDARY_X_ROTATION_SPRING = -1140522
    BOUNDARY_X_ROTATION_FIXED = -1140521
    BOUNDARY_AREA_RESTRAINT_Z = -1140520
    BOUNDARY_AREA_RESTRAINT_Y = -1140519
    BOUNDARY_AREA_RESTRAINT_X = -1140518
    BOUNDARY_LINEAR_RESTRAINT_ROT_X = -1140517
    BOUNDARY_LINEAR_RESTRAINT_Z = -1140516
    BOUNDARY_LINEAR_RESTRAINT_Y = -1140515
    BOUNDARY_LINEAR_RESTRAINT_X = -1140514
    BOUNDARY_RESTRAINT_ROT_Z = -1140513
    BOUNDARY_RESTRAINT_ROT_Y = -1140512
    BOUNDARY_RESTRAINT_ROT_X = -1140511
    BOUNDARY_RESTRAINT_Z = -1140510
    BOUNDARY_RESTRAINT_Y = -1140509
    BOUNDARY_RESTRAINT_X = -1140508
    BOUNDARY_DIRECTION_ROT_Z = -1140507
    BOUNDARY_DIRECTION_ROT_Y = -1140506
    BOUNDARY_DIRECTION_ROT_X = -1140505
    BOUNDARY_DIRECTION_Z = -1140504
    BOUNDARY_DIRECTION_Y = -1140503
    BOUNDARY_DIRECTION_X = -1140502
    BOUNDARY_CONDITIONS_IS_EXT = -1140501
    BOUNDARY_CONDITIONS_TYPE = -1140500
    KEY_SOURCE_PARAM = -1140423
    KEYNOTE_PARAM = -1140422
    KEYNOTE_NUMBER = -1140421
    SHEET_KEY_NUMBER = -1140420
    KEYNOTE_TEXT = -1140419
    KEY_VALUE = -1140418
    PHY_MATERIAL_PARAM_GRADE = -1140417
    PHY_MATERIAL_PARAM_SPECIES = -1140416
    PHY_MATERIAL_PARAM_EXP_COEFF = -1140415
    PHY_MATERIAL_PARAM_BENDING = -1140414
    PHY_MATERIAL_PARAM_SHEAR_MOD = -1140413
    PHY_MATERIAL_PARAM_POISSON_MOD = -1140412
    PHY_MATERIAL_PARAM_SHEAR_PERPENDICULAR = -1140410
    PHY_MATERIAL_PARAM_SHEAR_PARALLEL = -1140409
    PHY_MATERIAL_PARAM_COMPRESSION_PERPENDICULAR = -1140408
    PHY_MATERIAL_PARAM_COMPRESSION_PARALLEL = -1140407
    PHY_MATERIAL_PARAM_YOUNG_MOD = -1140401
    PHY_MATERIAL_PARAM_TYPE = -1140400
    ELEM_CATEGORY_PARAM_MT = -1140363
    ELEM_CATEGORY_PARAM = -1140362
    MATERIAL_VOLUME = -1140361
    MATERIAL_AREA = -1140360
    MATERIAL_ASPAINT = -1140359
    MATERIAL_NAME = -1140355
    RBS_PIPE_SLOPE_OPTIONS_DEF_PARAM = -1140340
    FABRICATION_SERVICE_PARAM = -1140339
    CONNECTOR_ANGLE_OF_DEFLECTION = -1140338
    CONNECTOR_LENGTH = -1140337
    RBS_DUCT_SYSTEM_CALCULATION_PARAM = -1140336
    RBS_PIPE_SYSTEM_CALCULATION_PARAM = -1140335
    RBS_PIPING_SYSTEM_TYPE_PARAM = -1140334
    RBS_DUCT_SYSTEM_TYPE_PARAM = -1140333
    RBS_SYSTEM_ABBREVIATION_PARAM = -1140332
    MEP_SYSTEM_LINE_GRAPHICS_OVERRIDES_PARAM = -1140331
    RBS_PIPE_SLOPE_DEF_PARAM = -1140330
    CONNECTOR_ENGAGEMENT_LENGTH = -1140329
    RBS_SYSTEM_FLOW_CONVERSION_METHOD_PARAM = -1140328
    RBS_SYSTEM_NUM_ELEMENTS_PARAM = -1140327
    RBS_SYSTEM_BASE_ELEMENT_PARAM = -1140326
    RBS_SYSTEM_CLASSIFICATION_PARAM = -1140325
    RBS_SYSTEM_NAME_PARAM = -1140324
    PHY_MATERIAL_PARAM_LIGHT_WEIGHT = -1140323
    PHY_MATERIAL_PARAM_BEHAVIOR = -1140322
    PHY_MATERIAL_PARAM_RESISTANCE_CALC_STRENGTH = -1140321
    PHY_MATERIAL_PARAM_REDUCTION_FACTOR = -1140320
    PHY_MATERIAL_PARAM_MINIMUM_TENSILE_STRENGTH = -1140319
    PHY_MATERIAL_PARAM_MINIMUM_YIELD_STRESS = -1140318
    PHY_MATERIAL_PARAM_SHEAR_STRENGTH_REDUCTION = -1140317
    PHY_MATERIAL_PARAM_SHEAR_REINFORCEMENT = -1140316
    PHY_MATERIAL_PARAM_BENDING_REINFORCEMENT = -1140315
    PHY_MATERIAL_PARAM_CONCRETE_COMPRESSION = -1140314
    PHY_MATERIAL_PARAM_EXP_COEFF3 = -1140312
    PHY_MATERIAL_PARAM_EXP_COEFF2 = -1140311
    PHY_MATERIAL_PARAM_EXP_COEFF1 = -1140310
    PHY_MATERIAL_PARAM_UNIT_WEIGHT = -1140309
    PHY_MATERIAL_PARAM_SHEAR_MOD3 = -1140308
    PHY_MATERIAL_PARAM_SHEAR_MOD2 = -1140307
    PHY_MATERIAL_PARAM_SHEAR_MOD1 = -1140306
    PHY_MATERIAL_PARAM_POISSON_MOD3 = -1140305
    PHY_MATERIAL_PARAM_POISSON_MOD2 = -1140304
    PHY_MATERIAL_PARAM_POISSON_MOD1 = -1140303
    PHY_MATERIAL_PARAM_YOUNG_MOD3 = -1140302
    PHY_MATERIAL_PARAM_YOUNG_MOD2 = -1140301
    PHY_MATERIAL_PARAM_YOUNG_MOD1 = -1140300
    RBS_PIPE_SIZE_MAXIMUM = -1140284
    RBS_PIPE_SIZE_MINIMUM = -1140283
    RBS_DUCT_PRESSURE_DROP = -1140282
    ROUTING_PREFERENCE_PARAM = -1140281
    RBS_DUCT_ROUTING_PREFERENCE_PARAM = -1140280
    RBS_SEGMENT_DESCRIPTION_PARAM = -1140279
    RBS_PIPE_JOINTTYPE_PARAM = -1140278
    RBS_PIPE_SEGMENT_PARAM = -1140277
    RBS_ROUTING_PREFERENCE_PARAM = -1140276
    RBS_PARALLELPIPES_VERTICAL_OFFSET_VALUE = -1140275
    RBS_PARALLELPIPES_HORIZONTAL_OFFSET_VALUE = -1140274
    RBS_PARALLELPIPES_VERTICAL_NUMBER = -1140273
    RBS_PARALLELPIPES_HORIZONTAL_NUMBER = -1140272
    RBS_PARALLELCONDUITS_VERTICAL_OFFSET_VALUE = -1140271
    RBS_PARALLELCONDUITS_HORIZONTAL_OFFSET_VALUE = -1140270
    RBS_PARALLELCONDUITS_VERTICAL_NUMBER = -1140269
    RBS_PARALLELCONDUITS_HORIZONTAL_NUMBER = -1140268
    RBS_FP_SPRINKLER_ORIFICE_SIZE_PARAM = -1140266
    RBS_FP_SPRINKLER_TEMPERATURE_RATING_PARAM = -1140265
    RBS_FP_SPRINKLER_K_FACTOR_PARAM = -1140264
    RBS_FP_SPRINKLER_PRESSURE_CLASS_PARAM = -1140263
    RBS_FP_SPRINKLER_ORIFICE_PARAM = -1140262
    RBS_FP_SPRINKLER_COVERAGE_PARAM = -1140261
    RBS_FP_SPRINKLER_RESPONSE_PARAM = -1140260
    MEP_PROFILE_TYPE_PARAM = -1140259
    RBS_SHOW_PROFILE_TYPE = -1140258
    RBS_PIPE_SYSTEM_FIXTURE_UNIT_PARAM = -1140257
    RBS_PIPE_SLOPE = -1140256
    RBS_DUCT_SLOPE = -1140255
    RBS_CURVE_UTSLOPE = -1140254
    RBS_PIPE_VOLUME_PARAM = -1140253
    RBS_PIPE_WFU_PARAM = -1140252
    RBS_PIPE_HWFU_PARAM = -1140251
    RBS_PIPE_CWFU_PARAM = -1140250
    RBS_PIPE_FLOW_CONFIGURATION_PARAM = -1140249
    RBS_PIPE_FLOW_DIRECTION_PARAM = -1140248
    RBS_PIPE_FIXTURE_UNITS_PARAM = -1140246
    RBS_PIPE_STATIC_PRESSURE = -1140242
    RBS_PIPE_INSULATION_THICKNESS = -1140241
    RBS_DUCT_BOTTOM_ELEVATION = -1140240
    RBS_DUCT_TOP_ELEVATION = -1140239
    RBS_PIPE_OUTER_DIAMETER = -1140238
    RBS_PIPE_INVERT_ELEVATION = -1140237
    RBS_PIPE_TYPE_FITTING_LOSS_METHOD_PARAM = -1140234
    RBS_PIPE_TYPE_FITTING_LOSS_TABLE_PARAM = -1140233
    RBS_PIPE_TYPE_FITTING_LOSS_KFACTOR_PARAM = -1140232
    RBS_PIPE_TYPE_VALVE_LOSS_CVFACTOR_PARAM = -1140231
    RBS_PIPE_FITTING_LOSS_METHOD_PARAM = -1140230
    RBS_PIPE_FITTING_LOSS_TABLE_PARAM = -1140229
    RBS_PIPE_FITTING_LOSS_KFACTOR_PARAM = -1140228
    RBS_PIPE_VALVE_LOSS_CVFACTOR_PARAM = -1140227
    RBS_PIPE_ADDITIONAL_FLOW_PARAM = -1140226
    RBS_PIPE_DIAMETER_PARAM = -1140225
    RBS_CURVE_SLOPE = -1140224
    RBS_ADJUSTABLE_CONNECTOR = -1140223
    RBS_FLOW_FACTOR_PARAM = -1140222
    RBS_DUCT_FLOW_CONFIGURATION_PARAM = -1140221
    RBS_DUCT_FLOW_DIRECTION_PARAM = -1140219
    RBS_PIPE_FLUID_TYPE_PARAM = -1140218
    RBS_PIPE_FLUID_TEMPERATURE_PARAM = -1140217
    RBS_PIPE_FLUID_VISCOSITY_PARAM = -1140215
    RBS_PIPE_FLUID_DENSITY_PARAM = -1140214
    RBS_PIPE_FLOW_PARAM = -1140213
    RBS_PIPE_INNER_DIAM_PARAM = -1140212
    RBS_PIPE_REYNOLDS_NUMBER_PARAM = -1140211
    RBS_PIPE_RELATIVE_ROUGHNESS_PARAM = -1140210
    RBS_PIPE_FLOW_STATE_PARAM = -1140209
    RBS_PIPE_FRICTION_FACTOR_PARAM = -1140208
    RBS_PIPE_VELOCITY_PARAM = -1140207
    RBS_PIPE_FRICTION_PARAM = -1140206
    RBS_PIPE_PRESSUREDROP_PARAM = -1140205
    RBS_PIPE_ROUGHNESS_PARAM = -1140204
    RBS_PIPE_MATERIAL_PARAM = -1140202
    RBS_PIPE_CONNECTIONTYPE_PARAM = -1140201
    RBS_PIPE_CLASS_PARAM = -1140200
    RBS_ELEC_CIRCUIT_SLOT_INDEX = -1140181
    CIRCUIT_WAYS_PARAM = -1140180
    CIRCUIT_LOAD_CLASSIFICATION_ABBREVIATION_PARAM = -1140179
    CIRCUIT_PHASE_PARAM = -1140178
    RBS_ELEC_CIRCUIT_NAMING_INDEX = -1140177
    RBS_ELEC_CIRCUIT_CONNECTION_TYPE_PARAM = -1140176
    RBS_ELEC_CIRCUIT_PATH_OFFSET_PARAM = -1140175
    RBS_ELEC_CIRCUIT_PATH_MODE_PARAM = -1140174
    RBS_ELEC_CIRCUIT_START_SLOT = -1140173
    CONNECTOR_GENDER_TYPE = -1140172
    CONNECTOR_JOINT_TYPE = -1140171
    RBS_ELEC_PANEL_CONFIGURATION_PARAM = -1140170
    RBS_ELEC_PANEL_LOCATION_PARAM = -1140169
    PANEL_SCHEDULE_NAME = -1140168
    TEMPLATE_NAME = -1140167
    RBS_ELEC_PANEL_CURRENT_PHASEC_PARAM = -1140166
    RBS_ELEC_PANEL_CURRENT_PHASEB_PARAM = -1140165
    RBS_ELEC_PANEL_CURRENT_PHASEA_PARAM = -1140164
    RBS_ELEC_LOADSUMMARY_DEMAND_FACTOR_RULE_PARAM = -1140163
    RBS_ELEC_LOADSUMMARY_DEMAND_CURRENT_PARAM = -1140162
    RBS_ELEC_LOADSUMMARY_CONNECTED_CURRENT_PARAM = -1140161
    RBS_ELEC_LOADSUMMARY_DEMAND_LOAD_PARAM = -1140160
    RBS_ELEC_LOADSUMMARY_DEMAND_FACTOR_PARAM = -1140159
    RBS_ELEC_LOADSUMMARY_CONNECTED_LOAD_PARAM = -1140158
    RBS_ELEC_LOADSUMMARY_LOADCLASSIFICATION_PARAM = -1140157
    RBS_ELEC_CIRCUIT_NOTES_PARAM = -1140156
    RBS_ELEC_CIRCUIT_NUMBER_OF_ELEMENTS_PARAM = -1140155
    RBS_ELEC_CIRCUIT_FRAME_PARAM = -1140154
    RBS_ELEC_PANEL_TOTAL_DEMAND_CURRENT_PARAM = -1140153
    RBS_ELEC_PANEL_TOTAL_CONNECTED_CURRENT_PARAM = -1140152
    RBS_ELEC_PANEL_TOTAL_DEMAND_FACTOR_PARAM = -1140151
    RBS_ELEC_PANEL_SCHEDULE_FOOTER_NOTES_PARAM = -1140150
    RBS_ELEC_PANEL_SCHEDULE_HEADER_NOTES_PARAM = -1140149
    RBS_ELEC_PANEL_NUMWIRES_PARAM = -1140148
    RBS_ELEC_PANEL_NUMPHASES_PARAM = -1140147
    RBS_ELEC_PANEL_NEUTRAL_RATING_PARAM = -1140146
    RBS_ELEC_PANEL_NEUTRAL_BUS_PARAM = -1140145
    RBS_ELEC_PANEL_GROUND_BUS_PARAM = -1140144
    RBS_ELEC_PANEL_BUSSING_PARAM = -1140143
    RBS_ELEC_PANEL_SUBFEED_LUGS_PARAM = -1140142
    RBS_ELEC_PANEL_SUPPLY_FROM_PARAM = -1140141
    RBS_ELEC_PANEL_MCB_RATING_PARAM = -1140140
    RBS_ELEC_PANEL_MAINSTYPE_PARAM = -1140139
    RBS_ELEC_PANEL_FEED_PARAM = -1140138
    RBS_CONDUITRUN_OUTER_DIAM_PARAM = -1140137
    RBS_CONDUITRUN_INNER_DIAM_PARAM = -1140136
    RBS_CONDUITRUN_DIAMETER_PARAM = -1140135
    RBS_CABLETRAYRUN_WIDTH_PARAM = -1140134
    RBS_CABLETRAYRUN_HEIGHT_PARAM = -1140133
    RBS_CABLETRAYCONDUITRUN_LENGTH_PARAM = -1140132
    RBS_LOAD_SUB_CLASSIFICATION_MOTOR = -1140131
    RBS_CABLETRAY_SHAPETYPE = -1140130
    RBS_CABLETRAYCONDUIT_BENDORFITTING = -1140129
    RBS_CTC_SERVICE_TYPE = -1140128
    RBS_CONDUIT_OUTER_DIAM_PARAM = -1140127
    RBS_CONDUIT_INNER_DIAM_PARAM = -1140126
    RBS_CTC_BOTTOM_ELEVATION = -1140125
    RBS_CTC_TOP_ELEVATION = -1140124
    RBS_CONDUIT_DIAMETER_PARAM = -1140123
    RBS_CABLETRAY_WIDTH_PARAM = -1140122
    RBS_CABLETRAY_HEIGHT_PARAM = -1140121
    CIRCUIT_LOAD_CLASSIFICATION_PARAM = -1140120
    CABLETRAY_MINBENDMULTIPLIER_PARAM = -1140119
    CONDUIT_STANDARD_TYPE_PARAM = -1140118
    RBS_CONDUIT_TRADESIZE = -1140117
    RBS_CONDUIT_BENDRADIUS = -1140116
    RBS_CABLETRAY_BENDRADIUS = -1140115
    RBS_CABLETRAY_RUNGHEIGHT = -1140114
    RBS_CABLETRAY_RUNGWIDTH = -1140113
    RBS_CABLETRAY_RUNGSPACE = -1140112
    RBS_CABLETRAY_THICKNESS = -1140111
    RBS_ELEC_SWITCH_ID_PARAM = -1140110
    RBS_WIRE_CIRCUIT_DESCRIPTION = -1140109
    RBS_WIRE_CIRCUIT_LOAD_NAME = -1140108
    RBS_WIRE_NUM_CONDUCTORS_PARAM = -1140107
    RBS_ELEC_WIRE_TICKMARK_STATE = -1140106
    RBS_ELEC_CIRCUIT_PANEL_PARAM = -1140104
    RBS_ELEC_CIRCUIT_NUMBER = -1140103
    RBS_ELEC_WIRE_CIRCUITS = -1140102
    RBS_ELEC_CIRCUIT_WIRE_NUM_RUNS_PARAM = -1140101
    RBS_ELEC_CIRCUIT_WIRE_NUM_HOTS_PARAM = -1140100
    RBS_ELEC_CIRCUIT_WIRE_NUM_NEUTRALS_PARAM = -1140099
    RBS_ELEC_CIRCUIT_WIRE_NUM_GROUNDS_PARAM = -1140098
    RBS_ELEC_WIRE_TYPE = -1140097
    RBS_ELEC_WIRE_ELEVATION = -1140096
    RBS_ELEC_WIRE_HOT_ADJUSTMENT = -1140094
    RBS_ELEC_WIRE_NEUTRAL_ADJUSTMENT = -1140093
    RBS_ELEC_WIRE_GROUND_ADJUSTMENT = -1140092
    RBS_ELEC_WIRE_SHARE_NEUTRAL = -1140091
    RBS_ELEC_WIRE_SHARE_GROUND = -1140090
    RBS_ELEC_CIRCUIT_NAME = -1140089
    RBS_FAMILY_CONTENT_SECONDARY_DISTRIBSYS = -1140088
    RBS_ELEC_CIRCUIT_NAMING = -1140087
    RBS_ELEC_CIRCUIT_PREFIX_SEPARATOR = -1140086
    RBS_ELEC_CIRCUIT_PREFIX = -1140085
    RBS_ELEC_MODIFICATIONS = -1140084
    RBS_ELEC_ENCLOSURE = -1140083
    RBS_ELEC_MAINS = -1140082
    RBS_ELEC_MOUNTING = -1140081
    RBS_ELEC_SHORT_CIRCUIT_RATING = -1140080
    RBS_ELEC_MAX_POLE_BREAKERS = -1140079
    RBS_ELEC_PANEL_NAME = -1140078
    RBS_ELEC_PANEL_TOTALESTLOAD_HVAC_PARAM = -1140077
    RBS_ELEC_PANEL_TOTALLOAD_HVAC_PARAM = -1140076
    RBS_ELEC_PANEL_TOTALESTLOAD_LIGHT_PARAM = -1140075
    RBS_ELEC_PANEL_TOTALLOAD_LIGHT_PARAM = -1140074
    RBS_ELEC_PANEL_TOTALESTLOAD_POWER_PARAM = -1140073
    RBS_ELEC_PANEL_TOTALLOAD_POWER_PARAM = -1140072
    RBS_ELEC_PANEL_TOTALESTLOAD_OTHER_PARAM = -1140071
    RBS_ELEC_PANEL_TOTALLOAD_OTHER_PARAM = -1140070
    RBS_ELEC_PANEL_TOTALESTLOAD_PARAM = -1140069
    RBS_ELEC_PANEL_TOTALLOAD_PARAM = -1140068
    RBS_ELEC_DEMANDFACTOR_LOADCLASSIFICATION_PARAM = -1140067
    RBS_ELEC_DEMANDFACTOR_LOAD_PARAM = -1140066
    RBS_ELEC_DEMANDFACTOR_DEMANDLOAD_PARAM = -1140065
    RBS_FAMILY_CONTENT_DISTRIBUTION_SYSTEM = -1140064
    RBS_DISTRIBUTIONSYS_VLL_PARAM = -1140063
    RBS_DISTRIBUTIONSYS_VLG_PARAM = -1140062
    RBS_DISTRIBUTIONSYS_PHASE_PARAM = -1140061
    RBS_DISTRIBUTIONSYS_CONFIG_PARAM = -1140060
    RBS_DISTRIBUTIONSYS_NUMWIRES_PARAM = -1140059
    RBS_VOLTAGETYPE_VOLTAGE_PARAM = -1140058
    RBS_VOLTAGETYPE_MINVOLTAGE_PARAM = -1140057
    RBS_VOLTAGETYPE_MAXVOLTAGE_PARAM = -1140056
    RBS_ELEC_APPARENT_LOAD_PHASEC = -1140055
    RBS_ELEC_APPARENT_LOAD_PHASEB = -1140054
    RBS_ELEC_APPARENT_LOAD_PHASEA = -1140053
    RBS_ELEC_TRUE_LOAD_PHASEC = -1140052
    RBS_ELEC_TRUE_LOAD_PHASEB = -1140051
    RBS_ELEC_TRUE_LOAD_PHASEA = -1140050
    RBS_ELEC_TRUE_CURRENT_PARAM = -1140049
    RBS_ELEC_TRUE_CURRENT_PHASEA_PARAM = -1140048
    RBS_ELEC_TRUE_CURRENT_PHASEB_PARAM = -1140047
    RBS_ELEC_TRUE_CURRENT_PHASEC_PARAM = -1140046
    RBS_ELEC_APPARENT_CURRENT_PARAM = -1140045
    RBS_ELEC_APPARENT_CURRENT_PHASEA_PARAM = -1140044
    RBS_ELEC_APPARENT_CURRENT_PHASEB_PARAM = -1140043
    RBS_ELEC_APPARENT_CURRENT_PHASEC_PARAM = -1140042
    RBS_ELEC_VOLTAGE_DROP_PARAM = -1140041
    RBS_ELEC_CALC_COEFFICIENT_UTILIZATION = -1140040
    RBS_ELEC_CIRCUIT_LENGTH_PARAM = -1140039
    RBS_ELEC_CIRCUIT_RATING_PARAM = -1140038
    RBS_ELEC_CIRCUIT_WIRE_SIZE_PARAM = -1140037
    RBS_ELEC_CIRCUIT_WIRE_TYPE_PARAM = -1140036
    RBS_ELEC_ROOM_CAVITY_RATIO = -1140035
    FBX_LIGHT_PHOTOMETRIC_FILE = -1140034
    RBS_ELEC_ROOM_AVERAGE_ILLUMINATION = -1140033
    RBS_ELEC_ROOM_REFLECTIVITY_FLOOR = -1140032
    RBS_ELEC_ROOM_REFLECTIVITY_WALLS = -1140031
    RBS_ELEC_ROOM_REFLECTIVITY_CEILING = -1140030
    RBS_ELEC_ROOM_LIGHTING_CALC_WORKPLANE = -1140029
    RBS_WIRE_MATERIAL_PARAM = -1140028
    RBS_WIRE_TEMPERATURE_RATING_PARAM = -1140027
    RBS_WIRE_INSULATION_PARAM = -1140026
    RBS_WIRE_MAX_CONDUCTOR_SIZE_PARAM = -1140025
    RBS_WIRE_NEUTRAL_MULTIPLIER_PARAM = -1140024
    RBS_WIRE_NEUTRAL_INCLUDED_IN_BALANCED_LOAD_PARAM = -1140023
    RBS_WIRE_NEUTRAL_MODE_PARAM = -1140022
    RBS_WIRE_CONDUIT_TYPE_PARAM = -1140021
    RBS_ELEC_AMBIENT_TEMPERATURE = -1140020
    RBS_ELEC_CIRCUIT_TYPE = -1140018
    RBS_ELEC_LOAD_CLASSIFICATION = -1140014
    RBS_ELEC_TRUE_LOAD_PHASE3 = -1140013
    RBS_ELEC_TRUE_LOAD_PHASE2 = -1140012
    RBS_ELEC_TRUE_LOAD_PHASE1 = -1140011
    RBS_ELEC_TRUE_LOAD = -1140010
    RBS_ELEC_POWER_FACTOR_STATE = -1140009
    RBS_ELEC_POWER_FACTOR = -1140008
    RBS_ELEC_APPARENT_LOAD_PHASE3 = -1140007
    RBS_ELEC_APPARENT_LOAD_PHASE2 = -1140006
    RBS_ELEC_APPARENT_LOAD_PHASE1 = -1140005
    RBS_ELEC_APPARENT_LOAD = -1140004
    RBS_ELEC_BALANCED_LOAD = -1140003
    RBS_ELEC_VOLTAGE = -1140002
    RBS_ELEC_NUMBER_OF_POLES = -1140001
    RBS_CONNECTOR_DESCRIPTION = -1140000
    VIEW_FAMILY_SCHEDULES = -1139999
    VIEW_FAMILY_AND_TYPE_SCHEDULES = -1139998
    VIEW_TYPE_SCHEDULES = -1139997
    MARKUPS_PRIVATE = -1133908
    MARKUPS_NOTES = -1133907
    MARKUPS_HISTORY = -1133906
    MARKUPS_STATUS = -1133905
    MARKUPS_LABEL = -1133904
    MARKUPS_CREATOR = -1133903
    MARKUPS_CREATED = -1133902
    MARKUPS_MODIFIED = -1133901
    VIEW_SCHEMA_SETTING_FOR_SYSTEM_TEMPLATE = -1133900
    LEGEND_COMPONENT_DETAIL_LEVEL = -1133753
    LEGEND_COMPONENT_LENGTH = -1133752
    LEGEND_COMPONENT_VIEW = -1133751
    LEGEND_COMPONENT = -1133750
    OPTION_SET_ID = -1133603
    OPTION_NAME = -1133602
    PRIMARY_OPTION_ID = -1133601
    OPTION_SET_NAME = -1133600
    GROUP_ATTACHED_PARENT_NAME = -1133503
    GROUP_ALLOWED_VIEW_TYPES = -1133502
    GROUP_OFFSET_FROM_LEVEL = -1133501
    GROUP_LEVEL = -1133500
    MEP_SYSTEM_FILL_GRAPHICS_OVERRIDES_PARAM = -1133418
    DUCT_TERMINAL_ENGAGEMENT_LENGTH = -1133417
    CONNECTOR_INSIDE_DIAMETER = -1133416
    CONNECTOR_DIAMETER = -1133415
    RBS_CABLETRAYCONDUIT_CONNECTORELEM_TYPE = -1133414
    RBS_CABLETRAYCONDUIT_SYSTEM_TYPE = -1133413
    RBS_CONNECTOR_ISPRIMARY = -1133412
    CONNECTOR_REFERENCE_INDEX = -1133411
    RBS_PIPE_CONNECTOR_SYSTEM_CLASSIFICATION_PARAM = -1133410
    CONNECTOR_ANGLE = -1133409
    RBS_DUCT_CONNECTOR_SYSTEM_CLASSIFICATION_PARAM = -1133408
    CONNECTOR_INDEX = -1133406
    CONNECTOR_VISIBLE_SIZE = -1133405
    CONNECTOR_HEIGHT = -1133404
    CONNECTOR_WIDTH = -1133403
    CONNECTOR_RADIUS = -1133401
    CONNECTOR_PROFILE_TYPE = -1133400
    PIPING_GENDER_TYPE = -1115974
    PIPING_CONNECTION_TYPE = -1115973
    RBS_PART_TYPE = -1115958
    PEAK_LATENT_COOLING_LOAD = -1114819
    PEAK_AIRFLOW_PARAM = -1114818
    SPACE_REFERENCE_LEVEL_PARAM = -1114817
    SPACE_INFILTRATION_AIRFLOW = -1114816
    SPACE_INFILTRATION_AIRFLOW_PER_AREA = -1114815
    SPACE_OUTDOOR_AIRFLOW = -1114814
    SPACE_OUTDOOR_AIRFLOW_PER_PERSON = -1114813
    SPACE_OUTDOOR_AIRFLOW_PER_AREA = -1114812
    SPACE_AIR_CHANGES_PER_HOUR = -1114811
    SPACE_POWER_LOAD_PARAM = -1114810
    SPACE_LIGHTING_LOAD_PARAM = -1114809
    SPACE_PEOPLE_LOAD_PARAM = -1114808
    SPACE_POWER_LOAD_PER_AREA_PARAM = -1114807
    SPACE_LIGHTING_LOAD_PER_AREA_PARAM = -1114806
    SPACE_PEOPLE_LATENT_HEAT_GAIN_PER_PERSON_PARAM = -1114805
    SPACE_PEOPLE_SENSIBLE_HEAT_GAIN_PER_PERSON_PARAM = -1114804
    SPACE_AREA_PER_PERSON_PARAM = -1114803
    SPACE_AIRFLOW_PER_AREA_PARAM = -1114802
    PEAK_COOLING_LOAD_PARAM = -1114801
    PEAK_HEATING_LOAD_PARAM = -1114800
    SPACE_DEHUMIDIFICATION_SET_POINT = -1114711
    SPACE_HUMIDIFICATION_SET_POINT = -1114710
    SPACE_COOLING_SET_POINT = -1114709
    SPACE_HEATING_SET_POINT = -1114708
    ZONE_LEVEL_OFFSET_TOP = -1114707
    ZONE_LEVEL_OFFSET = -1114706
    SYSTEM_ZONE_LEVEL_ID = -1114705
    ZONE_CALCULATED_HYDRONIC_COOLINGFLOW_PARAM = -1114702
    ZONE_CALCULATED_HYDRONIC_HEATINGFLOW_PARAM = -1114701
    ZONE_SPACE_OUTDOOR_AIR_OPTION_PARAM = -1114700
    RBS_GBXML_OPENING_TYPE = -1114400
    ROOM_CALCULATION_POINT = -1114399
    GRID_BANK_COL_WIDTH = -1114398
    GRID_BANK_ROW_HEIGHT = -1114397
    GRID_BANK_COL_NUM = -1114396
    GRID_BANK_ROW_NUM = -1114395
    RBS_CURVETYPE_DEFAULT_BEND_PARAM = -1114394
    RBS_CURVETYPE_DEFAULT_HORIZONTAL_BEND_PARAM = -1114393
    RBS_CURVETYPE_MULTISHAPE_TRANSITION_OVALROUND_PARAM = -1114392
    RBS_CURVETYPE_MULTISHAPE_TRANSITION_RECTOVAL_PARAM = -1114391
    RBS_CURVETYPE_DEFAULT_TEEDOWN_PARAM = -1114390
    RBS_CURVETYPE_DEFAULT_TEEUP_PARAM = -1114389
    RBS_CURVETYPE_DEFAULT_ELBOWDOWN_PARAM = -1114388
    RBS_CURVETYPE_DEFAULT_ELBOWUP_PARAM = -1114387
    RBS_ENERGY_ANALYSIS_EXPORT_CATEGORY_PARAM = -1114386
    RBS_ENERGY_ANALYSIS_EXPORT_COMPLEXITY_PARAM = -1114385
    SPACE_ZONE_NAME = -1114384
    RBS_ENERGY_ANALYSIS_EXPORT_GBXML_DEFAULTS_PARAM = -1114383
    RBS_HVACLOAD_PLENUM_COOLING_LOAD_PARAM = -1114382
    RBS_HVACLOAD_SKYLIGHT_COOLING_LOAD_PARAM = -1114381
    RBS_HVACLOAD_PARTITION_COOLING_LOAD_PARAM = -1114380
    RBS_HVACLOAD_DOOR_COOLING_LOAD_PARAM = -1114379
    RBS_HVACLOAD_WINDOW_COOLING_LOAD_PARAM = -1114378
    RBS_HVACLOAD_WALL_COOLING_LOAD_PARAM = -1114377
    RBS_HVACLOAD_ROOF_COOLING_LOAD_PARAM = -1114376
    RBS_HVACLOAD_SKYLIGHT_AREA_PARAM = -1114375
    RBS_HVACLOAD_PARTITION_AREA_PARAM = -1114374
    RBS_HVACLOAD_FLOOR_AREA_PARAM = -1114373
    RBS_HVACLOAD_DOOR_AREA_PARAM = -1114372
    RBS_HVACLOAD_WINDOW_AREA_PARAM = -1114371
    RBS_HVACLOAD_WALL_AREA_PARAM = -1114370
    RBS_HVACLOAD_ROOF_AREA_PARAM = -1114369
    RBS_ENERGY_ANALYSIS_VIEW_COORD_AXIS_MODE = -1114368
    RBS_ENERGY_ANALYSIS_VIEW_RBE_MODE = -1114367
    RBS_ENERGY_ANALYSIS_VIEW_SHADING_SURFACES_MODE = -1114366
    RBS_ENERGY_ANALYSIS_VIEW_TRANSPARENT_MODE = -1114365
    RBS_ENERGY_ANALYSIS_VIEW_SURFACES_MODE = -1114364
    RBS_ENERGY_ANALYSIS_VIEW_INNER_SHELL_MODE = -1114363
    RBS_ENERGY_ANALYSIS_VIEW_OUTER_SHELL_MODE = -1114362
    RBS_ENERGY_ANALYSIS_VIEW_BUILDING_SHELL_MODE = -1114361
    RBS_LINING_THICKNESS_FOR_DUCT = -1114360
    RBS_INSULATION_THICKNESS_FOR_PIPE = -1114359
    RBS_INSULATION_THICKNESS_FOR_DUCT = -1114358
    BUILDING_UNOCCUPIED_COOLING_SET_POINT_PARAM = -1114357
    BUILDING_CLOSING_TIME_PARAM = -1114356
    BUILDING_OPENING_TIME_PARAM = -1114355
    SPACE_PEOPLE_ACTIVITY_LEVEL_PARAM = -1114354
    SPACE_ELEC_EQUIPMENT_RADIANT_PERCENTAGE_PARAM = -1114353
    SPACE_POWER_SCHEDULE_PARAM = -1114351
    SPACE_LIGHTING_SCHEDULE_PARAM = -1114350
    SPACE_OCCUPANCY_SCHEDULE_PARAM = -1114349
    SPACE_INFILTRATION_PARAM = -1114348
    SPACE_CARPETING_PARAM = -1114347
    ZONE_AIR_VOLUME_CALCULATION_TYPE_PARAM = -1114345
    ZONE_COIL_BYPASS_PERCENTAGE_PARAM = -1114344
    ZONE_CALCULATED_AREA_PER_COOLING_LOAD_PARAM = -1114343
    ZONE_CALCULATED_AREA_PER_HEATING_LOAD_PARAM = -1114342
    ZONE_USE_AIR_CHANGES_PER_HOUR_PARAM = -1114341
    ZONE_USE_OUTSIDE_AIR_PER_AREA_PARAM = -1114340
    ZONE_USE_OUTSIDE_AIR_PER_PERSON_PARAM = -1114339
    ZONE_USE_DEHUMIDIFICATION_SETPOINT_PARAM = -1114338
    ZONE_USE_HUMIDIFICATION_SETPOINT_PARAM = -1114337
    ZONE_OUTDOOR_AIR_INFORMATION_PARAM = -1114336
    ZONE_COOLING_INFORMATION_PARAM = -1114335
    ZONE_HEATING_INFORMATION_PARAM = -1114334
    RBS_ENERGY_ANALYSIS_SLIVER_SPACE_TOLERANCE = -1114333
    ZONE_AREA_GROSS = -1114332
    ZONE_VOLUME_GROSS = -1114331
    SPACE_IS_PLENUM = -1114330
    SPACE_IS_OCCUPIABLE = -1114329
    SPACE_ASSOC_ROOM_NUMBER = -1114328
    SPACE_ASSOC_ROOM_NAME = -1114327
    ZONE_PHASE = -1114326
    ZONE_PHASE_ID = -1114325
    RBS_ENERGY_ANALYSIS_PROJECT_PHASE_PARAM = -1114324
    ROOM_CALCULATED_SUPPLY_AIRFLOW_PER_AREA_PARAM = -1114323
    ROOM_CALCULATED_COOLING_LOAD_PER_AREA_PARAM = -1114322
    ROOM_CALCULATED_HEATING_LOAD_PER_AREA_PARAM = -1114321
    ZONE_CALCULATED_SUPPLY_AIRFLOW_PER_AREA_PARAM = -1114320
    ZONE_CALCULATED_COOLING_LOAD_PER_AREA_PARAM = -1114319
    ZONE_CALCULATED_HEATING_LOAD_PER_AREA_PARAM = -1114318
    ZONE_LEVEL_ID = -1114317
    ZONE_OA_RATE_PER_ACH_PARAM = -1114316
    ZONE_OUTSIDE_AIR_PER_AREA_PARAM = -1114315
    ZONE_OUTSIDE_AIR_PER_PERSON_PARAM = -1114314
    ZONE_DEHUMIDIFICATION_SET_POINT_PARAM = -1114313
    ZONE_HUMIDIFICATION_SET_POINT_PARAM = -1114312
    ZONE_COOLING_AIR_TEMPERATURE_PARAM = -1114311
    ZONE_HEATING_AIR_TEMPERATURE_PARAM = -1114310
    ZONE_COOLING_SET_POINT_PARAM = -1114309
    ZONE_HEATING_SET_POINT_PARAM = -1114308
    ZONE_CALCULATED_SUPPLY_AIRFLOW_PARAM = -1114307
    ZONE_CALCULATED_COOLING_LOAD_PARAM = -1114306
    ZONE_CALCULATED_HEATING_LOAD_PARAM = -1114305
    ZONE_SERVICE_TYPE_PARAM = -1114304
    ZONE_VOLUME = -1114303
    ZONE_PERIMETER = -1114302
    ZONE_AREA = -1114301
    ZONE_NAME = -1114300
    RBS_ENERGY_ANALYSIS_VIEW_UPDATE_SURFACES = -1114299
    RBS_PROJECT_CONSTRUCTION_TYPE_SHADINGFACTOR_PARAM = -1114296
    RBS_CONSTRUCTION_TYPE_SHADINGFACTOR_PARAM = -1114295
    RBS_ENERGY_ANALYSIS_GROUND_PLANE_PARAM = -1114293
    RBS_ENERGY_ANALYSIS_SURFACE_ORIGIN_Z = -1114292
    RBS_ENERGY_ANALYSIS_SURFACE_ORIGIN_Y = -1114291
    RBS_ENERGY_ANALYSIS_SURFACE_ORIGIN_X = -1114290
    RBS_ENERGY_ANALYSIS_SURFACE_AZIMUTH = -1114289
    RBS_ENERGY_ANALYSIS_SURFACE_TILT = -1114288
    RBS_ENERGY_ANALYSIS_SURFACE_CADOBJECTID = -1114287
    RBS_ENERGY_ANALYSIS_SURFACE_ADJACENT_SPACE_ID2 = -1114286
    RBS_ENERGY_ANALYSIS_SURFACE_ADJACENT_SPACE_ID1 = -1114285
    ROOM_EDIT_ELECTRICAL_LOADS_PARAM = -1114284
    ROOM_EDIT_PEOPLE_LOADS_PARAM = -1114283
    RBS_PROJECT_LOCATION_PARAM = -1114282
    ROOM_ACTUAL_LIGHTING_LOAD_PER_AREA_PARAM = -1114261
    ROOM_ACTUAL_POWER_LOAD_PER_AREA_PARAM = -1114260
    ROOM_BASE_HEAT_LOAD_ON_PARAM = -1114259
    ROOM_LIGHTING_LOAD_UNITS_PARAM = -1114258
    ROOM_POWER_LOAD_UNITS_PARAM = -1114257
    ROOM_DESIGN_COOLING_LOAD_PARAM = -1114256
    ROOM_CALCULATED_COOLING_LOAD_PARAM = -1114255
    ROOM_DESIGN_HEATING_LOAD_PARAM = -1114254
    ROOM_CALCULATED_HEATING_LOAD_PARAM = -1114253
    ROOM_BASE_RETURN_AIRFLOW_ON_PARAM = -1114252
    ROOM_CONSTRUCTION_SET_PARAM = -1114251
    RBS_CONSTRUCTION_SET_PARAM = -1114249
    RBS_SERVICE_TYPE_PARAM = -1114248
    RBS_GBXML_SURFACE_AREA = -1114247
    RBS_GBXML_SURFACE_TYPE = -1114246
    RBS_GBXML_SURFACE_NAME = -1114245
    FAMILY_ELECTRICAL_MAINTAIN_ANNOTATION_ORIENTATION = -1114243
    RBS_FAMILY_CONTENT_ANNOTATION_DISPLAY = -1114242
    RBS_ELECTRICAL_DATA = -1114241
    RBS_CALCULATED_SIZE = -1114240
    ROOM_PEOPLE_SENSIBLE_HEAT_GAIN_PER_PERSON_PARAM = -1114239
    RBS_IS_CUSTOM_FITTING = -1114238
    RBS_CONNECTOR_OFFSET_OBSOLETE = -1114237
    RBS_LOOKUP_TABLE_NAME = -1114236
    ROOM_DESIGN_LIGHTING_LOAD_PARAM = -1114230
    ROOM_DESIGN_POWER_LOAD_PARAM = -1114229
    ROOM_ACTUAL_LIGHTING_LOAD_PARAM = -1114226
    ROOM_ACTUAL_POWER_LOAD_PARAM = -1114225
    ROOM_BASE_LIGHTING_LOAD_ON_PARAM = -1114224
    ROOM_BASE_POWER_LOAD_ON_PARAM = -1114223
    ROOM_DESIGN_OTHER_LOAD_PER_AREA_PARAM = -1114222
    ROOM_DESIGN_MECHANICAL_LOAD_PER_AREA_PARAM = -1114221
    ROOM_DESIGN_LIGHTING_LOAD_PER_AREA_PARAM = -1114220
    ROOM_DESIGN_POWER_LOAD_PER_AREA_PARAM = -1114219
    FBX_LIGHT_BALLAST_LOSS = -1114218
    FBX_LIGHT_TOTAL_LIGHT_LOSS = -1114217
    RBS_ROOM_COEFFICIENT_UTILIZATION = -1114216
    RBS_FAMILY_CONTENT_TAKEOFF_FIXED_LENGTH = -1114215
    RBS_FAMILY_CONTENT_TAKEOFF_PROJLENGTH = -1114214
    RBS_FAMILY_CONTENT_TAKEOFF_LENGTH = -1114213
    RBS_FAMILY_CONTENT_OFFSET_HEIGHT = -1114212
    RBS_FAMILY_CONTENT_OFFSET_WIDTH = -1114211
    FAMILY_CONTENT_PART_TYPE = -1114206
    GBXML_EDIT_DATA_PARAM = -1114197
    ROOM_ACTUAL_EXHAUST_AIRFLOW_PARAM = -1114196
    ROOM_ACTUAL_RETURN_AIRFLOW_PARAM = -1114195
    ROOM_ACTUAL_SUPPLY_AIRFLOW_PARAM = -1114194
    ROOM_PEOPLE_LATENT_HEAT_GAIN_PER_PERSON_PARAM = -1114189
    ROOM_PEOPLE_TOTAL_HEAT_GAIN_PER_PERSON_PARAM = -1114188
    ROOM_CALCULATED_SUPPLY_AIRFLOW_PARAM = -1114180
    ROOM_DESIGN_EXHAUST_AIRFLOW_PARAM = -1114178
    ROOM_DESIGN_RETURN_AIRFLOW_PARAM = -1114177
    ROOM_DESIGN_SUPPLY_AIRFLOW_PARAM = -1114176
    ROOM_AREA_PER_PERSON_PARAM = -1114175
    ROOM_NUMBER_OF_PEOPLE_PARAM = -1114174
    ROOM_OCCUPANCY_UNIT_PARAM = -1114173
    ROOM_SPACE_TYPE_PARAM = -1114172
    ROOM_CONDITION_TYPE_PARAM = -1114171
    PROJECT_POSTAL_CODE = -1114169
    PROJECT_BUILDING_TYPE = -1114168
    RBS_SIZE_LOCK = -1114167
    RBS_ADDITIONAL_FLOW = -1114166
    RBS_CURVETYPE_MAX_WIDTH_PARAM = -1114165
    RBS_PIPE_FITTING_LOSS_METHOD_SETTINGS = -1114150
    RBS_DUCT_FITTING_LOSS_METHOD_SETTINGS = -1114149
    RBS_CURVETYPE_DEFAULT_CAP_PARAM = -1114148
    RBS_PIPE_FITTING_LOSS_METHOD_SERVER_PARAM = -1114147
    RBS_DUCT_FITTING_LOSS_METHOD_SERVER_PARAM = -1114146
    RBS_CURVETYPE_DEFAULT_MECHJOINT_PARAM = -1114145
    RBS_PIPE_SIZE_FORMATTED_PARAM = -1114144
    RBS_DUCT_SIZE_FORMATTED_PARAM = -1114143
    RBS_DUCT_STATIC_PRESSURE = -1114142
    RBS_FLEX_PIPE_TYPE_PARAM = -1114141
    RBS_PIPE_TYPE_PARAM = -1114140
    RBS_FLEX_DUCT_TYPE_PARAM = -1114139
    RBS_DUCT_TYPE_PARAM = -1114138
    RBS_DUCT_FITTING_LOSS_TABLE_PARAM = -1114137
    RBS_DUCT_FITTING_LOSS_METHOD_PARAM = -1114136
    RBS_FLEXDUCT_ROUNDTYPE_PARAM = -1114135
    RBS_CURVETYPE_PREFERRED_BRANCH_PARAM = -1114134
    RBS_CURVETYPE_DEFAULT_TAKEOFF_PARAM = -1114133
    RBS_OFFSET_PARAM = -1114132
    RBS_CURVETYPE_DEFAULT_UNION_PARAM = -1114131
    RBS_HYDRAULIC_DIAMETER_PARAM = -1114129
    RBS_REYNOLDSNUMBER_PARAM = -1114128
    RBS_EQ_DIAMETER_PARAM = -1114127
    RBS_CURVETYPE_MULTISHAPE_TRANSITION_PARAM = -1114126
    RBS_SECTION = -1114125
    RBS_LOSS_COEFFICIENT = -1114124
    RBS_MAX_FLOW = -1114123
    RBS_MIN_FLOW = -1114122
    RBS_VELOCITY_PRESSURE = -1114121
    RBS_CURVE_SURFACE_AREA = -1114120
    RBS_CURVETYPE_MAX_HEIGHT_PARAM = -1114119
    RBS_LINING_THICKNESS = -1114118
    RBS_INSULATION_THICKNESS = -1114117
    RBS_FRICTION = -1114116
    RBS_CURVETYPE_ROUGHNESS_PARAM = -1114114
    RBS_CURVETYPE_DEFAULT_TRANSITION_PARAM = -1114113
    RBS_CURVETYPE_DEFAULT_CROSS_PARAM = -1114112
    RBS_CURVETYPE_DEFAULT_TEE_PARAM = -1114111
    RBS_CURVETYPE_DEFAULT_ELBOW_PARAM = -1114110
    RBS_PRESSURE_DROP = -1114108
    RBS_VELOCITY = -1114107
    RBS_CURVE_VERT_OFFSET_PARAM = -1114106
    RBS_CURVE_HOR_OFFSET_PARAM = -1114105
    RBS_FLOW_OBSOLETE = -1114104
    RBS_CURVE_DIAMETER_PARAM = -1114103
    RBS_CURVE_HEIGHT_PARAM = -1114102
    RBS_CURVE_WIDTH_PARAM = -1114101
    RBS_FLEX_PATTERN_PARAM = -1114005
    RBS_END_OFFSET_PARAM = -1114003
    RBS_START_OFFSET_PARAM = -1114002
    RBS_END_LEVEL_PARAM = -1114001
    RBS_START_LEVEL_PARAM = -1114000
    ANALYTICAL_MEMBER_FORCE_END_ALL_NON_ZERO = -1060014
    ANALYTICAL_MEMBER_FORCE_START_ALL_NON_ZERO = -1060013
    STRUCTURAL_MEMBER_FORCES = -1060012
    ANALYTICAL_MEMBER_FORCE_END_MZ = -1060011
    ANALYTICAL_MEMBER_FORCE_END_MY = -1060010
    ANALYTICAL_MEMBER_FORCE_END_MX = -1060009
    ANALYTICAL_MEMBER_FORCE_END_FZ = -1060008
    ANALYTICAL_MEMBER_FORCE_END_FY = -1060007
    ANALYTICAL_MEMBER_FORCE_END_FX = -1060006
    ANALYTICAL_MEMBER_FORCE_START_MZ = -1060005
    ANALYTICAL_MEMBER_FORCE_START_MY = -1060004
    ANALYTICAL_MEMBER_FORCE_START_MX = -1060003
    ANALYTICAL_MEMBER_FORCE_START_FZ = -1060002
    ANALYTICAL_MEMBER_FORCE_START_FY = -1060001
    ANALYTICAL_MEMBER_FORCE_START_FX = -1060000
    DIVIDEDPATH_TOTAL_PATH_LENGTH = -1050441
    DIVIDEDPATH_DISPLAY_NODE_NUMBERS = -1050440
    DIVIDEDPATH_MERGED_POINT_NUM = -1050439
    DIVIDEDPATH_DISPLAY_NODES = -1050437
    DIVIDEDPATH_DISPLAY_REFERENCE_CURVES = -1050436
    DIVIDEDPATH_JUSTIFICATION = -1050435
    DIVIDEDPATH_LAYOUT_FIXED_NUM_POINT = -1050434
    DIVIDEDPATH_FLIP_DIRECTION = -1050433
    DIVIDEDPATH_MEASUREMENT_TYPE = -1050432
    DIVIDEDPATH_MAX_DISTANCE = -1050431
    DIVIDEDPATH_MIN_DISTANCE = -1050430
    DIVIDEDPATH_END_INDENT = -1050429
    DIVIDEDPATH_BEGINNING_INDENT = -1050428
    DIVIDEDPATH_DISTANCE = -1050427
    DIVIDEDPATH_LAYOUT = -1050426
    ALIGNMENT_STATION_LABEL_SET_END_STATION = -1019203
    ALIGNMENT_STATION_LABEL_SET_START_STATION = -1019202
    ALIGNMENT_STATION_LABEL_SET_INTERVAL = -1019201
    ALIGNMENT_STATION_LABEL_SET_OFFSET = -1019200
    WALL_SINGLE_SLANT_ANGLE_FROM_VERTICAL = -1019101
    WALL_CROSS_SECTION = -1019100
    IFC_ORGANIZATION = -1019011
    IFC_APPLICATION_VERSION = -1019010
    IFC_APPLICATION_NAME = -1019009
    PROJECT_ORGANIZATION_NAME = -1019008
    PROJECT_ORGANIZATION_DESCRIPTION = -1019007
    PROJECT_BUILDING_NAME = -1019006
    PROJECT_AUTHOR = -1019005
    IFC_SITE_GUID = -1019004
    IFC_BUILDING_GUID = -1019003
    IFC_PROJECT_GUID = -1019002
    IFC_TYPE_GUID = -1019001
    IFC_GUID = -1019000
    STRUCT_CONNECTION_TYPE_NAME = -1018850
    STRUCT_CONNECTION_CUTBACK = -1018805
    STRUCT_CONNECTION_COLUMN_BASE = -1018804
    STRUCT_CONNECTION_COLUMN_TOP = -1018803
    STRUCT_CONNECTION_BEAM_END = -1018802
    STRUCT_CONNECTION_BEAM_START = -1018801
    STRUCT_CONNECTION_APPLY_TO = -1018800
    REBAR_CONTAINER_BAR_TYPE = -1018505
    REINFORCEMENT_VOLUME = -1018503
    REIN_EST_BAR_VOLUME = -1018502
    REIN_EST_BAR_LENGTH = -1018501
    REIN_EST_NUMBER_OF_BARS = -1018500
    PATH_REIN_SHAPE_2 = -1018362
    PATH_REIN_SHAPE_1 = -1018361
    PATH_REIN_SPANLENGTH_ALT_OFFSET = -1018360
    PATH_REIN_SPANLENGTH_BARLENGTH_ALT = -1018359
    PATH_REIN_SPANLENGTH_BARLENGTH_PRIM = -1018358
    PATH_REIN_SPANLENGTH_TOP_ALT = -1018357
    PATH_REIN_END_SPANHOOK_ALT = -1018356
    PATH_REIN_END_SPANHOOK_PRIM = -1018355
    PATH_REIN_SUMMARY = -1018354
    PATH_REIN_SPANLENGTH_BOTTOM_ALT = -1018353
    PATH_REIN_SPANLENGTH_BOTTOM_PRIM = -1018352
    PATH_REIN_SPANHOOK_ALT = -1018351
    PATH_REIN_SPANHOOK_PRIM = -1018350
    PATH_REIN_ADDL_OFFSET = -1018322
    PATH_REIN_ALT_OFFSET = -1018321
    PATH_REIN_END_HOOK_ORIENT_2_WALL = -1018320
    PATH_REIN_END_HOOK_ORIENT_1_WALL = -1018319
    PATH_REIN_END_HOOK_ORIENT_2_SLAB = -1018318
    PATH_REIN_END_HOOK_ORIENT_1_SLAB = -1018317
    PATH_REIN_END_HOOK_TYPE_2 = -1018316
    PATH_REIN_END_HOOK_TYPE_1 = -1018315
    PATH_REIN_HOOK_ORIENT_2_WALL = -1018314
    PATH_REIN_HOOK_ORIENT_1_WALL = -1018313
    PATH_REIN_HOOK_ORIENT_2_SLAB = -1018312
    PATH_REIN_HOOK_ORIENT_1_SLAB = -1018311
    PATH_REIN_HOOK_TYPE_2 = -1018310
    PATH_REIN_HOOK_TYPE_1 = -1018309
    PATH_REIN_LENGTH_2 = -1018308
    PATH_REIN_LENGTH_1 = -1018307
    PATH_REIN_TYPE_2 = -1018306
    PATH_REIN_TYPE_1 = -1018305
    PATH_REIN_ALTERNATING = -1018304
    PATH_REIN_NUMBER_OF_BARS = -1018303
    PATH_REIN_SPACING = -1018302
    PATH_REIN_FACE_WALL = -1018301
    PATH_REIN_FACE_SLAB = -1018300
    REBAR_BAR_DEFORMATION_TYPE = -1018274
    REBAR_SYSTEM_SPACING_BOTTOM_DIR_2_GENERIC = -1018273
    REBAR_SYSTEM_SPACING_BOTTOM_DIR_1_GENERIC = -1018272
    REBAR_SYSTEM_SPACING_TOP_DIR_2_GENERIC = -1018271
    REBAR_SYSTEM_SPACING_TOP_DIR_1_GENERIC = -1018270
    REBAR_SYSTEM_NUMBER_OF_LINES_BOTTOM_DIR_2_GENERIC = -1018269
    REBAR_SYSTEM_NUMBER_OF_LINES_BOTTOM_DIR_1_GENERIC = -1018268
    REBAR_SYSTEM_NUMBER_OF_LINES_TOP_DIR_2_GENERIC = -1018267
    REBAR_SYSTEM_NUMBER_OF_LINES_TOP_DIR_1_GENERIC = -1018266
    REBAR_SYSTEM_BAR_TYPE_BOTTOM_DIR_2_GENERIC = -1018257
    REBAR_SYSTEM_BAR_TYPE_BOTTOM_DIR_1_GENERIC = -1018256
    REBAR_SYSTEM_BAR_TYPE_TOP_DIR_2_GENERIC = -1018255
    REBAR_SYSTEM_BAR_TYPE_TOP_DIR_1_GENERIC = -1018254
    REBAR_SYSTEM_ACTIVE_BOTTOM_DIR_2_GENERIC = -1018253
    REBAR_SYSTEM_ACTIVE_BOTTOM_DIR_1_GENERIC = -1018252
    REBAR_SYSTEM_ACTIVE_TOP_DIR_2_GENERIC = -1018251
    REBAR_SYSTEM_ACTIVE_TOP_DIR_1_GENERIC = -1018250
    REBAR_SYSTEM_SPACING_BACK_DIR_2 = -1018225
    REBAR_SYSTEM_SPACING_BACK_DIR_1 = -1018224
    REBAR_SYSTEM_SPACING_FRONT_DIR_2 = -1018223
    REBAR_SYSTEM_SPACING_FRONT_DIR_1 = -1018222
    REBAR_SYSTEM_NUMBER_OF_LINES_BACK_DIR_2 = -1018221
    REBAR_SYSTEM_NUMBER_OF_LINES_BACK_DIR_1 = -1018220
    REBAR_SYSTEM_NUMBER_OF_LINES_FRONT_DIR_2 = -1018219
    REBAR_SYSTEM_NUMBER_OF_LINES_FRONT_DIR_1 = -1018218
    REBAR_SYSTEM_HOOK_TYPE_BACK_DIR_2 = -1018217
    REBAR_SYSTEM_HOOK_TYPE_BACK_DIR_1 = -1018216
    REBAR_SYSTEM_HOOK_TYPE_FRONT_DIR_2 = -1018215
    REBAR_SYSTEM_HOOK_TYPE_FRONT_DIR_1 = -1018214
    REBAR_SYSTEM_HOOK_ORIENT_BACK_DIR_2 = -1018213
    REBAR_SYSTEM_HOOK_ORIENT_BACK_DIR_1 = -1018212
    REBAR_SYSTEM_HOOK_ORIENT_FRONT_DIR_2 = -1018211
    REBAR_SYSTEM_HOOK_ORIENT_FRONT_DIR_1 = -1018210
    REBAR_SYSTEM_BAR_TYPE_BACK_DIR_2 = -1018209
    REBAR_SYSTEM_BAR_TYPE_BACK_DIR_1 = -1018208
    REBAR_SYSTEM_BAR_TYPE_FRONT_DIR_2 = -1018207
    REBAR_SYSTEM_BAR_TYPE_FRONT_DIR_1 = -1018206
    REBAR_SYSTEM_ACTIVE_BACK_DIR_2 = -1018205
    REBAR_SYSTEM_ACTIVE_BACK_DIR_1 = -1018204
    REBAR_SYSTEM_ACTIVE_FRONT_DIR_2 = -1018203
    REBAR_SYSTEM_ACTIVE_FRONT_DIR_1 = -1018200
    REBAR_SYSTEM_SPACING_BOTTOM_DIR_2 = -1018124
    REBAR_SYSTEM_SPACING_BOTTOM_DIR_1 = -1018123
    REBAR_SYSTEM_SPACING_TOP_DIR_2 = -1018122
    REBAR_SYSTEM_SPACING_TOP_DIR_1 = -1018121
    REBAR_SYSTEM_NUMBER_OF_LINES_BOTTOM_DIR_2 = -1018120
    REBAR_SYSTEM_NUMBER_OF_LINES_BOTTOM_DIR_1 = -1018119
    REBAR_SYSTEM_NUMBER_OF_LINES_TOP_DIR_2 = -1018118
    REBAR_SYSTEM_NUMBER_OF_LINES_TOP_DIR_1 = -1018117
    REBAR_SYSTEM_HOOK_TYPE_BOTTOM_DIR_2 = -1018116
    REBAR_SYSTEM_HOOK_TYPE_BOTTOM_DIR_1 = -1018115
    REBAR_SYSTEM_HOOK_TYPE_TOP_DIR_2 = -1018114
    REBAR_SYSTEM_HOOK_TYPE_TOP_DIR_1 = -1018113
    REBAR_SYSTEM_HOOK_ORIENT_BOTTOM_DIR_2 = -1018112
    REBAR_SYSTEM_HOOK_ORIENT_BOTTOM_DIR_1 = -1018111
    REBAR_SYSTEM_HOOK_ORIENT_TOP_DIR_2 = -1018110
    REBAR_SYSTEM_HOOK_ORIENT_TOP_DIR_1 = -1018109
    REBAR_SYSTEM_BAR_TYPE_BOTTOM_DIR_2 = -1018108
    REBAR_SYSTEM_BAR_TYPE_BOTTOM_DIR_1 = -1018107
    REBAR_SYSTEM_BAR_TYPE_TOP_DIR_2 = -1018106
    REBAR_SYSTEM_BAR_TYPE_TOP_DIR_1 = -1018105
    REBAR_SYSTEM_ACTIVE_BOTTOM_DIR_2 = -1018104
    REBAR_SYSTEM_ACTIVE_BOTTOM_DIR_1 = -1018103
    REBAR_SYSTEM_ACTIVE_TOP_DIR_2 = -1018102
    REBAR_SYSTEM_ACTIVE_TOP_DIR_1 = -1018100
    REBAR_SYSTEM_SPANHOOK_TOP_DIR_2 = -1018055
    REBAR_SYSTEM_SPANHOOK_BOTTOM_DIR_2 = -1018054
    REBAR_SYSTEM_SPANHOOK_RIGHT_DIR_1 = -1018053
    REBAR_SYSTEM_SPANHOOK_LEFT_DIR_1 = -1018052
    REBAR_SYSTEM_SPANACTIVE_DIR_2 = -1018051
    REBAR_SYSTEM_SPANACTIVE_DIR_1 = -1018050
    REBAR_SYSTEM_ADDL_INTERIOR_OFFSET = -1018027
    REBAR_SYSTEM_ADDL_EXTERIOR_OFFSET = -1018026
    REBAR_SYSTEM_ADDL_BOTTOM_OFFSET = -1018025
    REBAR_SYSTEM_ADDL_TOP_OFFSET = -1018024
    REBAR_SYSTEM_TOP_MINOR_MATCHES_BOTTOM_MINOR = -1018023
    REBAR_SYSTEM_TOP_MAJOR_MATCHES_BOTTOM_MAJOR = -1018022
    REBAR_SYSTEM_BOTTOM_MAJOR_MATCHES_BOTTOM_MINOR = -1018021
    REBAR_SYSTEM_TOP_MAJOR_MATCHES_TOP_MINOR = -1018020
    REBAR_SYSTEM_LAYER_SUMMARY_DIR_2_NO_SPACING = -1018019
    REBAR_SYSTEM_LAYER_SUMMARY_DIR_2_WITH_SPACING = -1018018
    REBAR_SYSTEM_LAYER_SUMMARY_DIR_1_NO_SPACING = -1018017
    REBAR_SYSTEM_LAYER_SUMMARY_DIR_1_WITH_SPACING = -1018016
    REBAR_SYSTEM_LAYER_SUMMARY_BOTTOM_DIR_2_NO_SPACING = -1018015
    REBAR_SYSTEM_LAYER_SUMMARY_BOTTOM_DIR_2_WITH_SPACING = -1018014
    REBAR_SYSTEM_LAYER_SUMMARY_BOTTOM_DIR_1_NO_SPACING = -1018013
    REBAR_SYSTEM_LAYER_SUMMARY_BOTTOM_DIR_1_WITH_SPACING = -1018012
    REBAR_SYSTEM_LAYER_SUMMARY_TOP_DIR_2_NO_SPACING = -1018011
    REBAR_SYSTEM_LAYER_SUMMARY_TOP_DIR_2_WITH_SPACING = -1018010
    REBAR_SYSTEM_LAYER_SUMMARY_TOP_DIR_1_NO_SPACING = -1018009
    REBAR_SYSTEM_LAYER_SUMMARY_TOP_DIR_1_WITH_SPACING = -1018008
    REBAR_SYSTEM_COVER_BOTTOM = -1018007
    REBAR_SYSTEM_COVER_TOP = -1018006
    REBAR_SYSTEM_OVERRIDE = -1018005
    REBAR_SYSTEM_LAYER_SUMMARY_NO_SPACING = -1018003
    REBAR_SYSTEM_LAYER_SUMMARY_WITH_SPACING = -1018002
    REBAR_SYSTEM_LAYOUT_RULE = -1018001
    REBAR_SYSTEM_COVER_SIDE = -1018000
    FABRIC_WIRE_OFFSET = -1017739
    FABRIC_WIRE_DISTANCE = -1017738
    FABRIC_WIRE_LENGTH = -1017737
    FABRIC_WIRE_TYPE = -1017736
    BENT_FABRIC_PARAM_LONGITUDINAL_CUT_LENGTH = -1017734
    FABRIC_PARAM_SHARED_FAMILY_KEY = -1017733
    FABRIC_PARAM_CUT_BY_HOST = -1017732
    BENT_FABRIC_PARAM_STRAIGHT_WIRES_LOCATION = -1017731
    CONSTRAINT_FIXED_OFFSET = -1017730
    BENT_FABRIC_PARAM_BEND_DIRECTION = -1017729
    FABRIC_PARAM_SPAN_TAG_COMPONENT_REFERENCE = -1017728
    FABRIC_PARAM_SPAN_SYM_D_RIGHT = -1017727
    FABRIC_PARAM_SPAN_SYM_D_LEFT = -1017726
    FABRIC_PARAM_SPAN_SYM_D_BOTTOM = -1017725
    FABRIC_PARAM_SPAN_SYM_D_TOP = -1017724
    FABRIC_PARAM_SPAN_SYM_RIGHT = -1017723
    FABRIC_PARAM_SPAN_SYM_LEFT = -1017722
    FABRIC_PARAM_SPAN_SYM_BOTTOM = -1017721
    FABRIC_PARAM_SPAN_SYM_TOP = -1017720
    FABRIC_PARAM_TAG_VIEW = -1017713
    FABRIC_PARAM_CUT_SHEET_MASS = -1017712
    FABRIC_PARAM_TOTAL_SHEET_MASS = -1017711
    FABRIC_PARAM_CUT_OVERALL_WIDTH = -1017710
    FABRIC_PARAM_CUT_OVERALL_LENGTH = -1017709
    FABRIC_PARAM_COVER_OFFSET = -1017708
    FABRIC_PARAM_MINOR_LAPSPLICE_LENGTH = -1017707
    FABRIC_PARAM_MAJOR_LAPSPLICE_LENGTH = -1017706
    FABRIC_PARAM_LOCATION_GENERIC = -1017705
    FABRIC_PARAM_LAPSPLICE_POSITION = -1017704
    FABRIC_PARAM_LOCATION_WALL = -1017703
    FABRIC_PARAM_LOCATION_SLAB = -1017702
    FABRIC_PARAM_SHEET_TYPE = -1017701
    FABRIC_BEND_DIAMETER = -1017625
    FABRIC_SHEET_MASSUNIT = -1017624
    FABRIC_SHEET_MINOR_REINFORCEMENT_AREA = -1017623
    FABRIC_SHEET_MAJOR_REINFORCEMENT_AREA = -1017622
    FABRIC_SHEET_MASS = -1017621
    FABRIC_SHEET_MINOR_SPACING = -1017620
    FABRIC_SHEET_MINOR_NUMBER_OF_WIRES = -1017619
    FABRIC_SHEET_MINOR_LAYOUT_PATTERN = -1017618
    FABRIC_SHEET_MINOR_END_OVERHANG = -1017617
    FABRIC_SHEET_MINOR_START_OVERHANG = -1017616
    FABRIC_SHEET_WIDTH = -1017615
    FABRIC_SHEET_OVERALL_WIDTH = -1017614
    FABRIC_SHEET_MAJOR_SPACING = -1017613
    FABRIC_SHEET_MAJOR_NUMBER_OF_WIRES = -1017612
    FABRIC_SHEET_MAJOR_LAYOUT_PATTERN = -1017611
    FABRIC_SHEET_MAJOR_END_OVERHANG = -1017610
    FABRIC_SHEET_MAJOR_START_OVERHANG = -1017609
    FABRIC_SHEET_LENGTH = -1017608
    FABRIC_SHEET_OVERALL_LENGTH = -1017607
    FABRIC_SHEET_DEFAULT_MINOR_LAPSPLICE_LENGTH = -1017606
    FABRIC_SHEET_DEFAULT_MAJOR_LAPSPLICE_LENGTH = -1017605
    FABRIC_SHEET_MINOR_DIRECTION_WIRE_TYPE = -1017604
    FABRIC_SHEET_MAJOR_DIRECTION_WIRE_TYPE = -1017603
    FABRIC_SHEET_PHYSICAL_MATERIAL_ASSET = -1017602
    FABRIC_WIRE_DIAMETER = -1017601
    REBAR_QUANITY_BY_DISTRIB = -1017065
    REBAR_MIN_LENGTH = -1017064
    REBAR_MAX_LENGTH = -1017063
    REBAR_MAXIM_SUFFIX = -1017062
    REBAR_MINIM_SUFFIX = -1017061
    REBAR_NUMBER_SUFFIX = -1017060
    REBAR_DISTRIBUTION_TYPE = -1017057
    DPART_CAN_HOST_REBAR = -1017056
    REBAR_HOST_CATEGORY = -1017055
    REBAR_SHAPE_PARAM_END_HOOK_TAN_LEN = -1017054
    REBAR_SHAPE_PARAM_START_HOOK_TAN_LEN = -1017053
    REBAR_INTERNAL_MULTIPLANAR_END_CONNECTOR = -1017052
    REBAR_INTERNAL_MULTIPLANAR_START_CONNECTOR = -1017051
    REBAR_INTERNAL_MULTIPLANAR_DUPLICATE = -1017050
    REBAR_INTERNAL_MULTIPLANAR = -1017049
    REBAR_SHAPE_OUT_OF_PLANE_BEND_DIAMETER = -1017048
    REBAR_INSTANCE_STIRRUP_TIE_ATTACHMENT = -1017047
    REBAR_SHAPE_STIRRUP_TIE_ATTACHMENT = -1017046
    REBAR_SHAPE_SPIRAL_BASE_FINISHING_TURNS = -1017045
    REBAR_SHAPE_SPIRAL_TOP_FINISHING_TURNS = -1017044
    REBAR_SHAPE_SPIRAL_HEIGHT = -1017043
    REBAR_SHAPE_SPIRAL_PITCH = -1017042
    REBAR_STANDARD_HOOK_BEND_DIAMETER = -1017041
    REBAR_INCLUDE_LAST_BAR = -1017040
    REBAR_INCLUDE_FIRST_BAR = -1017039
    REBAR_INSTANCE_BEND_DIAMETER = -1017038
    REBAR_INSTANCE_BAR_DIAMETER = -1017037
    REBAR_SHAPE_END_HOOK_OFFSET = -1017036
    REBAR_SHAPE_END_HOOK_LENGTH = -1017035
    REBAR_SHAPE_START_HOOK_OFFSET = -1017034
    REBAR_SHAPE_START_HOOK_LENGTH = -1017033
    REBAR_ELEM_SCHEDULE_MARK = -1017032
    FABRIC_PARAM_ROUNDING = -1017028
    REBAR_ELEMENT_ROUNDING = -1017027
    REBAR_ELEM_HOOK_STYLE = -1017026
    REBAR_SHAPE_HOOK_END_TYPE = -1017024
    REBAR_SHAPE_HOOK_START_TYPE = -1017023
    REBAR_SHAPE_HOOK_STYLE = -1017022
    REBAR_BAR_ALLOWED_BAR_TYPES = -1017021
    REBAR_SHAPE_ALLOWED_BAR_TYPES = -1017021
    REBAR_BAR_MAXIMUM_BEND_RADIUS = -1017020
    REBAR_BAR_STIRRUP_BEND_DIAMETER = -1017019
    REBAR_BAR_HOOK_LENGTHS = -1017018
    REBAR_HOOK_STYLE = -1017017
    REBAR_ELEM_LENGTH = -1017016
    REBAR_SHAPE = -1017015
    REBAR_ELEMENT_VISIBILITY = -1017014
    REBAR_ELEM_BAR_SPACING = -1017013
    REBAR_ELEM_QUANTITY_OF_BARS = -1017012
    REBAR_ELEM_LAYOUT_RULE = -1017011
    REBAR_STANDARD_BEND_DIAMETER = -1017010
    REBAR_ELEM_HOOK_END_ORIENT = -1017009
    REBAR_ELEM_HOOK_END_TYPE = -1017008
    REBAR_ELEM_HOOK_START_ORIENT = -1017007
    REBAR_ELEM_HOOK_START_TYPE = -1017006
    REBAR_ELEM_TOTAL_LENGTH = -1017005
    REBAR_HOOK_LINE_LEN_FACTOR = -1017004
    REBAR_HOOK_ANGLE = -1017003
    REBAR_BAR_STYLE = -1017002
    REBAR_BAR_DIAMETER = -1017000
    WALL_ALIGN_KEY_REF_PARAM = -1016021
    CWP_COPY_ROOF_INSERTS = -1016019
    CWP_COPY_FLOOR_INSERTS = -1016018
    CWP_COPY_WALL_INSERTS = -1016017
    CWP_LINKED_ROOM_PARAMS = -1016016
    CWP_LINKED_ROOM_PHASES = -1016015
    CWP_REUSE_GRIDS_SAME_NAME = -1016011
    CWP_REUSE_LEVELS_SAME_NAME = -1016010
    CWP_SPLIT_COLUMNS_AT_LEVELS = -1016009
    CWP_REUSE_EXISTING_GRIDS = -1016008
    CWP_REUSE_EXISTING_LEVELS = -1016007
    CWP_LEVEL_OFFSET = -1016006
    CWP_ADD_LEVEL_SUFFIX = -1016005
    CWP_ADD_LEVEL_PREFIX = -1016004
    CWP_ADD_GRID_SUFFIX = -1016003
    CWP_ADD_GRID_PREFIX = -1016002
    LOAD_USAGE_NAME = -1015259
    LOAD_COMBINATION_FACTOR = -1015256
    LOAD_COMBINATION_NAME = -1015255
    LOAD_NATURE_NAME = -1015254
    LOAD_CASE_SUBCATEGORY = -1015253
    LOAD_CASE_NATURE = -1015252
    LOAD_CASE_NUMBER = -1015251
    LOAD_CASE_NAME = -1015250
    LOAD_ATTR_AREA_FORCE_SCALE_FACTOR = -1015207
    LOAD_ATTR_LINEAR_FORCE_SCALE_FACTOR = -1015206
    LOAD_ARROW_SEPARATION = -1015205
    LOAD_ATTR_MOMENT_SCALE_FACTOR = -1015204
    LOAD_ATTR_MOMENT_ARROW_LINE = -1015203
    LOAD_ATTR_MOMENT_ARROW_ARC = -1015202
    LOAD_ATTR_FORCE_SCALE_FACTOR = -1015201
    LOAD_ATTR_FORCE_ARROW_TYPE = -1015200
    LOAD_DESCRIPTION = -1015084
    LOAD_COMMENTS = -1015083
    LOAD_CASE_NATURE_TEXT = -1015082
    LOAD_ALL_NON_0_LOADS = -1015080
    LOAD_AREA_IS_PROJECTED = -1015070
    LOAD_AREA_AREA = -1015069
    LOAD_AREA_FORCE_FZ3 = -1015068
    LOAD_AREA_FORCE_FY3 = -1015067
    LOAD_AREA_FORCE_FX3 = -1015066
    LOAD_AREA_FORCE_FZ2 = -1015065
    LOAD_AREA_FORCE_FY2 = -1015064
    LOAD_AREA_FORCE_FX2 = -1015063
    LOAD_AREA_FORCE_FZ1 = -1015062
    LOAD_AREA_FORCE_FY1 = -1015061
    LOAD_AREA_FORCE_FX1 = -1015060
    LOAD_LINEAR_LENGTH = -1015043
    LOAD_IS_PROJECTED = -1015042
    LOAD_MOMENT_MZ2 = -1015041
    LOAD_MOMENT_MY2 = -1015040
    LOAD_MOMENT_MX2 = -1015039
    LOAD_MOMENT_MZ1 = -1015038
    LOAD_MOMENT_MY1 = -1015037
    LOAD_MOMENT_MX1 = -1015036
    LOAD_LINEAR_FORCE_FZ2 = -1015035
    LOAD_LINEAR_FORCE_FY2 = -1015034
    LOAD_LINEAR_FORCE_FX2 = -1015033
    LOAD_LINEAR_FORCE_FZ1 = -1015032
    LOAD_LINEAR_FORCE_FY1 = -1015031
    LOAD_LINEAR_FORCE_FX1 = -1015030
    LOAD_MOMENT_MZ = -1015015
    LOAD_MOMENT_MY = -1015014
    LOAD_MOMENT_MX = -1015013
    LOAD_FORCE_FZ = -1015012
    LOAD_FORCE_FY = -1015011
    LOAD_FORCE_FX = -1015010
    LOAD_IS_HOSTED = -1015006
    LOAD_IS_REACTION = -1015005
    LOAD_IS_CREATED_BY_API = -1015004
    LOAD_IS_UNIFORM = -1015003
    LOAD_USE_LOCAL_COORDINATE_SYSTEM = -1015001
    LOAD_CASE_ID = -1015000
    SPAN_DIR_SYM_PARAM_RIGHT = -1014004
    SPAN_DIR_SYM_PARAM_LEFT = -1014003
    SPAN_DIR_SYM_PARAM_BOTTOM = -1014002
    SPAN_DIR_SYM_PARAM_TOP = -1014001
    SPAN_DIR_INST_PARAM_ANGLE = -1014000
    ANALYTICAL_GEOMETRY_IS_VALID = -1013451
    STRUCTURAL_ASSET_PARAM = -1013450
    ANALYTICAL_MODEL_CODE_CHECKING = -1013447
    ANALYTICAL_MODEL_NODES_MARK = -1013446
    ANALYTICAL_MODEL_FOUNDATIONS_MARK = -1013445
    ANALYTICAL_MODEL_SURFACE_ELEMENTS_MARK = -1013444
    ANALYTICAL_MODEL_STICK_ELEMENTS_MARK = -1013443
    FAMILY_ENABLE_CUTTING_IN_VIEWS = -1013442
    FAMILY_CAN_HOST_REBAR = -1013441
    CLEAR_COVER = -1013440
    CLEAR_COVER_BOTTOM = -1013439
    CLEAR_COVER_TOP = -1013438
    CLEAR_COVER_OTHER = -1013437
    CLEAR_COVER_INTERIOR = -1013436
    CLEAR_COVER_EXTERIOR = -1013435
    COVER_TYPE_LENGTH = -1013434
    COVER_TYPE_NAME = -1013433
    JOIST_SYSTEM_CLEAR_SPACING_PARAM = -1013432
    JOIST_SYSTEM_FIXED_SPACING_PARAM = -1013431
    JOIST_SYSTEM_MAXIMUM_SPACING_PARAM = -1013430
    CURVE_EDGE_OFFSET = -1013429
    BEAM_SYSTEM_3D_PARAM = -1013427
    JOIST_SYSTEM_NEW_BEAM_TYPE_NO_FAM_NAME_PARAM = -1013419
    BEAM_SYSTEM_TAG_INST_PARAM_ANGLE = -1013418
    BEAM_SYSTEM_TAG_PARAM_RIGHT = -1013417
    BEAM_SYSTEM_TAG_PARAM_LEFT = -1013416
    JOIST_SYSTEM_NUM_BEAMS_SAME_TYPE = -1013415
    BEAM_H_JUSTIFICATION = -1013414
    BEAM_V_JUSTIFICATION = -1013413
    CURVE_SUPPORT_OFFSET = -1013412
    JOIST_SYSTEM_NEW_BEAM_TYPE_PARAM = -1013411
    JOIST_SYSTEM_LAYOUT_RULE_PARAM = -1013410
    JOIST_SYSTEM_JUSTIFICATION_PARAM = -1013409
    JOIST_SYSTEM_SPACING_PARAM = -1013408
    JOIST_SYSTEM_NUMBER_OF_LINES_PARAM = -1013407
    RBS_DUCT_FLOW_PARAM = -1013405
    CURTAINGRID_BELT_RATIO_V = -1013391
    CURTAINGRID_BELT_RATIO_U = -1013390
    CURTAINGRID_USE_CURVE_DIST_V = -1013389
    CURTAINGRID_USE_CURVE_DIST_U = -1013388
    CURTAINGRID_ADJUST_BORDER_V = -1013387
    CURTAINGRID_ADJUST_BORDER_U = -1013386
    CURTAINGRID_BELT_V = -1013385
    CURTAINGRID_BELT_U = -1013384
    CURTAINGRID_ORIGIN_V = -1013383
    CURTAINGRID_ORIGIN_U = -1013382
    CURTAINGRID_ANGLE_V = -1013380
    CURTAINGRID_ANGLE_U = -1013379
    SPACING_NUM_DIVISIONS_V = -1013377
    SPACING_NUM_DIVISIONS_U = -1013376
    SPACING_JUSTIFICATION_V = -1013375
    SPACING_JUSTIFICATION_U = -1013374
    SPACING_LENGTH_V = -1013373
    SPACING_LENGTH_U = -1013372
    SPACING_LAYOUT_V = -1013371
    SPACING_LAYOUT_U = -1013370
    CURTAINGRID_BELT_RATIO_2 = -1013369
    CURTAINGRID_BELT_RATIO_1 = -1013368
    CURTAIN_VERSION_PARAM = -1013367
    PADDING_LENGTH = -1013366
    CURTAINGRID_USE_CURVE_DIST = -1013354
    SPACING_JUSTIFICATION = -1013353
    SPACING_NUM_DIVISIONS = -1013352
    SPACING_LENGTH = -1013351
    SPACING_LAYOUT = -1013350
    CURTAINGRID_USE_CURVE_DIST_2 = -1013349
    CURTAINGRID_USE_CURVE_DIST_1 = -1013348
    CURTAINGRID_ADJUST_BORDER_2 = -1013347
    CURTAINGRID_ADJUST_BORDER_1 = -1013346
    CURTAINGRID_BELT_2 = -1013345
    CURTAINGRID_BELT_1 = -1013344
    CURTAINGRID_ORIGIN_2 = -1013343
    CURTAINGRID_ORIGIN_1 = -1013342
    CURTAINGRID_ANGLE_2 = -1013340
    CURTAINGRID_ANGLE_1 = -1013339
    SPACING_NUM_DIVISIONS_2 = -1013337
    SPACING_NUM_DIVISIONS_1 = -1013336
    SPACING_JUSTIFICATION_2 = -1013335
    SPACING_JUSTIFICATION_1 = -1013334
    SPACING_LENGTH_2 = -1013333
    SPACING_LENGTH_1 = -1013332
    SPACING_LAYOUT_2 = -1013331
    SPACING_LAYOUT_1 = -1013330
    CURTAINGRID_USE_CURVE_DIST_HORIZ = -1013319
    CURTAINGRID_USE_CURVE_DIST_VERT = -1013318
    CURTAINGRID_ADJUST_BORDER_HORIZ = -1013317
    CURTAINGRID_ADJUST_BORDER_VERT = -1013316
    CURTAINGRID_BELT_HORIZ = -1013315
    CURTAINGRID_BELT_VERT = -1013314
    CURTAINGRID_ORIGIN_HORIZ = -1013313
    CURTAINGRID_ORIGIN_VERT = -1013312
    CURTAINGRID_ANGLE_HORIZ = -1013310
    CURTAINGRID_ANGLE_VERT = -1013309
    GRIDLINE_SPEC_STATUS = -1013308
    SPACING_NUM_DIVISIONS_HORIZ = -1013307
    SPACING_NUM_DIVISIONS_VERT = -1013306
    SPACING_JUSTIFICATION_HORIZ = -1013305
    SPACING_JUSTIFICATION_VERT = -1013304
    SPACING_LENGTH_HORIZ = -1013303
    SPACING_LENGTH_VERT = -1013302
    SPACING_LAYOUT_HORIZ = -1013301
    SPACING_LAYOUT_VERT = -1013300
    DESIGN_OPTION_ID = -1013201
    DESIGN_OPTION_PARAM = -1013200
    PLAN_REGION_VIEW_RANGE = -1013103
    GUIDE_GRID_NAME_PARAM = -1013002
    GUIDE_GRID_SPACING_PARAM = -1013001
    SKETCH_GRID_SPACING_PARAM = -1013000
    JOIN_STRENGTH_ORDER = -1012870
    FAMILY_HOSTING_BEHAVIOR = -1012843
    FAMILY_IS_ELEVATION_MARK_BODY = -1012842
    FAMILY_USE_PRECUT_SHAPE = -1012841
    WALL_SWEEP_DEFAULT_SETBACK_PARAM = -1012840
    WALL_SWEEP_CUTS_WALL_PARAM = -1012839
    WALL_SWEEP_CUT_BY_INSERTS_PARAM = -1012838
    SLAB_EDGE_PROFILE_PARAM = -1012837
    GUTTER_PROFILE_PARAM = -1012836
    REVEAL_PROFILE_PARAM = -1012835
    FAMILY_SHARED = -1012834
    FAMILY_WORK_PLANE_BASED = -1012833
    FAMILY_AUTOJOIN = -1012832
    FAMILY_IS_PARAMETRIC = -1012831
    FAMILY_KEEP_TEXT_READABLE = -1012830
    WALL_BOTTOM_EXTENSION_DIST_PARAM = -1012829
    WALL_TOP_EXTENSION_DIST_PARAM = -1012828
    SWEEP_BASE_VERT_OFFSET = -1012827
    SWEEP_BASE_OFFSET = -1012825
    SLAB_EDGE_MATERIAL_PARAM = -1012824
    GUTTER_MATERIAL_PARAM = -1012823
    FASCIA_MATERIAL_PARAM = -1012822
    SWEEP_BASE_FLOOR_SUBCATEGORY_ID = -1012821
    SWEEP_BASE_ROOF_SUBCATEGORY_ID = -1012820
    FASCIA_PROFILE_PARAM = -1012819
    DECAL_SUBCATEGORY_ID = -1012818
    DECAL_HEIGHT = -1012815
    DECAL_WIDTH = -1012814
    DECAL_LOCK_PROPORTIONS = -1012813
    DECAL_ATTRIBUTES = -1012812
    FAMILY_ALLOW_CUT_WITH_VOIDS = -1012811
    FAMILY_KEY_EXT_PARAM = -1012810
    WALL_SWEEP_WALL_SUBCATEGORY_ID = -1012809
    FAMILY_ALWAYS_VERTICAL = -1012808
    FAMILY_ROTATE_WITH_COMPONENT = -1012807
    HOST_VOLUME_COMPUTED = -1012806
    HOST_AREA_COMPUTED = -1012805
    WALL_SWEEP_WALL_OFFSET_PARAM = -1012804
    WALL_SWEEP_OFFSET_PARAM = -1012802
    WALL_SWEEP_LEVEL_PARAM = -1012801
    WALL_SWEEP_PROFILE_PARAM = -1012800
    FAMILY_ROTATE_TEXT_WITH_COMPONENT = -1012706
    AREA_SCHEME_NAME = -1012705
    AREA_SCHEME_ID = -1012704
    AREA_TYPE_TEXT = -1012703
    AREA_TYPE = -1012701
    CONTOUR_LABELS_RELATIVE_BASE = -1012622
    CONTOUR_LABELS_ELEV_BASE_TYPE = -1012621
    PROPERTY_SEGMENT_SUBCATEGORY_ID = -1012620
    PROPERTY_SEGMENT_L_R = -1012619
    PROPERTY_SEGMENT_RADIUS = -1012618
    PROPERTY_SEGMENT_E_W = -1012617
    PROPERTY_SEGMENT_BEARING = -1012616
    PROPERTY_SEGMENT_N_S = -1012615
    PROPERTY_SEGMENT_DISTANCE = -1012614
    PROPERTY_LENGTH_UNITS = -1012613
    PROPERTY_AREA_UNITS = -1012612
    VOLUME_NET = -1012611
    PROJECTED_SURFACE_AREA = -1012610
    CONTOUR_LABELS_LINEAR_UNITS = -1012609
    CONTOUR_LABELS_PRIMARY_ONLY = -1012608
    PROPERTY_SUBCATEGORY_ID = -1012607
    PROPERTY_AREA_OPEN = -1012606
    VOLUME_FILL = -1012604
    VOLUME_CUT = -1012603
    SURFACE_PERIMETER = -1012602
    SURFACE_AREA = -1012601
    PROPERTY_AREA = -1012600
    BUILDINGPAD_HEIGHTABOVELEVEL_PARAM = -1012502
    BUILDINGPAD_THICKNESS = -1012501
    TOPOGRAPHY_LINK_PATH = -1012409
    TOPOGRAPHY_LINK_NAME = -1012408
    BOUNDARY_RADIUS = -1012407
    CONTOUR_SUBCATEGORY_ID = -1012405
    BOUNDARY_BEARING = -1012404
    BOUNDARY_DISTANCE = -1012403
    CONTOUR_ELEVATION_STEP = -1012402
    CONTOUR_ELEVATION = -1012401
    POINT_ELEVATION = -1012400
    VOLUME_OF_INTEREST_NAME = -1012205
    VOLUME_OF_INTEREST_VIEWS_VISIBLE = -1012203
    VIEWER_VOLUME_OF_INTEREST_CROP = -1012202
    DATUM_VOLUME_OF_INTEREST = -1012201
    ORIENT_BY_VIEW = -1012200
    ROOM_PHASE = -1012113
    ROOM_PHASE_ID = -1012112
    PHASE_SEQUENCE_NUMBER = -1012111
    PHASE_NAME = -1012110
    VIEW_FAMILY = -1012109
    VIEW_TYPE = -1012106
    VIEW_PHASE_FILTER = -1012103
    VIEW_PHASE = -1012102
    PHASE_DEMOLISHED = -1012101
    PHASE_CREATED = -1012100
    MASS_DATA_SLAB = -1012098
    ENERGY_ANALYSIS_HVAC_SYSTEM = -1012062
    ENERGY_ANALYSIS_OUTDOOR_AIR_INFORMATION_PARAM = -1012061
    ENERGY_ANALYSIS_MASSZONE_USEENERGYDATASETTINGS = -1012060
    ENERGY_ANALYSIS_MASSZONE_DIVIDEPERIMETER = -1012059
    ENERGY_ANALYSIS_MASSZONE_COREOFFSET = -1012058
    ENERGY_ANALYSIS_SHADE_DEPTH = -1012057
    ENERGY_ANALYSIS_CONCEPTUAL_CONSTRUCTION = -1012056
    ENERGY_ANALYSIS_SKYLIGHT_WIDTH = -1012055
    ENERGY_ANALYSIS_PERCENTAGE_SKYLIGHTS = -1012054
    ENERGY_ANALYSIS_GLAZING_IS_SHADED = -1012053
    ENERGY_ANALYSIS_SILL_HEIGHT = -1012052
    ENERGY_ANALYSIS_PERCENTAGE_GLAZING = -1012051
    ENERGY_ANALYSIS_MASS_ZONING = -1012050
    ENERGY_ANALYSIS_BUILDING_OPERATING_SCHEDULE = -1012047
    ENERGY_ANALYSIS_CREATE_ANALYTICAL_MODEL = -1012046
    MASS_DATA_SURFACE_DATA_SOURCE = -1012045
    MASS_DATA_SKYLIGHT_WIDTH = -1012044
    MASS_DATA_PERCENTAGE_SKYLIGHTS = -1012043
    MASS_DATA_SILL_HEIGHT = -1012042
    MASS_DATA_SHADE_DEPTH = -1012041
    MASS_DATA_GLAZING_IS_SHADED = -1012040
    MASS_DATA_PERCENTAGE_GLAZING = -1012039
    MASS_DATA_UNDERGROUND = -1012038
    MASS_DATA_MASS_OPENING_AREA = -1012037
    MASS_DATA_MASS_SKYLIGHT_AREA = -1012036
    MASS_DATA_MASS_WINDOW_AREA = -1012035
    MASS_DATA_MASS_ROOF_AREA = -1012034
    MASS_DATA_MASS_INTERIOR_WALL_AREA = -1012033
    MASS_DATA_MASS_EXTERIOR_WALL_AREA = -1012032
    MASS_DATA_SUBCATEGORY = -1012031
    MASS_DATA_CONCEPTUAL_CONSTRUCTION = -1012030
    MASS_ZONE_CONDITION_TYPE_PARAM = -1012027
    MASS_ZONE_SPACE_TYPE_PARAM = -1012026
    MASS_ZONE_FLOOR_AREA = -1012025
    CONCEPTUAL_CONSTRUCTION_MATERIAL = -1012024
    MASS_SURFACEDATA_MATERIAL = -1012023
    MASS_ZONE_MATERIAL = -1012022
    MASS_ZONE_VOLUME = -1012021
    LEVEL_DATA_MASS_TYPE_DESCRIPTION = -1012020
    LEVEL_DATA_MASS_INSTANCE_COMMENTS = -1012019
    LEVEL_DATA_MASS_TYPE_COMMENTS = -1012018
    LEVEL_DATA_MASS_FAMILY_AND_TYPE_PARAM = -1012017
    LEVEL_DATA_MASS_FAMILY_PARAM = -1012016
    LEVEL_DATA_SPACE_USAGE = -1012015
    LEVEL_DATA_OWNING_LEVEL = -1012014
    LEVEL_DATA_MASS_TYPE_PARAM = -1012013
    LEVEL_DATA_VOLUME = -1012012
    LEVEL_DATA_SURFACE_AREA = -1012011
    LEVEL_DATA_FLOOR_AREA = -1012010
    LEVEL_DATA_FLOOR_PERIMETER = -1012009
    MASS_GROSS_VOLUME = -1012007
    MASS_GROSS_SURFACE_AREA = -1012006
    MASS_FLOOR_AREA_LEVELS = -1012005
    MASS_GROSS_AREA = -1012004
    MASSING_INTEGRATION_LEVEL = -1012000
    PROJECT_REVISION_REVISION_ISSUED = -1011957
    PROJECT_REVISION_ENUMERATION = -1011956
    PROJECT_REVISION_REVISION_ISSUED_BY = -1011955
    PROJECT_REVISION_REVISION_ISSUED_TO = -1011954
    PROJECT_REVISION_REVISION_DATE = -1011953
    PROJECT_REVISION_REVISION_DESCRIPTION = -1011952
    PROJECT_REVISION_REVISION_NUM = -1011951
    PROJECT_REVISION_SEQUENCE_NUM = -1011950
    REVISION_CLOUD_REVISION_ISSUED_BY = -1011906
    REVISION_CLOUD_REVISION_ISSUED_TO = -1011904
    REVISION_CLOUD_REVISION_DATE = -1011903
    REVISION_CLOUD_REVISION_DESCRIPTION = -1011902
    REVISION_CLOUD_REVISION_NUM = -1011901
    REVISION_CLOUD_REVISION = -1011900
    REPEATING_DETAIL_ROTATION = -1011109
    REPEATING_DETAIL_INSIDE = -1011107
    REPEATING_DETAIL_ELEMENT = -1011106
    REPEATING_DETAIL_LAYOUT = -1011105
    REPEATING_DETAIL_SPACING = -1011104
    REPEATING_DETAIL_NUMBER = -1011103
    INSULATION_SCALE = -1011101
    INSULATION_WIDTH = -1011100
    VIEW_PARTS_VISIBILITY = -1011003
    VIEW_DETAIL_LEVEL = -1011002
    PLUMBING_FIXTURES_VENT_CONNECTION = -1010707
    PLUMBING_FIXTURES_WASTE_CONNECTION = -1010706
    PLUMBING_FIXTURES_CW_CONNECTION = -1010705
    PLUMBING_FIXTURES_HW_CONNECTION = -1010704
    PLUMBING_FIXTURES_TRAP = -1010703
    PLUMBING_FIXTURES_DRAIN = -1010702
    PLUMBING_FIXTURES_SUPPLY_PIPE = -1010701
    PLUMBING_FIXTURES_SUPPLY_FITTING = -1010700
    LIGHTING_FIXTURE_LIGHT_EMITTER = -1010508
    FBX_LIGHT_SPOT_FIELD_ANGLE = -1010507
    FBX_LIGHT_SPOT_BEAM_ANGLE = -1010506
    FBX_LIGHT_SPOT_TILT_ANGLE = -1010505
    FBX_LIGHT_LIMUNOUS_FLUX = -1010503
    LIGHTING_FIXTURE_LAMP = -1010501
    LIGHTING_FIXTURE_WATTAGE = -1010500
    ELECTICAL_EQUIP_VOLTAGE = -1010401
    ELECTICAL_EQUIP_WATTAGE = -1010400
    CURTAIN_WALL_SYSPANEL_THICKNESS = -1010304
    CURTAIN_WALL_PANEL_HOST_ID = -1010303
    CURTAIN_WALL_SYSPANEL_OFFSET = -1010302
    CURTAIN_WALL_PANELS_WIDTH = -1010301
    CURTAIN_WALL_PANELS_HEIGHT = -1010300
    ALL_MODEL_MODEL = -1010109
    ALL_MODEL_MANUFACTURER = -1010108
    ALL_MODEL_INSTANCE_COMMENTS = -1010106
    ALL_MODEL_TYPE_COMMENTS = -1010105
    ALL_MODEL_URL = -1010104
    ALL_MODEL_DESCRIPTION = -1010103
    RGB_B_PARAM = -1010024
    RGB_G_PARAM = -1010023
    RGB_R_PARAM = -1010022
    ELLIPSE_Y_PARAM = -1010021
    ELLIPSE_X_PARAM = -1010020
    GROUPNAME_PARAM = -1010018
    ICON_INDEX_PARAM = -1010017
    SHOW_ICON_PARAM = -1010016
    DEBUGTAB_DATABOUNDCONTROLSDEMO_DOUBLE = -1010013
    DEBUGTAB_DATABOUNDCONTROLSDEMO_INTEGER = -1010012
    DEBUGTAB_DATABOUNDCONTROLSDEMO_BOOLEAN = -1010011
    DEBUGTAB_DATABOUNDCONTROLSDEMO_ENUM = -1010010
    GENERIC_DEPTH = -1010003
    CASEWORK_DEPTH = -1010003
    ANALYTICAL_MODEL_END_PROJECTION_ORTHOGONAL = -1009532
    ANALYTICAL_MODEL_START_PROJECTION_ORTHOGONAL = -1009531
    ANALYTICAL_LINK_RELEASE_ROTATION_Z = -1009530
    ANALYTICAL_LINK_RELEASE_ROTATION_Y = -1009529
    ANALYTICAL_LINK_RELEASE_ROTATION_X = -1009528
    ANALYTICAL_LINK_RELEASE_TRANSLATION_Z = -1009527
    ANALYTICAL_LINK_RELEASE_TRANSLATION_Y = -1009526
    ANALYTICAL_LINK_RELEASE_TRANSLATION_X = -1009525
    ANALYTICAL_MODEL_PHYSICAL_TYPE = -1009524
    ANALYTICAL_MODEL_SKETCH_PROJECTION = -1009523
    ANALYTICAL_MODEL_SKETCH_ALIGNMENT_METHOD = -1009522
    ANALYTICAL_MODEL_WALL_BASE_PROJECTION = -1009521
    ANALYTICAL_MODEL_WALL_TOP_PROJECTION = -1009520
    ANALYTICAL_MODEL_WALL_PROJECTION = -1009519
    ANALYTICAL_MODEL_WALL_ALIGNMENT_METHOD = -1009518
    ANALYTICAL_MODEL_FLOOR_PROJECTION = -1009517
    ANALYTICAL_MODEL_FLOOR_ALIGNMENT_METHOD = -1009516
    ANALYTICAL_MODEL_COLUMN_BASE_EXTENSION = -1009515
    ANALYTICAL_MODEL_BASE_EXTENSION_METHOD = -1009514
    ANALYTICAL_MODEL_COLUMN_TOP_EXTENSION = -1009513
    ANALYTICAL_MODEL_TOP_EXTENSION_METHOD = -1009512
    ANALYTICAL_MODEL_TOP_Y_PROJECTION = -1009511
    ANALYTICAL_MODEL_TOP_Z_PROJECTION = -1009510
    ANALYTICAL_MODEL_TOP_ALIGNMENT_METHOD = -1009509
    ANALYTICAL_MODEL_BASE_Y_PROJECTION = -1009508
    ANALYTICAL_MODEL_BASE_Z_PROJECTION = -1009507
    ANALYTICAL_MODEL_BASE_ALIGNMENT_METHOD = -1009506
    ANALYTICAL_MODEL_END_Z_PROJECTION = -1009505
    ANALYTICAL_MODEL_END_Y_PROJECTION = -1009504
    ANALYTICAL_MODEL_END_ALIGNMENT_METHOD = -1009503
    ANALYTICAL_MODEL_START_Z_PROJECTION = -1009502
    ANALYTICAL_MODEL_START_Y_PROJECTION = -1009501
    ANALYTICAL_MODEL_START_ALIGNMENT_METHOD = -1009500
    ELEMENT_LOCKED_PARAM = -1009000
    STAIRS_RAILING_BALUSTER_IS_POST = -1008633
    STAIRS_RAILING_CONNECTION = -1008632
    STAIRS_RAILING_ANGLED_CONNECTION = -1008631
    STAIRS_RAILING_TANGENT_CONNECTION = -1008630
    STAIRS_RAILING_HEIGHT_SHIFT_VAL = -1008629
    STAIRS_RAILING_HEIGHT_SHIFT_TYPE = -1008628
    STAIRS_RAILING_RAIL_NAME = -1008627
    STAIRS_RAILING_BALUSTER_PLACEMENT = -1008626
    STAIRS_RAILING_BALUSTER_SLOPE_ANGLE = -1008625
    STAIRS_RAILING_BALUSTER_BOTTOM_ANGLE = -1008624
    STAIRS_RAILING_BALUSTER_TOP_ANGLE = -1008623
    STAIRS_RAILING_BALUSTER_HEIGHT = -1008622
    STAIRS_RAILING_HEIGHT_OFFSET = -1008621
    STAIRS_RAILING_BASE_LEVEL_PARAM = -1008620
    STAIRS_RAILING_BALUSTER_OFFSET = -1008619
    STAIRS_RAILING_BALUSTER_FAMILY = -1008618
    STAIRS_RAILING_RAIL_OFFSET = -1008617
    STAIRS_RAILING_RAIL_HEIGHT = -1008616
    STAIRS_RAILING_RAIL_STRUCTURE = -1008615
    STAIRS_RAILING_SHAPE = -1008614
    STAIRS_RAILING_BALUSTER_LENGTH = -1008612
    STAIRS_RAILING_BALUSTER_WIDTH = -1008611
    STAIRS_RAILING_BALUSTERS_PER_TREAD = -1008610
    STAIRS_RAILING_BALUSTER_SPACING = -1008609
    STAIRS_RAILING_BALUSTER_SPACING_TYPE = -1008608
    STAIRS_RAILING_BALUSTER_SHAPE = -1008605
    STAIRS_RAILING_THICKNESS = -1008604
    STAIRS_RAILING_WIDTH = -1008603
    STAIRS_RAILING_HEIGHT = -1008602
    RAMP_ATTR_TEXT_SIZE = -1008310
    RAMP_ATTR_TEXT_FONT = -1008309
    RAMP_ATTR_MATERIAL = -1008308
    RAMP_ATTR_RIGHT_BALUSTER_ATTACH_PT = -1008307
    RAMP_ATTR_LEFT_BALUSTER_ATTACH_PT = -1008306
    RAMP_ATTR_SHAPE = -1008305
    RAMP_ATTR_THICKNESS = -1008304
    RAMP_MAX_RUN_LENGTH = -1008303
    RAMP_ATTR_MIN_INV_SLOPE = -1008301
    ASSIGN_TEMPLATE_ON_VIEW_CREATION = -1008211
    DEFAULT_VIEW_TEMPLATE = -1008210
    PLAN_VIEW_VIEW_DIR = -1008209
    POCHE_MAT_ID = -1008208
    ELEVATN_TAG = -1008207
    CALLOUT_TAG = -1008206
    SECTION_TAG = -1008205
    CALLOUT_SYNCRONIZE_BOUND_OFFSET_FAR = -1008203
    CALLOUT_CORNER_SHEET_RADIUS = -1008201
    CALLOUT_ATTR_HEAD_TAG = -1008200
    GRID_BUBBLE_END_2 = -1008005
    GRID_BUBBLE_END_1 = -1008004
    DATUM_BUBBLE_LOCATION_IN_ELEV = -1008003
    DATUM_BUBBLE_END_1 = -1008002
    DATUM_BUBBLE_END_2 = -1008001
    DATUM_TEXT = -1008000
    ELLIPSE_FOCUS_MRK_VISIBLE = -1007905
    ARC_WALL_CNTR_MRK_VISIBLE = -1007900
    ARC_CURVE_CNTR_MRK_VISIBLE = -1007900
    REF_TABLE_PARAM_NAME = -1007851
    REF_TABLE_ELEM_NAME = -1007850
    RBS_PANEL_SCHEDULE_SHEET_APPEARANCE_INST_PARAM = -1007808
    RBS_PANEL_SCHEDULE_SHEET_APPEARANCE_PARAM = -1007807
    SCHEDULE_EMBEDDED_PARAM = -1007806
    SCHEDULE_SHEET_APPEARANCE_PARAM = -1007805
    SCHEDULE_FORMAT_PARAM = -1007804
    SCHEDULE_GROUP_PARAM = -1007803
    SCHEDULE_FILTER_PARAM = -1007801
    SCHEDULE_FIELDS_PARAM = -1007800
    RASTER_SYMBOL_LINKLOAD_STATUS = -1007771
    RASTER_ENABLE_SNAPS = -1007770
    RASTER_SYMBOL_PAGENUMBER = -1007769
    RASTER_HORIZONTAL_SCALE = -1007768
    RASTER_VERTICAL_SCALE = -1007767
    RASTER_SYMBOL_HEIGHT = -1007766
    RASTER_SYMBOL_WIDTH = -1007765
    RASTER_SYMBOL_RESOLUTION = -1007764
    RASTER_SYMBOL_FILENAME = -1007763
    RASTER_SYMBOL_VIEWNAME = -1007762
    RASTER_SYMBOL_PIXELHEIGHT = -1007761
    RASTER_SYMBOL_PIXELWIDTH = -1007760
    RASTER_LOCK_PROPORTIONS = -1007752
    RASTER_SHEETHEIGHT = -1007751
    RASTER_SHEETWIDTH = -1007750
    IMPORT_ADT_ENTITY_ROLL = -1007738
    IMPORT_ADT_ENTITY_THICKNESS = -1007737
    IMPORT_ADT_ENTITY_LENGTH = -1007736
    IMPORT_ADT_ENTITY_WIDTH = -1007735
    IMPORT_ADT_ENTITY_HEIGHT = -1007734
    IMPORT_ADT_COMPONENTS_DESC = -1007733
    IMPORT_ADT_ENTITY_STYLE = -1007732
    IMPORT_ADT_ENTITY_STRUCT_TYPE = -1007731
    IMPORT_ADT_ENTITY_TYPE = -1007730
    RVT_LINK_PHASE_MAP = -1007728
    RVT_LINK_REFERENCE_TYPE = -1007727
    RVT_LINK_FILE_NAME_WITHOUT_EXT = -1007726
    RVT_LEVEL_OFFSET = -1007725
    RVT_HOST_LEVEL = -1007724
    RVT_SOURCE_LEVEL = -1007723
    RVT_LINK_INSTANCE_NAME = -1007721
    GEO_LOCATION = -1007720
    IMPORT_INSTANCE_SCALE = -1007706
    IMPORT_BACKGROUND = -1007705
    IMPORT_DISPLAY_UNITS = -1007704
    IMPORT_BASE_LEVEL_OFFSET = -1007703
    IMPORT_BASE_LEVEL = -1007702
    IMPORT_SCALE = -1007701
    IMPORT_SYMBOL_NAME = -1007700
    ELEV_SYMBOL_ID = -1007610
    ELEV_REFERENCE_LABEL_POS = -1007609
    ELEV_ASSOC_DATUM = -1007608
    ELEV_VIEW_NAME_POS = -1007607
    ELEV_SHOW_VIEW_NAME = -1007605
    ELEV_TEXT_POS = -1007604
    ELEV_ARROW_FILLED = -1007603
    ELEV_ARROW_ANGLE = -1007602
    ELEV_SHAPE = -1007601
    ELEV_WIDTH = -1007600
    COLOR_FILL_SWATCH_HEIGHT_PARAM = -1007504
    COLOR_FILL_SWATCH_WIDTH_PARAM = -1007503
    COLOR_FILL_FILTERED_PARAM = -1007502
    SHEET_GUIDE_GRID = -1007419
    SHEET_CURRENT_REVISION_ISSUED = -1007418
    SHEET_CURRENT_REVISION_ISSUED_BY = -1007417
    SHEET_CURRENT_REVISION_ISSUED_TO = -1007416
    SHEET_CURRENT_REVISION_DATE = -1007415
    SHEET_CURRENT_REVISION_DESCRIPTION = -1007414
    SHEET_REVISIONS_ON_SHEET = -1007413
    SHEET_CURRENT_REVISION = -1007412
    SHEET_HEIGHT = -1007411
    SHEET_WIDTH = -1007410
    SHEET_FILE_PATH = -1007409
    SHEET_APPROVED_BY = -1007408
    SHEET_DESIGNED_BY = -1007407
    SHEET_SCHEDULED = -1007406
    SHEET_CHECKED_BY = -1007405
    SHEET_DRAWN_BY = -1007404
    SHEET_DATE = -1007403
    SHEET_SCALE = -1007402
    SHEET_NUMBER = -1007401
    SHEET_NAME = -1007400
    SPACING_APPEND = -1007398
    AUTO_JOIN_CONDITION_WALL = -1007395
    AUTO_MULLION_BORDER2_HORIZ = -1007394
    AUTO_MULLION_BORDER1_HORIZ = -1007393
    AUTO_MULLION_BORDER2_VERT = -1007392
    AUTO_MULLION_BORDER1_VERT = -1007391
    AUTO_MULLION_INTERIOR_HORIZ = -1007390
    AUTO_MULLION_INTERIOR_VERT = -1007389
    AUTO_PANEL_WALL = -1007388
    AUTO_JOIN_CONDITION = -1007387
    AUTO_PANEL = -1007386
    AUTO_MULLION_BORDER2_GRID2 = -1007385
    AUTO_MULLION_BORDER1_GRID2 = -1007384
    AUTO_MULLION_BORDER2_GRID1 = -1007383
    AUTO_MULLION_BORDER1_GRID1 = -1007382
    AUTO_MULLION_INTERIOR_GRID2 = -1007381
    AUTO_MULLION_INTERIOR_GRID1 = -1007380
    CURTAIN_GRID_BASE_ORIENTATION = -1007364
    MULLION_ANGLE = -1007363
    MULLION_POSITION = -1007362
    MULLION_PROFILE = -1007361
    TRAP_MULL_WIDTH = -1007359
    MULLION_DEPTH2 = -1007358
    MULLION_DEPTH1 = -1007357
    MULLION_DEPTH = -1007356
    LV_MULLION_LEG2 = -1007355
    LV_MULLION_LEG1 = -1007354
    MULLION_CORNER_TYPE = -1007353
    MULLION_FAM_TYPE = -1007352
    MULLION_OFFSET = -1007351
    CIRC_MULLION_RADIUS = -1007350
    CUST_MULLION_THICK = -1007322
    CUST_MULLION_WIDTH2 = -1007321
    CUST_MULLION_WIDTH1 = -1007320
    RECT_MULLION_THICK = -1007304
    RECT_MULLION_WIDTH2 = -1007301
    RECT_MULLION_WIDTH1 = -1007300
    STAIRS_INST_ALWAYS_UP = -1007278
    STAIRS_ATTR_TRIM_TOP = -1007277
    STAIRS_INST_DOWN_ARROW_ON = -1007276
    STAIRS_INST_DOWN_LABEL_TEXT = -1007275
    STAIRS_INST_DOWN_LABEL_ON = -1007274
    STAIRS_INST_UP_ARROW_ON = -1007273
    STAIRS_INST_UP_LABEL_TEXT = -1007272
    STAIRS_INST_UP_LABEL_ON = -1007271
    STAIRS_ATTR_TEXT_SIZE = -1007270
    STAIRS_ATTR_TEXT_FONT = -1007269
    STAIRS_ATTR_BODY_MATERIAL = -1007268
    STAIRS_ATTR_LANDING_CARRIAGE = -1007267
    STAIRS_ATTR_LANDINGS_OVERLAPPING = -1007266
    STAIRS_ATTR_RIGHT_SIDE_STRINGER = -1007265
    STAIRS_ATTR_LEFT_SIDE_STRINGER = -1007264
    STAIRS_ATTR_NOSING_PLACEMENT = -1007263
    STAIRS_ATTR_RISER_TREAD_CONNECT = -1007262
    STAIRS_ATTR_RISER_THICKNESS = -1007261
    STAIRS_ATTR_NUM_MID_STRINGERS = -1007260
    STAIRS_ATTR_STAIRS_CUT_OFFSET = -1007259
    STAIRS_ATTR_LAST_RISER = -1007258
    STAIRS_ATTR_FIRST_RISER = -1007257
    STAIRS_ATTR_STAIRS_BOTTOM = -1007256
    STAIRS_ATTR_MONOLITHIC_STAIRS = -1007255
    STAIRS_ATTR_CALC_ENABLED = -1007254
    STAIRS_ATTR_CALC_MAX = -1007253
    STAIRS_ATTR_CALC_MIN = -1007252
    STAIRS_ATTR_EQ_RESULT = -1007251
    STAIRS_ACTUAL_TREAD_DEPTH = -1007250
    STAIRS_ATTR_TREAD_MULT = -1007249
    STAIRS_ATTR_RISER_MULT = -1007248
    STAIRS_ATTR_STAIR_CALCULATOR = -1007247
    STAIRS_ACTUAL_NUM_RISERS = -1007246
    STAIRS_ATTR_BREAK_SYM_IN_CUTLINE = -1007245
    STAIRS_ATTR_RISER_MATERIAL = -1007244
    STAIRS_ATTR_RISER_TYPE = -1007243
    STAIRS_ATTR_TREAD_MATERIAL = -1007242
    STAIRS_ATTR_NOSING_LENGTH = -1007241
    STAIRS_ATTR_TREAD_FRONT_PROFILE = -1007240
    STAIRS_ATTR_STRINGER_MATERIAL = -1007239
    STAIRS_ATTR_STRINGER_OFFSET = -1007238
    STAIRS_ATTR_STRINGER_CARRIAGE = -1007237
    STAIRS_ATTR_SIDE_STRINGER_TYPE_PARAM = -1007236
    STAIRS_MULTISTORY_TOP_LEVEL_PARAM = -1007235
    STAIRS_STRINGERS_PRESENT = -1007234
    STAIRS_TOP_OFFSET = -1007219
    STAIRS_BASE_OFFSET = -1007218
    STAIRS_ATTR_RISER_ANGLE = -1007212
    STAIRS_ATTR_TREAD_THICKNESS = -1007211
    STAIRS_ATTR_STRINGER_THICKNESS = -1007210
    STAIRS_ATTR_STRINGER_HEIGHT = -1007209
    STAIRS_ATTR_RISERS_PRESENT = -1007208
    STAIRS_ACTUAL_RISER_HEIGHT = -1007206
    STAIRS_DESIRED_NUM_RISERS = -1007205
    STAIRS_ATTR_TREAD_WIDTH = -1007204
    STAIRS_ATTR_MINIMUM_TREAD_DEPTH = -1007203
    STAIRS_ATTR_MAX_RISER_HEIGHT = -1007202
    STAIRS_TOP_LEVEL_PARAM = -1007201
    STAIRS_BASE_LEVEL_PARAM = -1007200
    LEVEL_IS_STRUCTURAL = -1007112
    LEVEL_IS_BUILDING_STORY = -1007111
    LEVEL_UP_TO_LEVEL = -1007110
    LEVEL_RELATIVE_BASE_TYPE = -1007109
    LEVEL_ELEV = -1007102
    LEVEL_NAME = -1007101
    LEVEL_HEAD_TAG = -1007100
    MULTI_REFERENCE_ANNOTATION_SHOW_DIMENSION_TEXT = -1007054
    MULTI_REFERENCE_ANNOTATION_DIMENSION_STYLE = -1007053
    MULTI_REFERENCE_ANNOTATION_GROUP_TAG_HEADS = -1007052
    MULTI_REFERENCE_ANNOTATION_TAG_TYPE = -1007051
    MULTI_REFERENCE_ANNOTATION_REFERENCE_CATEGORY = -1007050
    TAG_LEADER_TYPE = -1007006
    TAG_NO_BREAK_PARAM_STRINGS = -1007005
    ROOM_TAG_ORIENTATION_PARAM = -1007004
    TAG_ORIENTATION_PARAM = -1007003
    TAG_SAMPLE_TEXT = -1007001
    TAG_TAG = -1007000
    DIAMETER_SYMBOL_TEXT = -1006999
    DIAMETER_SYMBOL_LOCATION = -1006998
    RADIUS_SYMBOL_TEXT = -1006997
    VIS_GRAPHICS_COORDINATION_MODEL = -1006970
    VIS_GRAPHICS_POINT_CLOUDS = -1006969
    VIS_GRAPHICS_WORKSETS = -1006968
    VIS_GRAPHICS_ANALYTICAL_MODEL = -1006967
    VIS_GRAPHICS_DESIGNOPTIONS = -1006966
    VIS_GRAPHICS_RVT_LINKS = -1006965
    VIS_GRAPHICS_FILTERS = -1006964
    VIS_GRAPHICS_IMPORT = -1006963
    VIS_GRAPHICS_ANNOTATION = -1006962
    VIS_GRAPHICS_MODEL = -1006961
    LEVEL_ATTR_ROOM_COMPUTATION_AUTOMATIC = -1006941
    LEVEL_ATTR_ROOM_COMPUTATION_HEIGHT = -1006940
    LEVEL_ROOM_COMPUTATION_HEIGHT = -1006939
    ROOM_COMPUTATION_HEIGHT = -1006928
    ALWAYS_ZERO_LENGTH = -1006927
    ROOM_COMPUTATION_METHOD = -1006926
    ROOM_LOWER_OFFSET = -1006925
    ROOM_UPPER_OFFSET = -1006924
    ROOM_UPPER_LEVEL = -1006922
    ROOM_VOLUME = -1006921
    ROOM_HEIGHT = -1006920
    ROOM_PERIMETER = -1006917
    ROOM_LEVEL_ID = -1006916
    ROOM_OCCUPANCY = -1006909
    ROOM_DEPARTMENT = -1006907
    ROOM_FINISH_BASE = -1006906
    ROOM_FINISH_CEILING = -1006905
    ROOM_FINISH_WALL = -1006904
    ROOM_FINISH_FLOOR = -1006903
    ROOM_AREA = -1006902
    ROOM_NUMBER = -1006901
    ROOM_NAME = -1006900
    SPATIAL_FIELD_MGR_LEGEND_HOR_ORIGIN_GAP = -1006861
    SPATIAL_FIELD_MGR_LEGEND_VERT_ORIGIN_GAP = -1006860
    SPATIAL_FIELD_MGR_LEGEND_WIDTH = -1006859
    SPATIAL_FIELD_MGR_LEGEND_HEIGHT = -1006858
    VIEW_ANALYSIS_RESULTS_VISIBILITY = -1006857
    SPATIAL_FIELD_MGR_LEGEND_TEXT_TYPE = -1006856
    SPATIAL_FIELD_MGR_RESULTS_VISIBILITY = -1006855
    SPATIAL_FIELD_MGR_LEGEND_SHOW_DESCRIPTION = -1006854
    SPATIAL_FIELD_MGR_LEGEND_SHOW_CONFIG_NAME = -1006853
    SPATIAL_FIELD_MGR_DESCRIPTION = -1006852
    SPATIAL_FIELD_MGR_CURRENT_NAME = -1006851
    SPATIAL_FIELD_MGR_RANGE = -1006850
    GRID_END_SEGMENTS_LENGTH = -1006711
    GRID_END_SEGMENT_PATTERN = -1006710
    GRID_END_SEGMENT_COLOR = -1006709
    GRID_END_SEGMENT_WEIGHT = -1006708
    GRID_CENTER_SEGMENT_PATTERN = -1006707
    GRID_CENTER_SEGMENT_COLOR = -1006706
    GRID_CENTER_SEGMENT_WEIGHT = -1006705
    GRID_CENTER_SEGMENT_STYLE = -1006704
    GRID_BUBBLE_LINE_PEN = -1006703
    GRID_HEAD_TAG = -1006700
    STAIRS_PATH_FULL_STEP_ARROW = -1006661
    STAIRS_PATH_START_EXTENSION = -1006660
    NUMBER_SYSTEM_TEXT_SIZE = -1006645
    NUMBER_SYSTEM_TAG_TYPE = -1006644
    NUMBER_SYSTEM_DISPLAY_RULE = -1006643
    NUMBER_SYSTEM_REFERENCE = -1006642
    NUMBER_SYSTEM_JUSTIFY = -1006641
    NUMBER_SYSTEM_ORIENTATION = -1006639
    NUMBER_SYSTEM_REFERENCE_OFFSET = -1006638
    NUMBER_SYSTEM_JUSTIFY_OFFSET = -1006637
    STAIRS_TEXT_ORIENTATION = -1006636
    STAIRS_TEXT_TYPE = -1006635
    STAIRS_DOWN_TEXT = -1006634
    STAIRS_SHOW_DOWN_TEXT = -1006633
    STAIRS_UP_TEXT = -1006632
    STAIRS_SHOW_UP_TEXT = -1006631
    SHOW_ARROWHEAD_TO_CUT_MARK = -1006630
    DRAW_FOR_EACH_RUN = -1006628
    ARROWHEAD_END_AT_RISER = -1006627
    STAIRS_PATH_START_FROM_RISER = -1006626
    DISTANCE_TO_CUT_MARK = -1006625
    LINE_SHAPE_AT_CORNER = -1006624
    ARROWHEAD_TYPE = -1006623
    START_SYMBOL_TYPE = -1006622
    CUT_MARK_SYMBOL_SIZE = -1006621
    CUT_LINE_TYPE = -1006620
    CUT_LINE_ANGLE = -1006619
    CUT_LINE_EXTENSION = -1006618
    CUT_LINE_DISTANCE = -1006617
    CUT_MARK_SYMBOL = -1006616
    SECTION_BROKEN_DISPLAY_STYLE = -1006615
    SECTION_COARSER_SCALE_PULLDOWN_IMPERIAL = -1006614
    SECTION_COARSER_SCALE_PULLDOWN_METRIC = -1006613
    SECTION_PARENT_VIEW_NAME = -1006612
    SECTION_SHOW_IN_ONE_VIEW_ONLY = -1006609
    SECTION_ATTR_TAIL_TAG = -1006608
    SECTION_ATTR_TAIL_WIDTH = -1006604
    SECTION_ATTR_TAIL_LENGTH = -1006603
    VIEWER_DETAIL_NUMBER = -1006602
    VIEWER_SHEET_NUMBER = -1006601
    SECTION_ATTR_HEAD_TAG = -1006600
    ALIGNMENT_STATION_LABEL_STATION_VALUE = -1006599
    ALIGNMENT_STATION_LABEL_IND_STATION = -1006598
    ALIGNMENT_STATION_LABEL_INCLUDE_STATION = -1006597
    SPOT_DIM_LEADER_LINE = -1006596
    ALIGNMENT_STATION_LABEL_DISTANCE = -1006595
    ARROW_CENTERED = -1006524
    INTERIOR_TICK_DISPLAY = -1006523
    WITNS_LINE_TICK_MARK = -1006522
    DIM_TOTAL_LENGTH = -1006521
    DIM_REFERENCE_COUNT = -1006520
    ALTERNATE_UNITS_SUFFIX = -1006519
    ALTERNATE_UNITS_PREFIX = -1006518
    EQUALITY_WITNESS_DISPLAY = -1006517
    DIM_STYLE_SUPPRESS_SPACES = -1006516
    EQUALITY_FORMULA = -1006515
    DIM_STYLE_LEADER_TICK_MARK = -1006514
    EQUALITY_TEXT_FOR_ANGULAR_DIM = -1006513
    EQUALITY_TEXT_FOR_CONTINUOUS_LINEAR_DIM = -1006512
    DIM_TEXT_LOCATION_FOR_LEADER = -1006511
    DIM_LEADER_DISPLAY_CONDITION = -1006510
    DIM_LEADER_SHOULDER_LENGTH = -1006509
    DIM_LEADER_TYPE = -1006508
    DIM_TO_INTERSECTING_GRIDS = -1006507
    DIM_TO_INTERSECTING_WALLS = -1006506
    DIM_TO_INSERT_TYPE = -1006505
    FIXED_ROTATION = -1006504
    KEEP_READABLE = -1006503
    LEADER_LINE = -1006502
    LEADER_OFFSET_SHEET = -1006501
    DIM_TO_INSERTS = -1006500
    SPOT_SLOPE_OFFSET_FROM_REFERENCE = -1006494
    SPOT_SLOPE_SLOPE_REPRESENTATION = -1006493
    SPOT_SLOPE_SLOPE_DIRECTION = -1006492
    SPOT_ELEV_LOWER_VALUE = -1006491
    SPOT_ELEV_SINGLE_OR_UPPER_VALUE = -1006490
    SPOT_ELEV_IND_TYPE_ELEVATION = -1006489
    SPOT_COORDINATE_INCLUDE_ELEVATION = -1006488
    SPOT_COORDINATE_ELEVATION_SUFFIX = -1006487
    SPOT_COORDINATE_ELEVATION_PREFIX = -1006486
    SPOT_COORDINATE_BOTTOM_SUFFIX = -1006485
    SPOT_COORDINATE_BOTTOM_PREFIX = -1006484
    SPOT_COORDINATE_TOP_SUFFIX = -1006483
    SPOT_COORDINATE_TOP_PREFIX = -1006482
    SPOT_ELEV_LOWER_SUFFIX = -1006481
    SPOT_ELEV_LOWER_PREFIX = -1006480
    SPOT_ELEV_SINGLE_OR_UPPER_SUFFIX = -1006479
    SPOT_ELEV_SINGLE_OR_UPPER_PREFIX = -1006478
    BASELINE_DIM_OFFSET = -1006477
    SPOT_ELEV_BEND_LEADER = -1006476
    SPOT_ELEV_IND_TYPE_BOTTOM = -1006475
    SPOT_ELEV_IND_TYPE_TOP = -1006474
    SPOT_ELEV_IND_BOTTOM = -1006473
    SPOT_ELEV_IND_TOP = -1006472
    SPOT_ELEV_TEXT_LOCATION = -1006471
    SPOT_ELEV_ROTATE_WITH_COMPONENT = -1006470
    SPOT_ELEV_DISPLAY_ELEVATIONS = -1006469
    ORDINATE_DIM_SETTING = -1006468
    LINEAR_DIM_TYPE = -1006467
    SPOT_DIM_LEADER = -1006466
    DIM_STYLE_FLIPPED_DIM_LINE_EXTENSION = -1006465
    DIM_STYLE_INTERIOR_TICK_MARK = -1006464
    SPOT_TEXT_FROM_LEADER = -1006462
    SPOT_COORDINATE_BASE = -1006461
    DIM_STYLE_ANGULAR_UNITS_ALT = -1006460
    SPOT_ELEV_IND_TYPE = -1006458
    SPOT_ELEV_BOT_VALUE = -1006457
    ALTERNATE_UNITS = -1006456
    SPOT_ELEV_TOP_VALUE = -1006455
    DIM_STYLE_LINEAR_UNITS_ALT = -1006454
    SPOT_ELEV_TEXT_ORIENTATION = -1006453
    SPOT_ELEV_IND_ELEVATION = -1006452
    SPOT_ELEV_IND_EW = -1006451
    SPOT_ELEV_IND_NS = -1006450
    ARROW_CLOSED = -1006449
    DIM_STYLE_READ_CONVENTION = -1006448
    HEAVY_END_PEN = -1006447
    DIM_STYLE_DIM_LINE_SNAP_DIST = -1006446
    DIM_STYLE_CENTERLINE_TICK_MARK = -1006445
    SPOT_ELEV_LINE_PEN = -1006444
    SPOT_ELEV_TICK_MARK_PEN = -1006443
    SPOT_ELEV_LEADER_ARROWHEAD = -1006442
    SPOT_ELEV_RELATIVE_BASE = -1006441
    SPOT_ELEV_FLIP_TEXT_VERT = -1006440
    SPOT_ELEV_TEXT_HORIZ_OFFSET = -1006439
    SPOT_ELEV_BASE = -1006437
    SPOT_ELEV_SYMBOL = -1006436
    DIM_STYLE_SHOW_OPENING_HT = -1006435
    DIM_STYLE_CENTERLINE_PATTERN = -1006434
    DIM_WITNS_LINE_EXTENSION_BELOW = -1006433
    DIM_WITNS_LINE_CNTRL = -1006432
    DIM_LINE_EXTENSION = -1006431
    DIM_STYLE_CENTERLINE_SYMBOL = -1006430
    DIM_TEXT_BACKGROUND = -1006429
    DIM_STYLE_ANGULAR_UNITS = -1006428
    DIM_STYLE_LINEAR_UNITS = -1006427
    LEADER_ARROW_WIDTH = -1006426
    ARROW_FILLED = -1006425
    HEAVY_TICK_MARK_PEN = -1006420
    ARROW_SIZE = -1006414
    ARROW_TYPE = -1006413
    TICK_MARK_PEN = -1006412
    TEXT_POSITION = -1006411
    RADIUS_SYMBOL_LOCATION = -1006408
    CENTER_MARK_SIZE = -1006407
    ARC_CENTER_MARK = -1006406
    WITNS_LINE_GAP_TO_ELT = -1006405
    WITNS_LINE_EXTENSION = -1006404
    TEXT_DIST_TO_LINE = -1006401
    TEXT_ALIGNMENT = -1006400
    MODEL_TEXT_SIZE = -1006336
    TEXT_STYLE_SIZE = -1006335
    TEXT_STYLE_FONT = -1006334
    SHOW_TITLE = -1006333
    TITLE_STYLE_UNDERLINE = -1006332
    TITLE_STYLE_ITALIC = -1006331
    TITLE_STYLE_BOLD = -1006330
    TITLE_SIZE = -1006329
    TITLE_FONT = -1006328
    TEXT_WIDTH_SCALE = -1006327
    TEXT_TAB_SIZE = -1006326
    ARC_LEADER_PARAM = -1006325
    DIM_LEADER_ARROWHEAD = -1006323
    SHEET_ISSUE_DATE = -1006322
    PROJECT_ISSUE_DATE = -1006321
    PROJECT_STATUS = -1006320
    CLIENT_NAME = -1006319
    PROJECT_ADDRESS = -1006318
    PROJECT_NAME = -1006317
    PROJECT_NUMBER = -1006316
    LEADER_ARROWHEAD = -1006315
    TEXT_BACKGROUND = -1006314
    TEXT_STYLE_UNDERLINE = -1006313
    TEXT_STYLE_ITALIC = -1006312
    TEXT_STYLE_BOLD = -1006311
    CURVE_IS_FILLED = -1006310
    TEXT_ALIGN_VERT = -1006309
    TEXT_ALIGN_HORZ = -1006308
    TEXT_TEXT = -1006307
    LINE_PATTERN = -1006305
    LINE_COLOR = -1006304
    LINE_PEN = -1006303
    TEXT_COLOR = -1006302
    TEXT_SIZE = -1006301
    TEXT_FONT = -1006300
    REFERENCE_LINE_SUBCATEGORY = -1006221
    CLINE_SUBCATEGORY = -1006220
    EDGE_LINEWORK = -1006212
    BUILDING_CURVE_GSTYLE_PLUS_INVISIBLE = -1006211
    BUILDING_CURVE_GSTYLE = -1006210
    FAMILY_CURVE_GSTYLE_FOR_2010_MASS = -1006207
    HEAD_ON_PLACEMENT_METHOD = -1006206
    IS_VISIBLE_PARAM = -1006205
    FAMILY_CURVE_GSTYLE_PLUS_INVISIBLE_PLUS_STICK_SYM_MINUS_ANALYTICAL = -1006204
    FAMILY_CURVE_GSTYLE_PLUS_INVISIBLE_MINUS_ANALYTICAL = -1006203
    FAMILY_CURVE_GSTYLE_PLUS_INVISIBLE_PLUS_STICK_SYM = -1006202
    FAMILY_CURVE_GSTYLE_PLUS_INVISIBLE = -1006201
    FAMILY_ELEM_SUBCATEGORY = -1006200
    STAIRS_CURVE_TYPE = -1006100
    ROOF_SLOPE = -1006016
    CURVE_PARAM_STEEL_CANTILEVER = -1006015
    CURVE_PARAM_CONCRETE_CANTILEVER = -1006014
    CURVE_NUMBER_OF_SEGMENTS = -1006013
    SPECIFY_SLOPE_OR_OFFSET = -1006012
    SLOPE_ARROW_LEVEL_END = -1006011
    SLOPE_ARROW_LEVEL_START = -1006010
    CURVE_LEVEL = -1006009
    CURVE_HEIGHT_OFFSET = -1006008
    CURVE_IS_SLOPE_DEFINING = -1006007
    DEFINES_CONSTANT_HEIGHT = -1006006
    ROOF_CURVE_HEIGHT_AT_WALL = -1006005
    ROOF_CURVE_HEIGHT_OFFSET = -1006001
    ROOF_CURVE_IS_SLOPE_DEFINING = -1006000
    STRUCTURAL_SECTION_ISHAPE_WEBTHICKNESS_LOCATION = -1005567
    STRUCTURAL_SECTION_ISHAPE_FLANGETHICKNESS_LOCATION = -1005566
    STRUCTURAL_SECTION_TOP_WEB_FILLET = -1005565
    STRUCTURAL_SECTION_SLOPED_WEB_ANGLE = -1005564
    STRUCTURAL_SECTION_SLOPED_FLANGE_ANGLE = -1005563
    STRUCTURAL_SECTION_CANTILEVER_HEIGHT = -1005562
    STRUCTURAL_SECTION_CANTILEVER_LENGTH = -1005561
    STRUCTURAL_SECTION_BOTTOM_CUT_HEIGHT = -1005560
    STRUCTURAL_SECTION_BOTTOM_CUT_WIDTH = -1005559
    STRUCTURAL_SECTION_TOP_CUT_HEIGHT = -1005558
    STRUCTURAL_SECTION_TOP_CUT_WIDTH = -1005557
    STRUCTURAL_FAMILY_CODE_NAME = -1005556
    STRUCTURAL_FAMILY_NAME_KEY = -1005555
    STRUCTURAL_SECTION_NAME_KEY = -1005554
    STRUCTURAL_SECTION_SIGMA_PROFILE_TOP_BEND_WIDTH = -1005553
    STRUCTURAL_SECTION_SIGMA_PROFILE_MIDDLE_BEND_WIDTH = -1005552
    STRUCTURAL_SECTION_SIGMA_PROFILE_BEND_WIDTH = -1005551
    STRUCTURAL_SECTION_ZPROFILE_BOTTOM_FLANGE_LENGTH = -1005550
    STRUCTURAL_SECTION_CPROFILE_FOLD_LENGTH = -1005549
    STRUCTURAL_SECTION_LPROFILE_LIP_LENGTH = -1005548
    STRUCTURAL_SECTION_LANGLE_BOLT_DIAMETER_SHORTER_FLANGE = -1005547
    STRUCTURAL_SECTION_LANGLE_BOLT_DIAMETER_LONGER_FLANGE = -1005546
    STRUCTURAL_SECTION_LANGLE_BOLT_SPACING_SHORTER_FLANGE = -1005545
    STRUCTURAL_SECTION_LANGLE_BOLT_SPACING_2_LONGER_FLANGE = -1005544
    STRUCTURAL_SECTION_LANGLE_BOLT_SPACING_1_LONGER_FLANGE = -1005543
    STRUCTURAL_SECTION_ISHAPE_BOLT_SPACING_WEB = -1005542
    STRUCTURAL_SECTION_ISHAPE_BOLT_SPACING_BETWEEN_ROWS = -1005541
    STRUCTURAL_SECTION_ISHAPE_BOLT_SPACING_TWO_ROWS = -1005540
    STRUCTURAL_SECTION_ISHAPE_BOLT_DIAMETER = -1005539
    STRUCTURAL_SECTION_ISHAPE_BOLT_SPACING = -1005538
    STRUCTURAL_SECTION_ISHAPE_WEB_TOE_OF_FILLET = -1005537
    STRUCTURAL_SECTION_ISHAPE_FLANGE_TOE_OF_FILLET = -1005536
    STRUCTURAL_SECTION_ISHAPE_CLEAR_WEB_HEIGHT = -1005535
    STRUCTURAL_SECTION_IWELDED_BOTTOMFLANGEWIDTH = -1005534
    STRUCTURAL_SECTION_IWELDED_BOTTOMFLANGETHICKNESS = -1005533
    STRUCTURAL_SECTION_IWELDED_TOPFLANGEWIDTH = -1005532
    STRUCTURAL_SECTION_IWELDED_TOPFLANGETHICKNESS = -1005531
    STRUCTURAL_SECTION_HSS_OUTERFILLET = -1005530
    STRUCTURAL_SECTION_HSS_INNERFILLET = -1005529
    STRUCTURAL_SECTION_ISHAPE_WEBFILLET = -1005528
    STRUCTURAL_SECTION_ISHAPE_FLANGEFILLET = -1005527
    STRUCTURAL_SECTION_ISHAPE_WEBHEIGHT = -1005526
    STRUCTURAL_SECTION_ISHAPE_WEBTHICKNESS = -1005525
    STRUCTURAL_SECTION_ISHAPE_FLANGETHICKNESS = -1005524
    STRUCTURAL_SECTION_COMMON_SHEAR_AREA_WEAK_AXIS = -1005523
    STRUCTURAL_SECTION_COMMON_SHEAR_AREA_STRONG_AXIS = -1005522
    STRUCTURAL_SECTION_COMMON_WARPING_CONSTANT = -1005521
    STRUCTURAL_SECTION_COMMON_TORSIONAL_MODULUS = -1005520
    STRUCTURAL_SECTION_COMMON_TORSIONAL_MOMENT_OF_INERTIA = -1005519
    STRUCTURAL_SECTION_COMMON_PLASTIC_MODULUS_WEAK_AXIS = -1005518
    STRUCTURAL_SECTION_COMMON_PLASTIC_MODULUS_STRONG_AXIS = -1005517
    STRUCTURAL_SECTION_COMMON_ELASTIC_MODULUS_WEAK_AXIS = -1005516
    STRUCTURAL_SECTION_COMMON_ELASTIC_MODULUS_STRONG_AXIS = -1005515
    STRUCTURAL_SECTION_COMMON_MOMENT_OF_INERTIA_WEAK_AXIS = -1005514
    STRUCTURAL_SECTION_COMMON_MOMENT_OF_INERTIA_STRONG_AXIS = -1005513
    STRUCTURAL_SECTION_COMMON_NOMINAL_WEIGHT = -1005512
    STRUCTURAL_SECTION_COMMON_PERIMETER = -1005511
    STRUCTURAL_SECTION_COMMON_ALPHA = -1005510
    STRUCTURAL_SECTION_COMMON_CENTROID_VERTICAL = -1005509
    STRUCTURAL_SECTION_COMMON_CENTROID_HORIZ = -1005508
    STRUCTURAL_SECTION_AREA = -1005507
    STRUCTURAL_SECTION_PIPESTANDARD_WALLDESIGNTHICKNESS = -1005506
    STRUCTURAL_SECTION_PIPESTANDARD_WALLNOMINALTHICKNESS = -1005505
    STRUCTURAL_SECTION_COMMON_DIAMETER = -1005504
    STRUCTURAL_SECTION_COMMON_HEIGHT = -1005503
    STRUCTURAL_SECTION_COMMON_WIDTH = -1005502
    STRUCTURAL_SECTION_SHAPE = -1005501
    STRUCTURAL_MATERIAL_PARAM = -1005500
    ANALYTICAL_DEFINE_THERMAL_PROPERTIES_BY = -1005439
    ANALYTIC_CONSTRUCTION_GBXML_TYPEID = -1005438
    ANALYTIC_CONSTRUCTION_LOOKUP_TABLE = -1005437
    ANALYTICAL_ROUGHNESS = -1005436
    ANALYTICAL_ABSORPTANCE = -1005435
    ANALYTICAL_THERMAL_MASS = -1005434
    ANALYTICAL_VISUAL_LIGHT_TRANSMITTANCE = -1005433
    ANALYTICAL_SOLAR_HEAT_GAIN_COEFFICIENT = -1005432
    ANALYTICAL_THERMAL_RESISTANCE = -1005431
    ANALYTICAL_HEAT_TRANSFER_COEFFICIENT = -1005430
    VIEW_DESIGN_OPTIONS_CONFIG = -1005400
    VIEW_UNDERLAY_TOP_ID = -1005335
    VIEW_GRAPH_SUN_PATH_SIZE = -1005334
    VIEW_GRAPH_SUN_PATH = -1005333
    VIEW_ANALYSIS_DISPLAY_STYLE = -1005332
    VIEW_GRAPH_SCHED_LEVEL_RELATIVE_BASE_TYPE = -1005331
    VIEW_GRAPH_SCHED_HIDDEN_LEVELS = -1005330
    VIEW_GRAPH_SCHED_TOTAL_ROWS = -1005329
    VIEW_GRAPH_SCHED_ROWS_COUNT = -1005328
    VIEW_GRAPH_SCHED_GRID_APPEARANCE = -1005327
    VIEW_GRAPH_SCHED_TEXT_APPEARANCE = -1005326
    VIEW_GRAPH_SCHED_TITLE = -1005325
    VIEW_GRAPH_SCHED_ROWS_FROM = -1005319
    VIEW_GRAPH_SCHED_GROUP_SIMILAR = -1005318
    VIEW_GRAPH_SCHED_MATERIAL_TYPES = -1005317
    VIEW_GRAPH_SCHED_LOCATIONS_HIGH = -1005316
    VIEW_GRAPH_SCHED_LOCATIONS_LOW = -1005315
    VIEW_GRAPH_SCHED_BOTTOM_LEVEL = -1005314
    VIEW_GRAPH_SCHED_TOP_LEVEL = -1005313
    VIEWPORT_ATTR_ORIENTATION_ON_SHEET = -1005254
    VIEWPORT_ATTR_SHOW_BOX = -1005253
    VIEWPORT_ATTR_SHOW_EXTENSION_LINE = -1005252
    VIEWPORT_ATTR_SHOW_LABEL = -1005251
    VIEWPORT_ATTR_LABEL_TAG = -1005250
    VIEW_SCALE_HAVENAME = -1005231
    VIEW_SCALE_CUSTOMNAME = -1005230
    VIEW_GRAPH_SCHED_OFF_GRID = -1005209
    VIEW_GRAPH_SCHED_UNITS_FORMAT = -1005208
    VIEWPORT_SHEET_NAME = -1005207
    VIEWPORT_SHEET_NUMBER = -1005206
    VIEWPORT_SCALE = -1005204
    VIEWPORT_VIEW_NAME = -1005203
    VIEWPORT_DETAIL_NUMBER = -1005201
    VIEW_TEMPLATE_FOR_SCHEDULE = -1005199
    RENDER_RPC_PROPERTIES = -1005198
    FAMILY_SYMBOLIC_REP = -1005197
    FAMILY_RENDERING_TYPE = -1005196
    RENDER_RPC_FILENAME = -1005195
    RENDER_PLANT_TRIM_HEIGHT = -1005194
    RENDER_PLANT_HEIGHT = -1005193
    RENDER_PLANT_NAME = -1005192
    VIEW_CAMERA_ORIENTATION = -1005184
    COLOR_SCHEME_LOCATION = -1005183
    VIEW_DEPENDENCY = -1005182
    VIEW_BACK_CLIPPING = -1005181
    VIEW_ASSOCIATED_ASSEMBLY_INSTANCE_ID = -1005179
    VIEW_GRAPH_SCHED_TOTAL_COLUMNS = -1005178
    VIEW_UNDERLAY_ORIENTATION = -1005177
    VIEW_TEMPLATE = -1005176
    VIEW_GRAPH_SCHED_NUMBER_COLUMNS = -1005175
    GRAPHIC_DISPLAY_OPTIONS = -1005173
    MODEL_GRAPHICS_STYLE_ANON_DRAFT = -1005172
    VIEW_REFERENCING_DETAIL = -1005171
    VIEW_REFERENCING_SHEET = -1005170
    VIEW_CAMERA_POSITION = -1005169
    PLAN_VIEW_NORTH = -1005168
    WALKTHROUGH_FRAMES_COUNT = -1005167
    PLAN_VIEW_LEVEL = -1005166
    MODEL_GRAPHICS_STYLE = -1005165
    VIEW_VISIBLE_CATEGORIES = -1005164
    VIEW_DISCIPLINE = -1005163
    PLAN_VIEW_RANGE = -1005162
    VIEW_MODEL_DISPLAY_MODE = -1005161
    VIEW_SHOW_MASSING = -1005160
    PLAN_VIEW_TOP_CLIP_HEIGHT = -1005159
    VIEW_CLEAN_JOINS = -1005158
    VIEW_SHEET_VIEWPORT_INFO = -1005157
    PLAN_VIEW_CUT_PLANE_HEIGHT = -1005155
    VIEW_DEPTH = -1005154
    VIEW_UNDERLAY_BOTTOM_ID = -1005153
    VIEW_SCALE_PULLDOWN_IMPERIAL = -1005152
    VIEW_SCALE_PULLDOWN_METRIC = -1005151
    VIEW_SCALE = -1005150
    VIEW_SCHEMA_SETTING_FOR_SYSTEM = -1005149
    VIEW_SCHEMA_SETTING_FOR_BUILDING = -1005148
    VIEW_FIXED_SKETCH_PLANE = -1005147
    GRAPHIC_DISPLAY_OPTIONS_PHOTO_EXPOSURE = -1005137
    GRAPHIC_DISPLAY_OPTIONS_FOG = -1005136
    GRAPHIC_DISPLAY_OPTIONS_BACKGROUND = -1005135
    GRAPHIC_DISPLAY_OPTIONS_SS_INTENSITY = -1005134
    GRAPHIC_DISPLAY_OPTIONS_LIGHTING = -1005133
    GRAPHIC_DISPLAY_OPTIONS_SHADOWS = -1005132
    GRAPHIC_DISPLAY_OPTIONS_MODEL = -1005131
    VIEWER3D_RENDER_SETTINGS = -1005124
    VIEWER_BOUND_FAR_CLIPPING = -1005123
    VIEWER_REFERENCE_LABEL_TEXT = -1005122
    VIEWER_IS_REFERENCE = -1005121
    VIEWER_REFERENCE_LABEL = -1005120
    VIEW_DESCRIPTION = -1005114
    VIEWER_MODEL_CLIP_BOX_ACTIVE = -1005113
    VIEW_NAME = -1005112
    VIEWER_BOUND_ACTIVE_NEAR = -1005111
    VIEWER_BOUND_ACTIVE_FAR = -1005110
    VIEWER_BOUND_ACTIVE_BOTTOM = -1005109
    VIEWER_BOUND_ACTIVE_TOP = -1005108
    VIEWER_BOUND_ACTIVE_LEFT = -1005107
    VIEWER_BOUND_ACTIVE_RIGHT = -1005106
    VIEWER_BOUND_OFFSET_NEAR = -1005105
    VIEWER_BOUND_OFFSET_FAR = -1005104
    VIEWER_BOUND_OFFSET_BOTTOM = -1005103
    VIEWER_BOUND_OFFSET_TOP = -1005102
    VIEWER_BOUND_OFFSET_LEFT = -1005101
    VIEWER_BOUND_OFFSET_RIGHT = -1005100
    VIEWER_ANNOTATION_CROP_ACTIVE = -1005094
    VIEWER_SHOW_UNCROPPED = -1005093
    VIEWER_CROP_REGION_DISABLED = -1005092
    VIEWER_CROP_REGION_VISIBLE = -1005091
    VIEWER_CROP_REGION = -1005090
    VIEWER_PERSPECTIVE = -1005050
    VIEWER_TARGET_ELEVATION = -1005002
    VIEWER_OPTION_VISIBILITY = -1005001
    VIEWER_EYE_ELEVATION = -1005000
    DIM_LABEL_IS_INSTANCE = -1004518
    DIM_ISREPORTING = -1004516
    DIM_LEADER = -1004515
    DIM_DISPLAY_EQ = -1004514
    DIM_NOT_MODIFIABLE = -1004513
    DIM_LABEL = -1004510
    DIM_LABEL_GP_SHOW = -1004502
    DIM_VALUE_ANGLE = -1004501
    DIM_VALUE_LENGTH = -1004500
    ELEM_REFERENCE_NAME_2D_XZ = -1004016
    CURVE_ELEM_DEFINES_SLOPE = -1004015
    RADIAL_ARRAY_ARC_RADIUS = -1004014
    CURVE_DETERMINES_ORIENTATION = -1004013
    DATUM_PLANE_DEFINES_WALL_CLOSURE = -1004012
    CURVE_IS_DETAIL = -1004011
    CURVE_ELEM_ARC_RADIUS = -1004010
    CURVE_ELEM_ARC_RANGE = -1004009
    CURVE_ELEM_ARC_END_ANGLE = -1004008
    CURVE_ELEM_ARC_START_ANGLE = -1004007
    CURVE_ELEM_LINE_ANGLE = -1004006
    CURVE_ELEM_LENGTH = -1004005
    ELEM_DELETABLE_IN_FAMILY = -1004004
    ELEM_REFERENCE_NAME = -1004003
    DATUM_PLANE_DEFINES_ORIGIN = -1004002
    ELEM_IS_REFERENCE = -1004001
    COLUMN_LOCATION_MARK = -1002563
    COLUMN_TOP_ATTACH_CUT_PARAM = -1002562
    COLUMN_BASE_ATTACH_CUT_PARAM = -1002561
    COLUMN_BASE_ATTACHED_PARAM = -1002560
    COLUMN_TOP_ATTACHED_PARAM = -1002559
    COLUMN_BASE_ATTACHMENT_OFFSET_PARAM = -1002558
    COLUMN_TOP_ATTACHMENT_OFFSET_PARAM = -1002557
    COLUMN_BASE_ATTACH_JUSTIFICATION_PARAM = -1002556
    COLUMN_TOP_ATTACH_JUSTIFICATION_PARAM = -1002555
    MATERIAL_PARAM_SHININESS = -1002554
    MATERIAL_PARAM_SMOOTHNESS = -1002553
    MATERIAL_PARAM_GLOW = -1002552
    MATERIAL_PARAM_TRANSPARENCY = -1002551
    MATERIAL_PARAM_COLOR = -1002550
    SEEK_ITEM_ID = -1002504
    OMNICLASS_DESCRIPTION = -1002503
    OMNICLASS_CODE = -1002502
    UNIFORMAT_DESCRIPTION = -1002501
    UNIFORMAT_CODE = -1002500
    SLOPE_END_HEIGHT = -1002401
    SLOPE_START_HEIGHT = -1002400
    CEILING_HAS_THICKNESS_PARAM = -1002302
    CEILING_THICKNESS_PARAM = -1002301
    CEILING_HEIGHTABOVELEVEL_PARAM = -1002300
    CEILING_THICKNESS = -1002206
    CEILING_ATTR_SYSTEMNAME_PARAM = -1002204
    CEILING_ATTR_SPACING2_PARAM = -1002203
    CEILING_ATTR_SPACING1_PARAM = -1002202
    CEILING_ATTR_PATTERN_PARAM = -1002201
    CEILING_ATTR_DEFAULT_HEIGHT_PARAM = -1002200
    FILLED_REGION_MASKING = -1002125
    BACKGROUND_PATTERN_COLOR_PARAM = -1002124
    FOREGROUND_PATTERN_COLOR_PARAM = -1002123
    BACKGROUND_DRAFT_PATTERN_ID_PARAM = -1002122
    FOREGROUND_ANY_PATTERN_ID_PARAM = -1002121
    FOREGROUND_DRAFT_PATTERN_ID_PARAM = -1002120
    BUILIDING_PAD_STRUCTURE_ID_PARAM = -1002119
    CEILING_STRUCTURE_ID_PARAM = -1002118
    ROOF_STRUCTURE_ID_PARAM = -1002117
    FLOOR_STRUCTURE_ID_PARAM = -1002116
    ANY_PATTERN_ID_PARAM_NO_NO = -1002115
    FILL_PATTERN_ID_PARAM_NO_NO = -1002114
    OBJECT_STYLE_MATERIAL_ID_PARAM = -1002113
    WRAPPING_AT_INSERTS_PARAM = -1002112
    WRAPPING_AT_ENDS_PARAM = -1002111
    COARSE_SCALE_FILL_PATTERN_COLOR = -1002110
    MODEL_CATEGORY_ID_PARAM = -1002109
    HOST_ID_PARAM = -1002108
    MATERIAL_ID_PARAM = -1002107
    COARSE_SCALE_FILL_PATTERN_ID_PARAM = -1002106
    ANY_PATTERN_ID_PARAM = -1002105
    WALL_STRUCTURE_ID_PARAM = -1002103
    SURFACE_PATTERN_ID_PARAM = -1002102
    FILL_PATTERN_ID_PARAM = -1002101
    ID_PARAM = -1002100
    SELECTION_EDITABLE_ONLY = -1002072
    EDITED_BY = -1002067
    SCHEDULE_TOP_LEVEL_OFFSET_PARAM = -1002066
    SCHEDULE_BASE_LEVEL_OFFSET_PARAM = -1002065
    SCHEDULE_TOP_LEVEL_PARAM = -1002064
    SCHEDULE_BASE_LEVEL_PARAM = -1002063
    SCHEDULE_LEVEL_PARAM = -1002062
    ELEM_ROOM_ID = -1002061
    ELEM_ROOM_NAME = -1002060
    ELEM_ROOM_NUMBER = -1002059
    ELEM_PARTITION_PARAM = -1002053
    ELEM_FAMILY_AND_TYPE_PARAM = -1002052
    ELEM_FAMILY_PARAM = -1002051
    ELEM_TYPE_PARAM = -1002050
    ELEM_TYPE_LABEL = -1002008
    BR_ORG_FILTER = -1002007
    BR_ORG_FOLDERS = -1002006
    SYMBOL_FAMILY_AND_TYPE_NAMES_PARAM = -1002003
    SYMBOL_FAMILY_NAME_PARAM = -1002002
    ALL_MODEL_FAMILY_NAME = -1002002
    ALL_MODEL_TYPE_NAME = -1002001
    SYMBOL_NAME_PARAM = -1002001
    SYMBOL_ID_PARAM = -1002000
    STRUCTURAL_DISPLAY_IN_HIDDEN_VIEWS = -1001956
    FLOOR_PARAM_SPAN_DIRECTION = -1001955
    FLOOR_PARAM_IS_STRUCTURAL = -1001954
    HOST_PERIMETER_COMPUTED = -1001953
    LEVEL_PARAM = -1001952
    FLOOR_HEIGHTABOVELEVEL_PARAM = -1001951
    FLOOR_ATTR_DEFAULT_HEIGHT_PARAM = -1001903
    FLOOR_ATTR_DEFAULT_THICKNESS_PARAM = -1001902
    FLOOR_ATTR_THICKNESS_PARAM = -1001900
    INSERT_ORIENTATION = -1001834
    PROFILE_PARAM_ALONG_PATH = -1001833
    PROFILE_FAM_TYPE_PLUS_NONE = -1001832
    PROFILE2_ANGLE = -1001831
    PROFILE2_FAM_TYPE = -1001830
    PROFILE2_FLIPPED_HOR = -1001829
    PROFILE2_OFFSET_Y = -1001828
    PROFILE2_OFFSET_X = -1001827
    PROFILE1_ANGLE = -1001826
    PROFILE1_FAM_TYPE = -1001825
    PROFILE1_FLIPPED_HOR = -1001824
    PROFILE1_OFFSET_Y = -1001823
    PROFILE1_OFFSET_X = -1001822
    FAM_PROFILE_USAGE = -1001821
    SWEEP_TRAJ_SEGMENTED = -1001820
    SWEEP_MAX_SEG_ANGLE = -1001819
    MODEL_OR_SYMBOLIC = -1001818
    PROFILE_ANGLE = -1001817
    PROFILE_FAM_TYPE = -1001816
    PROFILE_FLIPPED_HOR = -1001815
    PROFILE_OFFSET_Y = -1001814
    PROFILE_OFFSET_X = -1001813
    EXTRUSION_LENGTH = -1001812
    CURVE_VISIBILITY_PARAM = -1001809
    GEOM_VISIBILITY_PARAM = -1001808
    ELEMENT_IS_CUTTING = -1001807
    EXTRUSION_AUTO_PARAMS = -1001806
    BLEND_END_PARAM = -1001805
    BLEND_START_PARAM = -1001804
    REVOLUTION_END_ANGLE = -1001803
    REVOLUTION_START_ANGLE = -1001802
    EXTRUSION_END_PARAM = -1001801
    EXTRUSION_START_PARAM = -1001800
    SCHEDULE_TYPE_FOR_BROWSER = -1001718
    SCHEDULE_CATEGORY = -1001717
    FACEROOF_OFFSET_PARAM = -1001716
    FACEROOF_LEVEL_PARAM = -1001715
    ROOF_FACES_LOCATION = -1001714
    RELATED_TO_MASS = -1001713
    FASCIA_DEPTH_PARAM = -1001711
    ROOF_EAVE_CUT_PARAM = -1001710
    ROOF_RAFTER_OR_TRUSS_PARAM = -1001709
    ROOF_BASE_LEVEL_PARAM = -1001708
    CURVE_WALL_OFFSET_ROOFS = -1001707
    CURVE_WALL_OFFSET = -1001706
    ACTUAL_MAX_RIDGE_HEIGHT_PARAM = -1001705
    ROOF_UPTO_LEVEL_OFFSET_PARAM = -1001703
    ROOF_UPTO_LEVEL_PARAM = -1001702
    ROOF_LEVEL_OFFSET_PARAM = -1001701
    STRUCTURAL_ELEVATION_AT_BOTTOM_SURVEY = -1001658
    STRUCTURAL_ELEVATION_AT_TOP_SURVEY = -1001657
    STRUCTURAL_FLOOR_CORE_THICKNESS = -1001656
    STRUCTURAL_ELEVATION_AT_BOTTOM_CORE = -1001655
    STRUCTURAL_ELEVATION_AT_TOP_CORE = -1001654
    STRUCTURAL_REFERENCE_LEVEL_ELEVATION = -1001653
    ROOF_CONSTRAINT_OFFSET_PARAM = -1001652
    ROOF_CONSTRAINT_LEVEL_PARAM = -1001651
    HOST_SSE_CURVED_EDGE_CONDITION_PARAM = -1001603
    ROOF_ATTR_THICKNESS_PARAM = -1001601
    ROOF_ATTR_DEFAULT_THICKNESS_PARAM = -1001600
    STRUCTURAL_ELEVATION_AT_TOP = -1001598
    NODE_CONNECTION_STATUS = -1001597
    WALL_STRUCTURAL_SIGNIFICANT = -1001596
    STRUCTURAL_ANALYTICAL_BEAM_RIGID_LINK = -1001595
    STRUCTURAL_ANALYTICAL_COLUMN_HORIZONTAL_PROJECTION_PLANE = -1001594
    STRUCTURAL_ANALYTICAL_BEAM_HORIZONTAL_PROJECTION_PLANE = -1001593
    CONTINUOUS_FOOTING_BREAK_AT_INSERTS_DISABLE = -1001592
    CONTINUOUS_FOOTING_DEFAULT_END_EXTENSION_LENGTH = -1001591
    STRUCTURAL_ANALYTICAL_TESSELLATE = -1001589
    STRUCTURAL_ANALYTICAL_TESS_DEVIATION = -1001588
    STRUCTURAL_ANALYTICAL_HARD_POINTS = -1001587
    STRUCTURAL_BEND_DIR_ANGLE = -1001586
    STRUCTURAL_DISPLAY_IN_HIDDEN_VIEWS_COLUMN = -1001585
    STRUCTURAL_DISPLAY_IN_HIDDEN_VIEWS_FRAMING = -1001584
    STRUCTURAL_FLOOR_ANALYZES_AS = -1001577
    STRUCTURAL_ANALYZES_AS = -1001576
    STRUCTURAL_BEAM_CUTBACK_FOR_COLUMN = -1001575
    BEAM_V_JUSTIFICATION_OTHER_VALUE = -1001574
    STRUCTURAL_BEAM_ORIENTATION = -1001573
    STRUCTURAL_BEAM_END1_ELEVATION = -1001572
    STRUCTURAL_BEAM_END0_ELEVATION = -1001571
    FAMILY_EXPORT_AS_GEOMETRY = -1001570
    STRUCTURAL_FOUNDATION_LENGTH = -1001569
    STRUCTURAL_FOUNDATION_WIDTH = -1001568
    CONTINUOUS_FOOTING_LENGTH = -1001567
    CONTINUOUS_FOOTING_ECCENTRICITY = -1001564
    CONTINUOUS_FOOTING_STRUCTURAL_USAGE = -1001563
    CONTINUOUS_FOOTING_BEARING_WIDTH = -1001562
    STRUCTURAL_ELEVATION_AT_BOTTOM = -1001561
    FAMILY_STRUCT_FOOTING_USE_CAP_TOP = -1001560
    STRUCTURAL_COPING_DISTANCE = -1001559
    CONTINUOUS_FOOTING_WIDTH = -1001558
    STRUCTURAL_FOUNDATION_THICKNESS = -1001557
    CONTINUOUS_FOOTING_BOTTOM_HEEL = -1001556
    CONTINUOUS_FOOTING_TOP_HEEL = -1001555
    CONTINUOUS_FOOTING_BOTTOM_TOE = -1001554
    CONTINUOUS_FOOTING_TOP_TOE = -1001553
    STRUCTURAL_ANALYTICAL_MODEL = -1001552
    STRUCTURAL_ANALYTICAL_COLUMN_RIGID_LINK = -1001551
    FAMILY_STRUCT_MATERIAL_TYPE = -1001550
    STRUCTURAL_BOTTOM_RELEASE_MZ = -1001549
    STRUCTURAL_BOTTOM_RELEASE_MY = -1001548
    STRUCTURAL_BOTTOM_RELEASE_MX = -1001547
    STRUCTURAL_BOTTOM_RELEASE_FZ = -1001546
    STRUCTURAL_BOTTOM_RELEASE_FY = -1001545
    STRUCTURAL_BOTTOM_RELEASE_FX = -1001544
    STRUCTURAL_TOP_RELEASE_MZ = -1001543
    STRUCTURAL_TOP_RELEASE_MY = -1001542
    STRUCTURAL_TOP_RELEASE_MX = -1001541
    STRUCTURAL_TOP_RELEASE_FZ = -1001540
    STRUCTURAL_TOP_RELEASE_FY = -1001539
    STRUCTURAL_TOP_RELEASE_FX = -1001538
    STRUCTURAL_BOTTOM_RELEASE_TYPE = -1001537
    STRUCTURAL_TOP_RELEASE_TYPE = -1001536
    STRUCTURAL_ANALYTICAL_PROJECT_MEMBER_PLANE_COLUMN_BOTTOM = -1001535
    STRUCTURAL_ANALYTICAL_PROJECT_MEMBER_PLANE_COLUMN_TOP = -1001534
    STRUCTURAL_MATERIAL_TYPE = -1001531
    STRUCTURAL_CAMBER = -1001530
    STRUCTURAL_NUMBER_OF_STUDS = -1001529
    STRUCTURAL_END_RELEASE_MZ = -1001528
    STRUCTURAL_END_RELEASE_MY = -1001527
    STRUCTURAL_END_RELEASE_MX = -1001526
    STRUCTURAL_END_RELEASE_FZ = -1001525
    STRUCTURAL_END_RELEASE_FY = -1001524
    STRUCTURAL_END_RELEASE_FX = -1001523
    STRUCTURAL_START_RELEASE_MZ = -1001522
    STRUCTURAL_START_RELEASE_MY = -1001521
    STRUCTURAL_START_RELEASE_MX = -1001520
    STRUCTURAL_START_RELEASE_FZ = -1001519
    STRUCTURAL_START_RELEASE_FY = -1001518
    STRUCTURAL_START_RELEASE_FX = -1001517
    STRUCTURAL_END_RELEASE_TYPE = -1001516
    STRUCTURAL_START_RELEASE_TYPE = -1001515
    STRUCTURAL_WALL_BOTTOM_PROJECTION_PLANE = -1001514
    STRUCTURAL_WALL_TOP_PROJECTION_PLANE = -1001513
    STRUCTURAL_WALL_PROJECTION_SURFACE = -1001512
    STRUCTURAL_ANALYTICAL_PROJECT_FLOOR_PLANE = -1001510
    STRUCTURAL_ANALYTICAL_PROJECT_MEMBER_PLANE = -1001508
    STRUCTURAL_BRACE_REPRESENTATION = -1001507
    STRUCTURAL_STICK_SYMBOL_LOCATION = -1001503
    STRUCTURAL_BEAM_END_SUPPORT = -1001502
    STRUCTURAL_BEAM_START_SUPPORT = -1001501
    WINDOW_TYPE_ID = -1001405
    ALL_MODEL_TYPE_MARK = -1001405
    WALL_SWEEP_ORIENTATION = -1001399
    STRUCTURAL_ATTACHMENT_END_VALUE_ELEVATION = -1001398
    STRUCTURAL_ATTACHMENT_START_VALUE_ELEVATION = -1001397
    STRUCTURAL_ATTACHMENT_END_LEVEL_REFERENCE = -1001396
    STRUCTURAL_ATTACHMENT_START_LEVEL_REFERENCE = -1001395
    STRUCTURAL_ATTACHMENT_END_VALUE_RATIO = -1001393
    STRUCTURAL_ATTACHMENT_START_VALUE_RATIO = -1001392
    STRUCTURAL_ATTACHMENT_END_REFELEMENT_END = -1001391
    TYPE_WALL_CLOSURE = -1001390
    STRUCTURAL_ATTACHMENT_START_REFELEMENT_END = -1001389
    STRUCTURAL_ATTACHMENT_END_VALUE_DISTANCE = -1001388
    STRUCTURAL_ATTACHMENT_START_VALUE_DISTANCE = -1001387
    STRUCTURAL_ATTACHMENT_END_TYPE = -1001386
    STRUCTURAL_ATTACHMENT_START_TYPE = -1001385
    STRUCTURAL_FRAME_CUT_LENGTH = -1001384
    INSTANCE_REFERENCE_LEVEL_PARAM = -1001383
    INSTANCE_STRUCT_USAGE_PARAM = -1001381
    SKETCH_PLANE_PARAM = -1001380
    INSTANCE_LENGTH_PARAM = -1001375
    INSTANCE_MOVES_WITH_GRID_PARAM = -1001371
    INSTANCE_OFFSET_POS_PARAM = -1001370
    INSTANCE_SCHEDULE_ONLY_LEVEL_PARAM = -1001365
    INSTANCE_FREE_HOST_OFFSET_PARAM = -1001364
    INSTANCE_FREE_HOST_PARAM = -1001363
    INSTANCE_HEAD_HEIGHT_PARAM = -1001362
    INSTANCE_SILL_HEIGHT_PARAM = -1001361
    INSTANCE_ELEVATION_PARAM = -1001360
    FAMILY_TOP_LEVEL_OFFSET_PARAM = -1001358
    FAMILY_BASE_LEVEL_OFFSET_PARAM = -1001357
    FAMILY_LEVEL_PARAM = -1001352
    FAMILY_TOP_LEVEL_PARAM = -1001351
    FAMILY_BASE_LEVEL_PARAM = -1001350
    FAMILY_RFA_PATH_PSEUDO_PARAM = -1001338
    FAMILY_CATEGORY_PSEUDO_PARAM = -1001337
    FAMILY_NAME_PSEUDO_PARAM = -1001336
    FAMILY_USAGE_PSEUDO_PARAM = -1001335
    FAMILY_WPB_DEFAULT_ELEVATION = -1001320
    FAMILY_LINE_LENGTH_PARAM = -1001306
    FAMILY_ROUGH_WIDTH_PARAM = -1001305
    FAMILY_ROUGH_HEIGHT_PARAM = -1001304
    WINDOW_INSET = -1001303
    FAMILY_WINDOW_INSET_PARAM = -1001303
    FAMILY_THICKNESS_PARAM = -1001302
    WINDOW_THICKNESS = -1001302
    DOOR_THICKNESS = -1001302
    GENERIC_THICKNESS = -1001302
    FURNITURE_THICKNESS = -1001302
    DOOR_WIDTH = -1001301
    FURNITURE_WIDTH = -1001301
    CASEWORK_WIDTH = -1001301
    GENERIC_WIDTH = -1001301
    WINDOW_WIDTH = -1001301
    FAMILY_WIDTH_PARAM = -1001301
    FURNITURE_HEIGHT = -1001300
    DOOR_HEIGHT = -1001300
    CASEWORK_HEIGHT = -1001300
    WINDOW_HEIGHT = -1001300
    FAMILY_HEIGHT_PARAM = -1001300
    GENERIC_HEIGHT = -1001300
    DOOR_EVACUATION_EXIT_TYPE = -1001212
    WINDOW_OPERATION_TYPE = -1001211
    DOOR_OPERATION_TYPE = -1001211
    DOOR_FRAME_MATERIAL = -1001210
    DOOR_FRAME_TYPE = -1001209
    DOOR_FINISH = -1001208
    CURTAIN_WALL_PANELS_FINISH = -1001208
    CASEWORK_FINISH = -1001208
    GENERIC_FINISH = -1001208
    GENERIC_CONSTRUCTION_TYPE = -1001207
    DOOR_CONSTRUCTION_TYPE = -1001207
    WINDOW_CONSTRUCTION_TYPE = -1001207
    CURTAIN_WALL_PANELS_CONSTRUCTION_TYPE = -1001207
    CASEWORK_CONSTRUCTION_TYPE = -1001207
    FIRE_RATING = -1001206
    DOOR_FIRE_RATING = -1001206
    ALL_MODEL_COST = -1001205
    DOOR_COST = -1001205
    DOOR_NUMBER = -1001203
    ALL_MODEL_MARK = -1001203
    DPART_ORIGINAL_CATEGORY_ID = -1001140
    DPART_LAYER_CONSTRUCTION = -1001139
    DPART_PHASE_DEMOLISHED_BY_ORIGINAL = -1001138
    DPART_PHASE_CREATED_BY_ORIGINAL = -1001137
    DPART_LENGTH_COMPUTED = -1001136
    DPART_HEIGHT_COMPUTED = -1001135
    DPART_LAYER_WIDTH = -1001134
    DPART_AREA_COMPUTED = -1001133
    DPART_ORIGINAL_TYPE = -1001132
    OFFSETFACES_SHOW_SHAPE_HANDLES = -1001131
    DPART_LAYER_FUNCTION = -1001130
    DPART_VOLUME_COMPUTED = -1001129
    DPART_MATERIAL_BY_ORIGINAL = -1001128
    DPART_MATERIAL_ID_PARAM = -1001127
    DPART_ORIGINAL_FAMILY = -1001126
    DPART_ORIGINAL_CATEGORY = -1001125
    HOST_PANEL_SCHEDULE_AS_PANEL_PARAM = -1001124
    WALL_LOCATION_LINE_OFFSET_PARAM = -1001123
    WALL_KEY_REF_PARAM = -1001122
    MEASURE_FROM_STRUCTURE = -1001120
    WALL_STRUCTURAL_USAGE_PARAM = -1001119
    WALL_BOTTOM_IS_ATTACHED = -1001118
    WALL_TOP_IS_ATTACHED = -1001117
    WALL_TOP_OFFSET = -1001109
    WALL_BASE_OFFSET = -1001108
    WALL_BASE_CONSTRAINT = -1001107
    WALL_USER_HEIGHT_PARAM = -1001105
    WALL_HEIGHT_TYPE = -1001103
    WALL_BASE_HEIGHT_PARAM = -1001102
    ALLOW_AUTO_EMBED = -1001009
    WALL_ATTR_ROOM_BOUNDING = -1001007
    FUNCTION_PARAM = -1001006
    WALL_ATTR_DEFHEIGHT_PARAM = -1001002
    WALL_ATTR_HEIGHT_PARAM = -1001001
    WALL_ATTR_WIDTH_PARAM = -1001000
    INVALID = -1


class BuiltInParameterGroup:
    PG_ROUTE_ANALYSIS = -5000227
    PG_GEO_LOCATION = -5000226
    PG_STRUCTURAL_SECTION_GEOMETRY = -5000225
    PG_ENERGY_ANALYSIS_BLDG_CONS_MTL_THERMAL_PROPS = -5000221
    PG_ENERGY_ANALYSIS_ROOM_SPACE_DATA = -5000220
    PG_ENERGY_ANALYSIS_BUILDING_DATA = -5000219
    PG_COUPLER_ARRAY = -5000218
    PG_ENERGY_ANALYSIS_ADVANCED = -5000217
    PG_RELEASES_MEMBER_FORCES = -5000216
    PG_SECONDARY_END = -5000214
    PG_PRIMARY_END = -5000213
    PG_MOMENTS = -5000212
    PG_FORCES = -5000211
    PG_FABRICATION_PRODUCT_DATA = -5000210
    PG_REFERENCE = -5000208
    PG_GEOMETRY_POSITIONING = -5000207
    PG_DIVISION_GEOMETRY = -5000206
    PG_SEGMENTS_FITTINGS = -5000205
    PG_CONTINUOUSRAIL_END_TOP_EXTENSION = -5000204
    PG_CONTINUOUSRAIL_BEGIN_BOTTOM_EXTENSION = -5000203
    PG_STAIRS_WINDERS = -5000202
    PG_STAIRS_SUPPORTS = -5000201
    PG_STAIRS_OPEN_END_CONNECTION = -5000200
    PG_RAILING_SYSTEM_SECONDARY_FAMILY_HANDRAILS = -5000199
    PG_TERMINTATION = -5000198
    PG_STAIRS_TREADS_RISERS = -5000197
    PG_STAIRS_CALCULATOR_RULES = -5000196
    PG_SPLIT_PROFILE_DIMENSIONS = -5000195
    PG_LENGTH = -5000194
    PG_NODES = -5000193
    PG_ANALYTICAL_PROPERTIES = -5000192
    PG_ANALYTICAL_ALIGNMENT = -5000191
    PG_SYSTEMTYPE_RISEDROP = -5000190
    PG_LINING = -5000189
    PG_INSULATION = -5000188
    PG_OVERALL_LEGEND = -5000187
    PG_VISIBILITY = -5000186
    PG_SUPPORT = -5000185
    PG_RAILING_SYSTEM_SEGMENT_V_GRID = -5000184
    PG_RAILING_SYSTEM_SEGMENT_U_GRID = -5000183
    PG_RAILING_SYSTEM_SEGMENT_POSTS = -5000182
    PG_RAILING_SYSTEM_SEGMENT_PATTERN_REMAINDER = -5000181
    PG_RAILING_SYSTEM_SEGMENT_PATTERN_REPEAT = -5000180
    PG_RAILING_SYSTEM_FAMILY_SEGMENT_PATTERN = -5000179
    PG_RAILING_SYSTEM_FAMILY_HANDRAILS = -5000178
    PG_RAILING_SYSTEM_FAMILY_TOP_RAIL = -5000177
    PG_CONCEPTUAL_ENERGY_DATA_BUILDING_SERVICES = -5000176
    PG_DATA = -5000175
    PG_ELECTRICAL_CIRCUITING = -5000174
    PG_GENERAL = -5000173
    PG_FLEXIBLE = -5000172
    PG_ENERGY_ANALYSIS_CONCEPTUAL_MODEL = -5000171
    PG_ENERGY_ANALYSIS_DETAILED_MODEL = -5000170
    PG_ENERGY_ANALYSIS_DETAILED_AND_CONCEPTUAL_MODELS = -5000169
    PG_FITTING = -5000168
    PG_CONCEPTUAL_ENERGY_DATA = -5000167
    PG_AREA = -5000166
    PG_ADSK_MODEL_PROPERTIES = -5000165
    PG_CURTAIN_GRID_V = -5000164
    PG_CURTAIN_GRID_U = -5000163
    PG_DISPLAY = -5000162
    PG_ANALYSIS_RESULTS = -5000161
    PG_SLAB_SHAPE_EDIT = -5000160
    PG_LIGHT_PHOTOMETRICS = -5000159
    PG_PATTERN_APPLICATION = -5000158
    PG_GREEN_BUILDING = -5000157
    PG_PROFILE_2 = -5000156
    PG_PROFILE_1 = -5000155
    PG_PROFILE = -5000154
    PG_TRUSS_FAMILY_BOTTOM_CHORD = -5000153
    PG_TRUSS_FAMILY_TOP_CHORD = -5000152
    PG_TRUSS_FAMILY_DIAG_WEB = -5000151
    PG_TRUSS_FAMILY_VERT_WEB = -5000150
    PG_TITLE = -5000149
    PG_FIRE_PROTECTION = -5000148
    PG_ROTATION_ABOUT = -5000147
    PG_TRANSLATION_IN = -5000146
    PG_ANALYTICAL_MODEL = -5000145
    PG_REBAR_ARRAY = -5000144
    PG_REBAR_SYSTEM_LAYERS = -5000143
    PG_CURTAIN_GRID = -5000141
    PG_CURTAIN_MULLION_2 = -5000140
    PG_CURTAIN_MULLION_HORIZ = -5000139
    PG_CURTAIN_MULLION_1 = -5000138
    PG_CURTAIN_MULLION_VERT = -5000137
    PG_CURTAIN_GRID_2 = -5000136
    PG_CURTAIN_GRID_HORIZ = -5000135
    PG_CURTAIN_GRID_1 = -5000134
    PG_CURTAIN_GRID_VERT = -5000133
    PG_IFC = -5000131
    PG_AELECTRICAL = -5000130
    PG_ENERGY_ANALYSIS = -5000129
    PG_STRUCTURAL_ANALYSIS = -5000128
    PG_MECHANICAL_AIRFLOW = -5000127
    PG_MECHANICAL_LOADS = -5000126
    PG_ELECTRICAL_LOADS = -5000125
    PG_ELECTRICAL_LIGHTING = -5000124
    PG_TEXT = -5000123
    PG_VIEW_CAMERA = -5000122
    PG_VIEW_EXTENTS = -5000121
    PG_PATTERN = -5000120
    PG_CONSTRAINTS = -5000119
    PG_PHASING = -5000114
    PG_MECHANICAL = -5000113
    PG_STRUCTURAL = -5000112
    PG_PLUMBING = -5000111
    PG_ELECTRICAL = -5000110
    PG_STAIR_STRINGERS = -5000109
    PG_STAIR_RISERS = -5000108
    PG_STAIR_TREADS = -5000107
    PG_UNDERLAY = -5000106
    PG_MATERIALS = -5000105
    PG_GRAPHICS = -5000104
    PG_CONSTRUCTION = -5000103
    PG_GEOMETRY = -5000101
    PG_IDENTITY_DATA = -5000100
    INVALID = -1


class BuiltInCategory:
    OST_StackedWalls_Obsolete_IdInWrongRange = -20034100
    OST_MassTags_Obsolete_IdInWrongRange = -20034005
    OST_MassSurface_Obsolete_IdInWrongRange = -20034004
    OST_MassFloor_Obsolete_IdInWrongRange = -20034003
    OST_Mass_Obsolete_IdInWrongRange = -20034000
    OST_WallRefPlanes_Obsolete_IdInWrongRange = -20000896
    OST_StickSymbols_Obsolete_IdInWrongRange = -20000828
    OST_RemovedGridSeg_Obsolete_IdInWrongRange = -20000827
    OST_PointClouds = -2010001
    OST_AssemblyOrigin_Lines = -2009661
    OST_AssemblyOrigin_Planes = -2009660
    OST_AssemblyOrigin_Points = -2009659
    OST_AssemblyOrigin = -2009658
    OST_LinksAnalytical = -2009657
    OST_FoundationSlabAnalyticalTags = -2009656
    OST_WallFoundationAnalyticalTags = -2009655
    OST_IsolatedFoundationAnalyticalTags = -2009654
    OST_WallAnalyticalTags = -2009653
    OST_FloorAnalyticalTags = -2009652
    OST_ColumnAnalyticalTags = -2009651
    OST_BraceAnalyticalTags = -2009650
    OST_BeamAnalyticalTags = -2009649
    OST_AnalyticalNodes_Lines = -2009648
    OST_AnalyticalNodes_Planes = -2009647
    OST_AnalyticalNodes_Points = -2009646
    OST_AnalyticalNodes = -2009645
    OST_RigidLinksAnalytical = -2009644
    OST_FoundationSlabAnalytical = -2009643
    OST_WallFoundationAnalytical = -2009642
    OST_IsolatedFoundationAnalytical = -2009641
    OST_WallAnalytical = -2009640
    OST_FloorAnalytical = -2009639
    OST_ColumnEndSegment = -2009638
    OST_ColumnStartSegment = -2009637
    OST_ColumnAnalytical = -2009636
    OST_BraceEndSegment = -2009635
    OST_BraceStartSegment = -2009634
    OST_BraceAnalytical = -2009633
    OST_BeamEndSegment = -2009632
    OST_BeamStartSegment = -2009631
    OST_BeamAnalytical = -2009630
    OST_CompassSecondaryMonth = -2009624
    OST_CompassPrimaryMonth = -2009623
    OST_CompassSectionFilled = -2009622
    OST_LightLine = -2009621
    OST_MultiSurface = -2009620
    OST_SunSurface = -2009619
    OST_Analemma = -2009618
    OST_SunsetText = -2009617
    OST_CompassSection = -2009616
    OST_CompassOuter = -2009615
    OST_SunriseText = -2009614
    OST_CompassInner = -2009613
    OST_SunPath2 = -2009612
    OST_SunPath1 = -2009611
    OST_Sun = -2009610
    OST_SunStudy = -2009609
    OST_StructuralTrussStickSymbols = -2009608
    OST_StructuralTrussHiddenLines = -2009607
    OST_TrussChord = -2009606
    OST_TrussWeb = -2009605
    OST_TrussBottomChordCurve = -2009604
    OST_TrussTopChordCurve = -2009603
    OST_TrussVertWebCurve = -2009602
    OST_TrussDiagWebCurve = -2009601
    OST_Truss = -2009600
    OST_RailingSystemTransitionHiddenLines_Deprecated = -2009549
    OST_RailingSystemTerminationHiddenLines_Deprecated = -2009548
    OST_RailingSystemRailHiddenLines_Deprecated = -2009547
    OST_RailingSystemTopRailHiddenLines_Deprecated = -2009546
    OST_RailingSystemHandRailBracketHiddenLines_Deprecated = -2009545
    OST_RailingSystemHandRailHiddenLines_Deprecated = -2009544
    OST_RailingSystemPanelBracketHiddenLines_Deprecated = -2009543
    OST_RailingSystemPanelHiddenLines_Deprecated = -2009542
    OST_RailingSystemBalusterHiddenLines_Deprecated = -2009541
    OST_RailingSystemPostHiddenLines_Deprecated = -2009540
    OST_RailingSystemSegmentHiddenLines_Deprecated = -2009539
    OST_RailingSystemHiddenLines_Deprecated = -2009538
    OST_StairStringer2012HiddenLines_Deprecated = -2009537
    OST_StairTread2012HiddenLines_Deprecated = -2009536
    OST_StairLanding2012HiddenLines_Deprecated = -2009535
    OST_StairRun2012HiddenLines_Deprecated = -2009534
    OST_Stairs2012HiddenLines_Deprecated = -2009533
    OST_MassHiddenLines = -2009532
    OST_CurtaSystemHiddenLines = -2009531
    OST_OBSOLETE_ElemArrayHiddenLines = -2009530
    OST_EntourageHiddenLines = -2009529
    OST_PlantingHiddenLines = -2009528
    OST_SpecialityEquipmentHiddenLines = -2009527
    OST_TopographyHiddenLines = -2009526
    OST_StructuralFramingSystemHiddenLines_Obsolete = -2009525
    OST_SiteHiddenLines = -2009524
    OST_RoadsHiddenLines = -2009523
    OST_ParkingHiddenLines = -2009522
    OST_PlumbingFixturesHiddenLines = -2009521
    OST_MechanicalEquipmentHiddenLines = -2009520
    OST_LightingFixturesHiddenLines = -2009519
    OST_FurnitureSystemsHiddenLines = -2009518
    OST_ElectricalFixturesHiddenLines = -2009517
    OST_ElectricalEquipmentHiddenLines = -2009516
    OST_CaseworkHiddenLines = -2009515
    OST_DetailComponentsHiddenLines = -2009514
    OST_ShaftOpeningHiddenLines = -2009513
    OST_GenericModelHiddenLines = -2009512
    OST_CurtainWallMullionsHiddenLines = -2009511
    OST_CurtainWallPanelsHiddenLines = -2009510
    OST_RampsHiddenLines = -2009509
    OST_StairsRailingHiddenLines = -2009508
    OST_StairsHiddenLines = -2009507
    OST_ColumnsHiddenLines = -2009506
    OST_FurnitureHiddenLines = -2009505
    OST_LinesHiddenLines = -2009504
    OST_CeilingsHiddenLines = -2009503
    OST_RoofsHiddenLines = -2009502
    OST_DoorsHiddenLines = -2009501
    OST_WindowsHiddenLines = -2009500
    OST_StructConnectionProfilesTags = -2009064
    OST_StructConnectionHoleTags = -2009063
    OST_CouplerHiddenLines = -2009062
    OST_CouplerTags = -2009061
    OST_Coupler = -2009060
    OST_StructConnectionWeldTags = -2009059
    OST_StructConnectionShearStudTags = -2009058
    OST_StructConnectionAnchorTags = -2009057
    OST_StructConnectionBoltTags = -2009056
    OST_StructConnectionPlateTags = -2009055
    OST_RebarHiddenLines = -2009050
    OST_StructSubConnections = -2009049
    OST_SteelElementStale = -2009048
    OST_StructConnectionModifiers = -2009047
    OST_StructConnectionWelds = -2009046
    OST_StructConnectionHoles = -2009045
    OST_StructConnectionShearStuds = -2009044
    OST_StructConnectionNobleWarning = -2009043
    OST_StructConnectionOthers = -2009042
    OST_StructConnectionBolts = -2009041
    OST_StructConnectionTags = -2009040
    OST_StructConnectionAnchors = -2009039
    OST_StructConnectionPlates = -2009038
    OST_StructConnectionProfiles = -2009037
    OST_StructConnectionReference = -2009036
    OST_StructConnectionFailed = -2009035
    OST_StructConnectionStale = -2009034
    OST_StructConnectionSymbol = -2009033
    OST_StructConnectionHiddenLines = -2009032
    OST_StructWeldLines = -2009031
    OST_StructConnections = -2009030
    OST_FabricAreaBoundary = -2009029
    OST_FabricReinSpanSymbol = -2009028
    OST_FabricReinforcementWire = -2009027
    OST_FabricReinforcementBoundary = -2009026
    OST_RebarSetToggle = -2009025
    OST_FabricAreaTags = -2009023
    OST_FabricReinforcementTags = -2009022
    OST_AreaReinTags = -2009021
    OST_RebarTags = -2009020
    OST_FabricAreaSketchSheetsLines = -2009019
    OST_FabricAreaSketchEnvelopeLines = -2009018
    OST_FabricAreas = -2009017
    OST_FabricReinforcement = -2009016
    OST_RebarCover = -2009015
    OST_CoverType = -2009014
    OST_RebarShape = -2009013
    OST_PathReinBoundary = -2009012
    OST_PathReinTags = -2009011
    OST_PathReinSpanSymbol = -2009010
    OST_PathRein = -2009009
    OST_Cage = -2009008
    OST_AreaReinXVisibility = -2009007
    OST_AreaReinBoundary = -2009006
    OST_AreaReinSpanSymbol = -2009005
    OST_AreaReinSketchOverride = -2009004
    OST_AreaRein = -2009003
    OST_RebarLines = -2009002
    OST_RebarSketchLines = -2009001
    OST_Rebar = -2009000
    OST_FabricationPipeworkInsulation = -2008221
    OST_FabricationDuctworkLining = -2008220
    OST_FabricationContainmentDrop = -2008219
    OST_FabricationContainmentRise = -2008218
    OST_FabricationPipeworkDrop = -2008217
    OST_FabricationPipeworkRise = -2008216
    OST_FabricationContainmentSymbology = -2008215
    OST_FabricationContainmentCenterLine = -2008214
    OST_FabricationContainmentTags = -2008213
    OST_FabricationContainment = -2008212
    OST_FabricationPipeworkSymbology = -2008211
    OST_FabricationPipeworkCenterLine = -2008210
    OST_FabricationPipeworkTags = -2008209
    OST_FabricationPipework = -2008208
    OST_FabricationDuctworkSymbology = -2008207
    OST_FabricationDuctworkDrop = -2008206
    OST_FabricationDuctworkRise = -2008205
    OST_FabricationHangerTags = -2008204
    OST_FabricationHangers = -2008203
    OST_OBSOLETE_FabricationPartsTmpGraphicDropDrag = -2008202
    OST_FabricationPartsTmpGraphicDrag = -2008201
    OST_OBSOLETE_FabricationPartsTmpGraphicDrop = -2008200
    OST_FabricationPartsTmpGraphicEnd = -2008199
    OST_FabricationDuctworkInsulation = -2008198
    OST_LayoutNodes = -2008197
    OST_FabricationDuctworkCenterLine = -2008196
    OST_FabricationServiceElements = -2008195
    OST_FabricationDuctworkTags = -2008194
    OST_FabricationDuctwork = -2008193
    OST_LayoutPathBase_Pipings = -2008192
    OST_NumberingSchemas = -2008191
    OST_DivisionRules = -2008190
    OST_gbXML_Shade = -2008187
    OST_AnalyticSurfaces = -2008186
    OST_AnalyticSpaces = -2008185
    OST_gbXML_OpeningAir = -2008184
    OST_gbXML_NonSlidingDoor = -2008183
    OST_gbXML_SlidingDoor = -2008182
    OST_gbXML_OperableSkylight = -2008181
    OST_gbXML_FixedSkylight = -2008180
    OST_gbXML_OperableWindow = -2008179
    OST_gbXML_FixedWindow = -2008178
    OST_gbXML_UndergroundCeiling = -2008177
    OST_gbXML_UndergroundSlab = -2008176
    OST_gbXML_UndergroundWall = -2008175
    OST_gbXML_SurfaceAir = -2008174
    OST_gbXML_Ceiling = -2008173
    OST_gbXML_InteriorFloor = -2008172
    OST_gbXML_InteriorWall = -2008171
    OST_gbXML_SlabOnGrade = -2008170
    OST_gbXML_RaisedFloor = -2008169
    OST_gbXML_Roof = -2008168
    OST_gbXML_ExteriorWall = -2008167
    OST_DivisionProfile = -2008165
    OST_SplitterProfile = -2008164
    OST_PipeSegments = -2008163
    OST_GraphicalWarning_OpenConnector = -2008162
    OST_PlaceHolderPipes = -2008161
    OST_PlaceHolderDucts = -2008160
    OST_PipingSystem_Reference_Visibility = -2008159
    OST_PipingSystem_Reference = -2008158
    OST_DuctSystem_Reference_Visibility = -2008157
    OST_DuctSystem_Reference = -2008156
    OST_PipeInsulationsTags = -2008155
    OST_DuctLiningsTags = -2008154
    OST_DuctInsulationsTags = -2008153
    OST_ElectricalInternalCircuits = -2008152
    OST_PanelScheduleGraphics = -2008151
    OST_CableTrayRun = -2008150
    OST_ConduitRun = -2008149
    OST_ParamElemElectricalLoadClassification = -2008148
    OST_DataPanelScheduleTemplates = -2008147
    OST_SwitchboardScheduleTemplates = -2008146
    OST_BranchPanelScheduleTemplates = -2008145
    OST_ConduitStandards = -2008144
    OST_ElectricalLoadClassifications = -2008143
    OST_ElectricalDemandFactorDefinitions = -2008142
    OST_ConduitFittingCenterLine = -2008141
    OST_CableTrayFittingCenterLine = -2008140
    OST_ConduitCenterLine = -2008139
    OST_ConduitDrop = -2008138
    OST_ConduitRiseDrop = -2008137
    OST_CableTrayCenterLine = -2008136
    OST_CableTrayDrop = -2008135
    OST_CableTrayRiseDrop = -2008134
    OST_ConduitTags = -2008133
    OST_Conduit = -2008132
    OST_CableTrayTags = -2008131
    OST_CableTray = -2008130
    OST_ConduitFittingTags = -2008129
    OST_ConduitFitting = -2008128
    OST_CableTrayFittingTags = -2008127
    OST_CableTrayFitting = -2008126
    OST_RoutingPreferences = -2008125
    OST_DuctLinings = -2008124
    OST_DuctInsulations = -2008123
    OST_PipeInsulations = -2008122
    OST_HVAC_Load_Schedules = -2008121
    OST_HVAC_Load_Building_Types = -2008120
    OST_HVAC_Load_Space_Types = -2008119
    OST_HVAC_Zones_Reference_Visibility = -2008118
    OST_HVAC_Zones_InteriorFill_Visibility = -2008117
    OST_HVAC_Zones_ColorFill = -2008116
    OST_ZoneTags = -2008115
    OST_LayoutPath_Bases = -2008114
    OST_WireTemperatureRatings = -2008113
    OST_WireInsulations = -2008112
    OST_WireMaterials = -2008111
    OST_HVAC_Zones_Reference = -2008110
    OST_HVAC_Zones_InteriorFill = -2008109
    OST_HVAC_Zones_Boundary = -2008108
    OST_HVAC_Zones = -2008107
    OST_Fluids = -2008106
    OST_PipeSchedules = -2008105
    OST_PipeMaterials = -2008104
    OST_PipeConnections = -2008103
    OST_EAConstructions = -2008102
    OST_SwitchSystem = -2008101
    OST_SprinklerTags = -2008100
    OST_Sprinklers = -2008099
    OST_RouteCurveBranch = -2008098
    OST_RouteCurveMain = -2008097
    OST_RouteCurve = -2008096
    OST_GbXML_Opening = -2008095
    OST_GbXML_SType_Underground = -2008094
    OST_GbXML_SType_Shade = -2008093
    OST_GbXML_SType_Exterior = -2008092
    OST_GbXML_SType_Interior = -2008091
    OST_GbXMLFaces = -2008090
    OST_WireHomeRunArrows = -2008089
    OST_LightingDeviceTags = -2008088
    OST_LightingDevices = -2008087
    OST_FireAlarmDeviceTags = -2008086
    OST_FireAlarmDevices = -2008085
    OST_DataDeviceTags = -2008084
    OST_DataDevices = -2008083
    OST_CommunicationDeviceTags = -2008082
    OST_CommunicationDevices = -2008081
    OST_SecurityDeviceTags = -2008080
    OST_SecurityDevices = -2008079
    OST_NurseCallDeviceTags = -2008078
    OST_NurseCallDevices = -2008077
    OST_TelephoneDeviceTags = -2008076
    OST_TelephoneDevices = -2008075
    OST_WireTickMarks = -2008074
    OST_PipeFittingInsulation = -2008073
    OST_PipeFittingCenterLine = -2008072
    OST_FlexPipeCurvesInsulation = -2008071
    OST_PipeCurvesInsulation = -2008070
    OST_PipeCurvesDrop = -2008069
    OST_DuctFittingLining = -2008068
    OST_DuctFittingInsulation = -2008067
    OST_DuctFittingCenterLine = -2008066
    OST_FlexDuctCurvesInsulation = -2008065
    OST_DuctCurvesLining = -2008064
    OST_DuctCurvesInsulation = -2008063
    OST_DuctCurvesDrop = -2008062
    OST_DuctFittingTags = -2008061
    OST_PipeFittingTags = -2008060
    OST_PipeColorFills = -2008059
    OST_PipeColorFillLegends = -2008058
    OST_WireTags = -2008057
    OST_PipeAccessoryTags = -2008056
    OST_PipeAccessory = -2008055
    OST_PipeCurvesRiseDrop = -2008054
    OST_FlexPipeCurvesPattern = -2008053
    OST_FlexPipeCurvesContour = -2008052
    OST_FlexPipeCurvesCenterLine = -2008051
    OST_FlexPipeCurves = -2008050
    OST_PipeFitting = -2008049
    OST_FlexPipeTags = -2008048
    OST_PipeTags = -2008047
    OST_PipeCurvesContour = -2008046
    OST_PipeCurvesCenterLine = -2008045
    OST_PipeCurves = -2008044
    OST_PipingSystem = -2008043
    OST_ElectricalDemandFactor = -2008042
    OST_ElecDistributionSys = -2008041
    OST_ElectricalVoltage = -2008040
    OST_Wire = -2008039
    OST_ElectricalCircuitTags = -2008038
    OST_ElectricalCircuit = -2008037
    OST_DuctCurvesRiseDrop = -2008036
    OST_FlexDuctCurvesPattern = -2008023
    OST_FlexDuctCurvesContour = -2008022
    OST_FlexDuctCurvesCenterLine = -2008021
    OST_FlexDuctCurves = -2008020
    OST_DuctAccessoryTags = -2008017
    OST_DuctAccessory = -2008016
    OST_DuctSystem = -2008015
    OST_DuctTerminalTags = -2008014
    OST_DuctTerminal = -2008013
    OST_DuctFitting = -2008010
    OST_DuctColorFills = -2008005
    OST_FlexDuctTags = -2008004
    OST_DuctTags = -2008003
    OST_DuctCurvesContour = -2008002
    OST_DuctCurvesCenterLine = -2008001
    OST_DuctCurves = -2008000
    OST_DuctColorFillLegends = -2007004
    OST_ConnectorElemZAxis = -2007003
    OST_ConnectorElemYAxis = -2007002
    OST_ConnectorElemXAxis = -2007001
    OST_ConnectorElem = -2007000
    OST_StructuralTendonTags = -2006276
    OST_StructuralTendonHiddenLines = -2006275
    OST_StructuralTendons = -2006274
    OST_ExpansionJointTags = -2006273
    OST_ExpansionJointHiddenLines = -2006272
    OST_ExpansionJoints = -2006271
    OST_VibrationIsolatorTags = -2006266
    OST_VibrationIsolators = -2006265
    OST_VibrationDamperTags = -2006264
    OST_VibrationDampers = -2006263
    OST_VibrationManagementHiddenLines = -2006262
    OST_VibrationManagement = -2006261
    OST_BridgeFramingTrusses = -2006248
    OST_BridgeFramingDiaphragms = -2006246
    OST_BridgeFramingCrossBracing = -2006245
    OST_BridgeFramingTags = -2006243
    OST_BridgeFramingHiddenLines = -2006242
    OST_BridgeFraming = -2006241
    OST_PierWallTags = -2006230
    OST_PierWalls = -2006229
    OST_PierPileTags = -2006226
    OST_PierPiles = -2006225
    OST_PierColumnTags = -2006222
    OST_PierColumns = -2006221
    OST_PierCapTags = -2006220
    OST_PierCaps = -2006219
    OST_ApproachSlabTags = -2006211
    OST_AbutmentWallTags = -2006210
    OST_AbutmentPileTags = -2006209
    OST_AbutmentFoundationTags = -2006208
    OST_ApproachSlabs = -2006205
    OST_AbutmentWalls = -2006204
    OST_AbutmentPiles = -2006203
    OST_AbutmentFoundations = -2006202
    OST_BridgeBearingTags = -2006178
    OST_BridgeGirderTags2021_Deprecated = -2006177
    OST_BridgeFoundationTags = -2006176
    OST_BridgeDeckTags = -2006175
    OST_BridgeArchTags2021_Deprecated = -2006174
    OST_BridgeCableTags = -2006173
    OST_BridgeTowerTags = -2006172
    OST_BridgePierTags = -2006171
    OST_BridgeAbutmentTags = -2006170
    OST_BridgeBearingHiddenLines = -2006158
    OST_BridgeGirderHiddenLines2021_Deprecated = -2006157
    OST_BridgeFoundationHiddenLines2021_Deprecated = -2006156
    OST_BridgeDeckHiddenLines = -2006155
    OST_BridgeArchHiddenLines2021_Deprecated = -2006154
    OST_BridgeCableHiddenLines2021_Deprecated = -2006153
    OST_BridgeTowerHiddenLines2021_Deprecated = -2006152
    OST_BridgePierHiddenLines = -2006151
    OST_BridgeAbutmentHiddenLines = -2006150
    OST_BridgeBearings = -2006138
    OST_BridgeGirders = -2006137
    OST_BridgeFoundations = -2006136
    OST_BridgeDecks = -2006135
    OST_BridgeArches = -2006134
    OST_BridgeCables = -2006133
    OST_BridgeTowers = -2006132
    OST_BridgePiers = -2006131
    OST_BridgeAbutments = -2006130
    OST_DesignOptions = -2006114
    OST_DesignOptionSets = -2006112
    OST_StructuralBracePlanReps = -2006110
    OST_StructConnectionSymbols = -2006100
    OST_StructuralAnnotations = -2006090
    OST_RevisionCloudTags = -2006080
    OST_Revisions = -2006070
    OST_RevisionClouds = -2006060
    OST_EditCutProfile = -2006050
    OST_ElevationMarks = -2006045
    OST_GridHeads = -2006040
    OST_LevelHeads = -2006020
    OST_DecalType = -2006002
    OST_DecalElement = -2006001
    OST_VolumeOfInterest = -2006000
    OST_BoundaryConditions = -2005301
    OST_InternalAreaLoadTags = -2005255
    OST_InternalLineLoadTags = -2005254
    OST_InternalPointLoadTags = -2005253
    OST_AreaLoadTags = -2005252
    OST_LineLoadTags = -2005251
    OST_PointLoadTags = -2005250
    OST_LoadCasesSeismic = -2005218
    OST_LoadCasesTemperature = -2005217
    OST_LoadCasesAccidental = -2005216
    OST_LoadCasesRoofLive = -2005215
    OST_LoadCasesSnow = -2005214
    OST_LoadCasesWind = -2005213
    OST_LoadCasesLive = -2005212
    OST_LoadCasesDead = -2005211
    OST_LoadCases = -2005210
    OST_InternalAreaLoads = -2005207
    OST_InternalLineLoads = -2005206
    OST_InternalPointLoads = -2005205
    OST_InternalLoads = -2005204
    OST_AreaLoads = -2005203
    OST_LineLoads = -2005202
    OST_PointLoads = -2005201
    OST_Loads = -2005200
    OST_BeamSystemTags = -2005130
    OST_FootingSpanDirectionSymbol = -2005111
    OST_SpanDirectionSymbol = -2005110
    OST_SpotSlopesSymbols = -2005102
    OST_SpotCoordinateSymbols = -2005101
    OST_SpotElevSymbols = -2005100
    OST_StructuralConnectionHandlerTags_Deprecated = -2005031
    OST_TrussTags = -2005030
    OST_KeynoteTags = -2005029
    OST_DetailComponentTags = -2005028
    OST_MaterialTags = -2005027
    OST_FloorTags = -2005026
    OST_CurtaSystemTags = -2005025
    OST_HostFinTags = -2005024
    OST_StairsTags = -2005023
    OST_MultiCategoryTags = -2005022
    OST_PlantingTags = -2005021
    OST_AreaTags = -2005020
    OST_StructuralFoundationTags = -2005019
    OST_StructuralColumnTags = -2005018
    OST_ParkingTags = -2005017
    OST_SiteTags = -2005016
    OST_StructuralFramingTags = -2005015
    OST_SpecialityEquipmentTags = -2005014
    OST_GenericModelTags = -2005013
    OST_CurtainWallPanelTags = -2005012
    OST_WallTags = -2005011
    OST_PlumbingFixtureTags = -2005010
    OST_MechanicalEquipmentTags = -2005009
    OST_LightingFixtureTags = -2005008
    OST_FurnitureSystemTags = -2005007
    OST_FurnitureTags = -2005006
    OST_ElectricalFixtureTags = -2005004
    OST_ElectricalEquipmentTags = -2005003
    OST_CeilingTags = -2005002
    OST_CaseworkTags = -2005001
    OST_Tags = -2005000
    OST_MEPSpaceColorFill = -2003605
    OST_MEPSpaceReference = -2003604
    OST_MEPSpaceInteriorFill = -2003603
    OST_MEPSpaceReferenceVisibility = -2003602
    OST_MEPSpaceInteriorFillVisibility = -2003601
    OST_MEPSpaces = -2003600
    OST_StackedWalls = -2003500
    OST_MassGlazingAll = -2003423
    OST_MassFloorsAll = -2003422
    OST_MassWallsAll = -2003421
    OST_MassExteriorWallUnderground = -2003420
    OST_MassSlab = -2003419
    OST_MassShade = -2003418
    OST_MassOpening = -2003417
    OST_MassSkylights = -2003416
    OST_MassGlazing = -2003415
    OST_MassRoof = -2003414
    OST_MassExteriorWall = -2003413
    OST_MassInteriorWall = -2003412
    OST_MassZone = -2003411
    OST_MassAreaFaceTags = -2003410
    OST_HostTemplate = -2003409
    OST_MassFaceSplitter = -2003408
    OST_MassCutter = -2003407
    OST_ZoningEnvelope = -2003406
    OST_MassTags = -2003405
    OST_MassForm = -2003404
    OST_MassFloor = -2003403
    OST_Mass = -2003400
    OST_DividedSurface_DiscardedDivisionLines = -2003333
    OST_DividedSurfaceBelt = -2003332
    OST_TilePatterns = -2003331
    OST_AlwaysExcludedInAllViews = -2003330
    OST_DividedSurface_TransparentFace = -2003329
    OST_DividedSurface_PreDividedSurface = -2003328
    OST_DividedSurface_PatternFill = -2003327
    OST_DividedSurface_PatternLines = -2003326
    OST_DividedSurface_Gridlines = -2003325
    OST_DividedSurface_Nodes = -2003324
    OST_DividedSurface = -2003323
    OST_RepeatingDetailLines = -2003321
    OST_RampsDownArrow = -2003308
    OST_RampsUpArrow = -2003307
    OST_RampsDownText = -2003306
    OST_RampsUpText = -2003305
    OST_RampsStringerAboveCut = -2003304
    OST_RampsStringer = -2003303
    OST_RampsAboveCut = -2003302
    OST_RampsIncomplete = -2003301
    OST_TrussDummy = -2003300
    OST_ZoneSchemes = -2003225
    OST_AreaSchemes = -2003201
    OST_Areas = -2003200
    OST_ProjectInformation = -2003101
    OST_Sheets = -2003100
    OST_ProfileFamilies = -2003000
    OST_DetailComponents = -2002000
    OST_RoofSoffit = -2001393
    OST_EdgeSlab = -2001392
    OST_Gutter = -2001391
    OST_Fascia = -2001390
    OST_Entourage = -2001370
    OST_Planting = -2001360
    OST_Blocks = -2001359
    OST_StructuralStiffenerHiddenLines = -2001358
    OST_StructuralColumnLocationLine = -2001357
    OST_StructuralFramingLocationLine = -2001356
    OST_StructuralStiffenerTags = -2001355
    OST_StructuralStiffener = -2001354
    OST_FootingAnalyticalGeometry = -2001353
    OST_RvtLinks = -2001352
    OST_Automatic = -2001351
    OST_SpecialityEquipment = -2001350
    OST_ColumnAnalyticalRigidLinks = -2001344
    OST_SecondaryTopographyContours = -2001343
    OST_TopographyContours = -2001342
    OST_TopographySurface = -2001341
    OST_Topography = -2001340
    OST_TopographyLink = -2001339
    OST_StructuralTruss = -2001336
    OST_StructuralColumnStickSymbols = -2001335
    OST_HiddenStructuralColumnLines = -2001334
    OST_AnalyticalRigidLinks = -2001333
    OST_ColumnAnalyticalGeometry = -2001332
    OST_FramingAnalyticalGeometry = -2001331
    OST_StructuralColumns = -2001330
    OST_HiddenStructuralFramingLines = -2001329
    OST_KickerBracing = -2001328
    OST_StructuralFramingSystem = -2001327
    OST_VerticalBracing = -2001326
    OST_HorizontalBracing = -2001325
    OST_Purlin = -2001324
    OST_Joist = -2001323
    OST_Girder = -2001322
    OST_StructuralFramingOther = -2001321
    OST_StructuralFraming = -2001320
    OST_HiddenStructuralFoundationLines = -2001302
    OST_StructuralFoundation = -2001300
    OST_LinkBasePoint = -2001276
    OST_BasePointAxisZ = -2001275
    OST_BasePointAxisY = -2001274
    OST_BasePointAxisX = -2001273
    OST_SharedBasePoint = -2001272
    OST_ProjectBasePoint = -2001271
    OST_SiteRegion = -2001270
    OST_SitePropertyLineSegmentTags = -2001269
    OST_SitePropertyLineSegment = -2001268
    OST_SitePropertyTags = -2001267
    OST_SitePointBoundary = -2001266
    OST_SiteProperty = -2001265
    OST_BuildingPad = -2001263
    OST_SitePoint = -2001262
    OST_SiteSurface = -2001261
    OST_Site = -2001260
    OST_Sewer = -2001240
    OST_Roads = -2001220
    OST_Property = -2001200
    OST_Parking = -2001180
    OST_PlumbingFixtures = -2001160
    OST_MechanicalEquipment = -2001140
    OST_LightingFixtureSource = -2001121
    OST_LightingFixtures = -2001120
    OST_FurnitureSystems = -2001100
    OST_ElectricalFixtures = -2001060
    OST_ElectricalEquipment = -2001040
    OST_AlignmentStationLabels = -2001017
    OST_AlignmentStationLabelSets = -2001016
    OST_AlignmentsTags = -2001015
    OST_MinorStations_Deprecated = -2001014
    OST_MajorStations_Deprecated = -2001013
    OST_Alignments = -2001012
    OST_ElectricalCircuitNaming = -2001011
    OST_ZoneEquipment = -2001010
    OST_MEPAnalyticalWaterLoop = -2001009
    OST_MEPAnalyticalAirLoop = -2001008
    OST_MEPSystemZoneTags = -2001007
    OST_MEPSystemZoneReferenceLinesVisibility = -2001006
    OST_MEPSystemZoneInteriorFillVisibility = -2001005
    OST_MEPSystemZoneReferenceLines = -2001004
    OST_MEPSystemZoneInteriorFill = -2001003
    OST_MEPSystemZoneBoundary = -2001002
    OST_MEPSystemZone = -2001001
    OST_Casework = -2001000
    OST_ArcWallRectOpening = -2000999
    OST_DormerOpeningIncomplete = -2000998
    OST_SWallRectOpening = -2000997
    OST_ShaftOpening = -2000996
    OST_StructuralFramingOpening = -2000995
    OST_ColumnOpening = -2000994
    OST_RiseDropSymbols = -2000989
    OST_PipeHydronicSeparationSymbols = -2000988
    OST_MechanicalEquipmentSetBoundaryLines = -2000987
    OST_MechanicalEquipmentSetTags = -2000986
    OST_MechanicalEquipmentSet = -2000985
    OST_AnalyticalPipeConnectionLineSymbol = -2000984
    OST_AnalyticalPipeConnections = -2000983
    OST_Coordination_Model = -2000982
    OST_MultistoryStairs = -2000980
    OST_HiddenStructuralConnectionLines_Deprecated = -2000979
    OST_StructuralConnectionHandler_Deprecated = -2000978
    OST_CoordinateSystem = -2000977
    OST_FndSlabLocalCoordSys = -2000976
    OST_FloorLocalCoordSys = -2000975
    OST_WallLocalCoordSys = -2000974
    OST_BraceLocalCoordSys = -2000973
    OST_ColumnLocalCoordSys = -2000972
    OST_BeamLocalCoordSys = -2000971
    OST_MultiReferenceAnnotations = -2000970
    OST_DSR_LeaderTickMarkStyleId = -2000969
    OST_DSR_InteriorTickMarkStyleId = -2000968
    OST_DSR_ArrowHeadStyleId = -2000967
    OST_DSR_CenterlineTickMarkStyleId = -2000966
    OST_DSR_CenterlinePatternCatId = -2000965
    OST_DSR_DimStyleHeavyEndCategoryId = -2000964
    OST_DSR_DimStyleHeavyEndCatId = -2000963
    OST_DSR_DimStyleTickCategoryId = -2000962
    OST_DSR_LineAndTextAttrFontId = -2000961
    OST_DSR_LineAndTextAttrCategoryId = -2000960
    OST_NodeAnalyticalTags = -2000956
    OST_LinkAnalyticalTags = -2000955
    OST_RailingRailPathExtensionLines = -2000954
    OST_RailingRailPathLines = -2000953
    OST_StairsSupports = -2000952
    OST_RailingHandRailAboveCut = -2000951
    OST_RailingTopRailAboveCut = -2000950
    OST_RailingTermination = -2000949
    OST_RailingSupport = -2000948
    OST_RailingHandRail = -2000947
    OST_RailingTopRail = -2000946
    OST_StairsSketchPathLines = -2000945
    OST_StairsTriserNumbers = -2000944
    OST_StairsTriserTags = -2000943
    OST_StairsSupportTags = -2000942
    OST_StairsLandingTags = -2000941
    OST_StairsRunTags = -2000940
    OST_StairsPathsAboveCut = -2000939
    OST_StairsPaths = -2000938
    OST_StairsRiserLinesAboveCut = -2000937
    OST_StairsRiserLines = -2000936
    OST_StairsOutlinesAboveCut = -2000935
    OST_StairsOutlines = -2000934
    OST_StairsNosingLinesAboveCut = -2000933
    OST_StairsNosingLines = -2000932
    OST_StairsCutMarksAboveCut = -2000931
    OST_StairsCutMarks = -2000930
    OST_ComponentRepeaterSlot = -2000928
    OST_ComponentRepeater = -2000927
    OST_DividedPath = -2000926
    OST_IOSRoomCalculationPoint = -2000925
    OST_PropertySet = -2000924
    OST_AppearanceAsset = -2000923
    OST_StairStringer2012_Deprecated = -2000922
    OST_StairsTrisers = -2000921
    OST_StairsLandings = -2000920
    OST_StairsRuns = -2000919
    OST_Stair2012_Deprecated = -2000918
    OST_RailingSystemTags = -2000917
    OST_RailingSystemTransition = -2000916
    OST_RailingSystemTermination = -2000915
    OST_RailingSystemRail = -2000914
    OST_RailingSystemTopRail = -2000913
    OST_RailingSystemHandRailBracket = -2000912
    OST_RailingSystemHandRail = -2000911
    OST_RailingSystemHardware = -2000910
    OST_RailingSystemPanel = -2000909
    OST_RailingSystemBaluster = -2000908
    OST_RailingSystemPost = -2000907
    OST_RailingSystemSegment = -2000906
    OST_RailingSystem = -2000905
    OST_AdaptivePoints_HiddenLines = -2000904
    OST_AdaptivePoints_Lines = -2000903
    OST_AdaptivePoints_Planes = -2000902
    OST_AdaptivePoints_Points = -2000901
    OST_AdaptivePoints = -2000900
    OST_CeilingOpening = -2000899
    OST_FloorOpening = -2000898
    OST_RoofOpening = -2000897
    OST_WallRefPlanes = -2000896
    OST_StructLocationLineControl = -2000880
    OST_PathOfTravelTags = -2000834
    OST_PathOfTravelLines = -2000833
    OST_DimLockControlLeader = -2000832
    OST_MEPSpaceSeparationLines = -2000831
    OST_AreaPolylines = -2000830
    OST_RoomPolylines = -2000829
    OST_InstanceDrivenLineStyle = -2000828
    OST_RemovedGridSeg = -2000827
    OST_IOSOpening = -2000810
    OST_IOSTilePatternGrid = -2000800
    OST_ControlLocal = -2000774
    OST_ControlAxisZ = -2000773
    OST_ControlAxisY = -2000772
    OST_ControlAxisX = -2000721
    OST_XRayConstrainedProfileEdge = -2000720
    OST_XRayImplicitPathCurve = -2000719
    OST_XRayPathPoint = -2000718
    OST_XRayPathCurve = -2000717
    OST_XRaySideEdge = -2000716
    OST_XRayProfileEdge = -2000715
    OST_ReferencePoints_HiddenLines = -2000714
    OST_ReferencePoints_Lines = -2000713
    OST_ReferencePoints_Planes = -2000712
    OST_ReferencePoints_Points = -2000711
    OST_ReferencePoints = -2000710
    OST_Materials = -2000700
    OST_CeilingsCutPattern = -2000617
    OST_CeilingsDefault = -2000616
    OST_CeilingsFinish2 = -2000615
    OST_CeilingsFinish1 = -2000614
    OST_CeilingsSubstrate = -2000613
    OST_CeilingsInsulation = -2000612
    OST_CeilingsStructure = -2000611
    OST_CeilingsMembrane = -2000610
    OST_FloorsInteriorEdges = -2000609
    OST_FloorsCutPattern = -2000608
    OST_HiddenFloorLines = -2000607
    OST_FloorsDefault = -2000606
    OST_FloorsFinish2 = -2000605
    OST_FloorsFinish1 = -2000604
    OST_FloorsSubstrate = -2000603
    OST_FloorsInsulation = -2000602
    OST_FloorsStructure = -2000601
    OST_FloorsMembrane = -2000600
    OST_RoofsInteriorEdges = -2000598
    OST_RoofsCutPattern = -2000597
    OST_RoofsDefault = -2000596
    OST_RoofsFinish2 = -2000595
    OST_RoofsFinish1 = -2000594
    OST_RoofsSubstrate = -2000593
    OST_RoofsInsulation = -2000592
    OST_RoofsStructure = -2000591
    OST_RoofsMembrane = -2000590
    OST_WallsCutPattern = -2000588
    OST_HiddenWallLines = -2000587
    OST_WallsDefault = -2000586
    OST_WallsFinish2 = -2000585
    OST_WallsFinish1 = -2000584
    OST_WallsSubstrate = -2000583
    OST_WallsInsulation = -2000582
    OST_WallsStructure = -2000581
    OST_WallsMembrane = -2000580
    OST_PreviewLegendComponents = -2000576
    OST_LegendComponents = -2000575
    OST_Schedules = -2000573
    OST_ScheduleGraphics = -2000570
    OST_RasterImages = -2000560
    OST_ColorFillSchema = -2000552
    OST_RoomColorFill = -2000551
    OST_ColorFillLegends = -2000550
    OST_AnnotationCropSpecial = -2000549
    OST_CropBoundarySpecial = -2000548
    OST_AnnotationCrop = -2000547
    OST_FloorsAnalyticalGeometry = -2000546
    OST_WallsAnalyticalGeometry = -2000545
    OST_CalloutLeaderLine = -2000544
    OST_CeilingsSurfacePattern = -2000543
    OST_RoofsSurfacePattern = -2000542
    OST_FloorsSurfacePattern = -2000541
    OST_WallsSurfacePattern = -2000540
    OST_CalloutBoundary = -2000539
    OST_CalloutHeads = -2000538
    OST_Callouts = -2000537
    OST_CropBoundary = -2000536
    OST_Elev = -2000535
    OST_AxisZ = -2000533
    OST_AxisY = -2000532
    OST_AxisX = -2000531
    OST_CLines = -2000530
    OST_Lights = -2000520
    OST_ViewportLabel = -2000515
    OST_Viewports = -2000510
    OST_Camera_Lines = -2000501
    OST_Cameras = -2000500
    OST_MEPSpaceTags = -2000485
    OST_RoomTags = -2000480
    OST_DoorTags = -2000460
    OST_WindowTags = -2000450
    OST_SectionHeadWideLines = -2000404
    OST_SectionHeadMediumLines = -2000403
    OST_SectionHeadThinLines = -2000401
    OST_SectionHeads = -2000400
    OST_ContourLabels = -2000350
    OST_CurtaSystemFaceManager = -2000341
    OST_CurtaSystem = -2000340
    OST_AreaReport_Arc_Minus = -2000328
    OST_AreaReport_Arc_Plus = -2000327
    OST_AreaReport_Boundary = -2000326
    OST_AreaReport_Triangle = -2000325
    OST_CurtainGridsCurtaSystem = -2000323
    OST_CurtainGridsSystem = -2000322
    OST_CurtainGridsWall = -2000321
    OST_CurtainGridsRoof = -2000320
    OST_HostFinHF = -2000315
    OST_HostFinWall = -2000314
    OST_HostFinCeiling = -2000313
    OST_HostFinRoof = -2000312
    OST_HostFinFloor = -2000311
    OST_HostFin = -2000310
    OST_AnalysisDisplayStyle = -2000304
    OST_AnalysisResults = -2000303
    OST_RenderRegions = -2000302
    OST_SectionBox = -2000301
    OST_TextNotes = -2000300
    OST_Divisions = -2000291
    OST_Catalogs = -2000290
    OST_DirectionEdgeLines = -2000289
    OST_CenterLines = -2000288
    OST_LinesBeyond = -2000287
    OST_HiddenLines = -2000286
    OST_DemolishedLines = -2000285
    OST_OverheadLines = -2000284
    OST_TitleBlockWideLines = -2000283
    OST_TitleBlockMediumLines = -2000282
    OST_TitleBlockThinLines = -2000281
    OST_TitleBlocks = -2000280
    OST_Views = -2000279
    OST_Viewers = -2000278
    OST_PartHiddenLines = -2000271
    OST_PartTags = -2000270
    OST_Parts = -2000269
    OST_AssemblyTags = -2000268
    OST_Assemblies = -2000267
    OST_RoofTags = -2000266
    OST_SpotSlopes = -2000265
    OST_SpotCoordinates = -2000264
    OST_SpotElevations = -2000263
    OST_Constraints = -2000262
    OST_WeakDims = -2000261
    OST_Dimensions = -2000260
    OST_Levels = -2000240
    OST_DisplacementPath = -2000223
    OST_DisplacementElements = -2000222
    OST_GridChains = -2000221
    OST_Grids = -2000220
    OST_BrokenSectionLine = -2000202
    OST_SectionLine = -2000201
    OST_Sections = -2000200
    OST_ReferenceViewer = -2000198
    OST_ReferenceViewerSymbol = -2000197
    OST_ImportObjectStyles = -2000196
    OST_ModelText = -2000195
    OST_MaskingRegion = -2000194
    OST_Matchline = -2000193
    OST_FaceSplitter = -2000192
    OST_PlanRegion = -2000191
    OST_FilledRegion = -2000190
    OST_MassingProjectionOutlines = -2000187
    OST_MassingCutOutlines = -2000186
    OST_Massing = -2000185
    OST_Reveals = -2000182
    OST_Cornices = -2000181
    OST_Ramps = -2000180
    OST_RailingBalusterRailCut = -2000177
    OST_RailingBalusterRail = -2000176
    OST_Railings = -2000175
    OST_CurtainGrids = -2000173
    OST_CurtainWallMullionsCut = -2000172
    OST_CurtainWallMullions = -2000171
    OST_CurtainWallPanels = -2000170
    OST_AreaReference = -2000169
    OST_AreaInteriorFill = -2000168
    OST_RoomReference = -2000167
    OST_RoomInteriorFill = -2000166
    OST_AreaColorFill = -2000165
    OST_AreaReferenceVisibility = -2000164
    OST_AreaInteriorFillVisibility = -2000163
    OST_RoomReferenceVisibility = -2000162
    OST_RoomInteriorFillVisibility = -2000161
    OST_Rooms = -2000160
    OST_GenericModel = -2000151
    OST_GenericAnnotation = -2000150
    OST_Fixtures = -2000140
    OST_StairsRailingTags = -2000133
    OST_StairsRailingAboveCut = -2000132
    OST_StairsDownArrows = -2000131
    OST_StairsUpArrows = -2000130
    OST_StairsDownText = -2000129
    OST_StairsRailingRail = -2000128
    OST_StairsRailingBaluster = -2000127
    OST_StairsRailing = -2000126
    OST_StairsUpText = -2000125
    OST_StairsSupportsAboveCut = -2000124
    OST_StairsStringerCarriage = -2000123
    OST_StairsAboveCut_ToBeDeprecated = -2000122
    OST_StairsIncomplete_Deprecated = -2000121
    OST_Stairs = -2000120
    OST_IOSNavWheelPivotBall = -2000117
    OST_IOSRoomComputationHeight = -2000116
    OST_IOSRoomUpperLowerLines = -2000115
    OST_IOSDragBoxInverted = -2000114
    OST_IOSDragBox = -2000113
    OST_Phases = -2000112
    OST_IOS_GeoSite = -2000111
    OST_IOS_GeoLocations = -2000110
    OST_IOSFabricReinSpanSymbolCtrl = -2000109
    OST_GuideGrid = -2000107
    OST_EPS_Future = -2000106
    OST_EPS_Temporary = -2000105
    OST_EPS_New = -2000104
    OST_EPS_Demolished = -2000103
    OST_EPS_Existing = -2000102
    OST_IOSMeasureLineScreenSize = -2000101
    OST_Columns = -2000100
    OST_IOSRebarSystemSpanSymbolCtrl = -2000099
    OST_IOSRoomTagToRoomLines = -2000098
    OST_IOSAttachedDetailGroups = -2000097
    OST_IOSDetailGroups = -2000096
    OST_IOSModelGroups = -2000095
    OST_IOSSuspendedSketch = -2000094
    OST_IOSWallCoreBoundary = -2000093
    OST_IOSMeasureLine = -2000092
    OST_IOSArrays = -2000091
    OST_Curtain_Systems = -2000090
    OST_IOSBBoxScreenSize = -2000089
    OST_IOSSlabShapeEditorPointInterior = -2000088
    OST_IOSSlabShapeEditorPointBoundary = -2000087
    OST_IOSSlabShapeEditorBoundary = -2000086
    OST_IOSSlabShapeEditorAutoCrease = -2000085
    OST_IOSSlabShapeEditorExplitCrease = -2000084
    OST_ReferenceLines = -2000083
    OST_IOSNotSilhouette = -2000082
    OST_FillPatterns = -2000081
    OST_Furniture = -2000080
    OST_AreaSchemeLines = -2000079
    OST_GenericLines = -2000078
    OST_InsulationLines = -2000077
    OST_CloudLines = -2000076
    OST_IOSRoomPerimeterLines = -2000075
    OST_IOSCuttingGeometry = -2000074
    OST_IOSCrashGraphics = -2000073
    OST_IOSGroups = -2000072
    OST_IOSGhost = -2000071
    OST_StairsSketchLandingCenterLines = -2000070
    OST_StairsSketchRunLines = -2000069
    OST_StairsSketchRiserLines = -2000068
    OST_StairsSketchBoundaryLines = -2000067
    OST_RoomSeparationLines = -2000066
    OST_AxisOfRotation = -2000065
    OST_InvisibleLines = -2000064
    OST_IOSThinPixel_DashDot = -2000063
    OST_IOSThinPixel_Dash = -2000062
    OST_IOSThinPixel_Dot = -2000061
    OST_Extrusions = -2000060
    OST_IOS = -2000059
    OST_CutOutlines = -2000058
    OST_IOSThinPixel = -2000057
    OST_IOSFlipControl = -2000056
    OST_IOSSketchGrid = -2000055
    OST_IOSSuspendedSketch_obsolete = -2000054
    OST_IOSFreeSnapLine = -2000053
    OST_IOSDatumPlane = -2000052
    OST_Lines = -2000051
    OST_IOSConstructionLine = -2000050
    OST_IOSAlignmentGraphics = -2000049
    OST_IOSAligningLine = -2000048
    OST_IOSBackedUpElements = -2000047
    OST_IOSRegeneratedElements = -2000046
    OST_SketchLines = -2000045
    OST_CurvesWideLines = -2000044
    OST_CurvesMediumLines = -2000043
    OST_CurvesThinLines = -2000042
    OST_Curves = -2000041
    OST_CeilingsProjection = -2000040
    OST_CeilingsCut = -2000039
    OST_Ceilings = -2000038
    OST_RoofsProjection = -2000037
    OST_RoofsCut = -2000036
    OST_Roofs = -2000035
    OST_FloorsProjection = -2000034
    OST_FloorsCut = -2000033
    OST_Floors = -2000032
    OST_DoorsGlassProjection = -2000031
    OST_DoorsGlassCut = -2000030
    OST_DoorsFrameMullionProjection = -2000029
    OST_DoorsFrameMullionCut = -2000028
    OST_DoorsOpeningProjection = -2000027
    OST_DoorsOpeningCut = -2000026
    OST_DoorsPanelProjection = -2000025
    OST_DoorsPanelCut = -2000024
    OST_Doors = -2000023
    OST_WindowsOpeningProjection = -2000022
    OST_WindowsOpeningCut = -2000021
    OST_WindowsSillHeadProjection = -2000020
    OST_WindowsSillHeadCut = -2000019
    OST_WindowsFrameMullionProjection = -2000018
    OST_WindowsFrameMullionCut = -2000017
    OST_WindowsGlassProjection = -2000016
    OST_WindowsGlassCut = -2000015
    OST_Windows = -2000014
    OST_WallsProjectionOutlines = -2000013
    OST_WallsCutOutlines = -2000012
    OST_Walls = -2000011
    OST_IOSRegenerationFailure = -2000010
    OST_ScheduleViewParamGroup = -2000008
    OST_MatchSiteComponent = -2000007
    OST_MatchProfile = -2000006
    OST_MatchDetail = -2000005
    OST_MatchAnnotation = -2000004
    OST_MatchModel = -2000003
    OST_MatchAll = -2000002
    INVALID = -1


class PartsVisibility:
    ShowPartsOnly = 0
    ShowOriginalOnly = 1
    ShowPartsAndOriginal = 2
    Unset = -1


class ViewDetailLevel:
    Undefined = 0
    Coarse = 1
    Medium = 2
    Fine = 3


class ViewDiscipline:
    Architectural = 1
    Structural = 2
    Mechanical = 4
    Electrical = 8
    Plumbing = 16
    Coordination = 4095


class ViewDuplicateOption:
    Duplicate = 0
    AsDependent = 1
    WithDetailing = 2


class WorksetKind:
    OtherWorkset = 0
    FamilyWorkset = 1
    ViewWorkset = 2
    StandardWorkset = 3
    UserWorkset = 4


class WorksetVisibility:
    Visible = 0
    Hidden = 1
    UseGlobalSetting = 2


class WorksharingDisplayMode:
    Off = 0
    CheckoutStatus = 1
    Owners = 2
    ModelUpdates = 3
    Worksets = 4


class DisplayUnitType:
    DUT_METERS = 0
    DUT_CENTIMETERS = 1
    DUT_MILLIMETERS = 2
    DUT_DECIMAL_FEET = 3
    DUT_FEET_FRACTIONAL_INCHES = 4
    DUT_FRACTIONAL_INCHES = 5
    DUT_DECIMAL_INCHES = 6
    DUT_ACRES = 7
    DUT_HECTARES = 8
    DUT_METERS_CENTIMETERS = 9
    DUT_CUBIC_YARDS = 10
    DUT_SQUARE_FEET = 11
    DUT_SQUARE_METERS = 12
    DUT_CUBIC_FEET = 13
    DUT_CUBIC_METERS = 14
    DUT_DECIMAL_DEGREES = 15
    DUT_DEGREES_AND_MINUTES = 16
    DUT_GENERAL = 17
    DUT_FIXED = 18
    DUT_PERCENTAGE = 19
    DUT_SQUARE_INCHES = 20
    DUT_SQUARE_CENTIMETERS = 21
    DUT_SQUARE_MILLIMETERS = 22
    DUT_CUBIC_INCHES = 23
    DUT_CUBIC_CENTIMETERS = 24
    DUT_CUBIC_MILLIMETERS = 25
    DUT_LITERS = 26
    DUT_GALLONS_US = 27
    DUT_KILOGRAMS_PER_CUBIC_METER = 28
    DUT_POUNDS_MASS_PER_CUBIC_FOOT = 29
    DUT_POUNDS_MASS_PER_CUBIC_INCH = 30
    DUT_BRITISH_THERMAL_UNITS = 31
    DUT_CALORIES = 32
    DUT_KILOCALORIES = 33
    DUT_JOULES = 34
    DUT_KILOWATT_HOURS = 35
    DUT_THERMS = 36
    DUT_INCHES_OF_WATER_PER_100FT = 37
    DUT_PASCALS_PER_METER = 38
    DUT_WATTS = 39
    DUT_KILOWATTS = 40
    DUT_BRITISH_THERMAL_UNITS_PER_SECOND = 41
    DUT_BRITISH_THERMAL_UNITS_PER_HOUR = 42
    DUT_CALORIES_PER_SECOND = 43
    DUT_KILOCALORIES_PER_SECOND = 44
    DUT_WATTS_PER_SQUARE_FOOT = 45
    DUT_WATTS_PER_SQUARE_METER = 46
    DUT_INCHES_OF_WATER = 47
    DUT_PASCALS = 48
    DUT_KILOPASCALS = 49
    DUT_MEGAPASCALS = 50
    DUT_POUNDS_FORCE_PER_SQUARE_INCH = 51
    DUT_INCHES_OF_MERCURY = 52
    DUT_MILLIMETERS_OF_MERCURY = 53
    DUT_ATMOSPHERES = 54
    DUT_BARS = 55
    DUT_FAHRENHEIT = 56
    DUT_CELSIUS = 57
    DUT_KELVIN = 58
    DUT_RANKINE = 59
    DUT_FEET_PER_MINUTE = 60
    DUT_METERS_PER_SECOND = 61
    DUT_CENTIMETERS_PER_MINUTE = 62
    DUT_CUBIC_FEET_PER_MINUTE = 63
    DUT_LITERS_PER_SECOND = 64
    DUT_CUBIC_METERS_PER_SECOND = 65
    DUT_CUBIC_METERS_PER_HOUR = 66
    DUT_GALLONS_US_PER_MINUTE = 67
    DUT_GALLONS_US_PER_HOUR = 68
    DUT_AMPERES = 69
    DUT_KILOAMPERES = 70
    DUT_MILLIAMPERES = 71
    DUT_VOLTS = 72
    DUT_KILOVOLTS = 73
    DUT_MILLIVOLTS = 74
    DUT_HERTZ = 75
    DUT_CYCLES_PER_SECOND = 76
    DUT_LUX = 77
    DUT_FOOTCANDLES = 78
    DUT_FOOTLAMBERTS = 79
    DUT_CANDELAS_PER_SQUARE_METER = 80
    DUT_CANDELAS = 81
    DUT_CANDLEPOWER = 82
    DUT_LUMENS = 83
    DUT_VOLT_AMPERES = 84
    DUT_KILOVOLT_AMPERES = 85
    DUT_HORSEPOWER = 86
    DUT_NEWTONS = 87
    DUT_DECANEWTONS = 88
    DUT_KILONEWTONS = 89
    DUT_MEGANEWTONS = 90
    DUT_KIPS = 91
    DUT_KILOGRAMS_FORCE = 92
    DUT_TONNES_FORCE = 93
    DUT_POUNDS_FORCE = 94
    DUT_NEWTONS_PER_METER = 95
    DUT_DECANEWTONS_PER_METER = 96
    DUT_KILONEWTONS_PER_METER = 97
    DUT_MEGANEWTONS_PER_METER = 98
    DUT_KIPS_PER_FOOT = 99
    DUT_KILOGRAMS_FORCE_PER_METER = 100
    DUT_TONNES_FORCE_PER_METER = 101
    DUT_POUNDS_FORCE_PER_FOOT = 102
    DUT_NEWTONS_PER_SQUARE_METER = 103
    DUT_DECANEWTONS_PER_SQUARE_METER = 104
    DUT_KILONEWTONS_PER_SQUARE_METER = 105
    DUT_MEGANEWTONS_PER_SQUARE_METER = 106
    DUT_KIPS_PER_SQUARE_FOOT = 107
    DUT_KILOGRAMS_FORCE_PER_SQUARE_METER = 108
    DUT_TONNES_FORCE_PER_SQUARE_METER = 109
    DUT_POUNDS_FORCE_PER_SQUARE_FOOT = 110
    DUT_NEWTON_METERS = 111
    DUT_DECANEWTON_METERS = 112
    DUT_KILONEWTON_METERS = 113
    DUT_MEGANEWTON_METERS = 114
    DUT_KIP_FEET = 115
    DUT_KILOGRAM_FORCE_METERS = 116
    DUT_TONNE_FORCE_METERS = 117
    DUT_POUND_FORCE_FEET = 118
    DUT_METERS_PER_KILONEWTON = 119
    DUT_FEET_PER_KIP = 120
    DUT_SQUARE_METERS_PER_KILONEWTON = 121
    DUT_SQUARE_FEET_PER_KIP = 122
    DUT_CUBIC_METERS_PER_KILONEWTON = 123
    DUT_CUBIC_FEET_PER_KIP = 124
    DUT_INV_KILONEWTONS = 125
    DUT_INV_KIPS = 126
    DUT_FEET_OF_WATER_PER_100FT = 127
    DUT_FEET_OF_WATER = 128
    DUT_PASCAL_SECONDS = 129
    DUT_POUNDS_MASS_PER_FOOT_SECOND = 130
    DUT_CENTIPOISES = 131
    DUT_FEET_PER_SECOND = 132
    DUT_KIPS_PER_SQUARE_INCH = 133
    DUT_KILONEWTONS_PER_CUBIC_METER = 134
    DUT_POUNDS_FORCE_PER_CUBIC_FOOT = 135
    DUT_KIPS_PER_CUBIC_INCH = 136
    DUT_INV_FAHRENHEIT = 137
    DUT_INV_CELSIUS = 138
    DUT_NEWTON_METERS_PER_METER = 139
    DUT_DECANEWTON_METERS_PER_METER = 140
    DUT_KILONEWTON_METERS_PER_METER = 141
    DUT_MEGANEWTON_METERS_PER_METER = 142
    DUT_KIP_FEET_PER_FOOT = 143
    DUT_KILOGRAM_FORCE_METERS_PER_METER = 144
    DUT_TONNE_FORCE_METERS_PER_METER = 145
    DUT_POUND_FORCE_FEET_PER_FOOT = 146
    DUT_POUNDS_MASS_PER_FOOT_HOUR = 147
    DUT_KIPS_PER_INCH = 148
    DUT_KIPS_PER_CUBIC_FOOT = 149
    DUT_KIP_FEET_PER_DEGREE = 150
    DUT_KILONEWTON_METERS_PER_DEGREE = 151
    DUT_KIP_FEET_PER_DEGREE_PER_FOOT = 152
    DUT_KILONEWTON_METERS_PER_DEGREE_PER_METER = 153
    DUT_WATTS_PER_SQUARE_METER_KELVIN = 154
    DUT_BRITISH_THERMAL_UNITS_PER_HOUR_SQUARE_FOOT_FAHRENHEIT = 155
    DUT_CUBIC_FEET_PER_MINUTE_SQUARE_FOOT = 156
    DUT_LITERS_PER_SECOND_SQUARE_METER = 157
    DUT_RATIO_10 = 158
    DUT_RATIO_12 = 159
    DUT_SLOPE_DEGREES = 160
    DUT_RISE_OVER_INCHES = 161
    DUT_RISE_OVER_FOOT = 162
    DUT_RISE_OVER_MMS = 163
    DUT_WATTS_PER_CUBIC_FOOT = 164
    DUT_WATTS_PER_CUBIC_METER = 165
    DUT_BRITISH_THERMAL_UNITS_PER_HOUR_SQUARE_FOOT = 166
    DUT_BRITISH_THERMAL_UNITS_PER_HOUR_CUBIC_FOOT = 167
    DUT_TON_OF_REFRIGERATION = 168
    DUT_CUBIC_FEET_PER_MINUTE_CUBIC_FOOT = 169
    DUT_LITERS_PER_SECOND_CUBIC_METER = 170
    DUT_CUBIC_FEET_PER_MINUTE_TON_OF_REFRIGERATION = 171
    DUT_LITERS_PER_SECOND_KILOWATTS = 172
    DUT_SQUARE_FEET_PER_TON_OF_REFRIGERATION = 173
    DUT_SQUARE_METERS_PER_KILOWATTS = 174
    DUT_CURRENCY = 175
    DUT_LUMENS_PER_WATT = 176
    DUT_SQUARE_FEET_PER_THOUSAND_BRITISH_THERMAL_UNITS_PER_HOUR = 177
    DUT_KILONEWTONS_PER_SQUARE_CENTIMETER = 178
    DUT_NEWTONS_PER_SQUARE_MILLIMETER = 179
    DUT_KILONEWTONS_PER_SQUARE_MILLIMETER = 180
    DUT_RISE_OVER_120_INCHES = 181
    DUT_1_RATIO = 182
    DUT_RISE_OVER_10_FEET = 183
    DUT_HOUR_SQUARE_FOOT_FAHRENHEIT_PER_BRITISH_THERMAL_UNIT = 184
    DUT_SQUARE_METER_KELVIN_PER_WATT = 185
    DUT_BRITISH_THERMAL_UNIT_PER_FAHRENHEIT = 186
    DUT_JOULES_PER_KELVIN = 187
    DUT_KILOJOULES_PER_KELVIN = 188
    DUT_KILOGRAMS_MASS = 189
    DUT_TONNES_MASS = 190
    DUT_POUNDS_MASS = 191
    DUT_METERS_PER_SECOND_SQUARED = 192
    DUT_KILOMETERS_PER_SECOND_SQUARED = 193
    DUT_INCHES_PER_SECOND_SQUARED = 194
    DUT_FEET_PER_SECOND_SQUARED = 195
    DUT_MILES_PER_SECOND_SQUARED = 196
    DUT_FEET_TO_THE_FOURTH_POWER = 197
    DUT_INCHES_TO_THE_FOURTH_POWER = 198
    DUT_MILLIMETERS_TO_THE_FOURTH_POWER = 199
    DUT_CENTIMETERS_TO_THE_FOURTH_POWER = 200
    DUT_METERS_TO_THE_FOURTH_POWER = 201
    DUT_FEET_TO_THE_SIXTH_POWER = 202
    DUT_INCHES_TO_THE_SIXTH_POWER = 203
    DUT_MILLIMETERS_TO_THE_SIXTH_POWER = 204
    DUT_CENTIMETERS_TO_THE_SIXTH_POWER = 205
    DUT_METERS_TO_THE_SIXTH_POWER = 206
    DUT_SQUARE_FEET_PER_FOOT = 207
    DUT_SQUARE_INCHES_PER_FOOT = 208
    DUT_SQUARE_MILLIMETERS_PER_METER = 209
    DUT_SQUARE_CENTIMETERS_PER_METER = 210
    DUT_SQUARE_METERS_PER_METER = 211
    DUT_KILOGRAMS_MASS_PER_METER = 212
    DUT_POUNDS_MASS_PER_FOOT = 213
    DUT_RADIANS = 214
    DUT_GRADS = 215
    DUT_RADIANS_PER_SECOND = 216
    DUT_MILISECONDS = 217
    DUT_SECONDS = 218
    DUT_MINUTES = 219
    DUT_HOURS = 220
    DUT_KILOMETERS_PER_HOUR = 221
    DUT_MILES_PER_HOUR = 222
    DUT_KILOJOULES = 223
    DUT_KILOGRAMS_MASS_PER_SQUARE_METER = 224
    DUT_POUNDS_MASS_PER_SQUARE_FOOT = 225
    DUT_WATTS_PER_METER_KELVIN = 226
    DUT_JOULES_PER_GRAM_CELSIUS = 227
    DUT_JOULES_PER_GRAM = 228
    DUT_NANOGRAMS_PER_PASCAL_SECOND_SQUARE_METER = 229
    DUT_OHM_METERS = 230
    DUT_BRITISH_THERMAL_UNITS_PER_HOUR_FOOT_FAHRENHEIT = 231
    DUT_BRITISH_THERMAL_UNITS_PER_POUND_FAHRENHEIT = 232
    DUT_BRITISH_THERMAL_UNITS_PER_POUND = 233
    DUT_GRAINS_PER_HOUR_SQUARE_FOOT_INCH_MERCURY = 234
    DUT_PER_MILLE = 235
    DUT_DECIMETERS = 236
    DUT_JOULES_PER_KILOGRAM_CELSIUS = 237
    DUT_MICROMETERS_PER_METER_CELSIUS = 238
    DUT_MICROINCHES_PER_INCH_FAHRENHEIT = 239
    DUT_USTONNES_MASS = 240
    DUT_USTONNES_FORCE = 241
    DUT_LITERS_PER_MINUTE = 242
    DUT_FAHRENHEIT_DIFFERENCE = 243
    DUT_CELSIUS_DIFFERENCE = 244
    DUT_KELVIN_DIFFERENCE = 245
    DUT_RANKINE_DIFFERENCE = 246
    DUT_STATIONING_METERS = 247
    DUT_STATIONING_FEET = 248
    DUT_CUBIC_FEET_PER_HOUR = 249
    DUT_LITERS_PER_HOUR = 250
    DUT_RATIO_TO_1 = 251
    DUT_DECIMAL_US_SURVEY_FEET = 605
    DUT_UNDEFINED = -2
    DUT_CUSTOM = -1


class UnitType:
    UT_Length = 0
    UT_Area = 1
    UT_Volume = 2
    UT_Angle = 3
    UT_Number = 4
    UT_SheetLength = 5
    UT_SiteAngle = 6
    UT_HVAC_Density = 7
    UT_HVAC_Energy = 8
    UT_HVAC_Friction = 9
    UT_HVAC_Power = 10
    UT_HVAC_Power_Density = 11
    UT_HVAC_Pressure = 12
    UT_HVAC_Temperature = 13
    UT_HVAC_Velocity = 14
    UT_HVAC_Airflow = 15
    UT_HVAC_DuctSize = 16
    UT_HVAC_CrossSection = 17
    UT_HVAC_HeatGain = 18
    UT_Electrical_Current = 19
    UT_Electrical_Potential = 20
    UT_Electrical_Frequency = 21
    UT_Electrical_Illuminance = 22
    UT_Electrical_Luminous_Flux = 23
    UT_Electrical_Power = 24
    UT_HVAC_Roughness = 25
    UT_Force = 26
    UT_LinearForce = 27
    UT_AreaForce = 28
    UT_Moment = 29
    UT_ForceScale = 30
    UT_LinearForceScale = 31
    UT_AreaForceScale = 32
    UT_MomentScale = 33
    UT_Electrical_Apparent_Power = 34
    UT_Electrical_Power_Density = 35
    UT_Piping_Density = 36
    UT_Piping_Flow = 37
    UT_Piping_Friction = 38
    UT_Piping_Pressure = 39
    UT_Piping_Temperature = 40
    UT_Piping_Velocity = 41
    UT_Piping_Viscosity = 42
    UT_PipeSize = 43
    UT_Piping_Roughness = 44
    UT_Stress = 45
    UT_UnitWeight = 46
    UT_ThermalExpansion = 47
    UT_LinearMoment = 48
    UT_LinearMomentScale = 49
    UT_ForcePerLength = 50
    UT_ForceLengthPerAngle = 51
    UT_LinearForcePerLength = 52
    UT_LinearForceLengthPerAngle = 53
    UT_AreaForcePerLength = 54
    UT_Piping_Volume = 55
    UT_HVAC_Viscosity = 56
    UT_HVAC_CoefficientOfHeatTransfer = 57
    UT_HVAC_Airflow_Density = 58
    UT_Slope = 59
    UT_HVAC_Cooling_Load = 60
    UT_HVAC_Cooling_Load_Divided_By_Area = 61
    UT_HVAC_Cooling_Load_Divided_By_Volume = 62
    UT_HVAC_Heating_Load = 63
    UT_HVAC_Heating_Load_Divided_By_Area = 64
    UT_HVAC_Heating_Load_Divided_By_Volume = 65
    UT_HVAC_Airflow_Divided_By_Volume = 66
    UT_HVAC_Airflow_Divided_By_Cooling_Load = 67
    UT_HVAC_Area_Divided_By_Cooling_Load = 68
    UT_WireSize = 69
    UT_HVAC_Slope = 70
    UT_Piping_Slope = 71
    UT_Currency = 72
    UT_Electrical_Efficacy = 73
    UT_Electrical_Wattage = 74
    UT_Color_Temperature = 75
    UT_DecSheetLength = 76
    UT_Electrical_Luminous_Intensity = 77
    UT_Electrical_Luminance = 78
    UT_HVAC_Area_Divided_By_Heating_Load = 79
    UT_HVAC_Factor = 80
    UT_Electrical_Temperature = 81
    UT_Electrical_CableTraySize = 82
    UT_Electrical_ConduitSize = 83
    UT_Reinforcement_Volume = 84
    UT_Reinforcement_Length = 85
    UT_Electrical_Demand_Factor = 86
    UT_HVAC_DuctInsulationThickness = 87
    UT_HVAC_DuctLiningThickness = 88
    UT_PipeInsulationThickness = 89
    UT_HVAC_ThermalResistance = 90
    UT_HVAC_ThermalMass = 91
    UT_Acceleration = 92
    UT_Bar_Diameter = 93
    UT_Crack_Width = 94
    UT_Displacement_Deflection = 95
    UT_Energy = 96
    UT_Structural_Frequency = 97
    UT_Mass = 98
    UT_Mass_per_Unit_Length = 99
    UT_Moment_of_Inertia = 100
    UT_Surface_Area = 101
    UT_Period = 102
    UT_Pulsation = 103
    UT_Reinforcement_Area = 104
    UT_Reinforcement_Area_per_Unit_Length = 105
    UT_Reinforcement_Cover = 106
    UT_Reinforcement_Spacing = 107
    UT_Rotation = 108
    UT_Section_Area = 109
    UT_Section_Dimension = 110
    UT_Section_Modulus = 111
    UT_Section_Property = 112
    UT_Structural_Velocity = 113
    UT_Warping_Constant = 114
    UT_Weight = 115
    UT_Weight_per_Unit_Length = 116
    UT_HVAC_ThermalConductivity = 117
    UT_HVAC_SpecificHeat = 118
    UT_HVAC_SpecificHeatOfVaporization = 119
    UT_HVAC_Permeability = 120
    UT_Electrical_Resistivity = 121
    UT_MassDensity = 122
    UT_MassPerUnitArea = 123
    UT_Pipe_Dimension = 124
    UT_PipeMass = 125
    UT_PipeMassPerUnitLength = 126
    UT_HVAC_TemperatureDifference = 127
    UT_Piping_TemperatureDifference = 128
    UT_Electrical_TemperatureDifference = 129
    UT_TimeInterval = 130
    UT_Speed = 131
    UT_Stationing = 132
    UT_Undefined = -2
    UT_Custom = -1


class DisplayUnit:
    METRIC = 0
    IMPERIAL = 1


class BeamSystemJustifyType:
    Center = 1
    End = 2
    Beginning = 3
    DirectionLine = 4


class TextAlignFlags:
    TEF_ALIGN_LEFT = 64
    TEF_ALIGN_CENTER = 128
    TEF_ALIGN_RIGHT = 256
    TEF_ALIGN_TOP = 512
    TEF_ALIGN_MIDDLE = 1024
    TEF_ALIGN_BOTTOM = 2048


class TextAlignMask:
    horzAlignMask = 448
    vertAlignMask = 3584


class TextNoteLeaderStyles:
    LCS_NONE = 0
    LCS_ONE_SEG_LINE = 1
    LCS_ONE_SEG_ARC = 2
    LCS_TWO_SEG_LINE = 3


class SetComparisonResult:
    LeftEmpty = 1
    RightEmpty = 2
    BothEmpty = 3
    Disjoint = 4
    Overlap = 8
    Subset = 16
    Superset = 32
    Equal = 64


class TextElementBackground:
    TBGR_OPAQUE = 0
    TBGR_TRANSPARENT = 1


class ViewType:
    Undefined = 0
    FloorPlan = 1
    CeilingPlan = 2
    Elevation = 3
    ThreeD = 4
    Schedule = 5
    DrawingSheet = 6
    ProjectBrowser = 7
    Report = 8
    DraftingView = 10
    Legend = 11
    SystemBrowser = 12
    EngineeringPlan = 115
    AreaPlan = 116
    Section = 117
    Detail = 118
    CostReport = 119
    LoadsReport = 120
    PresureLossReport = 121
    ColumnSchedule = 122
    PanelSchedule = 123
    Walkthrough = 124
    Rendering = 125
    SystemsAnalysisReport = 126
    Internal = 214


class ViewPlanType:
    FloorPlan = 1
    CeilingPlan = 2


class AreaElemType:
    GrossArea = 0
    BOMAArea = 1


class PaperPlacementType:
    Center = 0
    Margins = 1


class MarginType:
    NoMargin = 0
    PrinterLimit = 1
    UserDefined = 2


class PrintRange:
    Current = 0
    Visible = 1
    Select = 2


class SlabShapeVertexType:
    Invalid = 0
    Corner = 1
    Edge = 2
    Interior = 3


class SlabShapeCreaseType:
    Invalid = 0
    Boundary = 1
    UserDrawn = 2
    Auto = 3


class EaveCutterType:
    PlumbCut = 33615
    TwoCutSquare = 33618
    TwoCutPlumb = 33619


class CurtainGridAlignType:
    NoJustify = 0
    Beginning = 1
    Center = 2
    End = 3


class VirtualPrinterType:
    #None = 0
    AdobePDF = 1
    DWFWriter = 2
    XPSWriter = 3


class DimensionShape:
    Linear = 0
    Angular = 1
    Radial = 2
    ArcLength = 3
    Spot = 4
    Diameter = 5
    Unknown = 6


class ElementReferenceType:
    REFERENCE_TYPE_NONE = 0
    REFERENCE_TYPE_LINEAR = 1
    REFERENCE_TYPE_SURFACE = 2
    REFERENCE_TYPE_FOREIGN = 3
    REFERENCE_TYPE_INSTANCE = 4
    REFERENCE_TYPE_CUT_EDGE = 5
    REFERENCE_TYPE_MESH = 6
    REFERENCE_TYPE_SUBELEMENT = 7


class HorizontalAlign:
    Left = 64
    Center = 128
    Right = 256


class ReferenceType:
    #None = 0
    WeakReference = 1
    StrongReference = 2


class DWFImageQuality:
    Default = 10
    Low = 11
    Medium = 12
    High = 13


class DWFImageFormat:
    Lossless = 0
    Lossy = 1


class GridNodeLocation:
    Interior = 0
    Boundary = 1
    Exterior = 2


class BorderTile:
    Empty = 0
    Partial = 1
    Overhanging = 2


class ComponentRotation:
    Angle0 = 0
    Angle90 = 90
    Angle180 = 180
    Angle270 = 270


class GridSegmentDirection:
    PositiveU = 0
    NegativeU = 1
    PositiveV = 2
    NegativeV = 3


class StructuralReleaseType:
    kFixed = 0
    kPinned = 1
    kBendingMoment = 2
    kUserDefined = 3


class StickSymbolLocation:
    StickViewCenter = 0
    StickViewTop = 1
    StickViewBottom = 2
    StickViewLocLine = 3


class AnalyzesAsType:
    AA_Hanger = 0
    AA_Gravity = 1
    AA_Lateral = 2
    AA_SlabOneWay = 3
    AA_Mat = 4
    AA_SlabOnGrade = 5
    AA_Not_For_Analysis = 6
    AA_SlabTwoWay = 7
    AA_GravityLateral = 8


class SlantedOrVerticalColumnType:
    CT_Vertical = 0
    CT_Angle = 1
    CT_EndPoint = 2


class ControlShape:
    VerticalArrow = 0
    HorizontalArrow = 1
    DoubleVerticalArrow = 2
    DoubleHorizontalArrow = 3


class FamilyPlacementType:
    OneLevelBased = 0
    OneLevelBasedHosted = 1
    TwoLevelsBased = 2
    ViewBased = 3
    WorkPlaneBased = 4
    CurveBased = 5
    CurveBasedDetail = 6
    CurveDrivenStructural = 7
    Adaptive = 8
    Invalid = 9


class TilePatternsBuiltIn:
    Rectangle = 1
    Triangle_Bent = 2
    Rhomboid = 3
    Hexagon = 4
    HalfStep = 5
    ThirdStep = 6
    TriangleCheckerboard_Bent = 7
    RectangleCheckerboard = 8
    RhomboidCheckerboard = 9
    TriangleStep_Bent = 10
    Arrows = 11
    ZigZag = 12
    Octagon = 13
    OctagonRotate = 14
    Triangle_Flat = 15
    TriangleCheckerboard_Flat = 16


class ConnectorJointType:
    Undefined = 0
    Flanged = 1
    Welded = 2
    Threaded = 3
    Grooved = 4
    Glued = 5
    Soldered = 6


class ConnectorGenderType:
    Undefined = 0
    Male = 1
    Female = 2


class ConnectorDomainType:
    Undefined = 0
    Hvac = 1
    Electrical = 2
    Piping = 3
    CableTrayConduit = 4
    StructuralAnalytical = 5


class Domain:
    DomainUndefined = 0
    DomainHvac = 1
    DomainElectrical = 2
    DomainPiping = 3
    DomainCableTrayConduit = 4


class AutomaticConnectionBehaviorType:
    Exclude = 0
    Active = 1
    Forced = 2
    Accepting = 3
    Full = 4


class ConnectorType:
    Invalid = 0
    End = 1
    Curve = 2
    Logical = 4
    Reference = 8
    Surface = 16
    EndSurface = 17
    Physical = 19
    NonEnd = 30
    MasterSurface = 32
    MainSurface = 32
    Family = 49
    NodeReference = 64
    BlankEnd = 128
    AnyEnd = 129
    Super = 256
    AllModes = 16777215


class ConnectorProfileType:
    Round = 0
    Rectangular = 1
    Oval = 2
    Invalid = -1


class FlowDirectionType:
    Bidirectional = 0
    In = 1
    Out = 2


class BehaviorType:
    Invalid = 0
    Normal = 1
    Bend = 2
    Branch = 4
    Intersection = 8
    Inline = 16
    BreakInto = 32
    OrientToObject = 64
    OrientToCenterLine = 128
    OrientToFace = 256
    SystemMember = 512
    BaseObject = 1024
    EndCap = 2048
    Valve = 4096
    Flange = 8192
    MechanicalCoupling = 16384
    VerticalBend = 32768
    ElectricalBaseObject = 65536
    Straight = 131072
    Flex = 262144
    Hanger = 524288
    Flat_Tap = 1048576
    Coupling = 2097152
    Round_CentreLine_Tap = 4194304
    Oval_CentreLine_Tap = 8388608
    Damper = 16777216


class BaseLoadOn:
    kUseEnteredLoad = 0
    kUseCalculatedLoad = 1
    kUseActualLoad = 2
    kNoOfBaseLoadOnMethods = 3
    kBySpaceType = -1
    kUseDefaultLoad = -1


class MEPSystemClassification:
    UndefinedSystemClassification = 0
    SupplyAir = 1
    ReturnAir = 2
    ExhaustAir = 3
    OtherAir = 4
    DataCircuit = 5
    PowerCircuit = 6
    SupplyHydronic = 7
    ReturnHydronic = 8
    Telephone = 9
    Security = 10
    FireAlarm = 11
    NurseCall = 12
    Controls = 13
    Communication = 14
    CondensateDrain = 15
    Sanitary = 16
    Vent = 17
    Storm = 18
    DomesticHotWater = 19
    DomesticColdWater = 20
    Recirculation = 21
    OtherPipe = 22
    FireProtectWet = 23
    FireProtectDry = 24
    FireProtectPreaction = 25
    FireProtectOther = 26
    SwitchTopology = 27
    Fitting = 28
    Global = 29
    PowerBalanced = 30
    PowerUnBalanced = 31
    CableTrayConduit = 32


class JunctionType:
    Tap = 0
    Tee = 1


class TextNoteLeaderTypes:
    TNLT_STRAIGHT_L = 0
    TNLT_STRAIGHT_R = 1
    TNLT_ARC_L = 2
    TNLT_ARC_R = 3


class HorizontalTextAlignment:
    Left = 0
    Right = 1
    Center = 2


class VerticalTextAlignment:
    Top = 0
    Bottom = 1
    Middle = 2


class LeaderAtachement:
    TopLine = 0
    Midpoint = 1
    BottomLine = 2


class TextListStyle:
    #None = 0
    Bullet = 1
    NumberArabic = 2
    LetterLowercase = 3
    LetterUppercase = 4
    NumberRomanLowercase = 5
    NumberRomanUppercase = 6


class TextBaselineStyle:
    Normal = 0
    Subscript = 1
    Superscript = 2


class ProfilePlaneLocation:
    Start = 0
    MidPoint = 1
    End = 2


class ParameterType:
    Invalid = 0
    Text = 1
    Integer = 2
    Number = 3
    Length = 4
    Area = 5
    Volume = 6
    Angle = 7
    URL = 8
    Material = 9
    YesNo = 10
    Force = 11
    LinearForce = 12
    AreaForce = 13
    Moment = 14
    NumberOfPoles = 15
    FixtureUnit = 16
    FamilyType = 17
    LoadClassification = 18
    Image = 19
    MultilineText = 20
    Custom = 99
    HVACDensity = 107
    HVACEnergy = 108
    HVACFriction = 109
    HVACPower = 110
    HVACPowerDensity = 111
    HVACPressure = 112
    HVACTemperature = 113
    HVACVelocity = 114
    HVACAirflow = 115
    HVACDuctSize = 116
    HVACCrossSection = 117
    HVACHeatGain = 118
    ElectricalCurrent = 119
    ElectricalPotential = 120
    ElectricalFrequency = 121
    ElectricalIlluminance = 122
    ElectricalLuminousFlux = 123
    ElectricalPower = 124
    HVACRoughness = 125
    ElectricalApparentPower = 134
    ElectricalPowerDensity = 135
    PipingDensity = 136
    PipingFlow = 137
    PipingFriction = 138
    PipingPressure = 139
    PipingTemperature = 140
    PipingVelocity = 141
    PipingViscosity = 142
    PipeSize = 143
    PipingRoughness = 144
    Stress = 145
    UnitWeight = 146
    ThermalExpansion = 147
    LinearMoment = 148
    ForcePerLength = 150
    ForceLengthPerAngle = 151
    LinearForcePerLength = 152
    LinearForceLengthPerAngle = 153
    AreaForcePerLength = 154
    PipingVolume = 155
    HVACViscosity = 156
    HVACCoefficientOfHeatTransfer = 157
    HVACAirflowDensity = 158
    Slope = 159
    HVACCoolingLoad = 160
    HVACCoolingLoadDividedByArea = 161
    HVACCoolingLoadDividedByVolume = 162
    HVACHeatingLoad = 163
    HVACHeatingLoadDividedByArea = 164
    HVACHeatingLoadDividedByVolume = 165
    HVACAirflowDividedByVolume = 166
    HVACAirflowDividedByCoolingLoad = 167
    HVACAreaDividedByCoolingLoad = 168
    WireSize = 169
    HVACSlope = 170
    PipingSlope = 171
    Currency = 172
    ElectricalEfficacy = 173
    ElectricalWattage = 174
    ColorTemperature = 175
    ElectricalLuminousIntensity = 177
    ElectricalLuminance = 178
    HVACAreaDividedByHeatingLoad = 179
    HVACFactor = 180
    ElectricalTemperature = 181
    ElectricalCableTraySize = 182
    ElectricalConduitSize = 183
    ReinforcementVolume = 184
    ReinforcementLength = 185
    ElectricalDemandFactor = 186
    HVACDuctInsulationThickness = 187
    HVACDuctLiningThickness = 188
    PipeInsulationThickness = 189
    HVACThermalResistance = 190
    HVACThermalMass = 191
    Acceleration = 192
    BarDiameter = 193
    CrackWidth = 194
    DisplacementDeflection = 195
    Energy = 196
    StructuralFrequency = 197
    Mass = 198
    MassPerUnitLength = 199
    MomentOfInertia = 200
    SurfaceArea = 201
    Period = 202
    Pulsation = 203
    ReinforcementArea = 204
    ReinforcementAreaPerUnitLength = 205
    ReinforcementCover = 206
    ReinforcementSpacing = 207
    Rotation = 208
    SectionArea = 209
    SectionDimension = 210
    SectionModulus = 211
    SectionProperty = 212
    StructuralVelocity = 213
    WarpingConstant = 214
    Weight = 215
    WeightPerUnitLength = 216
    HVACThermalConductivity = 217
    HVACSpecificHeat = 218
    HVACSpecificHeatOfVaporization = 219
    HVACPermeability = 220
    ElectricalResistivity = 221
    MassDensity = 222
    MassPerUnitArea = 223
    PipeDimension = 224
    PipeMass = 225
    PipeMassPerUnitLength = 226
    HVACTemperatureDifference = 227
    PipingTemperatureDifference = 228
    ElectricalTemperatureDifference = 229
    TimeInterval = 230
    Speed = 231
    Stationing = 232


class StorageType:
    #None = 0
    Integer = 1
    Double = 2
    String = 3
    ElementId = 4


class ModifierType:
    Category = 0
    Custom1 = 1
    Custom2 = 2
    Custom3 = 3
    FireRating = 4
    Function = 5
    Level = 6
    PhaseCreated = 7
    PhaseDemolished = 8
    PhaseStatus = 9
    StructuralMaterialType = 10
    StructuralUsage = 11
    SystemName = 12
    SystemType = 13
    Underlay = 14
    ViewType = 15
    Workset = 16
    AnalyzesAs = 17
    SystemClassification = 18
    DomainType = 19
    FabricationService = 20
    UnknownType = -1


class SpecialType:
    InteriorWall = 1
    ExteriorWall = 2
    FoundationWall = 3
    RetainingWall = 4
    Default = -1


class LayerCategoryType:
    Model = 0
    Annotation = 1
    AnalyticalModel = 2
    Imported = 3
    Modifier = 4
    Unsorted = -1


class CurveElement(Element):
    @property
    def GeometryCurve(self) -> Curve: ...
    @GeometryCurve.setter
    def GeometryCurve(self, curve: Curve) -> None: ...
    def SetGeometryCurve(self, curve: Curve, overrideJoins: bool) -> None: ...
    @property
    def CenterPointReference(self) -> Reference: ...
    @property
    def SketchPlane(self) -> SketchPlane: ...
    @SketchPlane.setter
    def SketchPlane(self, sketchPlane: SketchPlane) -> None: ...
    def SetSketchPlaneAndCurve(self, sketchPlane: SketchPlane, curve: Curve) -> None: ...
    @property
    def LineStyle(self) -> Element: ...
    @LineStyle.setter
    def LineStyle(self, lineStyle: Element) -> None: ...
    @property
    def CurveElementType(self) -> CurveElementType: ...
    @property
    def SupportsTangentLocks(self) -> bool: ...
    def GetLineStyleIds(self) -> ICollection: ...
    def GetAdjoinedCurveElements(self, end: int) -> ISet: ...
    def IsAdjoinedCurveElement(self, end: int, other: ElementId) -> bool: ...
    def HasTangentJoin(self, end: int, other: ElementId) -> bool: ...
    def HasTangentLocks(self, end: int) -> bool: ...
    def GetTangentLock(self, end: int, other: ElementId) -> bool: ...
    def SetTangentLock(self, end: int, other: ElementId, state: bool) -> None: ...


class Location(APIObject):
    def Move(self, translation: XYZ) -> bool: ...
    def Rotate(self, axis: Line, angle: float) -> bool: ...


class PointLocationOnCurve:
    def __init__(self, measType: PointOnCurveMeasurementType, measValue: float, measFrom: PointOnCurveMeasureFrom): ...
    @property
    def MeasurementType(self) -> PointOnCurveMeasurementType: ...
    @MeasurementType.setter
    def MeasurementType(self, measType: PointOnCurveMeasurementType) -> None: ...
    @property
    def MeasurementValue(self) -> float: ...
    @MeasurementValue.setter
    def MeasurementValue(self, measValue: float) -> None: ...
    @property
    def MeasureFrom(self) -> PointOnCurveMeasureFrom: ...
    @MeasureFrom.setter
    def MeasureFrom(self, measFrom: PointOnCurveMeasureFrom) -> None: ...
    @property
    def IsValidObject(self) -> bool: ...
    def Dispose(self) -> None: ...


class BaseImportOptions:
    @property
    def Unit(self) -> ImportUnit: ...
    @Unit.setter
    def Unit(self, unit: ImportUnit) -> None: ...
    @property
    def ColorMode(self) -> ImportColorMode: ...
    @ColorMode.setter
    def ColorMode(self, colorMode: ImportColorMode) -> None: ...
    @property
    def Placement(self) -> ImportPlacement: ...
    @Placement.setter
    def Placement(self, placement: ImportPlacement) -> None: ...
    @property
    def ThisViewOnly(self) -> bool: ...
    @ThisViewOnly.setter
    def ThisViewOnly(self, thisViewOnly: bool) -> None: ...
    @property
    def OrientToView(self) -> bool: ...
    @OrientToView.setter
    def OrientToView(self, orientToView: bool) -> None: ...
    @property
    def CustomScale(self) -> float: ...
    @CustomScale.setter
    def CustomScale(self, customScale: float) -> None: ...
    @property
    def VisibleLayersOnly(self) -> bool: ...
    @VisibleLayersOnly.setter
    def VisibleLayersOnly(self, visibleLayersOnly: bool) -> None: ...
    @property
    def AutoCorrectAlmostVHLines(self) -> bool: ...
    @AutoCorrectAlmostVHLines.setter
    def AutoCorrectAlmostVHLines(self, autoCorrectAlmostVHLines: bool) -> None: ...
    @property
    def ReferencePoint(self) -> XYZ: ...
    @ReferencePoint.setter
    def ReferencePoint(self, point: XYZ) -> None: ...
    @property
    def IsValidObject(self) -> bool: ...
    def SetLayerSelection(self, layerSelection: ICollection) -> None: ...
    def GetLayerSelection(self) -> ICollection: ...
    def Dispose(self) -> None: ...


class DWGImportOptions(BaseImportOptions):
    @overload
    def __init__(self, option: DWGImportOptions): ...
    @overload
    def __init__(self): ...
    def SetLineWeights(self, lineWeight: List[int]) -> None: ...
    def GetLineWeights(self) -> List[int]: ...


class DGNImportOptions(BaseImportOptions):
    @overload
    def __init__(self, option: DGNImportOptions): ...
    @overload
    def __init__(self): ...
    @property
    def IgnoreUnsupportedElementWarning(self) -> bool: ...
    @IgnoreUnsupportedElementWarning.setter
    def IgnoreUnsupportedElementWarning(self, ignoreUnsupportedElementWarning: bool) -> None: ...
    @property
    def DGNModelViewName(self) -> str: ...
    @DGNModelViewName.setter
    def DGNModelViewName(self, dgnModelViewName: str) -> None: ...


class SATImportOptions(BaseImportOptions):
    @overload
    def __init__(self, option: SATImportOptions): ...
    @overload
    def __init__(self): ...


class DWFImportOptions:
    @overload
    def __init__(self, option: DWFImportOptions): ...
    @overload
    def __init__(self, views: List[ElementId]): ...
    @property
    def IsValidObject(self) -> bool: ...
    def SetSheetViews(self, sheetViews: List[ElementId]) -> None: ...
    def GetSheetViews(self) -> List[ElementId]: ...
    def Dispose(self) -> None: ...


class SKPImportOptions(BaseImportOptions):
    @overload
    def __init__(self, option: SKPImportOptions): ...
    @overload
    def __init__(self): ...


class Instance(Element):
    def GetTransform(self) -> Transform: ...
    def GetTotalTransform(self) -> Transform: ...


class RevitLinkInstance(Instance):
    @overload
    def Create(document: Document, revitLinkTypeId: ElementId, placement: ImportPlacement) -> RevitLinkInstance: ...
    @overload
    def Create(document: Document, revitLinkTypeId: ElementId) -> RevitLinkInstance: ...
    def GetLinkDocument(self) -> Document: ...
    def MoveBasePointToHostBasePoint(self, resetToOriginalRotation: bool) -> None: ...
    def MoveOriginToHostOrigin(self, resetToOriginalRotation: bool) -> None: ...


class AreaVolumeSettings(Element):
    @property
    def ComputeVolumes(self) -> bool: ...
    @ComputeVolumes.setter
    def ComputeVolumes(self, computeRoomVolumes: bool) -> None: ...
    def GetAreaVolumeSettings(aDoc: Document) -> AreaVolumeSettings: ...
    def GetSpatialElementBoundaryLocation(self, spType: SpatialElementType) -> SpatialElementBoundaryLocation: ...
    def SetSpatialElementBoundaryLocation(self, spatialElementBoundaryLocation: SpatialElementBoundaryLocation, spType: SpatialElementType) -> None: ...


class SpatialElementBoundaryOptions:
    def __init__(self): ...
    @property
    def StoreFreeBoundaryFaces(self) -> bool: ...
    @StoreFreeBoundaryFaces.setter
    def StoreFreeBoundaryFaces(self, storeFreeBoundaryFaces: bool) -> None: ...
    @property
    def SpatialElementBoundaryLocation(self) -> SpatialElementBoundaryLocation: ...
    @SpatialElementBoundaryLocation.setter
    def SpatialElementBoundaryLocation(self, spatialElementBoundaryLocation: SpatialElementBoundaryLocation) -> None: ...
    @property
    def IsValidObject(self) -> bool: ...
    def Dispose(self) -> None: ...


class SpatialElement(Element):
    @Name.setter
    def Name(self, valueString: str) -> None: ...
    @property
    def Level(self) -> Level: ...
    def GetBoundarySegments(self, options: SpatialElementBoundaryOptions) -> List[BoundarySegment]: ...
    @property
    def Number(self) -> str: ...
    @Number.setter
    def Number(self, valueString: str) -> None: ...
    @property
    def Location(self) -> Location: ...
    @property
    def Area(self) -> float: ...
    @property
    def Perimeter(self) -> float: ...


class FailureHandlingOptions:
    @property
    def IsValidObject(self) -> bool: ...
    def SetForcedModalHandling(self, bFlag: bool) -> FailureHandlingOptions: ...
    def SetClearAfterRollback(self, bFlag: bool) -> FailureHandlingOptions: ...
    def SetDelayedMiniWarnings(self, bFlag: bool) -> FailureHandlingOptions: ...
    def SetTransactionFinalizer(self, finalizer: ITransactionFinalizer) -> FailureHandlingOptions: ...
    def SetFailuresPreprocessor(self, preprocessor: IFailuresPreprocessor) -> FailureHandlingOptions: ...
    def GetForcedModalHandling(self) -> bool: ...
    def GetClearAfterRollback(self) -> bool: ...
    def GetDelayedMiniWarnings(self) -> bool: ...
    def GetTransactionFinalizer(self) -> ITransactionFinalizer: ...
    def GetFailuresPreprocessor(self) -> IFailuresPreprocessor: ...
    def Dispose(self) -> None: ...


class Reference(APIObject):
    def __init__(self, element: Element): ...
    def CreateLinkReference(self, revitLinkInstance: RevitLinkInstance) -> Reference: ...
    def CreateReferenceInLink(self) -> Reference: ...
    @property
    def ElementId(self) -> ElementId: ...
    @property
    def LinkedElementId(self) -> ElementId: ...
    @property
    def ElementReferenceType(self) -> ElementReferenceType: ...
    @property
    def GlobalPoint(self) -> XYZ: ...
    @property
    def UVPoint(self) -> UV: ...
    def ConvertToStableRepresentation(self, document: Document) -> str: ...
    def ParseFromStableRepresentation(document: Document, representation: str) -> Reference: ...
    def EqualTo(self, reference: Reference) -> bool: ...
    def Contains(self, reference: Reference) -> bool: ...


class ReferencePoint(Element):
    @property
    def Name(self) -> str: ...
    @Name.setter
    def Name(self, A_0: str) -> None: ...
    def GetPointElementReference(self) -> PointElementReference: ...
    def SetPointElementReference(self, pointElementReference: PointElementReference) -> None: ...
    def GetCoordinateSystem(self) -> Transform: ...
    def SetCoordinateSystem(self, coordinateSystem: Transform) -> None: ...
    @property
    def Position(self) -> XYZ: ...
    @Position.setter
    def Position(self, A_0: XYZ) -> None: ...
    def GetInterpolatingCurves(self) -> CurveByPointsArray: ...
    def GetCoordinatePlaneReferenceXY(self) -> Reference: ...
    def GetCoordinatePlaneReferenceYZ(self) -> Reference: ...
    def GetCoordinatePlaneReferenceXZ(self) -> Reference: ...
    @property
    def Visible(self) -> bool: ...
    @Visible.setter
    def Visible(self, visible: bool) -> None: ...
    def GetVisibility(self) -> FamilyElementVisibility: ...
    def SetVisibility(self, visibility: FamilyElementVisibility) -> None: ...
    def GetHubId(self) -> ElementId: ...
    @property
    def CoordinatePlaneVisibility(self) -> CoordinatePlaneVisibility: ...
    @CoordinatePlaneVisibility.setter
    def CoordinatePlaneVisibility(self, A_0: CoordinatePlaneVisibility) -> None: ...
    @property
    def ShowNormalReferencePlaneOnly(self) -> bool: ...
    @ShowNormalReferencePlaneOnly.setter
    def ShowNormalReferencePlaneOnly(self, A_0: bool) -> None: ...


class ReferencePointArray(APIObject):
    def __init__(self): ...
    def Clear(self) -> None: ...
    @property
    def Size(self) -> int: ...
    @property
    def IsEmpty(self) -> bool: ...
    def ForwardIterator(self) -> ReferencePointArrayIterator: ...
    def ReverseIterator(self) -> ReferencePointArrayIterator: ...
    def GetEnumerator(self) -> IEnumerator: ...
    @property
    def Item(self, index: int) -> ReferencePoint: ...
    @Item.setter
    def Item(self, index: int, item: ReferencePoint) -> None: ...
    def Append(self, item: ReferencePoint) -> None: ...
    def Insert(self, item: ReferencePoint, index: int) -> None: ...


class ReferencePointArrayIterator(APIObject):
    def __init__(self): ...
    @property
    def Current(self) -> Object: ...
    def MoveNext(self) -> bool: ...
    def Reset(self) -> None: ...


class PointElementReference:


class PointOnPlane(PointElementReference):
    def NewPointOnPlane(doc: Document, planeReference: Reference, position: XYZ, xvec: XYZ) -> PointOnPlane: ...
    def GetPlaneReference(self) -> Reference: ...
    def SetPlaneReference(self, planeReference: Reference) -> None: ...
    def IsValidPlaneReference(doc: Document, planeReference: Reference) -> bool: ...
    @property
    def Position(self) -> UV: ...
    @Position.setter
    def Position(self, A_0: UV) -> None: ...
    @property
    def XVec(self) -> UV: ...
    @XVec.setter
    def XVec(self, A_0: UV) -> None: ...
    @property
    def Offset(self) -> float: ...
    @Offset.setter
    def Offset(self, A_0: float) -> None: ...


class PointOnEdge(PointElementReference):
    def GetEdgeReference(self) -> Reference: ...
    def SetEdgeReference(self, reference: Reference) -> None: ...
    @property
    def LocationOnCurve(self) -> PointLocationOnCurve: ...


class PointOnFace(PointElementReference):
    def GetFaceReference(self) -> Reference: ...
    def SetFaceReference(self, reference: Reference) -> None: ...
    @property
    def UV(self) -> UV: ...
    @UV.setter
    def UV(self, A_0: UV) -> None: ...


class PointOnEdgeFaceIntersection(PointElementReference):
    def GetEdgeReference(self) -> Reference: ...
    def SetEdgeReference(self, edgeReference: Reference) -> None: ...
    def GetFaceReference(self) -> Reference: ...
    def SetFaceReference(self, reference: Reference) -> None: ...
    @property
    def OrientWithEdge(self) -> bool: ...
    @OrientWithEdge.setter
    def OrientWithEdge(self, A_0: bool) -> None: ...


class PointOnEdgeEdgeIntersection(PointElementReference):
    def GetEdgeReference1(self) -> Reference: ...
    def SetEdgeReference1(self, edgeReference: Reference) -> None: ...
    def GetEdgeReference2(self) -> Reference: ...
    def SetEdgeReference2(self, edgeReference: Reference) -> None: ...


class PointRelativeToPoint(PointElementReference):
    def GetHostPointReference(self) -> Reference: ...
    def SetHostPointReference(self, hostPointReference: Reference) -> None: ...


class CurveByPoints(CurveElement):
    @property
    def SketchPlane(self) -> SketchPlane: ...
    @SketchPlane.setter
    def SketchPlane(self, sketchPlane: SketchPlane) -> None: ...
    def GetPoints(self) -> ReferencePointArray: ...
    def SetPoints(self, points: ReferencePointArray) -> None: ...
    def SortPoints(arr: ReferencePointArray) -> bool: ...
    @property
    def IsReferenceLine(self) -> bool: ...
    @IsReferenceLine.setter
    def IsReferenceLine(self, A_0: bool) -> None: ...
    def GetVisibility(self) -> FamilyElementVisibility: ...
    def SetVisibility(self, visibility: FamilyElementVisibility) -> None: ...
    @property
    def Subcategory(self) -> GraphicsStyle: ...
    @Subcategory.setter
    def Subcategory(self, subcategory: GraphicsStyle) -> None: ...
    @property
    def Visible(self) -> bool: ...
    @Visible.setter
    def Visible(self, A_0: bool) -> None: ...
    @property
    def ReferenceType(self) -> ReferenceType: ...
    @ReferenceType.setter
    def ReferenceType(self, referenceType: ReferenceType) -> None: ...


class CurveByPointsArray(APIObject):
    def __init__(self): ...
    def Clear(self) -> None: ...
    @property
    def Size(self) -> int: ...
    @property
    def IsEmpty(self) -> bool: ...
    def ForwardIterator(self) -> CurveByPointsArrayIterator: ...
    def ReverseIterator(self) -> CurveByPointsArrayIterator: ...
    def GetEnumerator(self) -> IEnumerator: ...
    @property
    def Item(self, index: int) -> CurveByPoints: ...
    @Item.setter
    def Item(self, index: int, item: CurveByPoints) -> None: ...
    def Append(self, item: CurveByPoints) -> None: ...
    def Insert(self, item: CurveByPoints, index: int) -> None: ...


class CurveByPointsArrayIterator(APIObject):
    def __init__(self): ...
    @property
    def Current(self) -> Object: ...
    def MoveNext(self) -> bool: ...
    def Reset(self) -> None: ...


class ElementArray(APIObject):
    def __init__(self): ...
    def Clear(self) -> None: ...
    @property
    def Size(self) -> int: ...
    @property
    def IsEmpty(self) -> bool: ...
    def ForwardIterator(self) -> ElementArrayIterator: ...
    def ReverseIterator(self) -> ElementArrayIterator: ...
    def GetEnumerator(self) -> IEnumerator: ...
    @property
    def Item(self, index: int) -> Element: ...
    @Item.setter
    def Item(self, index: int, item: Element) -> None: ...
    def Append(self, item: Element) -> None: ...
    def Insert(self, item: Element, index: int) -> None: ...


class ElementArrayIterator(APIObject):
    def __init__(self): ...
    @property
    def Current(self) -> Object: ...
    def MoveNext(self) -> bool: ...
    def Reset(self) -> None: ...


class Options(APIObject):
    @overload
    def __init__(self, pOptions: Options): ...
    @overload
    def __init__(self): ...
    @property
    def DetailLevel(self) -> ViewDetailLevel: ...
    @DetailLevel.setter
    def DetailLevel(self, level: ViewDetailLevel) -> None: ...
    @property
    def ComputeReferences(self) -> bool: ...
    @ComputeReferences.setter
    def ComputeReferences(self, A_0: bool) -> None: ...
    @property
    def View(self) -> View: ...
    @View.setter
    def View(self, specificView: View) -> None: ...
    @property
    def IncludeNonVisibleObjects(self) -> bool: ...
    @IncludeNonVisibleObjects.setter
    def IncludeNonVisibleObjects(self, includeNonVisibleObjects: bool) -> None: ...


class GeometryObject(APIObject):
    @property
    def Visibility(self) -> Visibility: ...
    @property
    def GraphicsStyleId(self) -> ElementId: ...
    @property
    def IsElementGeometry(self) -> bool: ...
    @property
    def Id(self) -> int: ...
    def op_Equality(first: GeometryObject, second: GeometryObject) -> bool: ...
    def op_Inequality(first: GeometryObject, second: GeometryObject) -> bool: ...
    def Equals(self, obj: Object) -> bool: ...
    def GetHashCode(self) -> int: ...


class Curve(GeometryObject):
    @property
    def IsBound(self) -> bool: ...
    @property
    def IsClosed(self) -> bool: ...
    def Tessellate(self) -> List[XYZ]: ...
    def Evaluate(self, parameter: float, normalized: bool) -> XYZ: ...
    @property
    def Reference(self) -> Reference: ...
    def GetEndPoint(self, index: int) -> XYZ: ...
    def GetEndPointReference(self, index: int) -> Reference: ...
    def GetEndParameter(self, index: int) -> float: ...
    def MakeBound(self, startParameter: float, endParameter: float) -> None: ...
    def MakeUnbound(self) -> None: ...
    def ComputeNormalizedParameter(self, rawParameter: float) -> float: ...
    def ComputeRawParameter(self, normalizedParameter: float) -> float: ...
    @property
    def ApproximateLength(self) -> float: ...
    @property
    def Length(self) -> float: ...
    def Distance(self, point: XYZ) -> float: ...
    @property
    def IsCyclic(self) -> bool: ...
    @property
    def Period(self) -> float: ...
    def CreateTransformed(self, transform: Transform) -> Curve: ...
    def CreateReversed(self) -> Curve: ...
    def CreateOffset(self, offsetDist: float, referenceVector: XYZ) -> Curve: ...
    def ComputeDerivatives(self, parameter: float, normalized: bool) -> Transform: ...
    @overload
    def IsInside(self, parameter: float) -> Tuple[bool, int]: ...
    @overload
    def IsInside(self, parameter: float) -> bool: ...
    @overload
    def Intersect(self, curve: Curve) -> Tuple[SetComparisonResult, IntersectionResultArray]: ...
    @overload
    def Intersect(self, curve: Curve) -> SetComparisonResult: ...
    def Project(self, point: XYZ) -> IntersectionResult: ...
    def Clone(self) -> Curve: ...
    def SetGraphicsStyleId(self, id: ElementId) -> None: ...
    def ComputeClosestPoints(self, otherCurve: Curve, withinThisCurveBounds: bool, withinOtherCurveBounds: bool, returnAllCriticalPnts: bool) -> Tuple[List[ClosestPointsPairBetweenTwoCurves]]: ...


class Arc(Curve):
    @property
    def Center(self) -> XYZ: ...
    @property
    def Normal(self) -> XYZ: ...
    @property
    def XDirection(self) -> XYZ: ...
    @property
    def YDirection(self) -> XYZ: ...
    @property
    def Radius(self) -> float: ...
    @overload
    def Create(end0: XYZ, end1: XYZ, pointOnArc: XYZ) -> Arc: ...
    @overload
    def Create(plane: Plane, radius: float, startAngle: float, endAngle: float) -> Arc: ...
    @overload
    def Create(center: XYZ, radius: float, startAngle: float, endAngle: float, xAxis: XYZ, yAxis: XYZ) -> Arc: ...


class Ellipse(Curve):
    @property
    def Center(self) -> XYZ: ...
    @property
    def Normal(self) -> XYZ: ...
    @property
    def XDirection(self) -> XYZ: ...
    @property
    def YDirection(self) -> XYZ: ...
    @property
    def RadiusX(self) -> float: ...
    @property
    def RadiusY(self) -> float: ...
    def CreateCurve(center: XYZ, xRadius: float, yRadius: float, xAxis: XYZ, yAxis: XYZ, startParameter: float, endParameter: float) -> Curve: ...


class Line(Curve):
    @property
    def Origin(self) -> XYZ: ...
    @property
    def Direction(self) -> XYZ: ...
    def CreateBound(endpoint1: XYZ, endpoint2: XYZ) -> Line: ...
    def CreateUnbound(origin: XYZ, direction: XYZ) -> Line: ...


class NurbSpline(Curve):
    @property
    def isClosed(self) -> bool: ...
    @isClosed.setter
    def isClosed(self, closed: bool) -> None: ...
    @property
    def isRational(self) -> bool: ...
    @property
    def Degree(self) -> int: ...
    @property
    def CtrlPoints(self) -> List[XYZ]: ...
    @property
    def Weights(self) -> DoubleArray: ...
    @property
    def Knots(self) -> DoubleArray: ...
    @Knots.setter
    def Knots(self, knots: DoubleArray) -> None: ...
    def SetControlPointsAndWeights(self, ctrlPoints: List[XYZ], weights: DoubleArray) -> None: ...
    @overload
    def CreateCurve(hermiteSpline: HermiteSpline) -> Curve: ...
    @overload
    def CreateCurve(controlPoints: List[XYZ], weights: List[float]) -> Curve: ...
    @overload
    def CreateCurve(degree: int, knots: List[float], controlPoints: List[XYZ], weights: List[float]) -> Curve: ...
    @overload
    def CreateCurve(degree: int, knots: List[float], controlPoints: List[XYZ]) -> Curve: ...
    def Create(hermiteSpline: HermiteSpline) -> NurbSpline: ...


class Surface:
    @property
    def OrientationMatchesParametricOrientation(self) -> bool: ...
    @property
    def IsValidObject(self) -> bool: ...
    def Project(self, point: XYZ) -> Tuple[UV, float]: ...
    def ProjectWithGuessPoint(self, point: XYZ, guessUV: UV) -> Tuple[UV, float]: ...
    def GetBoundingBoxUV(self) -> BoundingBoxUV: ...
    def Dispose(self) -> None: ...


class Plane(Surface):
    @property
    def Normal(self) -> XYZ: ...
    @property
    def Origin(self) -> XYZ: ...
    @property
    def XVec(self) -> XYZ: ...
    @property
    def YVec(self) -> XYZ: ...
    def Create(frameOfReference: Frame) -> Plane: ...
    def CreateByThreePoints(point1: XYZ, point2: XYZ, point3: XYZ) -> Plane: ...
    def CreateByNormalAndOrigin(normal: XYZ, origin: XYZ) -> Plane: ...
    def CreateByOriginAndBasis(origin: XYZ, basisX: XYZ, basisY: XYZ) -> Plane: ...


class SketchPlane(Element):
    @property
    def IsSuitableForModelElements(self) -> bool: ...
    @overload
    def Create(document: Document, datumId: ElementId) -> SketchPlane: ...
    @overload
    def Create(document: Document, planarFaceReference: Reference) -> SketchPlane: ...
    @overload
    def Create(document: Document, plane: Plane) -> SketchPlane: ...
    def GetPlane(self) -> Plane: ...
    def GetPlaneReference(self) -> Reference: ...


class CurveElementType:
    Invalid = 0
    ModelCurve = 1
    DetailCurve = 2
    SymbolicCurve = 3
    ReferenceLine = 4
    SpaceSeparation = 5
    RoomSeparation = 6
    AreaSeparation = 7
    CurveByPoints = 8
    RepeatingDetail = 9
    Insulation = 10
    Cloud = 11


class CoordinatePlaneVisibility:
    Never = 0
    WhenSelected = 1
    Always = 2


class PointOnCurveMeasurementType:
    NonNormalizedCurveParameter = 1
    NormalizedCurveParameter = 2
    SegmentLength = 3
    NormalizedSegmentLength = 4
    ChordLength = 5
    Angle = 6


class PointOnCurveMeasureFrom:
    Beginning = 1
    End = 2


class ImportUnit:
    Default = 0
    Foot = 1
    Inch = 2
    Meter = 3
    Decimeter = 4
    Centimeter = 5
    Millimeter = 6
    Custom = 7


class ImportColorMode:
    Preserved = 0
    Inverted = 1
    BlackAndWhite = 2


class ImportPlacement:
    Site = 0
    Origin = 1
    Centered = 2
    Shared = 3


class SpatialElementType:
    Room = 1
    Area = 2
    Space = 3


class SpatialElementBoundaryLocation:
    Finish = 0
    Center = 1
    CoreBoundary = 2
    CoreCenter = 3


class DocumentType:
    Project = 0
    Family = 1
    Template = 2
    IFC = 3
    BuildingComponent = 4
    Other = 100


class FailureProcessingResult:
    Continue = 0
    ProceedWithCommit = 1
    ProceedWithRollBack = 2
    WaitForUserInput = 3


class ImportExportFileFormat:
    DWG = 1
    DWF = 2
    DWFX = 4
    GBXML = 6
    FBX = 7
    Image = 8
    DGN = 9
    Civil3D = 10
    Inventor = 11
    DXF = 12
    SAT = 13
    IFC = 14
    NWC = 15
    STL = 17


class UnitSystem:
    Metric = 0
    Imperial = 1


class Visibility:
    Visible = 0
    Highlight = 1
    Contextual = 2
    Invisible = 3


class GraphicsStyle(Element):
    @property
    def GraphicsStyleCategory(self) -> Category: ...
    @property
    def GraphicsStyleType(self) -> GraphicsStyleType: ...


class Material(Element):
    @property
    def UseRenderAppearanceForShading(self) -> bool: ...
    @UseRenderAppearanceForShading.setter
    def UseRenderAppearanceForShading(self, value: bool) -> None: ...
    @property
    def Shininess(self) -> int: ...
    @Shininess.setter
    def Shininess(self, shininess: int) -> None: ...
    @property
    def Smoothness(self) -> int: ...
    @Smoothness.setter
    def Smoothness(self, smoothness: int) -> None: ...
    @property
    def Transparency(self) -> int: ...
    @Transparency.setter
    def Transparency(self, transparency: int) -> None: ...
    @property
    def Color(self) -> Color: ...
    @Color.setter
    def Color(self, color: Color) -> None: ...
    @property
    def SurfaceForegroundPatternColor(self) -> Color: ...
    @SurfaceForegroundPatternColor.setter
    def SurfaceForegroundPatternColor(self, color: Color) -> None: ...
    @property
    def CutForegroundPatternColor(self) -> Color: ...
    @CutForegroundPatternColor.setter
    def CutForegroundPatternColor(self, color: Color) -> None: ...
    @property
    def SurfaceBackgroundPatternColor(self) -> Color: ...
    @SurfaceBackgroundPatternColor.setter
    def SurfaceBackgroundPatternColor(self, color: Color) -> None: ...
    @property
    def CutBackgroundPatternColor(self) -> Color: ...
    @CutBackgroundPatternColor.setter
    def CutBackgroundPatternColor(self, color: Color) -> None: ...
    @property
    def CutForegroundPatternId(self) -> ElementId: ...
    @CutForegroundPatternId.setter
    def CutForegroundPatternId(self, patternId: ElementId) -> None: ...
    @property
    def SurfaceForegroundPatternId(self) -> ElementId: ...
    @SurfaceForegroundPatternId.setter
    def SurfaceForegroundPatternId(self, patternId: ElementId) -> None: ...
    @property
    def CutBackgroundPatternId(self) -> ElementId: ...
    @CutBackgroundPatternId.setter
    def CutBackgroundPatternId(self, patternId: ElementId) -> None: ...
    @property
    def SurfaceBackgroundPatternId(self) -> ElementId: ...
    @SurfaceBackgroundPatternId.setter
    def SurfaceBackgroundPatternId(self, patternId: ElementId) -> None: ...
    @property
    def AppearanceAssetId(self) -> ElementId: ...
    @AppearanceAssetId.setter
    def AppearanceAssetId(self, appearanceAssetElementId: ElementId) -> None: ...
    @property
    def StructuralAssetId(self) -> ElementId: ...
    @StructuralAssetId.setter
    def StructuralAssetId(self, assetId: ElementId) -> None: ...
    @property
    def ThermalAssetId(self) -> ElementId: ...
    @ThermalAssetId.setter
    def ThermalAssetId(self, assetId: ElementId) -> None: ...
    @property
    def MaterialClass(self) -> str: ...
    @MaterialClass.setter
    def MaterialClass(self, materialClass: str) -> None: ...
    @property
    def MaterialCategory(self) -> str: ...
    @MaterialCategory.setter
    def MaterialCategory(self, materialCategory: str) -> None: ...
    def Create(document: Document, name: str) -> ElementId: ...
    def IsMaterialOrValidDefault(pElem: Element, materialId: ElementId) -> bool: ...
    def IsNameUnique(aDocument: Document, name: str) -> bool: ...
    def Duplicate(self, name: str) -> Material: ...
    def SetMaterialAspectByPropertySet(self, aspect: MaterialAspect, propertySetId: ElementId) -> None: ...
    def ClearMaterialAspect(self, aspect: MaterialAspect) -> None: ...


class Category(APIObject):
    @property
    def Name(self) -> str: ...
    @property
    def LineColor(self) -> Color: ...
    @LineColor.setter
    def LineColor(self, lineColor: Color) -> None: ...
    @property
    def IsCuttable(self) -> bool: ...
    @property
    def CanAddSubcategory(self) -> bool: ...
    def GetLineWeight(self, graphicsStyleType: GraphicsStyleType) -> Nullable: ...
    def SetLineWeight(self, lineWeight: int, graphicsStyleType: GraphicsStyleType) -> None: ...
    def GetLinePatternId(self, graphicsStyleType: GraphicsStyleType) -> ElementId: ...
    def SetLinePatternId(self, linePatternId: ElementId, graphicsStyleType: GraphicsStyleType) -> None: ...
    def GetGraphicsStyle(self, graphicsStyleType: GraphicsStyleType) -> GraphicsStyle: ...
    @overload
    def GetCategory(document: Document, categoryId: ElementId) -> Category: ...
    @overload
    def GetCategory(document: Document, categoryId: BuiltInCategory) -> Category: ...
    def IsBuiltInCategoryValid(builtInCategory: BuiltInCategory) -> bool: ...
    @property
    def SubCategories(self) -> CategoryNameMap: ...
    @property
    def Parent(self) -> Category: ...
    @property
    def Id(self) -> ElementId: ...
    @property
    def Material(self) -> Material: ...
    @Material.setter
    def Material(self, material: Material) -> None: ...
    @property
    def Visible(self, view: View) -> bool: ...
    @Visible.setter
    def Visible(self, view: View, visible: bool) -> None: ...
    @property
    def AllowsBoundParameters(self) -> bool: ...
    @property
    def AllowsVisibilityControl(self, view: View) -> bool: ...
    @property
    def HasMaterialQuantities(self) -> bool: ...
    @property
    def IsTagCategory(self) -> bool: ...
    @property
    def CategoryType(self) -> CategoryType: ...
    @property
    def IsVisibleInUI(self) -> bool: ...
    def GetHashCode(self) -> int: ...


class LabelUtils:
    @overload
    def GetLabelFor(buildingType: gbXMLBuildingType, document: Document) -> str: ...
    @overload
    def GetLabelFor(unitSymbolType: UnitSymbolType) -> str: ...
    @overload
    def GetLabelFor(unitType: UnitType) -> str: ...
    @overload
    def GetLabelFor(displayUnitType: DisplayUnitType) -> str: ...
    @overload
    def GetLabelFor(pipeFlowState: PipeFlowState, doc: Document) -> str: ...
    @overload
    def GetLabelFor(pipeLossMethodType: PipeLossMethodType, doc: Document) -> str: ...
    @overload
    def GetLabelFor(ductLossMethodType: DuctLossMethodType, doc: Document) -> str: ...
    @overload
    def GetLabelFor(builtInCategory: BuiltInCategory) -> str: ...
    @overload
    def GetLabelFor(builtInParamGroup: BuiltInParameterGroup) -> str: ...
    @overload
    def GetLabelFor(paramType: ParameterType) -> str: ...
    @overload
    def GetLabelFor(builtInParam: BuiltInParameter, language: LanguageType) -> str: ...
    @overload
    def GetLabelFor(builtInParam: BuiltInParameter) -> str: ...
    @property
    def IsValidObject(self) -> bool: ...
    def GetLabelForUnit(unitTypeId: ForgeTypeId) -> str: ...
    def GetLabelForSpec(specTypeId: ForgeTypeId) -> str: ...
    def GetLabelForSymbol(symbolTypeId: ForgeTypeId) -> str: ...
    def GetStructuralSectionShapeName(shape: StructuralSectionShape) -> str: ...
    def Dispose(self) -> None: ...


class CategoryType:
    Invalid = 0
    Model = 1
    Annotation = 2
    Internal = 4
    AnalyticalModel = 5


class GraphicsStyleType:
    Projection = 1
    Cut = 2


class MaterialAspect:
    Structural = 0
    Thermal = 1


class UnitSymbolType:
    UST_NONE = 0
    UST_M = 1
    UST_CM = 101
    UST_MM = 201
    UST_LF = 301
    UST_FOOT_SINGLE_QUOTE = 302
    UST_FT = 303
    UST_INCH_DOUBLE_QUOTE = 601
    UST_IN = 602
    UST_ACRES = 701
    UST_HECTARES = 801
    UST_CY = 1001
    UST_SF = 1101
    UST_FT_SUP_2 = 1102
    UST_FT_CARET_2 = 1103
    UST_M_SUP_2 = 1201
    UST_M_CARET_2 = 1202
    UST_CF = 1301
    UST_FT_SUP_3 = 1302
    UST_FT_CARET_3 = 1303
    UST_M_SUP_3 = 1401
    UST_M_CARET_3 = 1402
    UST_DEGREE_SYMBOL = 1501
    UST_PERCENT_SIGN = 1901
    UST_IN_SUP_2 = 2001
    UST_IN_CARET_2 = 2002
    UST_CM_SUP_2 = 2101
    UST_CM_CARET_2 = 2102
    UST_MM_SUP_2 = 2201
    UST_MM_CARET_2 = 2202
    UST_IN_SUP_3 = 2301
    UST_IN_CARET_3 = 2302
    UST_CM_SUP_3 = 2401
    UST_CM_CARET_3 = 2402
    UST_MM_SUP_3 = 2501
    UST_MM_CARET_3 = 2502
    UST_L = 2601
    UST_GAL = 2701
    UST_KG_PER_CU_M = 2801
    UST_LB_MASS_PER_CU_FT = 2901
    UST_LBM_PER_CU_FT = 2902
    UST_LB_MASS_PER_CU_IN = 3001
    UST_LBM_PER_CU_IN = 3002
    UST_BTU = 3101
    UST_CAL = 3201
    UST_KCAL = 3301
    UST_JOULE = 3401
    UST_KWH = 3501
    UST_THERM = 3601
    UST_IN_WG_PER_100FT = 3701
    UST_PASCAL_PER_M = 3801
    UST_WATT = 3901
    UST_KILOWATT = 4001
    UST_BTU_PER_S = 4101
    UST_BTU_PER_H = 4201
    UST_CAL_PER_S = 4301
    UST_KCAL_PER_S = 4401
    UST_WATT_PER_SQ_FT = 4501
    UST_WATT_PER_SQ_M = 4601
    UST_IN_WG = 4701
    UST_PASCAL = 4801
    UST_KILOPASCAL = 4901
    UST_MEGAPASCAL = 5001
    UST_PSI = 5101
    UST_LB_FORCE_PER_SQ_IN = 5102
    UST_PSIG = 5103
    UST_PSIA = 5104
    UST_LBF_PER_SQ_IN = 5105
    UST_IN_HG = 5201
    UST_MM_HG = 5301
    UST_ATM = 5401
    UST_BAR = 5501
    UST_DEGREE_F = 5601
    UST_DEGREE_C = 5701
    UST_KELVIN = 5801
    UST_DEGREE_R = 5901
    UST_FT_PER_MIN = 6001
    UST_FPM = 6002
    UST_M_PER_S = 6101
    UST_CM_PER_MIN = 6201
    UST_CU_FT_PER_MIN = 6301
    UST_CFM = 6302
    UST_L_PER_S = 6401
    UST_LPS = 6402
    UST_CU_M_PER_S = 6501
    UST_CMS = 6502
    UST_CU_M_PER_H = 6601
    UST_CMH = 6602
    UST_GAL_PER_MIN = 6701
    UST_GPM = 6702
    UST_USGPM = 6703
    UST_GAL_PER_H = 6801
    UST_GPH = 6802
    UST_USGPH = 6803
    UST_AMPERE = 6901
    UST_KILOAMPERE = 7001
    UST_MILLIAMPERE = 7101
    UST_VOLT = 7201
    UST_KILOVOLT = 7301
    UST_MILLIVOLT = 7401
    UST_HZ = 7501
    UST_CPS = 7601
    UST_LX = 7701
    UST_FC = 7801
    UST_FTC = 7802
    UST_FL = 7901
    UST_FL_LOWERCASE = 7902
    UST_FTL = 7903
    UST_CD_PER_SQ_M = 8001
    UST_CD = 8101
    UST_LM = 8301
    UST_VOLTAMPERE = 8401
    UST_KILOVOLTAMPERE = 8501
    UST_HP = 8601
    UST_N = 8701
    UST_DA_N = 8801
    UST_K_N = 8901
    UST_M_N = 9001
    UST_KIP = 9101
    UST_KGF = 9201
    UST_TF = 9301
    UST_LB_FORCE = 9401
    UST_LBF = 9402
    UST_N_PER_M = 9501
    UST_DA_N_PER_M = 9601
    UST_K_N_PER_M = 9701
    UST_M_N_PER_M = 9801
    UST_KIP_PER_FT = 9901
    UST_KGF_PER_M = 10001
    UST_TF_PER_M = 10101
    UST_LB_FORCE_PER_FT = 10201
    UST_LBF_PER_FT = 10202
    UST_N_PER_M_SUP_2 = 10301
    UST_DA_N_PER_M_SUP_2 = 10401
    UST_K_N_PER_M_SUP_2 = 10501
    UST_M_N_PER_M_SUP_2 = 10601
    UST_KSF = 10701
    UST_KIP_PER_SQ_FT = 10702
    UST_KGF_PER_M_SUP_2 = 10801
    UST_TF_PER_M_SUP_2 = 10901
    UST_PSF = 11001
    UST_LB_FORCE_PER_SQ_FT = 11002
    UST_LBF_PER_SQ_FT = 11003
    UST_N_DASH_M = 11101
    UST_DA_N_DASH_M = 11201
    UST_K_N_DASH_M = 11301
    UST_M_N_DASH_M = 11401
    UST_KIP_DASH_FT = 11501
    UST_KGF_DASH_M = 11601
    UST_TF_DASH_M = 11701
    UST_LB_FORCE_DASH_FT = 11801
    UST_LBF_DASH_FT = 11802
    UST_M_PER_K_N = 11901
    UST_FT_PER_KIP = 12001
    UST_M_SUP_2_PER_K_N = 12101
    UST_FT_SUP_2_PER_KIP = 12201
    UST_M_SUP_3_PER_K_N = 12301
    UST_FT_SUP_3_PER_KIP = 12401
    UST_INV_K_N = 12501
    UST_INV_KIP = 12601
    UST_FTH2O_PER_100FT = 12701
    UST_FT_OF_WATER_PER_100FT = 12702
    UST_FEET_OF_WATER_PER_100FT = 12703
    UST_FTH2O = 12801
    UST_FT_OF_WATER = 12802
    UST_FEET_OF_WATER = 12803
    UST_PA_S = 12901
    UST_LB_FORCE_PER_FT_S = 13001
    UST_LBM_PER_FT_S = 13002
    UST_CP = 13101
    UST_FT_PER_S = 13201
    UST_FPS = 13202
    UST_KSI = 13301
    UST_KIP_PER_SQ_IN = 13302
    UST_KN_PER_M_SUP_3 = 13401
    UST_LB_FORCE_PER_CU_FT = 13501
    UST_LBF_PER_CU_FT = 13502
    UST_KIP_PER_IN_SUP_3 = 13601
    UST_INV_DEGREE_F = 13701
    UST_INV_DEGREE_C = 13801
    UST_N_DASH_M_PER_M = 13901
    UST_DA_N_DASH_M_PER_M = 14001
    UST_K_N_DASH_M_PER_M = 14101
    UST_M_N_DASH_M_PER_M = 14201
    UST_KIP_DASH_FT_PER_FT = 14301
    UST_KGF_DASH_M_PER_M = 14401
    UST_TF_DASH_M_PER_M = 14501
    UST_LB_FORCE_DASH_FT_PER_FT = 14601
    UST_LBF_DASH_FT_PER_FT = 14602
    UST_LB_FORCE_PER_FT_H = 14701
    UST_LBM_PER_FT_H = 14702
    UST_KIPS_PER_IN = 14801
    UST_KIPS_PER_CU_FT = 14901
    UST_KIP_FT_PER_DEGREE = 15001
    UST_K_N_M_PER_DEGREE = 15101
    UST_KIP_FT_PER_DEGREE_PER_FT = 15201
    UST_K_N_M_PER_DEGREE_PER_M = 15301
    UST_WATT_PER_SQ_M_K = 15401
    UST_BTU_PER_H_SQ_FT_DEGREE_F = 15501
    UST_CFM_PER_SQ_FT = 15601
    UST_CFM_PER_SF = 15602
    UST_LPS_PER_SQ_M = 15701
    UST_L_PER_S_SQ_M = 15702
    UST_COLON_10 = 15801
    UST_COLON_12 = 15901
    UST_SLOPE_DEGREE_SYMBOL = 16001
    UST_WATT_PER_CU_FT = 16401
    UST_WATT_PER_CU_M = 16501
    UST_BTU_PER_H_SQ_FT = 16601
    UST_BTU_PER_H_CU_FT = 16701
    UST_TON = 16801
    UST_TON_OF_REFRIGERATION = 16802
    UST_CFM_PER_CU_FT = 16901
    UST_CFM_PER_CF = 16902
    UST_L_PER_S_CU_M = 17001
    UST_CFM_PER_TON = 17101
    UST_L_PER_S_KW = 17201
    UST_SQ_FT_PER_TON = 17301
    UST_SF_PER_TON = 17302
    UST_SQ_M_PER_KW = 17401
    UST_DOLLAR = 17501
    UST_EURO_SUFFIX = 17502
    UST_EURO_PREFIX = 17503
    UST_POUND = 17504
    UST_YEN = 17505
    UST_CHINESE_HONG_KONG_SAR = 17506
    UST_WON = 17507
    UST_SHEQEL = 17508
    UST_DONG = 17509
    UST_BAHT = 17510
    UST_KRONER = 17511
    UST_LM_PER_W = 17601
    UST_SF_PER_MBH = 17701
    UST_SF_PER_KBTU_PER_H = 17702
    UST_SQ_FT_PER_MBH = 17703
    UST_SQ_FT_PER_KBTU_PER_H = 17704
    UST_K_N_PER_CM_SUP_2 = 17801
    UST_N_PER_MM_SUP_2 = 17901
    UST_K_N_PER_MM_SUP_2 = 18001
    UST_ONE_COLON = 18201
    UST_H_SQ_FT_DEGREE_F_PER_BTU = 18401
    UST_SQ_M_K_PER_WATT = 18501
    UST_BTU_PER_F = 18601
    UST_J_PER_KELVIN = 18701
    UST_KJ_PER_KELVIN = 18801
    UST_KGM = 18901
    UST_TM = 19001
    UST_LB_MASS = 19101
    UST_LBM = 19102
    UST_M_PER_SQ_S = 19201
    UST_KM_PER_SQ_S = 19301
    UST_IN_PER_SQ_S = 19401
    UST_FT_PER_SQ_S = 19501
    UST_MI_PER_SQ_S = 19601
    UST_FT_SUP_4 = 19701
    UST_IN_SUP_4 = 19801
    UST_MM_SUP_4 = 19901
    UST_CM_SUP_4 = 20001
    UST_M_SUP_4 = 20101
    UST_FT_SUP_6 = 20201
    UST_IN_SUP_6 = 20301
    UST_MM_SUP_6 = 20401
    UST_CM_SUP_6 = 20501
    UST_M_SUP_6 = 20601
    UST_SQ_FT_PER_FT = 20701
    UST_SQ_IN_PER_FT = 20801
    UST_SQ_MM_PER_M = 20901
    UST_SQ_CM_PER_M = 21001
    UST_SQ_M_PER_M = 21101
    UST_KGM_PER_M = 21201
    UST_LB_MASS_PER_FT = 21301
    UST_LBM_PER_FT = 21302
    UST_RAD = 21401
    UST_GRAD = 21501
    UST_RAD_PER_S = 21601
    UST_MS = 21701
    UST_S = 21801
    UST_MIN = 21901
    UST_H = 22001
    UST_KM_PER_H = 22101
    UST_MI_PER_H = 22201
    UST_KJ = 22301
    UST_KGM_PER_SQ_M = 22401
    UST_LBM_PER_SQ_FT = 22501
    UST_WATTS_PER_METER_KELVIN = 22601
    UST_J_PER_G_CELSIUS = 22701
    UST_J_PER_G = 22801
    UST_NG_PER_PA_S_SQ_M = 22901
    UST_OHM_M = 23001
    UST_BTU_PER_H_FT_DEGREE_F = 23101
    UST_BTU_PER_LB_DEGREE_F = 23201
    UST_BTU_PER_LB = 23301
    UST_GR_PER_H_SQ_FT_IN_HG = 23401
    UST_PER_MILLE_SIGN = 23501
    UST_DM = 23601
    UST_J_PER_KG_CELSIUS = 23701
    UST_UM_PER_M_C = 23801
    UST_UIN_PER_IN_F = 23901
    UST_USTONNES_MASS_TONS = 24001
    UST_USTONNES_MASS_T = 24002
    UST_USTONNES_MASS_ST = 24003
    UST_USTONNES_FORCE_TONSF = 24101
    UST_USTONNES_FORCE_STF = 24102
    UST_USTONNES_FORCE_AS_MASS_TONS = 24103
    UST_USTONNES_FORCE_AS_MASS_T = 24104
    UST_USTONNES_FORCE_AS_MASS_ST = 24105
    UST_L_PER_M = 24201
    UST_LPM = 24202
    UST_DEGREE_F_DIFFERENCE = 24301
    UST_DELTA_DEGREE_F = 24302
    UST_DEGREE_C_DIFFERENCE = 24401
    UST_DELTA_DEGREE_C = 24402
    UST_KELVIN_DIFFERENCE = 24501
    UST_DELTA_KELVIN = 24502
    UST_DEGREE_R_DIFFERENCE = 24601
    UST_DELTA_DEGREE_R = 24602
    UST_US_SURVEY_FT = 60501
    UST_CUSTOM = -1


class LineAndTextAttrSymbol(ElementType):


class TextElementType(LineAndTextAttrSymbol):


class TextElement(Element):
    @property
    def Symbol(self) -> TextElementType: ...
    @property
    def BaseDirection(self) -> XYZ: ...
    @property
    def UpDirection(self) -> XYZ: ...
    @property
    def Height(self) -> float: ...
    @property
    def Width(self) -> float: ...
    @Width.setter
    def Width(self, width: float) -> None: ...
    @property
    def Coord(self) -> XYZ: ...
    @Coord.setter
    def Coord(self, position: XYZ) -> None: ...
    @property
    def Text(self) -> str: ...
    @Text.setter
    def Text(self, text: str) -> None: ...
    @property
    def HorizontalAlignment(self) -> HorizontalTextAlignment: ...
    @HorizontalAlignment.setter
    def HorizontalAlignment(self, alignment: HorizontalTextAlignment) -> None: ...
    @property
    def VerticalAlignment(self) -> VerticalTextAlignment: ...
    @VerticalAlignment.setter
    def VerticalAlignment(self, alignment: VerticalTextAlignment) -> None: ...
    @property
    def KeepRotatedTextReadable(self) -> bool: ...
    @KeepRotatedTextReadable.setter
    def KeepRotatedTextReadable(self, value: bool) -> None: ...
    @property
    def IsTextWrappingActive(self) -> bool: ...
    @overload
    def GetMinimumAllowedWidth(cdda: Document, typeId: ElementId) -> float: ...
    @overload
    def GetMinimumAllowedWidth(self) -> float: ...
    @overload
    def GetMaximumAllowedWidth(cdda: Document, typeId: ElementId) -> float: ...
    @overload
    def GetMaximumAllowedWidth(self) -> float: ...


class TextNoteType(TextElementType):


class TextNoteOptions:
    @overload
    def __init__(self, typeId: ElementId): ...
    @overload
    def __init__(self): ...
    @property
    def TypeId(self) -> ElementId: ...
    @TypeId.setter
    def TypeId(self, typeId: ElementId) -> None: ...
    @property
    def Rotation(self) -> float: ...
    @Rotation.setter
    def Rotation(self, rotation: float) -> None: ...
    @property
    def HorizontalAlignment(self) -> HorizontalTextAlignment: ...
    @HorizontalAlignment.setter
    def HorizontalAlignment(self, horizontalAlignment: HorizontalTextAlignment) -> None: ...
    @property
    def VerticalAlignment(self) -> VerticalTextAlignment: ...
    @VerticalAlignment.setter
    def VerticalAlignment(self, verticalAlignment: VerticalTextAlignment) -> None: ...
    @property
    def KeepRotatedTextReadable(self) -> bool: ...
    @KeepRotatedTextReadable.setter
    def KeepRotatedTextReadable(self, keepRotatedTextReadable: bool) -> None: ...
    @property
    def IsValidObject(self) -> bool: ...
    def Dispose(self) -> None: ...


class TextNote(TextElement):
    @property
    def TextNoteType(self) -> TextNoteType: ...
    @TextNoteType.setter
    def TextNoteType(self, A_0: TextNoteType) -> None: ...
    @property
    def LeaderCount(self) -> int: ...
    @property
    def LeaderLeftAttachment(self) -> LeaderAtachement: ...
    @LeaderLeftAttachment.setter
    def LeaderLeftAttachment(self, attachment: LeaderAtachement) -> None: ...
    @property
    def LeaderRightAttachment(self) -> LeaderAtachement: ...
    @LeaderRightAttachment.setter
    def LeaderRightAttachment(self, attachment: LeaderAtachement) -> None: ...
    @overload
    def Create(document: Document, viewId: ElementId, position: XYZ, width: float, text: str, options: TextNoteOptions) -> TextNote: ...
    @overload
    def Create(document: Document, viewId: ElementId, position: XYZ, width: float, text: str, typeId: ElementId) -> TextNote: ...
    @overload
    def Create(document: Document, viewId: ElementId, position: XYZ, text: str, options: TextNoteOptions) -> TextNote: ...
    @overload
    def Create(document: Document, viewId: ElementId, position: XYZ, text: str, typeId: ElementId) -> TextNote: ...
    def GetLeaders(self) -> List[Leader]: ...
    def AddLeader(self, leaderType: TextNoteLeaderTypes) -> Leader: ...
    def RemoveLeaders(self) -> None: ...
    def GetFormattedText(self) -> FormattedText: ...
    def SetFormattedText(self, formattedText: FormattedText) -> None: ...


class Leader(APIObject):
    @property
    def End(self) -> XYZ: ...
    @End.setter
    def End(self, xyz: XYZ) -> None: ...
    @property
    def Elbow(self) -> XYZ: ...
    @Elbow.setter
    def Elbow(self, xyz: XYZ) -> None: ...
    @property
    def Anchor(self) -> XYZ: ...
    @property
    def LeaderShape(self) -> LeaderShape: ...
    @property
    def IsValidObject(self) -> bool: ...


class LeaderArray(APIObject):
    def __init__(self): ...
    def Clear(self) -> None: ...
    @property
    def Size(self) -> int: ...
    @property
    def IsEmpty(self) -> bool: ...
    def ForwardIterator(self) -> LeaderArrayIterator: ...
    def ReverseIterator(self) -> LeaderArrayIterator: ...
    def GetEnumerator(self) -> IEnumerator: ...
    @property
    def Item(self, index: int) -> Leader: ...
    @Item.setter
    def Item(self, index: int, item: Leader) -> None: ...
    def Append(self, item: Leader) -> None: ...
    def Insert(self, item: Leader, index: int) -> None: ...


class LeaderArrayIterator(APIObject):
    def __init__(self): ...
    @property
    def Current(self) -> Object: ...
    def MoveNext(self) -> bool: ...
    def Reset(self) -> None: ...


class LeaderShape:
    Straight = 0
    Kinked = 1
    Arc = 2


class Dimension(Element):
    @property
    def References(self) -> ReferenceArray: ...
    @property
    def Curve(self) -> Curve: ...
    @property
    def View(self) -> View: ...
    @property
    def DimensionType(self) -> DimensionType: ...
    @DimensionType.setter
    def DimensionType(self, newType: DimensionType) -> None: ...
    @property
    def Name(self) -> str: ...
    @Name.setter
    def Name(self, value: str) -> None: ...
    @property
    def FamilyLabel(self) -> FamilyParameter: ...
    @FamilyLabel.setter
    def FamilyLabel(self, famPara: FamilyParameter) -> None: ...
    @property
    def DimensionShape(self) -> DimensionShape: ...
    @property
    def NumberOfSegments(self) -> int: ...
    @property
    def Segments(self) -> DimensionSegmentArray: ...
    @property
    def AreSegmentsEqual(self) -> bool: ...
    @AreSegmentsEqual.setter
    def AreSegmentsEqual(self, equal: bool) -> None: ...
    @property
    def Value(self) -> Nullable: ...
    @property
    def ValueString(self) -> str: ...
    @property
    def IsLocked(self) -> bool: ...
    @IsLocked.setter
    def IsLocked(self, lock: bool) -> None: ...
    @property
    def Prefix(self) -> str: ...
    @Prefix.setter
    def Prefix(self, prefix: str) -> None: ...
    @property
    def Suffix(self) -> str: ...
    @Suffix.setter
    def Suffix(self, suffix: str) -> None: ...
    @property
    def Above(self) -> str: ...
    @Above.setter
    def Above(self, above: str) -> None: ...
    @property
    def Below(self) -> str: ...
    @Below.setter
    def Below(self, below: str) -> None: ...
    @property
    def ValueOverride(self) -> str: ...
    @ValueOverride.setter
    def ValueOverride(self, below: str) -> None: ...
    @property
    def HasLeader(self) -> bool: ...
    @HasLeader.setter
    def HasLeader(self, newValue: bool) -> None: ...
    @property
    def LeaderEndPosition(self) -> XYZ: ...
    @LeaderEndPosition.setter
    def LeaderEndPosition(self, leaderPnt: XYZ) -> None: ...
    @property
    def Origin(self) -> XYZ: ...
    @property
    def TextPosition(self) -> XYZ: ...
    @TextPosition.setter
    def TextPosition(self, position: XYZ) -> None: ...
    @property
    def AreReferencesAvailable(self) -> bool: ...
    @property
    def IsValid(self) -> bool: ...
    def ResetTextPosition(self) -> None: ...
    def IsTextPositionAdjustable(self) -> bool: ...


class DimensionSegment(APIObject):
    @property
    def Origin(self) -> XYZ: ...
    @property
    def Value(self) -> Nullable: ...
    @property
    def ValueString(self) -> str: ...
    @property
    def IsLocked(self) -> bool: ...
    @IsLocked.setter
    def IsLocked(self, lock: bool) -> None: ...
    @property
    def Prefix(self) -> str: ...
    @Prefix.setter
    def Prefix(self, prefix: str) -> None: ...
    @property
    def Suffix(self) -> str: ...
    @Suffix.setter
    def Suffix(self, suffix: str) -> None: ...
    @property
    def Above(self) -> str: ...
    @Above.setter
    def Above(self, above: str) -> None: ...
    @property
    def Below(self) -> str: ...
    @Below.setter
    def Below(self, below: str) -> None: ...
    @property
    def ValueOverride(self) -> str: ...
    @ValueOverride.setter
    def ValueOverride(self, below: str) -> None: ...
    @property
    def LeaderEndPosition(self) -> XYZ: ...
    @LeaderEndPosition.setter
    def LeaderEndPosition(self, position: XYZ) -> None: ...
    def IsTextPositionAdjustable(self) -> bool: ...
    @property
    def TextPosition(self) -> XYZ: ...
    @TextPosition.setter
    def TextPosition(self, position: XYZ) -> None: ...
    def ResetTextPosition(self) -> None: ...


class DimensionSegmentArray(APIObject):
    def __init__(self): ...
    def Clear(self) -> None: ...
    @property
    def Size(self) -> int: ...
    @property
    def IsEmpty(self) -> bool: ...
    def ForwardIterator(self) -> DimensionSegmentArrayIterator: ...
    def ReverseIterator(self) -> DimensionSegmentArrayIterator: ...
    def GetEnumerator(self) -> IEnumerator: ...
    @property
    def Item(self, index: int) -> DimensionSegment: ...
    @Item.setter
    def Item(self, index: int, item: DimensionSegment) -> None: ...
    def Append(self, item: DimensionSegment) -> None: ...
    def Insert(self, item: DimensionSegment, index: int) -> None: ...


class DimensionSegmentArrayIterator(APIObject):
    def __init__(self): ...
    @property
    def Current(self) -> Object: ...
    def MoveNext(self) -> bool: ...
    def Reset(self) -> None: ...


class DimensionType(ElementType):
    @property
    def StyleType(self) -> DimensionStyleType: ...
    @property
    def AlternateUnits(self) -> AlternateUnits: ...
    @AlternateUnits.setter
    def AlternateUnits(self, alternateUnits: AlternateUnits) -> None: ...
    @property
    def AlternateUnitsPrefix(self) -> str: ...
    @AlternateUnitsPrefix.setter
    def AlternateUnitsPrefix(self, prefix: str) -> None: ...
    @property
    def AlternateUnitsSuffix(self) -> str: ...
    @AlternateUnitsSuffix.setter
    def AlternateUnitsSuffix(self, prefix: str) -> None: ...
    @property
    def UnitType(self) -> UnitType: ...
    def GetAlternateUnitsFormatOptions(self) -> FormatOptions: ...
    def SetAlternateUnitsFormatOptions(self, formatOptions: FormatOptions) -> None: ...
    def GetUnitsFormatOptions(self) -> FormatOptions: ...
    def SetUnitsFormatOptions(self, formatOptions: FormatOptions) -> None: ...
    def GetSpecTypeId(self) -> ForgeTypeId: ...
    def GetEqualityFormula(self) -> List[DimensionEqualityLabelFormatting]: ...
    def SetEqualityFormula(self, formattingArr: List[DimensionEqualityLabelFormatting]) -> None: ...
    def CanHaveEqualityFormula(self) -> bool: ...
    def GetOrdinateDimensionSetting(self) -> OrdinateDimensionSetting: ...
    def SetOrdinateDimensionSetting(self, ordinateDimSetting: OrdinateDimensionSetting) -> None: ...
    def CanHaveOrdinateDimensionSetting(self) -> bool: ...


class ElementSet(APIObject):
    def __init__(self): ...
    def Clear(self) -> None: ...
    @property
    def Size(self) -> int: ...
    @property
    def IsEmpty(self) -> bool: ...
    def ForwardIterator(self) -> ElementSetIterator: ...
    def ReverseIterator(self) -> ElementSetIterator: ...
    def GetEnumerator(self) -> IEnumerator: ...
    def Contains(self, item: Element) -> bool: ...
    def Insert(self, item: Element) -> bool: ...
    def Erase(self, item: Element) -> int: ...


class ElementSetIterator(APIObject):
    def __init__(self): ...
    @property
    def Current(self) -> Object: ...
    def MoveNext(self) -> bool: ...
    def Reset(self) -> None: ...


class ReferenceArray(APIObject):
    def __init__(self): ...
    def Clear(self) -> None: ...
    @property
    def Size(self) -> int: ...
    @property
    def IsEmpty(self) -> bool: ...
    def ForwardIterator(self) -> ReferenceArrayIterator: ...
    def ReverseIterator(self) -> ReferenceArrayIterator: ...
    def GetEnumerator(self) -> IEnumerator: ...
    @property
    def Item(self, index: int) -> Reference: ...
    @Item.setter
    def Item(self, index: int, item: Reference) -> None: ...
    def Append(self, item: Reference) -> None: ...
    def Insert(self, item: Reference, index: int) -> None: ...


class ReferenceArrayIterator(APIObject):
    def __init__(self): ...
    @property
    def Current(self) -> Object: ...
    def MoveNext(self) -> bool: ...
    def Reset(self) -> None: ...


class Parameter(APIObject):
    @property
    def Definition(self) -> Definition: ...
    @property
    def StorageType(self) -> StorageType: ...
    @property
    def IsReadOnly(self) -> bool: ...
    @property
    def UserModifiable(self) -> bool: ...
    @property
    def HasValue(self) -> bool: ...
    @overload
    def AsValueString(self, formatOptions: FormatOptions) -> str: ...
    @overload
    def AsValueString(self) -> str: ...
    def SetValueString(self, valueString: str) -> bool: ...
    @property
    def DisplayUnitType(self) -> DisplayUnitType: ...
    def GetUnitTypeId(self) -> ForgeTypeId: ...
    def AsString(self) -> str: ...
    def AsInteger(self) -> int: ...
    def AsDouble(self) -> float: ...
    def AsElementId(self) -> ElementId: ...
    @overload
    def Set(self, value: ElementId) -> bool: ...
    @overload
    def Set(self, value: float) -> bool: ...
    @overload
    def Set(self, value: int) -> bool: ...
    @overload
    def Set(self, value: str) -> bool: ...
    def ClearValue(self) -> bool: ...
    @property
    def Element(self) -> Element: ...
    @property
    def IsShared(self) -> bool: ...
    @property
    def GUID(self) -> Guid: ...
    @property
    def Id(self) -> ElementId: ...
    def AssociateWithGlobalParameter(self, gpId: ElementId) -> None: ...
    def DissociateFromGlobalParameter(self) -> None: ...
    def CanBeAssociatedWithGlobalParameter(self, gpId: ElementId) -> bool: ...
    def CanBeAssociatedWithGlobalParameters(self) -> bool: ...
    def GetAssociatedGlobalParameter(self) -> ElementId: ...


class Definition:
    @property
    def Name(self) -> str: ...
    @property
    def ParameterType(self) -> ParameterType: ...
    @property
    def ParameterGroup(self) -> BuiltInParameterGroup: ...
    @property
    def UnitType(self) -> UnitType: ...
    def GetSpecTypeId(self) -> ForgeTypeId: ...


class SubTransaction:
    def __init__(self, document: Document): ...
    @property
    def IsValidObject(self) -> bool: ...
    def Start(self) -> TransactionStatus: ...
    def Commit(self) -> TransactionStatus: ...
    def RollBack(self) -> TransactionStatus: ...
    def GetStatus(self) -> TransactionStatus: ...
    def HasStarted(self) -> bool: ...
    def HasEnded(self) -> bool: ...
    def Dispose(self) -> None: ...


class AlternateUnits:
    #None = 0
    Right = 1
    Below = 2


class DimensionStyleType:
    Linear = 0
    Angular = 1
    Radial = 2
    ArcLength = 3
    SpotElevation = 4
    SpotCoordinate = 5
    LinearFixed = 7
    SpotSlope = 8
    Diameter = 9
    AlignmentStationLabel = 10


class TransactionStatus:
    Uninitialized = 0
    Started = 1
    RolledBack = 2
    Committed = 3
    Pending = 4
    Error = 5
    Proceed = 6


class LocationPoint(Location):
    @property
    def Point(self) -> XYZ: ...
    @Point.setter
    def Point(self, point: XYZ) -> None: ...
    @property
    def Rotation(self) -> float: ...


class InsertableObject(ElementType):


class FamilySymbol(InsertableObject):
    @property
    def StructuralMaterialType(self) -> StructuralMaterialType: ...
    def GetFamilyPointLocations(self) -> List[FamilyPointLocation]: ...
    @property
    def Family(self) -> Family: ...
    @property
    def IsActive(self) -> bool: ...
    def Activate(self) -> None: ...
    def GetThermalProperties(self) -> FamilyThermalProperties: ...
    def SetThermalProperties(self, thermalProperties: FamilyThermalProperties) -> None: ...
    def HasThermalProperties(self) -> bool: ...
    def GetStructuralSection(self) -> StructuralSection: ...
    def SetStructuralSection(self, structuralSection: StructuralSection) -> None: ...
    def CanHaveStructuralSection(self) -> bool: ...


class SpatialElementTag(Element):
    @property
    def Location(self) -> Location: ...
    @property
    def IsOrphaned(self) -> bool: ...
    @property
    def IsTaggingLink(self) -> bool: ...
    @property
    def HasLeader(self) -> bool: ...
    @HasLeader.setter
    def HasLeader(self, value: bool) -> None: ...
    @property
    def HasElbow(self) -> bool: ...
    @property
    def TagOrientation(self) -> SpatialElementTagOrientation: ...
    @TagOrientation.setter
    def TagOrientation(self, orientation: SpatialElementTagOrientation) -> None: ...
    @property
    def TagText(self) -> str: ...
    @property
    def TagHeadPosition(self) -> XYZ: ...
    @TagHeadPosition.setter
    def TagHeadPosition(self, point: XYZ) -> None: ...
    @property
    def LeaderEnd(self) -> XYZ: ...
    @LeaderEnd.setter
    def LeaderEnd(self, point: XYZ) -> None: ...
    @property
    def LeaderElbow(self) -> XYZ: ...
    @LeaderElbow.setter
    def LeaderElbow(self, point: XYZ) -> None: ...
    @property
    def View(self) -> View: ...


class SpatialElementTagOrientation:
    Horizontal = 0
    Vertical = 1
    Model = 2


class IConnector:
    @property
    def CoordinateSystem(self) -> Transform: ...
    @property
    def Origin(self) -> XYZ: ...
    @property
    def Domain(self) -> Domain: ...
    @property
    def Shape(self) -> ConnectorProfileType: ...
    @property
    def Width(self) -> float: ...
    @property
    def Height(self) -> float: ...
    @property
    def Radius(self) -> float: ...


class Transform(APIObject):
    def __init__(self, source: Transform): ...
    @property
    def BasisX(self) -> XYZ: ...
    @BasisX.setter
    def BasisX(self, A_0: XYZ) -> None: ...
    @property
    def BasisY(self) -> XYZ: ...
    @BasisY.setter
    def BasisY(self, A_0: XYZ) -> None: ...
    @property
    def BasisZ(self) -> XYZ: ...
    @BasisZ.setter
    def BasisZ(self, A_0: XYZ) -> None: ...
    @property
    def Basis(self, idx: int) -> XYZ: ...
    @Basis.setter
    def Basis(self, idx: int, __unnamed001: XYZ) -> None: ...
    @property
    def Origin(self) -> XYZ: ...
    @Origin.setter
    def Origin(self, A_0: XYZ) -> None: ...
    @property
    def Identity() -> Transform: ...
    def CreateTranslation(vector: XYZ) -> Transform: ...
    def CreateRotation(axis: XYZ, angle: float) -> Transform: ...
    def CreateRotationAtPoint(axis: XYZ, angle: float, origin: XYZ) -> Transform: ...
    def CreateReflection(plane: Plane) -> Transform: ...
    def OfPoint(self, point: XYZ) -> XYZ: ...
    def OfVector(self, vec: XYZ) -> XYZ: ...
    @property
    def IsIdentity(self) -> bool: ...
    @property
    def IsTranslation(self) -> bool: ...
    @property
    def Scale(self) -> float: ...
    @property
    def HasReflection(self) -> bool: ...
    @property
    def IsConformal(self) -> bool: ...
    @property
    def Determinant(self) -> float: ...
    @property
    def Inverse(self) -> Transform: ...
    def op_Multiply(left: Transform, right: Transform) -> Transform: ...
    def Multiply(self, right: Transform) -> Transform: ...
    def ScaleBasis(self, scale: float) -> Transform: ...
    def ScaleBasisAndOrigin(self, scale: float) -> Transform: ...
    def AlmostEqual(self, right: Transform) -> bool: ...


class FabricationItemFile:
    def GetImage(self) -> Bitmap: ...
    @property
    def Identifier(self) -> str: ...
    @property
    def IsUsed(self) -> bool: ...
    @property
    def IsValidObject(self) -> bool: ...
    def IsValid(self) -> bool: ...
    def IsLoaded(self) -> bool: ...
    def Dispose(self) -> None: ...


class FabricationServiceButton:
    def GetImage(self) -> Bitmap: ...
    def GetConditionImage(self, condition: int) -> Bitmap: ...
    @property
    def Name(self) -> str: ...
    @property
    def Code(self) -> str: ...
    @property
    def ConditionCount(self) -> int: ...
    @property
    def ServiceId(self) -> int: ...
    @property
    def GroupIndex(self) -> int: ...
    @property
    def ButtonIndex(self) -> int: ...
    @property
    def IsAHanger(self) -> bool: ...
    @property
    def IsStraight(self) -> bool: ...
    @property
    def IsValidObject(self) -> bool: ...
    def IsValidConditionIndex(button: FabricationServiceButton, condition: int) -> bool: ...
    def GetConditionDescription(self, condition: int) -> str: ...
    def GetConditionLowerValue(self, condition: int) -> float: ...
    def GetConditionUpperValue(self, condition: int) -> float: ...
    def IsUnrestrictedCondition(self, condition: int) -> bool: ...
    def IsValid(self) -> bool: ...
    def IsExcluded(self) -> bool: ...
    def GetConditionName(self, condition: int) -> str: ...
    def ContainsFabricationPartType(self, partType: FabricationPartType) -> bool: ...
    def Dispose(self) -> None: ...


class MEPModel(APIObject):
    @property
    def ElectricalSystems(self) -> ElectricalSystemSet: ...
    @property
    def AssignedElectricalSystems(self) -> ElectricalSystemSet: ...
    @property
    def ConnectorManager(self) -> ConnectorManager: ...
    @property
    def IsValidObject(self) -> bool: ...
    def GetElectricalSystems(self) -> ISet: ...
    def GetAssignedElectricalSystems(self) -> ISet: ...


class ConnectorManager:
    @property
    def Connectors(self) -> ConnectorSet: ...
    @property
    def UnusedConnectors(self) -> ConnectorSet: ...
    @property
    def Owner(self) -> Element: ...
    @property
    def IsValidObject(self) -> bool: ...
    def Lookup(self, index: int) -> Connector: ...
    def Dispose(self) -> None: ...


class MEPSystem(Element):
    @property
    def ConnectorManager(self) -> ConnectorManager: ...
    @property
    def Elements(self) -> ElementSet: ...
    @property
    def BaseEquipment(self) -> FamilyInstance: ...
    @property
    def BaseEquipmentConnector(self) -> Connector: ...
    def Add(self, connectors: ConnectorSet) -> None: ...
    @overload
    def Remove(self, elementIds: ICollection) -> None: ...
    @overload
    def Remove(self, connectors: ConnectorSet) -> None: ...
    @property
    def IsValid(self) -> bool: ...
    @property
    def IsEmpty(self) -> bool: ...
    @property
    def SectionsCount(self) -> int: ...
    @property
    def PressureLossOfCriticalPath(self) -> float: ...
    @property
    def IsMultipleNetwork(self) -> bool: ...
    @property
    def HasFabricationParts(self) -> bool: ...
    @property
    def HasDesignParts(self) -> bool: ...
    @property
    def HasPlaceholders(self) -> bool: ...
    def GetSectionByIndex(self, index: int) -> MEPSection: ...
    def GetSectionByNumber(self, sectionNumber: int) -> MEPSection: ...
    def GetCriticalPathSectionNumbers(self) -> List[int]: ...
    def IsSystemDividable(self) -> bool: ...
    def GetPhysicalNetworksNumber(self) -> int: ...
    def DivideSystem(self, ADoc: Document) -> ICollection: ...


class SweptProfile:
    @property
    def StartSetBack(self) -> float: ...
    @property
    def EndSetBack(self) -> float: ...
    @property
    def IsValidObject(self) -> bool: ...
    def GetDrivingCurve(self) -> Curve: ...
    def GetSweptProfile(self) -> Profile: ...
    def Dispose(self) -> None: ...


class FamilyInstance(Instance):
    @property
    def Symbol(self) -> FamilySymbol: ...
    @Symbol.setter
    def Symbol(self, pFamilySymbol: FamilySymbol) -> None: ...
    @property
    def MEPModel(self) -> MEPModel: ...
    @property
    def StructuralMaterialType(self) -> StructuralMaterialType: ...
    @property
    def StructuralMaterialId(self) -> ElementId: ...
    @StructuralMaterialId.setter
    def StructuralMaterialId(self, value: ElementId) -> None: ...
    @property
    def StructuralUsage(self) -> StructuralInstanceUsage: ...
    @StructuralUsage.setter
    def StructuralUsage(self, instUsage: StructuralInstanceUsage) -> None: ...
    @property
    def StructuralType(self) -> StructuralType: ...
    @property
    def Room(self, phase: Phase) -> Room: ...
    @property
    def Room(self) -> Room: ...
    @property
    def Space(self, phase: Phase) -> Space: ...
    @property
    def Space(self) -> Space: ...
    @property
    def Location(self) -> Location: ...
    @property
    def Host(self) -> Element: ...
    @property
    def HostParameter(self) -> float: ...
    @property
    def HostFace(self) -> Reference: ...
    @property
    def HandOrientation(self) -> XYZ: ...
    @property
    def FacingOrientation(self) -> XYZ: ...
    @property
    def HandFlipped(self) -> bool: ...
    @property
    def FacingFlipped(self) -> bool: ...
    @property
    def Invisible(self) -> bool: ...
    @property
    def Mirrored(self) -> bool: ...
    @property
    def CanFlipHand(self) -> bool: ...
    @property
    def CanFlipFacing(self) -> bool: ...
    @property
    def CanRotate(self) -> bool: ...
    def flipHand(self) -> bool: ...
    def flipFacing(self) -> bool: ...
    def rotate(self) -> bool: ...
    @property
    def CanSplit(self) -> bool: ...
    def Split(self, param: float) -> ElementId: ...
    @property
    def FromRoom(self, phase: Phase) -> Room: ...
    @property
    def FromRoom(self) -> Room: ...
    @property
    def ToRoom(self, phase: Phase) -> Room: ...
    @property
    def ToRoom(self) -> Room: ...
    def FlipFromToRoom(self) -> None: ...
    def GetSubComponentIds(self) -> ICollection: ...
    @property
    def SuperComponent(self) -> Element: ...
    @property
    def ExtensionUtility(self) -> IExtension: ...
    def GetCopingIds(self) -> ICollection: ...
    def SetCopingIds(self, cutters: ICollection) -> bool: ...
    def AddCoping(self, cutter: FamilyInstance) -> bool: ...
    def RemoveCoping(self, cutter: FamilyInstance) -> bool: ...
    def GetFamilyPointPlacementReferences(self) -> List[FamilyPointPlacementReference]: ...
    @property
    def IsSlantedColumn(self) -> bool: ...
    def GetOriginalGeometry(self, options: Options) -> GeometryElement: ...
    @property
    def CanFlipWorkPlane(self) -> bool: ...
    @property
    def IsWorkPlaneFlipped(self) -> bool: ...
    @IsWorkPlaneFlipped.setter
    def IsWorkPlaneFlipped(self, flipped: bool) -> None: ...
    @property
    def HasSpatialElementCalculationPoint(self) -> bool: ...
    @property
    def HasSpatialElementFromToCalculationPoints(self) -> bool: ...
    def GetSpatialElementCalculationPoint(self) -> XYZ: ...
    def GetSpatialElementFromToCalculationPoints(self) -> List[XYZ]: ...
    def HasModifiedGeometry(self) -> bool: ...
    def HasSweptProfile(self) -> bool: ...
    def GetSweptProfile(self) -> SweptProfile: ...
    def GetReferences(self, referenceType: FamilyInstanceReferenceType) -> List[Reference]: ...
    def GetReferenceType(self, reference: Reference) -> FamilyInstanceReferenceType: ...
    def GetReferenceByName(self, name: str) -> Reference: ...
    def GetReferenceName(self, reference: Reference) -> str: ...


class FamilyInstanceReferenceType:
    Left = 0
    CenterLeftRight = 1
    Right = 2
    Front = 3
    CenterFrontBack = 4
    Back = 5
    Bottom = 6
    CenterElevation = 7
    Top = 8
    StrongReference = 9
    WeakReference = 10
    NotAReference = 11


class InternalDefinition(Definition):
    @property
    def Name(self) -> str: ...
    @property
    def ParameterType(self) -> ParameterType: ...
    @property
    def ParameterGroup(self) -> BuiltInParameterGroup: ...
    @ParameterGroup.setter
    def ParameterGroup(self, group: BuiltInParameterGroup) -> None: ...
    @property
    def BuiltInParameter(self) -> BuiltInParameter: ...
    @property
    def Visible(self) -> bool: ...
    @property
    def VariesAcrossGroups(self) -> bool: ...
    @property
    def Id(self) -> ElementId: ...
    @property
    def IsValidObject(self) -> bool: ...
    def SetAllowVaryBetweenGroups(self, document: Document, allowVaryBetweenGroups: bool) -> ICollection: ...
    def Dispose(self) -> None: ...


class SpecTypeId:
    @property
    def SpecificHeat() -> ForgeTypeId: ...
    @property
    def SpecificHeatOfVaporization() -> ForgeTypeId: ...
    @property
    def Speed() -> ForgeTypeId: ...
    @property
    def Stationing() -> ForgeTypeId: ...
    @property
    def StationingInterval() -> ForgeTypeId: ...
    @property
    def Stress() -> ForgeTypeId: ...
    @property
    def StructuralFrequency() -> ForgeTypeId: ...
    @property
    def StructuralVelocity() -> ForgeTypeId: ...
    @property
    def SurfaceAreaPerUnitLength() -> ForgeTypeId: ...
    @property
    def ThermalConductivity() -> ForgeTypeId: ...
    @property
    def ThermalExpansionCoefficient() -> ForgeTypeId: ...
    @property
    def ThermalGradientCoefficientForMoistureCapacity() -> ForgeTypeId: ...
    @property
    def ThermalMass() -> ForgeTypeId: ...
    @property
    def ThermalResistance() -> ForgeTypeId: ...
    @property
    def Time() -> ForgeTypeId: ...
    @property
    def UnitWeight() -> ForgeTypeId: ...
    @property
    def Volume() -> ForgeTypeId: ...
    @property
    def WarpingConstant() -> ForgeTypeId: ...
    @property
    def Wattage() -> ForgeTypeId: ...
    @property
    def Weight() -> ForgeTypeId: ...
    @property
    def WeightPerUnitLength() -> ForgeTypeId: ...
    @property
    def WireDiameter() -> ForgeTypeId: ...
    @property
    def Custom() -> ForgeTypeId: ...
    @property
    def Acceleration() -> ForgeTypeId: ...
    @property
    def AirFlow() -> ForgeTypeId: ...
    @property
    def AirFlowDensity() -> ForgeTypeId: ...
    @property
    def AirFlowDividedByCoolingLoad() -> ForgeTypeId: ...
    @property
    def AirFlowDividedByVolume() -> ForgeTypeId: ...
    @property
    def Angle() -> ForgeTypeId: ...
    @property
    def AngularSpeed() -> ForgeTypeId: ...
    @property
    def ApparentPower() -> ForgeTypeId: ...
    @property
    def Area() -> ForgeTypeId: ...
    @property
    def AreaDividedByCoolingLoad() -> ForgeTypeId: ...
    @property
    def AreaDividedByHeatingLoad() -> ForgeTypeId: ...
    @property
    def AreaForce() -> ForgeTypeId: ...
    @property
    def AreaForceScale() -> ForgeTypeId: ...
    @property
    def AreaSpringCoefficient() -> ForgeTypeId: ...
    @property
    def BarDiameter() -> ForgeTypeId: ...
    @property
    def CableTraySize() -> ForgeTypeId: ...
    @property
    def ColorTemperature() -> ForgeTypeId: ...
    @property
    def ConduitSize() -> ForgeTypeId: ...
    @property
    def CoolingLoad() -> ForgeTypeId: ...
    @property
    def CoolingLoadDividedByArea() -> ForgeTypeId: ...
    @property
    def CoolingLoadDividedByVolume() -> ForgeTypeId: ...
    @property
    def CostPerArea() -> ForgeTypeId: ...
    @property
    def CostRateEnergy() -> ForgeTypeId: ...
    @property
    def CostRatePower() -> ForgeTypeId: ...
    @property
    def CrackWidth() -> ForgeTypeId: ...
    @property
    def CrossSection() -> ForgeTypeId: ...
    @property
    def Currency() -> ForgeTypeId: ...
    @property
    def Current() -> ForgeTypeId: ...
    @property
    def DecimalSheetLength() -> ForgeTypeId: ...
    @property
    def DemandFactor() -> ForgeTypeId: ...
    @property
    def Diffusivity() -> ForgeTypeId: ...
    @property
    def Displacement() -> ForgeTypeId: ...
    @property
    def Distance() -> ForgeTypeId: ...
    @property
    def DuctInsulationThickness() -> ForgeTypeId: ...
    @property
    def DuctLiningThickness() -> ForgeTypeId: ...
    @property
    def DuctSize() -> ForgeTypeId: ...
    @property
    def Efficacy() -> ForgeTypeId: ...
    @property
    def ElectricalFrequency() -> ForgeTypeId: ...
    @property
    def ElectricalPotential() -> ForgeTypeId: ...
    @property
    def ElectricalPower() -> ForgeTypeId: ...
    @property
    def ElectricalPowerDensity() -> ForgeTypeId: ...
    @property
    def ElectricalResistivity() -> ForgeTypeId: ...
    @property
    def ElectricalTemperature() -> ForgeTypeId: ...
    @property
    def ElectricalTemperatureDifference() -> ForgeTypeId: ...
    @property
    def Energy() -> ForgeTypeId: ...
    @property
    def Factor() -> ForgeTypeId: ...
    @property
    def Flow() -> ForgeTypeId: ...
    @property
    def FlowPerPower() -> ForgeTypeId: ...
    @property
    def Force() -> ForgeTypeId: ...
    @property
    def ForceScale() -> ForgeTypeId: ...
    @property
    def HeatGain() -> ForgeTypeId: ...
    @property
    def HeatTransferCoefficient() -> ForgeTypeId: ...
    @property
    def HeatingLoad() -> ForgeTypeId: ...
    @property
    def HeatingLoadDividedByArea() -> ForgeTypeId: ...
    @property
    def HeatingLoadDividedByVolume() -> ForgeTypeId: ...
    @property
    def HvacDensity() -> ForgeTypeId: ...
    @property
    def HvacEnergy() -> ForgeTypeId: ...
    @property
    def HvacFriction() -> ForgeTypeId: ...
    @property
    def HvacMassPerTime() -> ForgeTypeId: ...
    @property
    def HvacPower() -> ForgeTypeId: ...
    @property
    def HvacPowerDensity() -> ForgeTypeId: ...
    @property
    def HvacPressure() -> ForgeTypeId: ...
    @property
    def HvacRoughness() -> ForgeTypeId: ...
    @property
    def HvacSlope() -> ForgeTypeId: ...
    @property
    def HvacTemperature() -> ForgeTypeId: ...
    @property
    def HvacTemperatureDifference() -> ForgeTypeId: ...
    @property
    def HvacVelocity() -> ForgeTypeId: ...
    @property
    def HvacViscosity() -> ForgeTypeId: ...
    @property
    def Illuminance() -> ForgeTypeId: ...
    @property
    def IsothermalMoistureCapacity() -> ForgeTypeId: ...
    @property
    def Length() -> ForgeTypeId: ...
    @property
    def LineSpringCoefficient() -> ForgeTypeId: ...
    @property
    def LinearForce() -> ForgeTypeId: ...
    @property
    def LinearForceScale() -> ForgeTypeId: ...
    @property
    def LinearMoment() -> ForgeTypeId: ...
    @property
    def LinearMomentScale() -> ForgeTypeId: ...
    @property
    def Luminance() -> ForgeTypeId: ...
    @property
    def LuminousFlux() -> ForgeTypeId: ...
    @property
    def LuminousIntensity() -> ForgeTypeId: ...
    @property
    def Mass() -> ForgeTypeId: ...
    @property
    def MassDensity() -> ForgeTypeId: ...
    @property
    def MassPerUnitArea() -> ForgeTypeId: ...
    @property
    def MassPerUnitLength() -> ForgeTypeId: ...
    @property
    def Moment() -> ForgeTypeId: ...
    @property
    def MomentOfInertia() -> ForgeTypeId: ...
    @property
    def MomentScale() -> ForgeTypeId: ...
    @property
    def Number() -> ForgeTypeId: ...
    @property
    def Period() -> ForgeTypeId: ...
    @property
    def Permeability() -> ForgeTypeId: ...
    @property
    def PipeDimension() -> ForgeTypeId: ...
    @property
    def PipeInsulationThickness() -> ForgeTypeId: ...
    @property
    def PipeMassPerUnitLength() -> ForgeTypeId: ...
    @property
    def PipeSize() -> ForgeTypeId: ...
    @property
    def PipingDensity() -> ForgeTypeId: ...
    @property
    def PipingFriction() -> ForgeTypeId: ...
    @property
    def PipingMass() -> ForgeTypeId: ...
    @property
    def PipingMassPerTime() -> ForgeTypeId: ...
    @property
    def PipingPressure() -> ForgeTypeId: ...
    @property
    def PipingRoughness() -> ForgeTypeId: ...
    @property
    def PipingSlope() -> ForgeTypeId: ...
    @property
    def PipingTemperature() -> ForgeTypeId: ...
    @property
    def PipingTemperatureDifference() -> ForgeTypeId: ...
    @property
    def PipingVelocity() -> ForgeTypeId: ...
    @property
    def PipingViscosity() -> ForgeTypeId: ...
    @property
    def PipingVolume() -> ForgeTypeId: ...
    @property
    def PointSpringCoefficient() -> ForgeTypeId: ...
    @property
    def PowerPerFlow() -> ForgeTypeId: ...
    @property
    def PowerPerLength() -> ForgeTypeId: ...
    @property
    def Pulsation() -> ForgeTypeId: ...
    @property
    def ReinforcementArea() -> ForgeTypeId: ...
    @property
    def ReinforcementAreaPerUnitLength() -> ForgeTypeId: ...
    @property
    def ReinforcementCover() -> ForgeTypeId: ...
    @property
    def ReinforcementLength() -> ForgeTypeId: ...
    @property
    def ReinforcementSpacing() -> ForgeTypeId: ...
    @property
    def ReinforcementVolume() -> ForgeTypeId: ...
    @property
    def Rotation() -> ForgeTypeId: ...
    @property
    def RotationAngle() -> ForgeTypeId: ...
    @property
    def RotationalLineSpringCoefficient() -> ForgeTypeId: ...
    @property
    def RotationalPointSpringCoefficient() -> ForgeTypeId: ...
    @property
    def SectionArea() -> ForgeTypeId: ...
    @property
    def SectionDimension() -> ForgeTypeId: ...
    @property
    def SectionModulus() -> ForgeTypeId: ...
    @property
    def SectionProperty() -> ForgeTypeId: ...
    @property
    def SheetLength() -> ForgeTypeId: ...
    @property
    def SiteAngle() -> ForgeTypeId: ...
    @property
    def Slope() -> ForgeTypeId: ...


class SymbolTypeId:
    @property
    def MPerS() -> ForgeTypeId: ...
    @property
    def MPerSSup2() -> ForgeTypeId: ...
    @property
    def MSup2() -> ForgeTypeId: ...
    @property
    def MSup2KPerW() -> ForgeTypeId: ...
    @property
    def MSup2PerKN() -> ForgeTypeId: ...
    @property
    def MSup2PerKw() -> ForgeTypeId: ...
    @property
    def MSup2PerM() -> ForgeTypeId: ...
    @property
    def MSup2PerS() -> ForgeTypeId: ...
    @property
    def MSup3() -> ForgeTypeId: ...
    @property
    def MSup3PerH() -> ForgeTypeId: ...
    @property
    def MSup3PerHMSup2() -> ForgeTypeId: ...
    @property
    def MSup3PerHMSup3() -> ForgeTypeId: ...
    @property
    def MSup3PerKN() -> ForgeTypeId: ...
    @property
    def MSup3PerKg() -> ForgeTypeId: ...
    @property
    def MSup3PerS() -> ForgeTypeId: ...
    @property
    def MSup3PerWS() -> ForgeTypeId: ...
    @property
    def MSup4() -> ForgeTypeId: ...
    @property
    def MSup6() -> ForgeTypeId: ...
    @property
    def MV() -> ForgeTypeId: ...
    @property
    def Mbh() -> ForgeTypeId: ...
    @property
    def Meter() -> ForgeTypeId: ...
    @property
    def MiPerSSup2() -> ForgeTypeId: ...
    @property
    def Min() -> ForgeTypeId: ...
    @property
    def Mm() -> ForgeTypeId: ...
    @property
    def MmCaret2() -> ForgeTypeId: ...
    @property
    def MmCaret3() -> ForgeTypeId: ...
    @property
    def MmH2O() -> ForgeTypeId: ...
    @property
    def MmH2OPerM() -> ForgeTypeId: ...
    @property
    def MmHg() -> ForgeTypeId: ...
    @property
    def MmSup2() -> ForgeTypeId: ...
    @property
    def MmSup2PerM() -> ForgeTypeId: ...
    @property
    def MmSup3() -> ForgeTypeId: ...
    @property
    def MmSup4() -> ForgeTypeId: ...
    @property
    def MmSup6() -> ForgeTypeId: ...
    @property
    def Mph() -> ForgeTypeId: ...
    @property
    def Ms() -> ForgeTypeId: ...
    @property
    def NDashM() -> ForgeTypeId: ...
    @property
    def NDashMPerM() -> ForgeTypeId: ...
    @property
    def NPerM() -> ForgeTypeId: ...
    @property
    def NPerMSup2() -> ForgeTypeId: ...
    @property
    def NPerMmSup2() -> ForgeTypeId: ...
    @property
    def NSPerMSup2() -> ForgeTypeId: ...
    @property
    def Newton() -> ForgeTypeId: ...
    @property
    def NgPerPaSMSup2() -> ForgeTypeId: ...
    @property
    def OhmM() -> ForgeTypeId: ...
    @property
    def OneColon() -> ForgeTypeId: ...
    @property
    def Pa() -> ForgeTypeId: ...
    @property
    def PaDashS() -> ForgeTypeId: ...
    @property
    def PaPerM() -> ForgeTypeId: ...
    @property
    def PerMille() -> ForgeTypeId: ...
    @property
    def Percent() -> ForgeTypeId: ...
    @property
    def Pi() -> ForgeTypeId: ...
    @property
    def Psf() -> ForgeTypeId: ...
    @property
    def Psi() -> ForgeTypeId: ...
    @property
    def Psia() -> ForgeTypeId: ...
    @property
    def Psig() -> ForgeTypeId: ...
    @property
    def Rad() -> ForgeTypeId: ...
    @property
    def RadPerS() -> ForgeTypeId: ...
    @property
    def Rpm() -> ForgeTypeId: ...
    @property
    def Rps() -> ForgeTypeId: ...
    @property
    def Second() -> ForgeTypeId: ...
    @property
    def Sf() -> ForgeTypeId: ...
    @property
    def SfHPerKbtu() -> ForgeTypeId: ...
    @property
    def SfPerMbh() -> ForgeTypeId: ...
    @property
    def SfPerTon() -> ForgeTypeId: ...
    @property
    def Shekel() -> ForgeTypeId: ...
    @property
    def Stf() -> ForgeTypeId: ...
    @property
    def Tf() -> ForgeTypeId: ...
    @property
    def TfDashM() -> ForgeTypeId: ...
    @property
    def TfDashMPerM() -> ForgeTypeId: ...
    @property
    def TfPerM() -> ForgeTypeId: ...
    @property
    def TfPerMSup2() -> ForgeTypeId: ...
    @property
    def Therm() -> ForgeTypeId: ...
    @property
    def Ton() -> ForgeTypeId: ...
    @property
    def TonOfRefrigeration() -> ForgeTypeId: ...
    @property
    def Tonne() -> ForgeTypeId: ...
    @property
    def Tonsf() -> ForgeTypeId: ...
    @property
    def UinPerInDegreeF() -> ForgeTypeId: ...
    @property
    def UkPound() -> ForgeTypeId: ...
    @property
    def UmPerMDegreeC() -> ForgeTypeId: ...
    @property
    def UsDollar() -> ForgeTypeId: ...
    @property
    def UsTonnesForceSt() -> ForgeTypeId: ...
    @property
    def UsTonnesForceT() -> ForgeTypeId: ...
    @property
    def UsTonnesForceTons() -> ForgeTypeId: ...
    @property
    def UsTonnesMassSt() -> ForgeTypeId: ...
    @property
    def UsTonnesMassT() -> ForgeTypeId: ...
    @property
    def UsTonnesMassTons() -> ForgeTypeId: ...
    @property
    def Usft() -> ForgeTypeId: ...
    @property
    def Usgph() -> ForgeTypeId: ...
    @property
    def Usgpm() -> ForgeTypeId: ...
    @property
    def VA() -> ForgeTypeId: ...
    @property
    def Volt() -> ForgeTypeId: ...
    @property
    def WMinPerFtSup3() -> ForgeTypeId: ...
    @property
    def WPerFt() -> ForgeTypeId: ...
    @property
    def WPerFtSup2() -> ForgeTypeId: ...
    @property
    def WPerFtSup3() -> ForgeTypeId: ...
    @property
    def WPerM() -> ForgeTypeId: ...
    @property
    def WPerMK() -> ForgeTypeId: ...
    @property
    def WPerMSup2() -> ForgeTypeId: ...
    @property
    def WPerMSup2K() -> ForgeTypeId: ...
    @property
    def WPerMSup3() -> ForgeTypeId: ...
    @property
    def WSPerMSup3() -> ForgeTypeId: ...
    @property
    def Watt() -> ForgeTypeId: ...
    @property
    def Won() -> ForgeTypeId: ...
    @property
    def Yen() -> ForgeTypeId: ...
    @property
    def InHg() -> ForgeTypeId: ...
    @property
    def InPerSSup2() -> ForgeTypeId: ...
    @property
    def InSup2() -> ForgeTypeId: ...
    @property
    def InSup2PerFt() -> ForgeTypeId: ...
    @property
    def InSup3() -> ForgeTypeId: ...
    @property
    def InSup4() -> ForgeTypeId: ...
    @property
    def InSup6() -> ForgeTypeId: ...
    @property
    def InchDoubleQuote() -> ForgeTypeId: ...
    @property
    def InvDegreeC() -> ForgeTypeId: ...
    @property
    def InvDegreeF() -> ForgeTypeId: ...
    @property
    def InvKN() -> ForgeTypeId: ...
    @property
    def InvKip() -> ForgeTypeId: ...
    @property
    def JPerG() -> ForgeTypeId: ...
    @property
    def JPerGDegreeC() -> ForgeTypeId: ...
    @property
    def JPerK() -> ForgeTypeId: ...
    @property
    def JPerKgDegreeC() -> ForgeTypeId: ...
    @property
    def Joule() -> ForgeTypeId: ...
    @property
    def KA() -> ForgeTypeId: ...
    @property
    def KJ() -> ForgeTypeId: ...
    @property
    def KJPerK() -> ForgeTypeId: ...
    @property
    def KN() -> ForgeTypeId: ...
    @property
    def KNDashM() -> ForgeTypeId: ...
    @property
    def KNDashMPerDegree() -> ForgeTypeId: ...
    @property
    def KNDashMPerDegreePerM() -> ForgeTypeId: ...
    @property
    def KNDashMPerM() -> ForgeTypeId: ...
    @property
    def KNPerCmSup2() -> ForgeTypeId: ...
    @property
    def KNPerM() -> ForgeTypeId: ...
    @property
    def KNPerMSup2() -> ForgeTypeId: ...
    @property
    def KNPerMSup3() -> ForgeTypeId: ...
    @property
    def KNPerMmSup2() -> ForgeTypeId: ...
    @property
    def KPa() -> ForgeTypeId: ...
    @property
    def KV() -> ForgeTypeId: ...
    @property
    def KVA() -> ForgeTypeId: ...
    @property
    def KW() -> ForgeTypeId: ...
    @property
    def KWh() -> ForgeTypeId: ...
    @property
    def Kcal() -> ForgeTypeId: ...
    @property
    def KcalPerS() -> ForgeTypeId: ...
    @property
    def Kelvin() -> ForgeTypeId: ...
    @property
    def KelvinInterval() -> ForgeTypeId: ...
    @property
    def Kg() -> ForgeTypeId: ...
    @property
    def KgPerH() -> ForgeTypeId: ...
    @property
    def KgPerKgK() -> ForgeTypeId: ...
    @property
    def KgPerM() -> ForgeTypeId: ...
    @property
    def KgPerMH() -> ForgeTypeId: ...
    @property
    def KgPerMS() -> ForgeTypeId: ...
    @property
    def KgPerMSup2() -> ForgeTypeId: ...
    @property
    def KgPerMSup3() -> ForgeTypeId: ...
    @property
    def KgPerMin() -> ForgeTypeId: ...
    @property
    def KgPerS() -> ForgeTypeId: ...
    @property
    def Kgf() -> ForgeTypeId: ...
    @property
    def KgfDashM() -> ForgeTypeId: ...
    @property
    def KgfDashMPerM() -> ForgeTypeId: ...
    @property
    def KgfPerM() -> ForgeTypeId: ...
    @property
    def KgfPerMSup2() -> ForgeTypeId: ...
    @property
    def Kip() -> ForgeTypeId: ...
    @property
    def KipDashFt() -> ForgeTypeId: ...
    @property
    def KipDashFtPerDegree() -> ForgeTypeId: ...
    @property
    def KipDashFtPerDegreePerFt() -> ForgeTypeId: ...
    @property
    def KipDashFtPerFt() -> ForgeTypeId: ...
    @property
    def KipPerFt() -> ForgeTypeId: ...
    @property
    def KipPerFtSup2() -> ForgeTypeId: ...
    @property
    def KipPerFtSup3() -> ForgeTypeId: ...
    @property
    def KipPerIn() -> ForgeTypeId: ...
    @property
    def KipPerInSup2() -> ForgeTypeId: ...
    @property
    def KipPerInSup3() -> ForgeTypeId: ...
    @property
    def KmPerH() -> ForgeTypeId: ...
    @property
    def KmPerSSup2() -> ForgeTypeId: ...
    @property
    def Krone() -> ForgeTypeId: ...
    @property
    def Ksf() -> ForgeTypeId: ...
    @property
    def Ksi() -> ForgeTypeId: ...
    @property
    def LPerH() -> ForgeTypeId: ...
    @property
    def LPerMin() -> ForgeTypeId: ...
    @property
    def LPerS() -> ForgeTypeId: ...
    @property
    def LPerSKw() -> ForgeTypeId: ...
    @property
    def LPerSMSup2() -> ForgeTypeId: ...
    @property
    def LPerSMSup3() -> ForgeTypeId: ...
    @property
    def LbForce() -> ForgeTypeId: ...
    @property
    def LbForceDashFt() -> ForgeTypeId: ...
    @property
    def LbForceDashFtPerFt() -> ForgeTypeId: ...
    @property
    def LbForcePerFt() -> ForgeTypeId: ...
    @property
    def LbForcePerFtSup2() -> ForgeTypeId: ...
    @property
    def LbForcePerFtSup3() -> ForgeTypeId: ...
    @property
    def LbForcePerInSup2() -> ForgeTypeId: ...
    @property
    def LbForceSPerFtSup2() -> ForgeTypeId: ...
    @property
    def LbMass() -> ForgeTypeId: ...
    @property
    def LbMassPerFt() -> ForgeTypeId: ...
    @property
    def LbMassPerFtDashH() -> ForgeTypeId: ...
    @property
    def LbMassPerFtDashS() -> ForgeTypeId: ...
    @property
    def LbMassPerFtSup2() -> ForgeTypeId: ...
    @property
    def LbMassPerFtSup3() -> ForgeTypeId: ...
    @property
    def LbMassPerH() -> ForgeTypeId: ...
    @property
    def LbMassPerInSup3() -> ForgeTypeId: ...
    @property
    def LbMassPerLbDegreeF() -> ForgeTypeId: ...
    @property
    def LbMassPerMin() -> ForgeTypeId: ...
    @property
    def LbMassPerS() -> ForgeTypeId: ...
    @property
    def Lbf() -> ForgeTypeId: ...
    @property
    def LbfDashFt() -> ForgeTypeId: ...
    @property
    def LbfDashFtPerFt() -> ForgeTypeId: ...
    @property
    def LbfPerFt() -> ForgeTypeId: ...
    @property
    def LbfPerFtSup2() -> ForgeTypeId: ...
    @property
    def LbfPerFtSup3() -> ForgeTypeId: ...
    @property
    def LbfPerInSup2() -> ForgeTypeId: ...
    @property
    def Lbm() -> ForgeTypeId: ...
    @property
    def LbmPerFt() -> ForgeTypeId: ...
    @property
    def LbmPerFtDashH() -> ForgeTypeId: ...
    @property
    def LbmPerFtDashS() -> ForgeTypeId: ...
    @property
    def LbmPerFtSup3() -> ForgeTypeId: ...
    @property
    def LbmPerInSup3() -> ForgeTypeId: ...
    @property
    def Lf() -> ForgeTypeId: ...
    @property
    def Liter() -> ForgeTypeId: ...
    @property
    def Lm() -> ForgeTypeId: ...
    @property
    def LmPerW() -> ForgeTypeId: ...
    @property
    def Lpm() -> ForgeTypeId: ...
    @property
    def Lps() -> ForgeTypeId: ...
    @property
    def LpsPerMSup2() -> ForgeTypeId: ...
    @property
    def Lx() -> ForgeTypeId: ...
    @property
    def MA() -> ForgeTypeId: ...
    @property
    def MCaret2() -> ForgeTypeId: ...
    @property
    def MCaret3() -> ForgeTypeId: ...
    @property
    def MH2O() -> ForgeTypeId: ...
    @property
    def MH2OPerM() -> ForgeTypeId: ...
    @property
    def MN() -> ForgeTypeId: ...
    @property
    def MNDashM() -> ForgeTypeId: ...
    @property
    def MNDashMPerM() -> ForgeTypeId: ...
    @property
    def MNPerM() -> ForgeTypeId: ...
    @property
    def MNPerMSup2() -> ForgeTypeId: ...
    @property
    def MPa() -> ForgeTypeId: ...
    @property
    def MPerKN() -> ForgeTypeId: ...
    @property
    def Custom() -> ForgeTypeId: ...
    @property
    def SlopeDegree() -> ForgeTypeId: ...
    @property
    def Acres() -> ForgeTypeId: ...
    @property
    def Ampere() -> ForgeTypeId: ...
    @property
    def Atm() -> ForgeTypeId: ...
    @property
    def Baht() -> ForgeTypeId: ...
    @property
    def Bar() -> ForgeTypeId: ...
    @property
    def Btu() -> ForgeTypeId: ...
    @property
    def BtuPerDegreeF() -> ForgeTypeId: ...
    @property
    def BtuPerH() -> ForgeTypeId: ...
    @property
    def BtuPerHFtDegreeF() -> ForgeTypeId: ...
    @property
    def BtuPerHFtSup2() -> ForgeTypeId: ...
    @property
    def BtuPerHFtSup2DegreeF() -> ForgeTypeId: ...
    @property
    def BtuPerHFtSup3() -> ForgeTypeId: ...
    @property
    def BtuPerLb() -> ForgeTypeId: ...
    @property
    def BtuPerLbDegreeF() -> ForgeTypeId: ...
    @property
    def BtuPerS() -> ForgeTypeId: ...
    @property
    def CP() -> ForgeTypeId: ...
    @property
    def Cal() -> ForgeTypeId: ...
    @property
    def CalPerS() -> ForgeTypeId: ...
    @property
    def Cd() -> ForgeTypeId: ...
    @property
    def CdPerFtSup2() -> ForgeTypeId: ...
    @property
    def CdPerMSup2() -> ForgeTypeId: ...
    @property
    def Cf() -> ForgeTypeId: ...
    @property
    def Cfh() -> ForgeTypeId: ...
    @property
    def Cfm() -> ForgeTypeId: ...
    @property
    def CfmPerCf() -> ForgeTypeId: ...
    @property
    def CfmPerFtSup2() -> ForgeTypeId: ...
    @property
    def CfmPerFtSup3() -> ForgeTypeId: ...
    @property
    def CfmPerSf() -> ForgeTypeId: ...
    @property
    def CfmPerTon() -> ForgeTypeId: ...
    @property
    def ChineseHongKongDollar() -> ForgeTypeId: ...
    @property
    def Cm() -> ForgeTypeId: ...
    @property
    def CmCaret2() -> ForgeTypeId: ...
    @property
    def CmCaret3() -> ForgeTypeId: ...
    @property
    def CmPerMin() -> ForgeTypeId: ...
    @property
    def CmSup2() -> ForgeTypeId: ...
    @property
    def CmSup2PerM() -> ForgeTypeId: ...
    @property
    def CmSup3() -> ForgeTypeId: ...
    @property
    def CmSup4() -> ForgeTypeId: ...
    @property
    def CmSup6() -> ForgeTypeId: ...
    @property
    def Cmh() -> ForgeTypeId: ...
    @property
    def Cms() -> ForgeTypeId: ...
    @property
    def Colon1() -> ForgeTypeId: ...
    @property
    def Colon10() -> ForgeTypeId: ...
    @property
    def Colon12() -> ForgeTypeId: ...
    @property
    def Cps() -> ForgeTypeId: ...
    @property
    def Cy() -> ForgeTypeId: ...
    @property
    def DaN() -> ForgeTypeId: ...
    @property
    def DaNDashM() -> ForgeTypeId: ...
    @property
    def DaNDashMPerM() -> ForgeTypeId: ...
    @property
    def DaNPerM() -> ForgeTypeId: ...
    @property
    def DaNPerMSup2() -> ForgeTypeId: ...
    @property
    def Degree() -> ForgeTypeId: ...
    @property
    def DegreeC() -> ForgeTypeId: ...
    @property
    def DegreeCInterval() -> ForgeTypeId: ...
    @property
    def DegreeF() -> ForgeTypeId: ...
    @property
    def DegreeFInterval() -> ForgeTypeId: ...
    @property
    def DegreeR() -> ForgeTypeId: ...
    @property
    def DegreeRInterval() -> ForgeTypeId: ...
    @property
    def DeltaDegreeC() -> ForgeTypeId: ...
    @property
    def DeltaDegreeF() -> ForgeTypeId: ...
    @property
    def DeltaDegreeR() -> ForgeTypeId: ...
    @property
    def DeltaK() -> ForgeTypeId: ...
    @property
    def Dm() -> ForgeTypeId: ...
    @property
    def DollarHPerBtu() -> ForgeTypeId: ...
    @property
    def DollarPerBtu() -> ForgeTypeId: ...
    @property
    def DollarPerFtSup2() -> ForgeTypeId: ...
    @property
    def DollarPerMSup2() -> ForgeTypeId: ...
    @property
    def DollarPerW() -> ForgeTypeId: ...
    @property
    def DollarPerWH() -> ForgeTypeId: ...
    @property
    def Dong() -> ForgeTypeId: ...
    @property
    def EuroPrefix() -> ForgeTypeId: ...
    @property
    def EuroSuffix() -> ForgeTypeId: ...
    @property
    def FL() -> ForgeTypeId: ...
    @property
    def Fc() -> ForgeTypeId: ...
    @property
    def FeetOfWater() -> ForgeTypeId: ...
    @property
    def FeetOfWaterPer100ft() -> ForgeTypeId: ...
    @property
    def FlLowercase() -> ForgeTypeId: ...
    @property
    def FootSingleQuote() -> ForgeTypeId: ...
    @property
    def Fpm() -> ForgeTypeId: ...
    @property
    def Fps() -> ForgeTypeId: ...
    @property
    def Ft() -> ForgeTypeId: ...
    @property
    def FtCaret2() -> ForgeTypeId: ...
    @property
    def FtCaret3() -> ForgeTypeId: ...
    @property
    def FtH2O() -> ForgeTypeId: ...
    @property
    def FtH2OPer100ft() -> ForgeTypeId: ...
    @property
    def FtL() -> ForgeTypeId: ...
    @property
    def FtOfWater() -> ForgeTypeId: ...
    @property
    def FtOfWaterPer100ft() -> ForgeTypeId: ...
    @property
    def FtPerKip() -> ForgeTypeId: ...
    @property
    def FtPerMin() -> ForgeTypeId: ...
    @property
    def FtPerS() -> ForgeTypeId: ...
    @property
    def FtPerSSup2() -> ForgeTypeId: ...
    @property
    def FtSup2() -> ForgeTypeId: ...
    @property
    def FtSup2HPerKbtu() -> ForgeTypeId: ...
    @property
    def FtSup2PerFt() -> ForgeTypeId: ...
    @property
    def FtSup2PerKip() -> ForgeTypeId: ...
    @property
    def FtSup2PerMbh() -> ForgeTypeId: ...
    @property
    def FtSup2PerS() -> ForgeTypeId: ...
    @property
    def FtSup2PerTon() -> ForgeTypeId: ...
    @property
    def FtSup3() -> ForgeTypeId: ...
    @property
    def FtSup3HPerMinBtu() -> ForgeTypeId: ...
    @property
    def FtSup3PerH() -> ForgeTypeId: ...
    @property
    def FtSup3PerKip() -> ForgeTypeId: ...
    @property
    def FtSup3PerLbMass() -> ForgeTypeId: ...
    @property
    def FtSup3PerMin() -> ForgeTypeId: ...
    @property
    def FtSup4() -> ForgeTypeId: ...
    @property
    def FtSup6() -> ForgeTypeId: ...
    @property
    def Ftc() -> ForgeTypeId: ...
    @property
    def Gal() -> ForgeTypeId: ...
    @property
    def GalPerH() -> ForgeTypeId: ...
    @property
    def GalPerMin() -> ForgeTypeId: ...
    @property
    def Gph() -> ForgeTypeId: ...
    @property
    def Gpm() -> ForgeTypeId: ...
    @property
    def GrPerHFtSup2InHg() -> ForgeTypeId: ...
    @property
    def Grad() -> ForgeTypeId: ...
    @property
    def HFtSup2DegreeFPerBtu() -> ForgeTypeId: ...
    @property
    def Hectare() -> ForgeTypeId: ...
    @property
    def Hour() -> ForgeTypeId: ...
    @property
    def Hp() -> ForgeTypeId: ...
    @property
    def Hz() -> ForgeTypeId: ...
    @property
    def In() -> ForgeTypeId: ...
    @property
    def InCaret2() -> ForgeTypeId: ...
    @property
    def InCaret3() -> ForgeTypeId: ...
    @property
    def InDashWg() -> ForgeTypeId: ...
    @property
    def InDashWgPer100ft() -> ForgeTypeId: ...


class UnitTypeId:
    @property
    def SquareInchesPerFoot() -> ForgeTypeId: ...
    @property
    def SquareMeterKelvinsPerWatt() -> ForgeTypeId: ...
    @property
    def SquareMeters() -> ForgeTypeId: ...
    @property
    def SquareMetersPerKilonewton() -> ForgeTypeId: ...
    @property
    def SquareMetersPerKilowatt() -> ForgeTypeId: ...
    @property
    def SquareMetersPerMeter() -> ForgeTypeId: ...
    @property
    def SquareMetersPerSecond() -> ForgeTypeId: ...
    @property
    def SquareMillimeters() -> ForgeTypeId: ...
    @property
    def SquareMillimetersPerMeter() -> ForgeTypeId: ...
    @property
    def Therms() -> ForgeTypeId: ...
    @property
    def ThousandBritishThermalUnitsPerHour() -> ForgeTypeId: ...
    @property
    def TonneForceMeters() -> ForgeTypeId: ...
    @property
    def TonneForceMetersPerMeter() -> ForgeTypeId: ...
    @property
    def Tonnes() -> ForgeTypeId: ...
    @property
    def TonnesForce() -> ForgeTypeId: ...
    @property
    def TonnesForcePerMeter() -> ForgeTypeId: ...
    @property
    def TonnesForcePerSquareMeter() -> ForgeTypeId: ...
    @property
    def TonsOfRefrigeration() -> ForgeTypeId: ...
    @property
    def UsGallons() -> ForgeTypeId: ...
    @property
    def UsGallonsPerHour() -> ForgeTypeId: ...
    @property
    def UsGallonsPerMinute() -> ForgeTypeId: ...
    @property
    def UsSurveyFeet() -> ForgeTypeId: ...
    @property
    def UsTonnesForce() -> ForgeTypeId: ...
    @property
    def UsTonnesMass() -> ForgeTypeId: ...
    @property
    def VoltAmperes() -> ForgeTypeId: ...
    @property
    def Volts() -> ForgeTypeId: ...
    @property
    def Watts() -> ForgeTypeId: ...
    @property
    def WattsPerCubicFoot() -> ForgeTypeId: ...
    @property
    def WattsPerCubicFootPerMinute() -> ForgeTypeId: ...
    @property
    def WattsPerCubicMeter() -> ForgeTypeId: ...
    @property
    def WattsPerCubicMeterPerSecond() -> ForgeTypeId: ...
    @property
    def WattsPerFoot() -> ForgeTypeId: ...
    @property
    def WattsPerMeter() -> ForgeTypeId: ...
    @property
    def WattsPerMeterKelvin() -> ForgeTypeId: ...
    @property
    def WattsPerSquareFoot() -> ForgeTypeId: ...
    @property
    def WattsPerSquareMeter() -> ForgeTypeId: ...
    @property
    def WattsPerSquareMeterKelvin() -> ForgeTypeId: ...
    @property
    def KilogramsPerSquareMeter() -> ForgeTypeId: ...
    @property
    def Kilojoules() -> ForgeTypeId: ...
    @property
    def KilojoulesPerKelvin() -> ForgeTypeId: ...
    @property
    def KilometersPerHour() -> ForgeTypeId: ...
    @property
    def KilometersPerSecondSquared() -> ForgeTypeId: ...
    @property
    def KilonewtonMeters() -> ForgeTypeId: ...
    @property
    def KilonewtonMetersPerDegree() -> ForgeTypeId: ...
    @property
    def KilonewtonMetersPerDegreePerMeter() -> ForgeTypeId: ...
    @property
    def KilonewtonMetersPerMeter() -> ForgeTypeId: ...
    @property
    def Kilonewtons() -> ForgeTypeId: ...
    @property
    def KilonewtonsPerCubicMeter() -> ForgeTypeId: ...
    @property
    def KilonewtonsPerMeter() -> ForgeTypeId: ...
    @property
    def KilonewtonsPerSquareCentimeter() -> ForgeTypeId: ...
    @property
    def KilonewtonsPerSquareMeter() -> ForgeTypeId: ...
    @property
    def KilonewtonsPerSquareMillimeter() -> ForgeTypeId: ...
    @property
    def Kilopascals() -> ForgeTypeId: ...
    @property
    def KilovoltAmperes() -> ForgeTypeId: ...
    @property
    def Kilovolts() -> ForgeTypeId: ...
    @property
    def KilowattHours() -> ForgeTypeId: ...
    @property
    def Kilowatts() -> ForgeTypeId: ...
    @property
    def KipFeet() -> ForgeTypeId: ...
    @property
    def KipFeetPerDegree() -> ForgeTypeId: ...
    @property
    def KipFeetPerDegreePerFoot() -> ForgeTypeId: ...
    @property
    def KipFeetPerFoot() -> ForgeTypeId: ...
    @property
    def Kips() -> ForgeTypeId: ...
    @property
    def KipsPerCubicFoot() -> ForgeTypeId: ...
    @property
    def KipsPerCubicInch() -> ForgeTypeId: ...
    @property
    def KipsPerFoot() -> ForgeTypeId: ...
    @property
    def KipsPerInch() -> ForgeTypeId: ...
    @property
    def KipsPerSquareFoot() -> ForgeTypeId: ...
    @property
    def KipsPerSquareInch() -> ForgeTypeId: ...
    @property
    def Liters() -> ForgeTypeId: ...
    @property
    def LitersPerHour() -> ForgeTypeId: ...
    @property
    def LitersPerMinute() -> ForgeTypeId: ...
    @property
    def LitersPerSecond() -> ForgeTypeId: ...
    @property
    def LitersPerSecondCubicMeter() -> ForgeTypeId: ...
    @property
    def LitersPerSecondKilowatt() -> ForgeTypeId: ...
    @property
    def LitersPerSecondSquareMeter() -> ForgeTypeId: ...
    @property
    def Lumens() -> ForgeTypeId: ...
    @property
    def LumensPerWatt() -> ForgeTypeId: ...
    @property
    def Lux() -> ForgeTypeId: ...
    @property
    def MeganewtonMeters() -> ForgeTypeId: ...
    @property
    def MeganewtonMetersPerMeter() -> ForgeTypeId: ...
    @property
    def Meganewtons() -> ForgeTypeId: ...
    @property
    def MeganewtonsPerMeter() -> ForgeTypeId: ...
    @property
    def MeganewtonsPerSquareMeter() -> ForgeTypeId: ...
    @property
    def Megapascals() -> ForgeTypeId: ...
    @property
    def Meters() -> ForgeTypeId: ...
    @property
    def MetersOfWaterColumn() -> ForgeTypeId: ...
    @property
    def MetersOfWaterColumnPerMeter() -> ForgeTypeId: ...
    @property
    def MetersPerKilonewton() -> ForgeTypeId: ...
    @property
    def MetersPerSecond() -> ForgeTypeId: ...
    @property
    def MetersPerSecondSquared() -> ForgeTypeId: ...
    @property
    def MetersToTheFourthPower() -> ForgeTypeId: ...
    @property
    def MetersToTheSixthPower() -> ForgeTypeId: ...
    @property
    def MicroinchesPerInchDegreeFahrenheit() -> ForgeTypeId: ...
    @property
    def MicrometersPerMeterDegreeCelsius() -> ForgeTypeId: ...
    @property
    def MilesPerHour() -> ForgeTypeId: ...
    @property
    def MilesPerSecondSquared() -> ForgeTypeId: ...
    @property
    def Milliamperes() -> ForgeTypeId: ...
    @property
    def Millimeters() -> ForgeTypeId: ...
    @property
    def MillimetersOfMercury() -> ForgeTypeId: ...
    @property
    def MillimetersOfWaterColumn() -> ForgeTypeId: ...
    @property
    def MillimetersOfWaterColumnPerMeter() -> ForgeTypeId: ...
    @property
    def MillimetersToTheFourthPower() -> ForgeTypeId: ...
    @property
    def MillimetersToTheSixthPower() -> ForgeTypeId: ...
    @property
    def Milliseconds() -> ForgeTypeId: ...
    @property
    def Millivolts() -> ForgeTypeId: ...
    @property
    def Minutes() -> ForgeTypeId: ...
    @property
    def NanogramsPerPascalSecondSquareMeter() -> ForgeTypeId: ...
    @property
    def NewtonMeters() -> ForgeTypeId: ...
    @property
    def NewtonMetersPerMeter() -> ForgeTypeId: ...
    @property
    def NewtonSecondsPerSquareMeter() -> ForgeTypeId: ...
    @property
    def Newtons() -> ForgeTypeId: ...
    @property
    def NewtonsPerMeter() -> ForgeTypeId: ...
    @property
    def NewtonsPerSquareMeter() -> ForgeTypeId: ...
    @property
    def NewtonsPerSquareMillimeter() -> ForgeTypeId: ...
    @property
    def OhmMeters() -> ForgeTypeId: ...
    @property
    def OneToRatio() -> ForgeTypeId: ...
    @property
    def PascalSeconds() -> ForgeTypeId: ...
    @property
    def Pascals() -> ForgeTypeId: ...
    @property
    def PascalsPerMeter() -> ForgeTypeId: ...
    @property
    def PerMille() -> ForgeTypeId: ...
    @property
    def Percentage() -> ForgeTypeId: ...
    @property
    def Pi() -> ForgeTypeId: ...
    @property
    def PoundForceFeet() -> ForgeTypeId: ...
    @property
    def PoundForceFeetPerFoot() -> ForgeTypeId: ...
    @property
    def PoundForceSecondsPerSquareFoot() -> ForgeTypeId: ...
    @property
    def PoundsForce() -> ForgeTypeId: ...
    @property
    def PoundsForcePerCubicFoot() -> ForgeTypeId: ...
    @property
    def PoundsForcePerFoot() -> ForgeTypeId: ...
    @property
    def PoundsForcePerSquareFoot() -> ForgeTypeId: ...
    @property
    def PoundsForcePerSquareInch() -> ForgeTypeId: ...
    @property
    def PoundsMass() -> ForgeTypeId: ...
    @property
    def PoundsMassPerCubicFoot() -> ForgeTypeId: ...
    @property
    def PoundsMassPerCubicInch() -> ForgeTypeId: ...
    @property
    def PoundsMassPerFoot() -> ForgeTypeId: ...
    @property
    def PoundsMassPerFootHour() -> ForgeTypeId: ...
    @property
    def PoundsMassPerFootSecond() -> ForgeTypeId: ...
    @property
    def PoundsMassPerHour() -> ForgeTypeId: ...
    @property
    def PoundsMassPerMinute() -> ForgeTypeId: ...
    @property
    def PoundsMassPerPoundDegreeFahrenheit() -> ForgeTypeId: ...
    @property
    def PoundsMassPerSecond() -> ForgeTypeId: ...
    @property
    def PoundsMassPerSquareFoot() -> ForgeTypeId: ...
    @property
    def Radians() -> ForgeTypeId: ...
    @property
    def RadiansPerSecond() -> ForgeTypeId: ...
    @property
    def Rankine() -> ForgeTypeId: ...
    @property
    def RankineInterval() -> ForgeTypeId: ...
    @property
    def RatioTo1() -> ForgeTypeId: ...
    @property
    def RatioTo10() -> ForgeTypeId: ...
    @property
    def RatioTo12() -> ForgeTypeId: ...
    @property
    def RevolutionsPerMinute() -> ForgeTypeId: ...
    @property
    def RevolutionsPerSecond() -> ForgeTypeId: ...
    @property
    def RiseDividedBy1000Millimeters() -> ForgeTypeId: ...
    @property
    def RiseDividedBy10Feet() -> ForgeTypeId: ...
    @property
    def RiseDividedBy120Inches() -> ForgeTypeId: ...
    @property
    def RiseDividedBy12Inches() -> ForgeTypeId: ...
    @property
    def RiseDividedBy1Foot() -> ForgeTypeId: ...
    @property
    def Seconds() -> ForgeTypeId: ...
    @property
    def SquareCentimeters() -> ForgeTypeId: ...
    @property
    def SquareCentimetersPerMeter() -> ForgeTypeId: ...
    @property
    def SquareFeet() -> ForgeTypeId: ...
    @property
    def SquareFeetPer1000BritishThermalUnitsPerHour() -> ForgeTypeId: ...
    @property
    def SquareFeetPerFoot() -> ForgeTypeId: ...
    @property
    def SquareFeetPerKip() -> ForgeTypeId: ...
    @property
    def SquareFeetPerSecond() -> ForgeTypeId: ...
    @property
    def SquareFeetPerTonOfRefrigeration() -> ForgeTypeId: ...
    @property
    def SquareInches() -> ForgeTypeId: ...
    @property
    def Custom() -> ForgeTypeId: ...
    @property
    def DegreesMinutes() -> ForgeTypeId: ...
    @property
    def FeetFractionalInches() -> ForgeTypeId: ...
    @property
    def FractionalInches() -> ForgeTypeId: ...
    @property
    def MetersCentimeters() -> ForgeTypeId: ...
    @property
    def SlopeDegrees() -> ForgeTypeId: ...
    @property
    def StationingFeet() -> ForgeTypeId: ...
    @property
    def StationingMeters() -> ForgeTypeId: ...
    @property
    def Acres() -> ForgeTypeId: ...
    @property
    def Amperes() -> ForgeTypeId: ...
    @property
    def Atmospheres() -> ForgeTypeId: ...
    @property
    def Bars() -> ForgeTypeId: ...
    @property
    def BritishThermalUnits() -> ForgeTypeId: ...
    @property
    def BritishThermalUnitsPerDegreeFahrenheit() -> ForgeTypeId: ...
    @property
    def BritishThermalUnitsPerHour() -> ForgeTypeId: ...
    @property
    def BritishThermalUnitsPerHourCubicFoot() -> ForgeTypeId: ...
    @property
    def BritishThermalUnitsPerHourFootDegreeFahrenheit() -> ForgeTypeId: ...
    @property
    def BritishThermalUnitsPerHourSquareFoot() -> ForgeTypeId: ...
    @property
    def BritishThermalUnitsPerHourSquareFootDegreeFahrenheit() -> ForgeTypeId: ...
    @property
    def BritishThermalUnitsPerPound() -> ForgeTypeId: ...
    @property
    def BritishThermalUnitsPerPoundDegreeFahrenheit() -> ForgeTypeId: ...
    @property
    def BritishThermalUnitsPerSecond() -> ForgeTypeId: ...
    @property
    def Calories() -> ForgeTypeId: ...
    @property
    def CaloriesPerSecond() -> ForgeTypeId: ...
    @property
    def Candelas() -> ForgeTypeId: ...
    @property
    def CandelasPerSquareFoot() -> ForgeTypeId: ...
    @property
    def CandelasPerSquareMeter() -> ForgeTypeId: ...
    @property
    def Celsius() -> ForgeTypeId: ...
    @property
    def CelsiusInterval() -> ForgeTypeId: ...
    @property
    def Centimeters() -> ForgeTypeId: ...
    @property
    def CentimetersPerMinute() -> ForgeTypeId: ...
    @property
    def CentimetersToTheFourthPower() -> ForgeTypeId: ...
    @property
    def CentimetersToTheSixthPower() -> ForgeTypeId: ...
    @property
    def Centipoises() -> ForgeTypeId: ...
    @property
    def CubicCentimeters() -> ForgeTypeId: ...
    @property
    def CubicFeet() -> ForgeTypeId: ...
    @property
    def CubicFeetPerHour() -> ForgeTypeId: ...
    @property
    def CubicFeetPerKip() -> ForgeTypeId: ...
    @property
    def CubicFeetPerMinute() -> ForgeTypeId: ...
    @property
    def CubicFeetPerMinuteCubicFoot() -> ForgeTypeId: ...
    @property
    def CubicFeetPerMinutePerBritishThermalUnitPerHour() -> ForgeTypeId: ...
    @property
    def CubicFeetPerMinuteSquareFoot() -> ForgeTypeId: ...
    @property
    def CubicFeetPerMinuteTonOfRefrigeration() -> ForgeTypeId: ...
    @property
    def CubicFeetPerPoundMass() -> ForgeTypeId: ...
    @property
    def CubicInches() -> ForgeTypeId: ...
    @property
    def CubicMeters() -> ForgeTypeId: ...
    @property
    def CubicMetersPerHour() -> ForgeTypeId: ...
    @property
    def CubicMetersPerHourCubicMeter() -> ForgeTypeId: ...
    @property
    def CubicMetersPerHourSquareMeter() -> ForgeTypeId: ...
    @property
    def CubicMetersPerKilogram() -> ForgeTypeId: ...
    @property
    def CubicMetersPerKilonewton() -> ForgeTypeId: ...
    @property
    def CubicMetersPerSecond() -> ForgeTypeId: ...
    @property
    def CubicMetersPerWattSecond() -> ForgeTypeId: ...
    @property
    def CubicMillimeters() -> ForgeTypeId: ...
    @property
    def CubicYards() -> ForgeTypeId: ...
    @property
    def Currency() -> ForgeTypeId: ...
    @property
    def CurrencyPerBritishThermalUnit() -> ForgeTypeId: ...
    @property
    def CurrencyPerBritishThermalUnitPerHour() -> ForgeTypeId: ...
    @property
    def CurrencyPerSquareFoot() -> ForgeTypeId: ...
    @property
    def CurrencyPerSquareMeter() -> ForgeTypeId: ...
    @property
    def CurrencyPerWatt() -> ForgeTypeId: ...
    @property
    def CurrencyPerWattHour() -> ForgeTypeId: ...
    @property
    def CyclesPerSecond() -> ForgeTypeId: ...
    @property
    def Decimeters() -> ForgeTypeId: ...
    @property
    def Degrees() -> ForgeTypeId: ...
    @property
    def DekanewtonMeters() -> ForgeTypeId: ...
    @property
    def DekanewtonMetersPerMeter() -> ForgeTypeId: ...
    @property
    def Dekanewtons() -> ForgeTypeId: ...
    @property
    def DekanewtonsPerMeter() -> ForgeTypeId: ...
    @property
    def DekanewtonsPerSquareMeter() -> ForgeTypeId: ...
    @property
    def Fahrenheit() -> ForgeTypeId: ...
    @property
    def FahrenheitInterval() -> ForgeTypeId: ...
    @property
    def Feet() -> ForgeTypeId: ...
    @property
    def FeetOfWater39_2DegreesFahrenheit() -> ForgeTypeId: ...
    @property
    def FeetOfWater39_2DegreesFahrenheitPer100Feet() -> ForgeTypeId: ...
    @property
    def FeetPerKip() -> ForgeTypeId: ...
    @property
    def FeetPerMinute() -> ForgeTypeId: ...
    @property
    def FeetPerSecond() -> ForgeTypeId: ...
    @property
    def FeetPerSecondSquared() -> ForgeTypeId: ...
    @property
    def FeetToTheFourthPower() -> ForgeTypeId: ...
    @property
    def FeetToTheSixthPower() -> ForgeTypeId: ...
    @property
    def Fixed() -> ForgeTypeId: ...
    @property
    def Footcandles() -> ForgeTypeId: ...
    @property
    def Footlamberts() -> ForgeTypeId: ...
    @property
    def General() -> ForgeTypeId: ...
    @property
    def Gradians() -> ForgeTypeId: ...
    @property
    def GrainsPerHourSquareFootInchMercury() -> ForgeTypeId: ...
    @property
    def Hectares() -> ForgeTypeId: ...
    @property
    def Hertz() -> ForgeTypeId: ...
    @property
    def Horsepower() -> ForgeTypeId: ...
    @property
    def HourSquareFootDegreesFahrenheitPerBritishThermalUnit() -> ForgeTypeId: ...
    @property
    def Hours() -> ForgeTypeId: ...
    @property
    def Inches() -> ForgeTypeId: ...
    @property
    def InchesOfMercury32DegreesFahrenheit() -> ForgeTypeId: ...
    @property
    def InchesOfWater60DegreesFahrenheit() -> ForgeTypeId: ...
    @property
    def InchesOfWater60DegreesFahrenheitPer100Feet() -> ForgeTypeId: ...
    @property
    def InchesPerSecondSquared() -> ForgeTypeId: ...
    @property
    def InchesToTheFourthPower() -> ForgeTypeId: ...
    @property
    def InchesToTheSixthPower() -> ForgeTypeId: ...
    @property
    def InverseDegreesCelsius() -> ForgeTypeId: ...
    @property
    def InverseDegreesFahrenheit() -> ForgeTypeId: ...
    @property
    def InverseKilonewtons() -> ForgeTypeId: ...
    @property
    def InverseKips() -> ForgeTypeId: ...
    @property
    def Joules() -> ForgeTypeId: ...
    @property
    def JoulesPerGram() -> ForgeTypeId: ...
    @property
    def JoulesPerGramDegreeCelsius() -> ForgeTypeId: ...
    @property
    def JoulesPerKelvin() -> ForgeTypeId: ...
    @property
    def JoulesPerKilogramDegreeCelsius() -> ForgeTypeId: ...
    @property
    def Kelvin() -> ForgeTypeId: ...
    @property
    def KelvinInterval() -> ForgeTypeId: ...
    @property
    def Kiloamperes() -> ForgeTypeId: ...
    @property
    def Kilocalories() -> ForgeTypeId: ...
    @property
    def KilocaloriesPerSecond() -> ForgeTypeId: ...
    @property
    def KilogramForceMeters() -> ForgeTypeId: ...
    @property
    def KilogramForceMetersPerMeter() -> ForgeTypeId: ...
    @property
    def Kilograms() -> ForgeTypeId: ...
    @property
    def KilogramsForce() -> ForgeTypeId: ...
    @property
    def KilogramsForcePerMeter() -> ForgeTypeId: ...
    @property
    def KilogramsForcePerSquareMeter() -> ForgeTypeId: ...
    @property
    def KilogramsPerCubicMeter() -> ForgeTypeId: ...
    @property
    def KilogramsPerHour() -> ForgeTypeId: ...
    @property
    def KilogramsPerKilogramKelvin() -> ForgeTypeId: ...
    @property
    def KilogramsPerMeter() -> ForgeTypeId: ...
    @property
    def KilogramsPerMeterHour() -> ForgeTypeId: ...
    @property
    def KilogramsPerMeterSecond() -> ForgeTypeId: ...
    @property
    def KilogramsPerMinute() -> ForgeTypeId: ...
    @property
    def KilogramsPerSecond() -> ForgeTypeId: ...


class IFamilyLoadOptions:
    def OnFamilyFound(self, familyInUse: bool) -> Tuple[bool, bool]: ...
    def OnSharedFamilyFound(self, sharedFamily: Family, familyInUse: bool) -> Tuple[bool, FamilySource, bool]: ...


class BooleanOperationsUtils:
    def ExecuteBooleanOperationModifyingOriginalSolid(solid0: Solid, solid1: Solid, booleanType: BooleanOperationsType) -> None: ...
    def CutWithHalfSpaceModifyingOriginalSolid(solid: Solid, plane: Plane) -> None: ...
    @property
    def IsValidObject(self) -> bool: ...
    def ExecuteBooleanOperation(solid0: Solid, solid1: Solid, booleanType: BooleanOperationsType) -> Solid: ...
    def CutWithHalfSpace(solid: Solid, plane: Plane) -> Solid: ...
    def Dispose(self) -> None: ...


class Solid(GeometryObject):
    @property
    def Edges(self) -> EdgeArray: ...
    @property
    def Faces(self) -> FaceArray: ...
    @property
    def SurfaceArea(self) -> float: ...
    @property
    def Volume(self) -> float: ...
    def ComputeCentroid(self) -> XYZ: ...
    def IntersectWithCurve(self, curve: Curve, options: SolidCurveIntersectionOptions) -> SolidCurveIntersection: ...
    def GetBoundingBox(self) -> BoundingBoxXYZ: ...


class BaseExportOptions:
    @property
    def PropOverrides(self) -> PropOverrideMode: ...
    @PropOverrides.setter
    def PropOverrides(self, propOverrides: PropOverrideMode) -> None: ...
    @property
    def LayerMapping(self) -> str: ...
    @LayerMapping.setter
    def LayerMapping(self, layerMapping: str) -> None: ...
    @property
    def HatchPatternsFileName(self) -> str: ...
    @HatchPatternsFileName.setter
    def HatchPatternsFileName(self, hatchPatternsFileName: str) -> None: ...
    @property
    def Colors(self) -> ExportColorMode: ...
    @Colors.setter
    def Colors(self, colors: ExportColorMode) -> None: ...
    @property
    def HideScopeBox(self) -> bool: ...
    @HideScopeBox.setter
    def HideScopeBox(self, hideScopeBox: bool) -> None: ...
    @property
    def HideReferencePlane(self) -> bool: ...
    @HideReferencePlane.setter
    def HideReferencePlane(self, hideReferencePlane: bool) -> None: ...
    @property
    def HideUnreferenceViewTags(self) -> bool: ...
    @HideUnreferenceViewTags.setter
    def HideUnreferenceViewTags(self, hideUnreferenceViewTags: bool) -> None: ...
    @property
    def PreserveCoincidentLines(self) -> bool: ...
    @PreserveCoincidentLines.setter
    def PreserveCoincidentLines(self, preserveCoincidentLines: bool) -> None: ...
    @property
    def IsValidObject(self) -> bool: ...
    def GetPredefinedSetupNames(document: Document) -> List[str]: ...
    def GetExportLayerTable(self) -> ExportLayerTable: ...
    def SetExportLayerTable(self, layerTable: ExportLayerTable) -> None: ...
    def GetExportLinetypeTable(self) -> ExportLinetypeTable: ...
    def SetExportLinetypeTable(self, linetypeTable: ExportLinetypeTable) -> None: ...
    def GetExportPatternTable(self) -> ExportPatternTable: ...
    def SetExportPatternTable(self, patternTable: ExportPatternTable) -> None: ...
    def GetExportFontTable(self) -> ExportFontTable: ...
    def SetExportFontTable(self, fontTable: ExportFontTable) -> None: ...
    def Dispose(self) -> None: ...


class ACADExportOptions(BaseExportOptions):
    @property
    def LineScaling(self) -> LineScaling: ...
    @LineScaling.setter
    def LineScaling(self, lineScaling: LineScaling) -> None: ...
    @property
    def LinetypesFileName(self) -> str: ...
    @LinetypesFileName.setter
    def LinetypesFileName(self, linetypesFileName: str) -> None: ...
    @property
    def TextTreatment(self) -> TextTreatment: ...
    @TextTreatment.setter
    def TextTreatment(self, textTreatment: TextTreatment) -> None: ...
    @property
    def ExportOfSolids(self) -> SolidGeometry: ...
    @ExportOfSolids.setter
    def ExportOfSolids(self, exportOfSolids: SolidGeometry) -> None: ...
    @property
    def ACAPreference(self) -> ACAObjectPreference: ...
    @ACAPreference.setter
    def ACAPreference(self, aCAPreference: ACAObjectPreference) -> None: ...
    @property
    def TargetUnit(self) -> ExportUnit: ...
    @TargetUnit.setter
    def TargetUnit(self, targetUnit: ExportUnit) -> None: ...
    @property
    def SharedCoords(self) -> bool: ...
    @SharedCoords.setter
    def SharedCoords(self, sharedCoords: bool) -> None: ...
    @property
    def ExportingAreas(self) -> bool: ...
    @ExportingAreas.setter
    def ExportingAreas(self, exportingAreas: bool) -> None: ...
    @property
    def MarkNonplotLayers(self) -> bool: ...
    @MarkNonplotLayers.setter
    def MarkNonplotLayers(self, markNonplotLayers: bool) -> None: ...
    @property
    def NonplotSuffix(self) -> str: ...
    @NonplotSuffix.setter
    def NonplotSuffix(self, nonplotSuffix: str) -> None: ...
    @property
    def FileVersion(self) -> ACADVersion: ...
    @FileVersion.setter
    def FileVersion(self, fileVersion: ACADVersion) -> None: ...
    @property
    def UseHatchBackgroundColor(self) -> bool: ...
    @UseHatchBackgroundColor.setter
    def UseHatchBackgroundColor(self, useHatchBackgroundColor: bool) -> None: ...
    @property
    def HatchBackgroundColor(self) -> Color: ...
    @HatchBackgroundColor.setter
    def HatchBackgroundColor(self, hatchBackgroundColor: Color) -> None: ...


class DWGExportOptions(ACADExportOptions):
    @overload
    def __init__(self, option: DWGExportOptions): ...
    @overload
    def __init__(self): ...
    @property
    def MergedViews(self) -> bool: ...
    @MergedViews.setter
    def MergedViews(self, mergedViews: bool) -> None: ...
    def GetPredefinedOptions(document: Document, setup: str) -> DWGExportOptions: ...


class DXFExportOptions(ACADExportOptions):
    @overload
    def __init__(self, option: DXFExportOptions): ...
    @overload
    def __init__(self): ...
    def GetPredefinedOptions(document: Document, setup: str) -> DXFExportOptions: ...


class SATExportOptions:
    @overload
    def __init__(self, option: SATExportOptions): ...
    @overload
    def __init__(self): ...
    @property
    def IsValidObject(self) -> bool: ...
    def Dispose(self) -> None: ...


class DGNExportOptions(BaseExportOptions):
    @overload
    def __init__(self, option: DGNExportOptions): ...
    @overload
    def __init__(self): ...
    @property
    def MergedViews(self) -> bool: ...
    @MergedViews.setter
    def MergedViews(self, mergedViews: bool) -> None: ...
    @property
    def SeedName(self) -> str: ...
    @SeedName.setter
    def SeedName(self, seedName: str) -> None: ...
    @property
    def MasterUnits(self) -> bool: ...
    @MasterUnits.setter
    def MasterUnits(self, masterUnits: bool) -> None: ...
    @property
    def FileVersion(self) -> DGNFileFormat: ...
    @FileVersion.setter
    def FileVersion(self, fileVersion: DGNFileFormat) -> None: ...
    @property
    def WorkingUnits(self) -> bool: ...
    @WorkingUnits.setter
    def WorkingUnits(self, workingUnits: bool) -> None: ...
    def GetPredefinedSetupNames(document: Document) -> List[str]: ...
    def GetExportLineweightTable(self) -> ExportLineweightTable: ...
    def SetExportLineweightTable(self, lineweightTable: ExportLineweightTable) -> None: ...
    def GetPredefinedOptions(document: Document, setup: str) -> DGNExportOptions: ...


class CADExportOptions:


class DWFExportOptions(CADExportOptions):
    def __init__(self): ...
    @property
    def ExportingAreas(self) -> bool: ...
    @ExportingAreas.setter
    def ExportingAreas(self, __set_formal: bool) -> None: ...
    @property
    def ExportTexture(self) -> bool: ...
    @ExportTexture.setter
    def ExportTexture(self, __set_formal: bool) -> None: ...
    @property
    def MergedViews(self) -> bool: ...
    @MergedViews.setter
    def MergedViews(self, __set_formal: bool) -> None: ...
    @property
    def ExportObjectData(self) -> bool: ...
    @ExportObjectData.setter
    def ExportObjectData(self, __set_formal: bool) -> None: ...
    @property
    def StopOnError(self) -> bool: ...
    @StopOnError.setter
    def StopOnError(self, __set_formal: bool) -> None: ...
    @property
    def PaperFormat(self) -> ExportPaperFormat: ...
    @PaperFormat.setter
    def PaperFormat(self, __set_formal: ExportPaperFormat) -> None: ...
    @property
    def PortraitLayout(self) -> bool: ...
    @PortraitLayout.setter
    def PortraitLayout(self, __set_formal: bool) -> None: ...
    @property
    def ImageFormat(self) -> DWFImageFormat: ...
    @ImageFormat.setter
    def ImageFormat(self, __set_formal: DWFImageFormat) -> None: ...
    @property
    def ImageQuality(self) -> DWFImageQuality: ...
    @ImageQuality.setter
    def ImageQuality(self, __set_formal: DWFImageQuality) -> None: ...
    @property
    def CropBoxVisible(self) -> bool: ...
    @CropBoxVisible.setter
    def CropBoxVisible(self, __set_formal: bool) -> None: ...
    @property
    def ExportOnlyViewId(self) -> ElementId: ...
    @ExportOnlyViewId.setter
    def ExportOnlyViewId(self, __set_formal: ElementId) -> None: ...


class DWFXExportOptions(DWFExportOptions):
    def __init__(self): ...


class FBXExportOptions:
    def __init__(self): ...
    @property
    def StopOnError(self) -> bool: ...
    @StopOnError.setter
    def StopOnError(self, __set_formal: bool) -> None: ...
    @property
    def UseLevelsOfDetail(self) -> bool: ...
    @UseLevelsOfDetail.setter
    def UseLevelsOfDetail(self, __set_formal: bool) -> None: ...
    @property
    def LevelsOfDetailValue(self) -> int: ...
    @LevelsOfDetailValue.setter
    def LevelsOfDetailValue(self, __set_formal: int) -> None: ...
    @property
    def WithoutBoundaryEdges(self) -> bool: ...
    @WithoutBoundaryEdges.setter
    def WithoutBoundaryEdges(self, __set_formal: bool) -> None: ...


class Area(SpatialElement):
    @property
    def IsGrossInterior(self) -> bool: ...
    @property
    def AreaScheme(self) -> AreaScheme: ...


class BasePoint(Element):
    @property
    def IsShared(self) -> bool: ...
    @property
    def Position(self) -> XYZ: ...
    @property
    def Clipped(self) -> bool: ...
    @Clipped.setter
    def Clipped(self, clipped: bool) -> None: ...
    @property
    def SharedPosition(self) -> XYZ: ...
    def GetProjectBasePoint(cda: Document) -> BasePoint: ...
    def GetSurveyPoint(cda: Document) -> BasePoint: ...


class ViewOrientation3D:
    def __init__(self, eyePosition: XYZ, upDirection: XYZ, forwardDirection: XYZ): ...
    @property
    def EyePosition(self) -> XYZ: ...
    @property
    def UpDirection(self) -> XYZ: ...
    @property
    def ForwardDirection(self) -> XYZ: ...
    @property
    def IsValidObject(self) -> bool: ...
    def Dispose(self) -> None: ...


class View3D(View):
    @property
    def IsLocked(self) -> bool: ...
    @property
    def IsPerspective(self) -> bool: ...
    @property
    def IsSectionBoxActive(self) -> bool: ...
    @IsSectionBoxActive.setter
    def IsSectionBoxActive(self, status: bool) -> None: ...
    def GetRenderingSettings(self) -> RenderingSettings: ...
    def SetRenderingSettings(self, settings: RenderingSettings) -> None: ...
    def CanResetCameraTarget(self) -> bool: ...
    def ResetCameraTarget(self) -> None: ...
    def CreateIsometric(document: Document, viewFamilyTypeId: ElementId) -> View3D: ...
    def CreatePerspective(document: Document, viewFamilyTypeId: ElementId) -> View3D: ...
    def GetOrientation(self) -> ViewOrientation3D: ...
    def GetSavedOrientation(self) -> ViewOrientation3D: ...
    def SetOrientation(self, newViewOrientation3D: ViewOrientation3D) -> None: ...
    def OrientTo(self, forwardDirection: XYZ) -> None: ...
    def SaveOrientation(self) -> None: ...
    def CanSaveOrientation(self) -> bool: ...
    def SaveOrientationAndLock(self) -> None: ...
    def RestoreOrientationAndLock(self) -> None: ...
    def HasBeenLocked(self) -> bool: ...
    def Unlock(self) -> None: ...
    def SetSectionBox(self, boundingBoxXYZ: BoundingBoxXYZ) -> None: ...
    def GetSectionBox(self) -> BoundingBoxXYZ: ...
    def CanToggleBetweenPerspectiveAndIsometric(self) -> bool: ...
    def ToggleToPerspective(self) -> None: ...
    def ToggleToIsometric(self) -> None: ...


class PropertyLine(Element):


class GenericImportOptions:
    @property
    def RefPoint(self) -> XYZ: ...
    @RefPoint.setter
    def RefPoint(self, __set_formal: XYZ) -> None: ...


class GBXMLImportOptions:
    def __init__(self): ...


class ViewSet(APIObject):
    def __init__(self): ...
    def Clear(self) -> None: ...
    @property
    def Size(self) -> int: ...
    @property
    def IsEmpty(self) -> bool: ...
    def ForwardIterator(self) -> ViewSetIterator: ...
    def ReverseIterator(self) -> ViewSetIterator: ...
    def GetEnumerator(self) -> IEnumerator: ...
    def Contains(self, item: View) -> bool: ...
    def Insert(self, item: View) -> bool: ...
    def Erase(self, item: View) -> int: ...


class ViewSetIterator(APIObject):
    def __init__(self): ...
    @property
    def Current(self) -> Object: ...
    def MoveNext(self) -> bool: ...
    def Reset(self) -> None: ...


class SlabShapeCrease:
    @property
    def Curve(self) -> Curve: ...
    @property
    def CreaseType(self) -> SlabShapeCreaseType: ...
    @property
    def EndPoints(self) -> SlabShapeVertexArray: ...


class SlabShapeEditor:
    @property
    def IsEnabled(self) -> bool: ...
    def Enable(self) -> None: ...
    @property
    def SlabShapeVertices(self) -> SlabShapeVertexArray: ...
    @property
    def SlabShapeCreases(self) -> SlabShapeCreaseArray: ...
    @overload
    def ModifySubElement(self, crease: SlabShapeCrease, offset: float) -> None: ...
    @overload
    def ModifySubElement(self, vertex: SlabShapeVertex, offset: float) -> None: ...
    def DrawPoint(self, location: XYZ) -> SlabShapeVertex: ...
    def DrawSplitLine(self, startVertex: SlabShapeVertex, endVertex: SlabShapeVertex) -> SlabShapeCreaseArray: ...
    def ResetSlabShape(self) -> None: ...
    def PickSupport(self, gLine: Line) -> None: ...


class FamilyElementVisibility(APIObject):
    def __init__(self, visibilityType: FamilyElementVisibilityType): ...
    @property
    def VisibilityType(self) -> FamilyElementVisibilityType: ...
    @property
    def IsShownOnlyWhenCut(self) -> bool: ...
    @IsShownOnlyWhenCut.setter
    def IsShownOnlyWhenCut(self, bvalue: bool) -> None: ...
    @property
    def IsShownInPlanRCPCut(self) -> bool: ...
    @IsShownInPlanRCPCut.setter
    def IsShownInPlanRCPCut(self, bvalue: bool) -> None: ...
    @property
    def IsShownInTopBottom(self) -> bool: ...
    @IsShownInTopBottom.setter
    def IsShownInTopBottom(self, bvalue: bool) -> None: ...
    @property
    def IsShownInFrontBack(self) -> bool: ...
    @IsShownInFrontBack.setter
    def IsShownInFrontBack(self, bvalue: bool) -> None: ...
    @property
    def IsShownInLeftRight(self) -> bool: ...
    @IsShownInLeftRight.setter
    def IsShownInLeftRight(self, bvalue: bool) -> None: ...
    @property
    def IsShownInCoarse(self) -> bool: ...
    @IsShownInCoarse.setter
    def IsShownInCoarse(self, bvalue: bool) -> None: ...
    @property
    def IsShownInMedium(self) -> bool: ...
    @IsShownInMedium.setter
    def IsShownInMedium(self, bvalue: bool) -> None: ...
    @property
    def IsShownInFine(self) -> bool: ...
    @IsShownInFine.setter
    def IsShownInFine(self, bvalue: bool) -> None: ...


class SlabShapeCreaseArray(APIObject):
    def __init__(self): ...
    def Clear(self) -> None: ...
    @property
    def Size(self) -> int: ...
    @property
    def IsEmpty(self) -> bool: ...
    def ForwardIterator(self) -> SlabShapeCreaseArrayIterator: ...
    def ReverseIterator(self) -> SlabShapeCreaseArrayIterator: ...
    def GetEnumerator(self) -> IEnumerator: ...
    @property
    def Item(self, index: int) -> SlabShapeCrease: ...
    @Item.setter
    def Item(self, index: int, item: SlabShapeCrease) -> None: ...
    def Append(self, item: SlabShapeCrease) -> None: ...
    def Insert(self, item: SlabShapeCrease, index: int) -> None: ...


class SlabShapeCreaseArrayIterator(APIObject):
    def __init__(self): ...
    @property
    def Current(self) -> Object: ...
    def MoveNext(self) -> bool: ...
    def Reset(self) -> None: ...


class SlabShapeVertex:
    @property
    def Position(self) -> XYZ: ...
    @property
    def VertexType(self) -> SlabShapeVertexType: ...


class SlabShapeVertexArray(APIObject):
    def __init__(self): ...
    def Clear(self) -> None: ...
    @property
    def Size(self) -> int: ...
    @property
    def IsEmpty(self) -> bool: ...
    def ForwardIterator(self) -> SlabShapeVertexArrayIterator: ...
    def ReverseIterator(self) -> SlabShapeVertexArrayIterator: ...
    def GetEnumerator(self) -> IEnumerator: ...
    @property
    def Item(self, index: int) -> SlabShapeVertex: ...
    @Item.setter
    def Item(self, index: int, item: SlabShapeVertex) -> None: ...
    def Append(self, item: SlabShapeVertex) -> None: ...
    def Insert(self, item: SlabShapeVertex, index: int) -> None: ...


class SlabShapeVertexArrayIterator(APIObject):
    def __init__(self): ...
    @property
    def Current(self) -> Object: ...
    def MoveNext(self) -> bool: ...
    def Reset(self) -> None: ...


class CategoryNameMap(APIObject):
    def __init__(self): ...
    def Clear(self) -> None: ...
    @property
    def Size(self) -> int: ...
    @property
    def IsEmpty(self) -> bool: ...
    def ForwardIterator(self) -> CategoryNameMapIterator: ...
    def ReverseIterator(self) -> CategoryNameMapIterator: ...
    def GetEnumerator(self) -> IEnumerator: ...
    @property
    def Item(self, key: str) -> Category: ...
    @Item.setter
    def Item(self, key: str, item: Category) -> None: ...
    def Contains(self, key: str) -> bool: ...
    def Insert(self, key: str, item: Category) -> bool: ...
    def Erase(self, key: str) -> int: ...


class CategoryNameMapIterator(APIObject):
    def __init__(self): ...
    @property
    def Current(self) -> Object: ...
    def MoveNext(self) -> bool: ...
    def Reset(self) -> None: ...
    @property
    def Key(self) -> str: ...


class Categories(CategoryNameMap):
    @property
    def Item(self, name: str) -> Category: ...
    @property
    def Item(self, categoryId: BuiltInCategory) -> Category: ...
    @Item.setter
    def Item(self, name: str, item: Category) -> None: ...
    def Contains(self, name: str) -> bool: ...
    @property
    def Size(self) -> int: ...
    @property
    def IsEmpty(self) -> bool: ...
    def ForwardIterator(self) -> CategoryNameMapIterator: ...
    def GetEnumerator(self) -> IEnumerator: ...
    def ReverseIterator(self) -> CategoryNameMapIterator: ...
    def Insert(self, key: str, item: Category) -> bool: ...
    def NewSubcategory(self, parentCategory: Category, name: str) -> Category: ...


class CurveArrArray(APIObject):
    def __init__(self): ...
    def Clear(self) -> None: ...
    @property
    def Size(self) -> int: ...
    @property
    def IsEmpty(self) -> bool: ...
    def ForwardIterator(self) -> CurveArrArrayIterator: ...
    def ReverseIterator(self) -> CurveArrArrayIterator: ...
    def GetEnumerator(self) -> IEnumerator: ...
    @property
    def Item(self, index: int) -> CurveArray: ...
    @Item.setter
    def Item(self, index: int, item: CurveArray) -> None: ...
    def Append(self, item: CurveArray) -> None: ...
    def Insert(self, item: CurveArray, index: int) -> None: ...


class CurveArrArrayIterator(APIObject):
    def __init__(self): ...
    @property
    def Current(self) -> Object: ...
    def MoveNext(self) -> bool: ...
    def Reset(self) -> None: ...


class CurveArray(APIObject):
    def __init__(self): ...
    def Clear(self) -> None: ...
    @property
    def Size(self) -> int: ...
    @property
    def IsEmpty(self) -> bool: ...
    def ForwardIterator(self) -> CurveArrayIterator: ...
    def ReverseIterator(self) -> CurveArrayIterator: ...
    def GetEnumerator(self) -> IEnumerator: ...
    @property
    def Item(self, index: int) -> Curve: ...
    @Item.setter
    def Item(self, index: int, item: Curve) -> None: ...
    def Append(self, item: Curve) -> None: ...
    def Insert(self, item: Curve, index: int) -> None: ...


class CurveArrayIterator(APIObject):
    def __init__(self): ...
    @property
    def Current(self) -> Object: ...
    def MoveNext(self) -> bool: ...
    def Reset(self) -> None: ...


class GeometryElement(GeometryObject):
    def GetEnumerator(self) -> IEnumerator: ...
    def GetBoundingBox(self) -> BoundingBoxXYZ: ...
    @property
    def MaterialElement(self) -> Material: ...
    def GetTransformed(self, transform: Transform) -> GeometryElement: ...


class BooleanOperationsType:
    Union = 0
    Difference = 1
    Intersect = 2


class SolidGeometry:
    Polymesh = 0
    ACIS = 1


class ACAObjectPreference:
    Object = 0
    Geometry = 1


class ExportUnit:
    Default = 0
    Inch = 1
    Foot = 2
    Millimeter = 3
    Centimeter = 4
    Meter = 5


class ExportSheetType:
    Current = 0
    Visible = 1
    Select = 2


class PropOverrideMode:
    ByEntity = 0
    ByLayer = 1
    NewLayer = 2


class LineScaling:
    ViewScale = 0
    ModelSpace = 1
    PaperSpace = 2


class TextTreatment:
    Exact = 0
    Approximate = 1


class ExportColorMode:
    IndexColors = 0
    TrueColor = 1
    TrueColorPerView = 2


class ACADVersion:
    R2007 = 3
    R2010 = 16
    R2013 = 22
    Default = 28
    R2018 = 28


class DGNFileFormat:
    DGNVersion7 = 19
    Default = 20
    DGNVersion8 = 20


class BuildingType:
    kAutomotiveFacility = 0
    kConventionCenter = 1
    kCourthouse = 2
    kDiningBarLoungeOrLeisure = 3
    kDiningCafeteriaFastFood = 4
    kDiningFamily = 5
    kDormitory = 6
    kExerciseCenter = 7
    kFireStation = 8
    kGymnasium = 9
    kHospitalOrHealthcare = 10
    kHotel = 11
    kLibrary = 12
    kManufacturing = 13
    kMotel = 14
    kMotionPictureTheatre = 15
    kMultiFamily = 16
    kMuseum = 17
    kOffice = 18
    kParkingGarage = 19
    kPenitentiary = 20
    kPerformingArtsTheater = 21
    kPoliceStation = 22
    kPostOffice = 23
    kReligiousBuilding = 24
    kRetail = 25
    kSchoolOrUniversity = 26
    kSportsArena = 27
    kTownHall = 28
    kTransportation = 29
    kWarehouse = 30
    kWorkshop = 31
    kNoOfBuildingTypes = -1


class ServiceType:
    kCentralHeatingRadiators = 0
    kCentralHeatingConvectors = 1
    kCentralHeatingRadiantFloor = 2
    kCentralHeatingHotAir = 3
    kOtherRoomHeater = 4
    kRadiantHeaterFlue = 5
    kRadiantHeaterNoFlue = 6
    kRadiantHeaterMultiburner = 7
    kForcedConvectionHeaterFlue = 8
    kForcedConvectionHeaterNoFlue = 9
    kVAVSingleDuct = 10
    kVAVDualDuct = 11
    kVAVIndoorPackagedCabinet = 12
    kVAVTerminalReheat = 13
    kFanCoilSystem = 14
    kInductionSystem = 15
    kConstantVolumeFixedOA = 16
    kConstantVolumeVariableOA = 17
    kConstantVolumeTerminalReheat = 18
    kMultizoneHotDeckColdDeck = 19
    kConstantVolumeDualDuct = 20
    kRadiantCooledCeilings = 21
    kActiveChilledBeams = 22
    kWaterLoopHeatPump = 23
    kVariableRefrigerantFlow = 24
    kSplitSystemsWithNaturalVentilation = 25
    kSplitSystemsWithMechanicalVentilation = 26
    kSplitSystemsWithMechanicalVentilationWithCooling = 27
    kNoServiceType = -1


class ExportPaperFormat:
    Default = 0
    ANSI_A = 1
    ANSI_B = 2
    ANSI_C = 3
    ANSI_D = 4
    ANSI_E = 5
    ISO_A4 = 6
    ISO_A3 = 7
    ISO_A2 = 8
    ISO_A1 = 9
    ISO_A0 = 10
    ISO_B4 = 11
    ISO_B3 = 12
    ISO_B2 = 13
    ISO_B1 = 14
    ARCH_A = 15
    ARCH_B = 16
    ARCH_C = 17
    ARCH_D = 18
    ARCH_E = 19
    ARCH_E1 = 20
    ARCH_E2 = 21
    ARCH_E3 = 22


class BoxPlacement:
    Center = 0
    TopLeft = 1
    TopRight = 2
    BottomRight = 3
    BottomLeft = 4


class FamilyElementVisibilityType:
    Model = 0
    ViewSpecific = 1


class FamilySource:
    Project = 0
    Family = 1


class CategorySet(APIObject):
    def __init__(self): ...
    def Clear(self) -> None: ...
    @property
    def Size(self) -> int: ...
    @property
    def IsEmpty(self) -> bool: ...
    def ForwardIterator(self) -> CategorySetIterator: ...
    def ReverseIterator(self) -> CategorySetIterator: ...
    def GetEnumerator(self) -> IEnumerator: ...
    def Contains(self, item: Category) -> bool: ...
    def Insert(self, item: Category) -> bool: ...
    def Erase(self, item: Category) -> int: ...


class CategorySetIterator(APIObject):
    def __init__(self): ...
    @property
    def Current(self) -> Object: ...
    def MoveNext(self) -> bool: ...
    def Reset(self) -> None: ...


class CombinableElementArray(APIObject):
    def __init__(self): ...
    def Clear(self) -> None: ...
    @property
    def Size(self) -> int: ...
    @property
    def IsEmpty(self) -> bool: ...
    def ForwardIterator(self) -> CombinableElementArrayIterator: ...
    def ReverseIterator(self) -> CombinableElementArrayIterator: ...
    def GetEnumerator(self) -> IEnumerator: ...
    @property
    def Item(self, index: int) -> CombinableElement: ...
    @Item.setter
    def Item(self, index: int, item: CombinableElement) -> None: ...
    def Append(self, item: CombinableElement) -> None: ...
    def Insert(self, item: CombinableElement, index: int) -> None: ...


class CombinableElementArrayIterator(APIObject):
    def __init__(self): ...
    @property
    def Current(self) -> Object: ...
    def MoveNext(self) -> bool: ...
    def Reset(self) -> None: ...


class HermiteSplineTangents:
    def __init__(self): ...
    @property
    def StartTangent(self) -> XYZ: ...
    @StartTangent.setter
    def StartTangent(self, startTangent: XYZ) -> None: ...
    @property
    def EndTangent(self) -> XYZ: ...
    @EndTangent.setter
    def EndTangent(self, endTangent: XYZ) -> None: ...
    @property
    def IsValidObject(self) -> bool: ...
    def Dispose(self) -> None: ...


class BoundingBoxXYZ(APIObject):
    def __init__(self): ...
    @property
    def Transform(self) -> Transform: ...
    @Transform.setter
    def Transform(self, A_0: Transform) -> None: ...
    @property
    def Min(self) -> XYZ: ...
    @Min.setter
    def Min(self, A_0: XYZ) -> None: ...
    @property
    def Max(self) -> XYZ: ...
    @Max.setter
    def Max(self, A_0: XYZ) -> None: ...
    @property
    def Bounds(self, bound: int) -> XYZ: ...
    @Bounds.setter
    def Bounds(self, bound: int, __unnamed001: XYZ) -> None: ...
    @property
    def MinEnabled(self, dim: int) -> bool: ...
    @MinEnabled.setter
    def MinEnabled(self, dim: int, enabled: bool) -> None: ...
    @property
    def MaxEnabled(self, dim: int) -> bool: ...
    @MaxEnabled.setter
    def MaxEnabled(self, dim: int, enabled: bool) -> None: ...
    @property
    def BoundEnabled(self, bound: int, dim: int) -> bool: ...
    @BoundEnabled.setter
    def BoundEnabled(self, bound: int, dim: int, enabled: bool) -> None: ...
    @property
    def Enabled(self) -> bool: ...
    @Enabled.setter
    def Enabled(self, enabled: bool) -> None: ...


class DoubleArray(APIObject):
    def __init__(self): ...
    def Clear(self) -> None: ...
    @property
    def Size(self) -> int: ...
    @property
    def IsEmpty(self) -> bool: ...
    def ForwardIterator(self) -> DoubleArrayIterator: ...
    def ReverseIterator(self) -> DoubleArrayIterator: ...
    def GetEnumerator(self) -> IEnumerator: ...
    @property
    def Item(self, index: int) -> float: ...
    @Item.setter
    def Item(self, index: int, item: float) -> None: ...
    def Append(self, item: float) -> Tuple[float]: ...
    def Insert(self, item: float, index: int) -> Tuple[float]: ...


class DoubleArrayIterator(APIObject):
    def __init__(self): ...
    @property
    def Current(self) -> Object: ...
    def MoveNext(self) -> bool: ...
    def Reset(self) -> None: ...


class FaceArray(APIObject):
    def __init__(self): ...
    def Clear(self) -> None: ...
    @property
    def Size(self) -> int: ...
    @property
    def IsEmpty(self) -> bool: ...
    def ForwardIterator(self) -> FaceArrayIterator: ...
    def ReverseIterator(self) -> FaceArrayIterator: ...
    def GetEnumerator(self) -> IEnumerator: ...
    @property
    def Item(self, index: int) -> Face: ...
    @Item.setter
    def Item(self, index: int, item: Face) -> None: ...
    def Append(self, item: Face) -> None: ...
    def Insert(self, item: Face, index: int) -> None: ...


class FaceArrayIterator(APIObject):
    def __init__(self): ...
    @property
    def Current(self) -> Object: ...
    def MoveNext(self) -> bool: ...
    def Reset(self) -> None: ...


class HermiteSpline(Curve):
    @property
    def IsPeriodic(self) -> bool: ...
    @property
    def ControlPoints(self) -> List[XYZ]: ...
    @ControlPoints.setter
    def ControlPoints(self, controlPoints: List[XYZ]) -> None: ...
    @property
    def Tangents(self) -> List[XYZ]: ...
    @property
    def Parameters(self) -> DoubleArray: ...
    @overload
    def Create(controlPoints: List[XYZ], periodic: bool, tangents: HermiteSplineTangents) -> HermiteSpline: ...
    @overload
    def Create(controlPoints: List[XYZ], periodic: bool) -> HermiteSpline: ...


class Point(GeometryObject):
    @overload
    def Create(coord: XYZ, id: ElementId) -> Point: ...
    @overload
    def Create(coord: XYZ) -> Point: ...
    @property
    def Coord(self) -> XYZ: ...
    @property
    def Reference(self) -> Reference: ...


class IntersectionResultArray(APIObject):
    def __init__(self): ...
    def Clear(self) -> None: ...
    @property
    def Size(self) -> int: ...
    @property
    def IsEmpty(self) -> bool: ...
    def ForwardIterator(self) -> IntersectionResultArrayIterator: ...
    def ReverseIterator(self) -> IntersectionResultArrayIterator: ...
    def GetEnumerator(self) -> IEnumerator: ...
    @property
    def Item(self, index: int) -> IntersectionResult: ...
    @Item.setter
    def Item(self, index: int, item: IntersectionResult) -> None: ...
    def Append(self, item: IntersectionResult) -> None: ...
    def Insert(self, item: IntersectionResult, index: int) -> None: ...


class IntersectionResultArrayIterator(APIObject):
    def __init__(self): ...
    @property
    def Current(self) -> Object: ...
    def MoveNext(self) -> bool: ...
    def Reset(self) -> None: ...


class Binding(APIObject):


class ElementBinding(Binding):
    @property
    def Categories(self) -> CategorySet: ...
    @Categories.setter
    def Categories(self, categories: CategorySet) -> None: ...


class InstanceBinding(ElementBinding):
    @overload
    def __init__(self, categories: CategorySet): ...
    @overload
    def __init__(self): ...


class TypeBinding(ElementBinding):
    @overload
    def __init__(self, categories: CategorySet): ...
    @overload
    def __init__(self): ...


class ProjectPosition:
    @overload
    def __init__(self, ew: float, ns: float, elevation: float, angle: float): ...
    @overload
    def __init__(self, other: ProjectPosition): ...
    @property
    def EastWest(self) -> float: ...
    @EastWest.setter
    def EastWest(self, eastWest: float) -> None: ...
    @property
    def NorthSouth(self) -> float: ...
    @NorthSouth.setter
    def NorthSouth(self, northSouth: float) -> None: ...
    @property
    def Elevation(self) -> float: ...
    @Elevation.setter
    def Elevation(self, elevation: float) -> None: ...
    @property
    def Angle(self) -> float: ...
    @Angle.setter
    def Angle(self, angle: float) -> None: ...
    @property
    def IsValidObject(self) -> bool: ...
    def Dispose(self) -> None: ...


class Blend(GenericForm):
    @property
    def TopSketch(self) -> Sketch: ...
    @property
    def BottomSketch(self) -> Sketch: ...
    @property
    def BottomOffset(self) -> float: ...
    @BottomOffset.setter
    def BottomOffset(self, bottomOffset: float) -> None: ...
    @property
    def TopOffset(self) -> float: ...
    @TopOffset.setter
    def TopOffset(self, topOffset: float) -> None: ...
    def GetVertexConnectionMap(self) -> VertexIndexPairArray: ...
    def SetVertexConnectionMap(self, vertexMap: VertexIndexPairArray) -> None: ...
    @property
    def BottomProfile(self) -> CurveArrArray: ...
    @property
    def TopProfile(self) -> CurveArrArray: ...


class SweptBlend(GenericForm):
    @property
    def TopSketch(self) -> Sketch: ...
    @property
    def TopProfileSymbol(self) -> FamilySymbolProfile: ...
    @property
    def BottomSketch(self) -> Sketch: ...
    @property
    def BottomProfileSymbol(self) -> FamilySymbolProfile: ...
    @property
    def PathSketch(self) -> Sketch: ...
    @property
    def SelectedPath(self) -> Curve: ...
    def GetVertexConnectionMap(self) -> VertexIndexPairArray: ...
    def SetVertexConnectionMap(self, vertexMap: VertexIndexPairArray) -> None: ...
    @property
    def BottomProfile(self) -> CurveArrArray: ...
    @property
    def TopProfile(self) -> CurveArrArray: ...


class VertexIndexPair:
    def __init__(self, iTop: int, iBottom: int): ...
    @property
    def Top(self) -> int: ...
    @Top.setter
    def Top(self, ivalue: int) -> None: ...
    @property
    def Bottom(self) -> int: ...
    @Bottom.setter
    def Bottom(self, ivalue: int) -> None: ...


class VertexIndexPairArray(APIObject):
    def __init__(self): ...
    def Clear(self) -> None: ...
    @property
    def Size(self) -> int: ...
    @property
    def IsEmpty(self) -> bool: ...
    def ForwardIterator(self) -> VertexIndexPairArrayIterator: ...
    def ReverseIterator(self) -> VertexIndexPairArrayIterator: ...
    def GetEnumerator(self) -> IEnumerator: ...
    @property
    def Item(self, index: int) -> VertexIndexPair: ...
    @Item.setter
    def Item(self, index: int, item: VertexIndexPair) -> None: ...
    def Append(self, item: VertexIndexPair) -> None: ...
    def Insert(self, item: VertexIndexPair, index: int) -> None: ...


class VertexIndexPairArrayIterator(APIObject):
    def __init__(self): ...
    @property
    def Current(self) -> Object: ...
    def MoveNext(self) -> bool: ...
    def Reset(self) -> None: ...


class DefinitionFile(APIObject):
    @property
    def Groups(self) -> DefinitionGroups: ...
    @property
    def Filename(self) -> str: ...


class City(APIObject):
    @property
    def Name(self) -> str: ...
    @property
    def WeatherStation(self) -> str: ...
    @property
    def Latitude(self) -> float: ...
    @property
    def Longitude(self) -> float: ...
    @property
    def TimeZone(self) -> float: ...


class CitySet(APIObject):
    def __init__(self): ...
    def Clear(self) -> None: ...
    @property
    def Size(self) -> int: ...
    @property
    def IsEmpty(self) -> bool: ...
    def ForwardIterator(self) -> CitySetIterator: ...
    def ReverseIterator(self) -> CitySetIterator: ...
    def GetEnumerator(self) -> IEnumerator: ...
    def Contains(self, item: City) -> bool: ...
    def Insert(self, item: City) -> bool: ...
    def Erase(self, item: City) -> int: ...


class CitySetIterator(APIObject):
    def __init__(self): ...
    @property
    def Current(self) -> Object: ...
    def MoveNext(self) -> bool: ...
    def Reset(self) -> None: ...


class DocumentSet(APIObject):
    def __init__(self): ...
    def Clear(self) -> None: ...
    @property
    def Size(self) -> int: ...
    @property
    def IsEmpty(self) -> bool: ...
    def ForwardIterator(self) -> DocumentSetIterator: ...
    def ReverseIterator(self) -> DocumentSetIterator: ...
    def GetEnumerator(self) -> IEnumerator: ...
    def Contains(self, item: Document) -> bool: ...
    def Insert(self, item: Document) -> bool: ...
    def Erase(self, item: Document) -> int: ...


class DocumentSetIterator(APIObject):
    def __init__(self): ...
    @property
    def Current(self) -> Object: ...
    def MoveNext(self) -> bool: ...
    def Reset(self) -> None: ...


class ModelPath:
    @property
    def CentralServerPath(self) -> str: ...
    @property
    def Empty(self) -> bool: ...
    @property
    def ServerPath(self) -> bool: ...
    @property
    def CloudPath(self) -> bool: ...
    @property
    def Region(self) -> str: ...
    @property
    def IsValidObject(self) -> bool: ...
    def Compare(self, otherPath: ModelPath) -> int: ...
    def GetProjectGUID(self) -> Guid: ...
    def GetModelGUID(self) -> Guid: ...
    def Dispose(self) -> None: ...


class FilePath(ModelPath):
    def __init__(self, path: str): ...


class ServerPath(ModelPath):
    def __init__(self, centralServerLocation: str, path: str): ...


class OpenOptions:
    def __init__(self): ...
    @property
    def DetachFromCentralOption(self) -> DetachFromCentralOption: ...
    @DetachFromCentralOption.setter
    def DetachFromCentralOption(self, detachFromCentralOption: DetachFromCentralOption) -> None: ...
    @property
    def Audit(self) -> bool: ...
    @Audit.setter
    def Audit(self, audit: bool) -> None: ...
    @property
    def AllowOpeningLocalByWrongUser(self) -> bool: ...
    @AllowOpeningLocalByWrongUser.setter
    def AllowOpeningLocalByWrongUser(self, allowOpeningLocalByWrongUser: bool) -> None: ...
    @property
    def OpenForeignOption(self) -> OpenForeignOption: ...
    @OpenForeignOption.setter
    def OpenForeignOption(self, openForeignOption: OpenForeignOption) -> None: ...
    @property
    def IsValidObject(self) -> bool: ...
    def GetOpenWorksetsConfiguration(self) -> WorksetConfiguration: ...
    def SetOpenWorksetsConfiguration(self, openConfiguration: WorksetConfiguration) -> None: ...
    def Dispose(self) -> None: ...


class ModelPathUtils:
    def IsValidUserVisibleFullServerPath(strPath: str) -> bool: ...
    def ConvertUserVisiblePathToModelPath(strPath: str) -> ModelPath: ...
    def ConvertModelPathToUserVisiblePath(path: ModelPath) -> str: ...
    @overload
    def ConvertCloudGUIDsToCloudPath(region: str, projectId: Guid, modelId: Guid) -> ModelPath: ...
    @overload
    def ConvertCloudGUIDsToCloudPath(projectId: Guid, modelId: Guid) -> ModelPath: ...
    @property
    def CloudRegionUS() -> str: ...
    @property
    def CloudRegionEMEA() -> str: ...


class Face(GeometryObject):
    def GetSurface(self) -> Surface: ...
    @property
    def OrientationMatchesSurfaceOrientation(self) -> bool: ...
    @property
    def HasRegions(self) -> bool: ...
    def GetRegions(self) -> List[Face]: ...
    @property
    def EdgeLoops(self) -> EdgeArrayArray: ...
    def GetEdgesAsCurveLoops(self) -> List[CurveLoop]: ...
    @property
    def MaterialElementId(self) -> ElementId: ...
    @property
    def IsTwoSided(self) -> bool: ...
    @overload
    def Triangulate(self, levelOfDetail: float) -> Mesh: ...
    @overload
    def Triangulate(self) -> Mesh: ...
    def Evaluate(self, params: UV) -> XYZ: ...
    def GetBoundingBox(self) -> BoundingBoxUV: ...
    @property
    def Reference(self) -> Reference: ...
    @property
    def Area(self) -> float: ...
    @property
    def IsCyclic(self, paramIdx: int) -> bool: ...
    @property
    def Period(self, paramIdx: int) -> float: ...
    def ComputeDerivatives(self, point: UV) -> Transform: ...
    def ComputeSecondDerivatives(self, point: UV) -> FaceSecondDerivatives: ...
    def ComputeNormal(self, point: UV) -> XYZ: ...
    @overload
    def IsInside(self, point: UV) -> Tuple[bool, IntersectionResult]: ...
    @overload
    def IsInside(self, point: UV) -> bool: ...
    @overload
    def Intersect(self, face: Face) -> Tuple[FaceIntersectionFaceResult, Curve]: ...
    @overload
    def Intersect(self, face: Face) -> FaceIntersectionFaceResult: ...
    @overload
    def Intersect(self, curve: Curve) -> Tuple[SetComparisonResult, IntersectionResultArray]: ...
    @overload
    def Intersect(self, curve: Curve) -> SetComparisonResult: ...
    def Project(self, point: XYZ) -> IntersectionResult: ...


class DetailCurve(CurveElement):


class DetailCurveArray(APIObject):
    def __init__(self): ...
    def Clear(self) -> None: ...
    @property
    def Size(self) -> int: ...
    @property
    def IsEmpty(self) -> bool: ...
    def ForwardIterator(self) -> DetailCurveArrayIterator: ...
    def ReverseIterator(self) -> DetailCurveArrayIterator: ...
    def GetEnumerator(self) -> IEnumerator: ...
    @property
    def Item(self, index: int) -> DetailCurve: ...
    @Item.setter
    def Item(self, index: int, item: DetailCurve) -> None: ...
    def Append(self, item: DetailCurve) -> None: ...
    def Insert(self, item: DetailCurve, index: int) -> None: ...


class DetailCurveArrayIterator(APIObject):
    def __init__(self): ...
    @property
    def Current(self) -> Object: ...
    def MoveNext(self) -> bool: ...
    def Reset(self) -> None: ...


class GeomCombination(CombinableElement):
    @property
    def AllMembers(self) -> CombinableElementArray: ...


class ModelCurve(CurveElement):
    def GetVisibility(self) -> FamilyElementVisibility: ...
    def SetVisibility(self, visibility: FamilyElementVisibility) -> None: ...
    @property
    def Subcategory(self) -> GraphicsStyle: ...
    @Subcategory.setter
    def Subcategory(self, subcategory: GraphicsStyle) -> None: ...
    @property
    def TrussCurveType(self) -> TrussCurveType: ...
    @TrussCurveType.setter
    def TrussCurveType(self, type: TrussCurveType) -> None: ...
    @property
    def IsReferenceLine(self) -> bool: ...
    def ChangeToReferenceLine(self) -> None: ...


class ModelCurveArray(APIObject):
    def __init__(self): ...
    def Clear(self) -> None: ...
    @property
    def Size(self) -> int: ...
    @property
    def IsEmpty(self) -> bool: ...
    def ForwardIterator(self) -> ModelCurveArrayIterator: ...
    def ReverseIterator(self) -> ModelCurveArrayIterator: ...
    def GetEnumerator(self) -> IEnumerator: ...
    @property
    def Item(self, index: int) -> ModelCurve: ...
    @Item.setter
    def Item(self, index: int, item: ModelCurve) -> None: ...
    def Append(self, item: ModelCurve) -> None: ...
    def Insert(self, item: ModelCurve, index: int) -> None: ...


class ModelCurveArrayIterator(APIObject):
    def __init__(self): ...
    @property
    def Current(self) -> Object: ...
    def MoveNext(self) -> bool: ...
    def Reset(self) -> None: ...


class SymbolicCurve(CurveElement):
    @property
    def IsDrawnInForeground(self) -> bool: ...
    @IsDrawnInForeground.setter
    def IsDrawnInForeground(self, isDrawnInForeground: bool) -> None: ...
    @property
    def ReferenceType(self) -> ReferenceType: ...
    @ReferenceType.setter
    def ReferenceType(self, referenceType: ReferenceType) -> None: ...
    def GetVisibility(self) -> FamilyElementVisibility: ...
    def SetVisibility(self, visibility: FamilyElementVisibility) -> None: ...
    @property
    def Subcategory(self) -> GraphicsStyle: ...
    @Subcategory.setter
    def Subcategory(self, subcategory: GraphicsStyle) -> None: ...


class SymbolicCurveArray(APIObject):
    def __init__(self): ...
    def Clear(self) -> None: ...
    @property
    def Size(self) -> int: ...
    @property
    def IsEmpty(self) -> bool: ...
    def ForwardIterator(self) -> SymbolicCurveArrayIterator: ...
    def ReverseIterator(self) -> SymbolicCurveArrayIterator: ...
    def GetEnumerator(self) -> IEnumerator: ...
    @property
    def Item(self, index: int) -> SymbolicCurve: ...
    @Item.setter
    def Item(self, index: int, item: SymbolicCurve) -> None: ...
    def Append(self, item: SymbolicCurve) -> None: ...
    def Insert(self, item: SymbolicCurve, index: int) -> None: ...


class SymbolicCurveArrayIterator(APIObject):
    def __init__(self): ...
    @property
    def Current(self) -> Object: ...
    def MoveNext(self) -> bool: ...
    def Reset(self) -> None: ...


class FamilyManager(APIObject):
    @property
    def CurrentType(self) -> FamilyType: ...
    @CurrentType.setter
    def CurrentType(self, familyType: FamilyType) -> None: ...
    @property
    def Types(self) -> FamilyTypeSet: ...
    def NewType(self, typeName: str) -> FamilyType: ...
    def DeleteCurrentType(self) -> None: ...
    def RenameCurrentType(self, typeName: str) -> None: ...
    @property
    def Parameters(self) -> FamilyParameterSet: ...
    @property
    def Parameter(self, guid: Guid) -> FamilyParameter: ...
    @property
    def Parameter(self, definition: Definition) -> FamilyParameter: ...
    @property
    def Parameter(self, parameterId: BuiltInParameter) -> FamilyParameter: ...
    @property
    def Parameter(self, parameterName: str) -> FamilyParameter: ...
    @overload
    def Set(self, familyParameter: FamilyParameter, value: ElementId) -> None: ...
    @overload
    def Set(self, familyParameter: FamilyParameter, value: float) -> None: ...
    @overload
    def Set(self, familyParameter: FamilyParameter, value: str) -> None: ...
    @overload
    def Set(self, familyParameter: FamilyParameter, value: int) -> None: ...
    def SetValueString(self, familyParameter: FamilyParameter, value: str) -> None: ...
    @overload
    def AddParameter(self, parameterName: str, parameterGroup: BuiltInParameterGroup, familyCategory: Category, isInstance: bool) -> FamilyParameter: ...
    @overload
    def AddParameter(self, parameterName: str, parameterGroup: BuiltInParameterGroup, parameterType: ParameterType, isInstance: bool) -> FamilyParameter: ...
    @overload
    def AddParameter(self, familyDefinition: ExternalDefinition, parameterGroup: BuiltInParameterGroup, isInstance: bool) -> FamilyParameter: ...
    def SetDescription(self, familyParameter: FamilyParameter, description: str) -> None: ...
    def RemoveParameter(self, familyParameter: FamilyParameter) -> None: ...
    def MakeInstance(self, familyParameter: FamilyParameter) -> None: ...
    def MakeType(self, familyParameter: FamilyParameter) -> None: ...
    def MakeReporting(self, familyParameter: FamilyParameter) -> None: ...
    def MakeNonReporting(self, familyParameter: FamilyParameter) -> None: ...
    def SetFormula(self, familyParameter: FamilyParameter, formula: str) -> None: ...
    def RenameParameter(self, familyParameter: FamilyParameter, name: str) -> None: ...
    def AssociateElementParameterToFamilyParameter(self, elementParameter: Parameter, familyParameter: FamilyParameter) -> None: ...
    @overload
    def ReplaceParameter(self, currentParameter: FamilyParameter, parameterName: str, parameterGroup: BuiltInParameterGroup, isInstance: bool) -> FamilyParameter: ...
    @overload
    def ReplaceParameter(self, currentParameter: FamilyParameter, familyDefinition: ExternalDefinition, parameterGroup: BuiltInParameterGroup, isInstance: bool) -> FamilyParameter: ...
    def CanElementParameterBeAssociated(self, elementParameter: Parameter) -> bool: ...
    def GetAssociatedFamilyParameter(self, elementParameter: Parameter) -> FamilyParameter: ...
    def IsParameterLockable(self, familyParameter: FamilyParameter) -> bool: ...
    def IsParameterLocked(self, familyParameter: FamilyParameter) -> bool: ...
    def SetParameterLocked(self, familyParameter: FamilyParameter, locked: bool) -> None: ...
    def GetParameters(self) -> List[FamilyParameter]: ...
    def ReorderParameters(self, parameters: List[FamilyParameter]) -> None: ...
    def IsUserAssignableParameterGroup(self, parameterGroup: BuiltInParameterGroup) -> bool: ...
    def SortParameters(self, order: ParametersOrder) -> None: ...


class IFCExportOptions:
    @overload
    def __init__(self, from_: IFCExportOptions): ...
    @overload
    def __init__(self): ...
    @property
    def FileVersion(self) -> IFCVersion: ...
    @FileVersion.setter
    def FileVersion(self, FileVersion: IFCVersion) -> None: ...
    @property
    def WallAndColumnSplitting(self) -> bool: ...
    @WallAndColumnSplitting.setter
    def WallAndColumnSplitting(self, WallAndColumnSplitting: bool) -> None: ...
    @property
    def ExportBaseQuantities(self) -> bool: ...
    @ExportBaseQuantities.setter
    def ExportBaseQuantities(self, ExportBaseQuantities: bool) -> None: ...
    @property
    def FamilyMappingFile(self) -> str: ...
    @FamilyMappingFile.setter
    def FamilyMappingFile(self, FamilyMappingFile: str) -> None: ...
    @property
    def SpaceBoundaryLevel(self) -> int: ...
    @SpaceBoundaryLevel.setter
    def SpaceBoundaryLevel(self, SpaceBoundaryLevel: int) -> None: ...
    @property
    def FilterViewId(self) -> ElementId: ...
    @FilterViewId.setter
    def FilterViewId(self, FilterViewId: ElementId) -> None: ...
    @property
    def IsValidObject(self) -> bool: ...
    def Assign(self, sourceOptions: IFCExportOptions) -> None: ...
    def AddOption(self, name: str, value: str) -> None: ...
    def Dispose(self) -> None: ...


class ReferenceWithContext:
    @property
    def Proximity(self) -> float: ...
    @property
    def IsValidObject(self) -> bool: ...
    def GetReference(self) -> Reference: ...
    def GetInstanceTransform(self) -> Transform: ...
    def Dispose(self) -> None: ...


class IPrintSetting:
    @property
    def PrintParameters(self) -> PrintParameters: ...


class InSessionPrintSetting:
    @property
    def PrintParameters(self) -> PrintParameters: ...
    def Dispose(self) -> None: ...


class PrintSetting(Element):
    @Name.setter
    def Name(self, valueString: str) -> None: ...
    @property
    def Name(self) -> str: ...
    @property
    def PrintParameters(self) -> PrintParameters: ...


class DatumPlane(Element):
    def ShowBubbleInView(self, datumEnd: DatumEnds, view: View) -> None: ...
    def HideBubbleInView(self, datumEnd: DatumEnds, view: View) -> None: ...
    def IsBubbleVisibleInView(self, datumEnd: DatumEnds, view: View) -> bool: ...
    def HasBubbleInView(self, datumEnd: DatumEnds, view: View) -> bool: ...
    def CanBeVisibleInView(self, view: View) -> bool: ...
    def GetDatumExtentTypeInView(self, datumEnd: DatumEnds, view: View) -> DatumExtentType: ...
    def Maximize3DExtents(self) -> None: ...
    def SetDatumExtentType(self, datumEnd: DatumEnds, view: View, extentMode: DatumExtentType) -> None: ...
    def GetCurvesInView(self, extentMode: DatumExtentType, view: View) -> List[Curve]: ...
    def SetCurveInView(self, extentMode: DatumExtentType, view: View, curve: Curve) -> None: ...
    def IsCurveValidInView(self, extentMode: DatumExtentType, view: View, curve: Curve) -> bool: ...
    def GetPropagationViews(self, view: View) -> ISet: ...
    def PropagateToViews(self, view: View, parallelViews: ISet) -> None: ...
    def IsLeaderValid(self, datumEnd: DatumEnds, view: View, leader: Leader) -> bool: ...
    def GetLeader(self, datumEnd: DatumEnds, view: View) -> Leader: ...
    def SetLeader(self, datumEnd: DatumEnds, view: View, pLeader: Leader) -> None: ...
    def AddLeader(self, datumEnd: DatumEnds, view: View) -> Leader: ...


class LevelType(LineAndTextAttrSymbol):


class Level(DatumPlane):
    @property
    def Elevation(self) -> float: ...
    @Elevation.setter
    def Elevation(self, elevation: float) -> None: ...
    @property
    def ProjectElevation(self) -> float: ...
    def Create(document: Document, elevation: float) -> Level: ...
    def GetPlaneReference(self) -> Reference: ...
    def FindAssociatedPlanViewId(self) -> ElementId: ...


class Phase(Element):


class PlanTopology(APIObject):
    @property
    def Level(self) -> Level: ...
    @property
    def Circuits(self) -> PlanCircuitSet: ...
    @property
    def Phase(self) -> Phase: ...
    def GetRoomIds(self) -> ICollection: ...


class PlanTopologySet(APIObject):
    def __init__(self): ...
    def Clear(self) -> None: ...
    @property
    def Size(self) -> int: ...
    @property
    def IsEmpty(self) -> bool: ...
    def ForwardIterator(self) -> PlanTopologySetIterator: ...
    def ReverseIterator(self) -> PlanTopologySetIterator: ...
    def GetEnumerator(self) -> IEnumerator: ...
    def Contains(self, item: PlanTopology) -> bool: ...
    def Insert(self, item: PlanTopology) -> bool: ...
    def Erase(self, item: PlanTopology) -> int: ...


class PlanTopologySetIterator(APIObject):
    def __init__(self): ...
    @property
    def Current(self) -> Object: ...
    def MoveNext(self) -> bool: ...
    def Reset(self) -> None: ...


class AnnotationSymbolType(FamilySymbol):


class BeamSystemType(ElementType):


class HostObjAttributes(ElementType):
    def GetCompoundStructure(self) -> CompoundStructure: ...
    def SetCompoundStructure(self, compoundStructure: CompoundStructure) -> None: ...


class CurtainSystemType(HostObjAttributes):


class LinkElementId:
    @overload
    def __init__(self, linkInstanceId: ElementId, elementId: ElementId): ...
    @overload
    def __init__(self, elementId: ElementId): ...
    def Equals(self, obj: Object) -> bool: ...
    def op_Equality(first: LinkElementId, second: LinkElementId) -> bool: ...
    def op_Inequality(first: LinkElementId, second: LinkElementId) -> bool: ...
    @property
    def LinkInstanceId(self) -> ElementId: ...
    @property
    def LinkedElementId(self) -> ElementId: ...
    @property
    def HostElementId(self) -> ElementId: ...


class HostedSweepType(HostObjAttributes):


class FloorType(HostObjAttributes):
    @property
    def IsFoundationSlab(self) -> bool: ...
    @property
    def StructuralMaterialId(self) -> ElementId: ...
    @StructuralMaterialId.setter
    def StructuralMaterialId(self, id: ElementId) -> None: ...
    @property
    def ThermalProperties(self) -> ThermalProperties: ...


class GridType(LineAndTextAttrSymbol):


class MullionType(FamilySymbol):


class MullionTypeSet(APIObject):
    def __init__(self): ...
    def Clear(self) -> None: ...
    @property
    def Size(self) -> int: ...
    @property
    def IsEmpty(self) -> bool: ...
    def ForwardIterator(self) -> MullionTypeSetIterator: ...
    def ReverseIterator(self) -> MullionTypeSetIterator: ...
    def GetEnumerator(self) -> IEnumerator: ...
    def Contains(self, item: MullionType) -> bool: ...
    def Insert(self, item: MullionType) -> bool: ...
    def Erase(self, item: MullionType) -> int: ...


class MullionTypeSetIterator(APIObject):
    def __init__(self): ...
    @property
    def Current(self) -> Object: ...
    def MoveNext(self) -> bool: ...
    def Reset(self) -> None: ...


class PanelType(FamilySymbol):


class PanelTypeSet(APIObject):
    def __init__(self): ...
    def Clear(self) -> None: ...
    @property
    def Size(self) -> int: ...
    @property
    def IsEmpty(self) -> bool: ...
    def ForwardIterator(self) -> PanelTypeSetIterator: ...
    def ReverseIterator(self) -> PanelTypeSetIterator: ...
    def GetEnumerator(self) -> IEnumerator: ...
    def Contains(self, item: PanelType) -> bool: ...
    def Insert(self, item: PanelType) -> bool: ...
    def Erase(self, item: PanelType) -> int: ...


class PanelTypeSetIterator(APIObject):
    def __init__(self): ...
    @property
    def Current(self) -> Object: ...
    def MoveNext(self) -> bool: ...
    def Reset(self) -> None: ...


class DefinitionBindingMap(APIObject):
    def __init__(self): ...
    def Clear(self) -> None: ...
    @property
    def Size(self) -> int: ...
    @property
    def IsEmpty(self) -> bool: ...
    def ForwardIterator(self) -> DefinitionBindingMapIterator: ...
    def ReverseIterator(self) -> DefinitionBindingMapIterator: ...
    def GetEnumerator(self) -> IEnumerator: ...
    @property
    def Item(self, key: Definition) -> Binding: ...
    @Item.setter
    def Item(self, key: Definition, item: Binding) -> None: ...
    def Contains(self, key: Definition) -> bool: ...
    def Insert(self, key: Definition, item: Binding) -> bool: ...
    def Erase(self, key: Definition) -> int: ...


class DefinitionBindingMapIterator(APIObject):
    def __init__(self): ...
    @property
    def Current(self) -> Object: ...
    def MoveNext(self) -> bool: ...
    def Reset(self) -> None: ...
    @property
    def Key(self) -> Definition: ...


class BindingMap(DefinitionBindingMap):
    @overload
    def Insert(self, key: Definition, item: Binding, parameterGroup: BuiltInParameterGroup) -> bool: ...
    @overload
    def Insert(self, key: Definition, item: Binding) -> bool: ...
    @overload
    def ReInsert(self, key: Definition, item: Binding, parameterGroup: BuiltInParameterGroup) -> bool: ...
    @overload
    def ReInsert(self, key: Definition, item: Binding) -> bool: ...
    def Remove(self, key: Definition) -> bool: ...
    def Contains(self, key: Definition) -> bool: ...
    @property
    def Item(self, key: Definition) -> Binding: ...
    @Item.setter
    def Item(self, key: Definition, item: Binding) -> None: ...
    def Clear(self) -> None: ...
    def Erase(self, key: Definition) -> int: ...


class PhaseArray(APIObject):
    def __init__(self): ...
    def Clear(self) -> None: ...
    @property
    def Size(self) -> int: ...
    @property
    def IsEmpty(self) -> bool: ...
    def ForwardIterator(self) -> PhaseArrayIterator: ...
    def ReverseIterator(self) -> PhaseArrayIterator: ...
    def GetEnumerator(self) -> IEnumerator: ...
    @property
    def Item(self, index: int) -> Phase: ...
    @Item.setter
    def Item(self, index: int, item: Phase) -> None: ...
    def Append(self, item: Phase) -> None: ...
    def Insert(self, item: Phase, index: int) -> None: ...


class PhaseArrayIterator(APIObject):
    def __init__(self): ...
    @property
    def Current(self) -> Object: ...
    def MoveNext(self) -> bool: ...
    def Reset(self) -> None: ...


class BarTypeDiameterOptions:
    @overload
    def __init__(self, barType: RebarBarType): ...
    @overload
    def __init__(self): ...
    @property
    def BarDiameter(self) -> float: ...
    @BarDiameter.setter
    def BarDiameter(self, barDiameter: float) -> None: ...
    @property
    def StandardBendDiameter(self) -> float: ...
    @StandardBendDiameter.setter
    def StandardBendDiameter(self, standardBendDiameter: float) -> None: ...
    @property
    def StandardHookBendDiameter(self) -> float: ...
    @StandardHookBendDiameter.setter
    def StandardHookBendDiameter(self, standardHookBendDiameter: float) -> None: ...
    @property
    def StirrupTieBendDiameter(self) -> float: ...
    @StirrupTieBendDiameter.setter
    def StirrupTieBendDiameter(self, stirrupTieBendDiameter: float) -> None: ...
    @property
    def IsValidObject(self) -> bool: ...
    def Dispose(self) -> None: ...


class RoofType(HostObjAttributes):
    @property
    def ThermalProperties(self) -> ThermalProperties: ...


class Settings(APIObject):
    @property
    def Categories(self) -> Categories: ...
    @property
    def ElectricalSetting(self) -> ElectricalSetting: ...
    @property
    def TilePatterns(self) -> TilePatterns: ...


class SlabEdgeType(HostedSweepType):


class SpotDimensionType(DimensionType):


class IViewSheetSet:
    @property
    def Views(self) -> ViewSet: ...
    @Views.setter
    def Views(self, views: ViewSet) -> None: ...


class InSessionViewSheetSet:
    @property
    def Views(self) -> ViewSet: ...
    @Views.setter
    def Views(self, views: ViewSet) -> None: ...
    def Dispose(self) -> None: ...


class ViewSheetSet(Element):
    @Name.setter
    def Name(self, valueString: str) -> None: ...
    @property
    def Name(self) -> str: ...
    @property
    def Views(self) -> ViewSet: ...
    @Views.setter
    def Views(self, views: ViewSet) -> None: ...


class WallType(HostObjAttributes):
    @property
    def Function(self) -> WallFunction: ...
    @Function.setter
    def Function(self, function: WallFunction) -> None: ...
    @property
    def ThermalProperties(self) -> ThermalProperties: ...
    @property
    def Kind(self) -> WallKind: ...
    @property
    def Width(self) -> float: ...


class WallFoundationType(HostObjAttributes):


class AnnotationSymbol(FamilyInstance):
    def duplicate(self) -> AnnotationSymbol: ...
    def GetLeaders(self) -> List[Leader]: ...
    @property
    def AnnotationSymbolType(self) -> AnnotationSymbolType: ...
    @AnnotationSymbolType.setter
    def AnnotationSymbolType(self, A_0: AnnotationSymbolType) -> None: ...
    def addLeader(self) -> None: ...
    def removeLeader(self) -> None: ...


class AreaTag(SpatialElementTag):
    @property
    def Area(self) -> Area: ...
    @property
    def AreaTagType(self) -> AreaTagType: ...
    @AreaTagType.setter
    def AreaTagType(self, A_0: AreaTagType) -> None: ...


class Connector:
    @property
    def Origin(self) -> XYZ: ...
    @Origin.setter
    def Origin(self, origin: XYZ) -> None: ...
    @property
    def CoordinateSystem(self) -> Transform: ...
    @property
    def Owner(self) -> Element: ...
    @property
    def Domain(self) -> Domain: ...
    @property
    def AllRefs(self) -> ConnectorSet: ...
    @property
    def ConnectorType(self) -> ConnectorType: ...
    @property
    def Shape(self) -> ConnectorProfileType: ...
    @property
    def Width(self) -> float: ...
    @Width.setter
    def Width(self, width: float) -> None: ...
    @property
    def Height(self) -> float: ...
    @Height.setter
    def Height(self, height: float) -> None: ...
    @property
    def Radius(self) -> float: ...
    @Radius.setter
    def Radius(self, radius: float) -> None: ...
    @property
    def Flow(self) -> float: ...
    @property
    def Coefficient(self) -> float: ...
    @property
    def Direction(self) -> FlowDirectionType: ...
    @property
    def AssignedFlowDirection(self) -> FlowDirectionType: ...
    @property
    def DuctSystemType(self) -> DuctSystemType: ...
    @property
    def ElectricalSystemType(self) -> ElectricalSystemType: ...
    @property
    def PipeSystemType(self) -> PipeSystemType: ...
    @property
    def Demand(self) -> float: ...
    @property
    def ConnectorManager(self) -> ConnectorManager: ...
    @property
    def VelocityPressure(self) -> float: ...
    @property
    def PressureDrop(self) -> float: ...
    @property
    def MEPSystem(self) -> MEPSystem: ...
    @property
    def IsConnected(self) -> bool: ...
    @property
    def AssignedFlowFactor(self) -> float: ...
    @AssignedFlowFactor.setter
    def AssignedFlowFactor(self, assignedFlowFactor: float) -> None: ...
    @property
    def AssignedLossCoefficient(self) -> float: ...
    @AssignedLossCoefficient.setter
    def AssignedLossCoefficient(self, assignedLossCoefficient: float) -> None: ...
    @property
    def AssignedPipeFlowConfiguration(self) -> PipeFlowConfigurationType: ...
    @property
    def AssignedDuctFlowConfiguration(self) -> DuctFlowConfigurationType: ...
    @property
    def AssignedDuctLossMethod(self) -> DuctLossMethodType: ...
    @property
    def AssignedPipeLossMethod(self) -> PipeLossMethodType: ...
    @property
    def AssignedPressureDrop(self) -> float: ...
    @AssignedPressureDrop.setter
    def AssignedPressureDrop(self, assignedPressureDrop: float) -> None: ...
    @property
    def AssignedFlow(self) -> float: ...
    @AssignedFlow.setter
    def AssignedFlow(self, assignedFlow: float) -> None: ...
    @property
    def AssignedFixtureUnits(self) -> float: ...
    @AssignedFixtureUnits.setter
    def AssignedFixtureUnits(self, assignedFixtureUnits: float) -> None: ...
    @property
    def AssignedKCoefficient(self) -> float: ...
    @AssignedKCoefficient.setter
    def AssignedKCoefficient(self, kCoefficient: float) -> None: ...
    @property
    def Angle(self) -> float: ...
    @Angle.setter
    def Angle(self, angle: float) -> None: ...
    @property
    def IsMovable(self) -> bool: ...
    def ConnectTo(self, connector: Connector) -> None: ...
    def DisconnectFrom(self, connector: Connector) -> None: ...
    def IsConnectedTo(self, connector: Connector) -> bool: ...
    @property
    def EngagementLength(self) -> float: ...
    @property
    def AllowsSlopeAdjustments(self) -> bool: ...
    @property
    def Utility(self) -> bool: ...
    @property
    def Description(self) -> str: ...
    @property
    def Id(self) -> int: ...
    @property
    def IsValidObject(self) -> bool: ...
    def GetFabricationConnectorInfo(self) -> FabricationConnectorInfo: ...
    def GetMEPConnectorInfo(self) -> MEPConnectorInfo: ...
    def Dispose(self) -> None: ...


class ConnectorSet(APIObject):
    def __init__(self): ...
    def Clear(self) -> None: ...
    @property
    def Size(self) -> int: ...
    @property
    def IsEmpty(self) -> bool: ...
    def ForwardIterator(self) -> ConnectorSetIterator: ...
    def ReverseIterator(self) -> ConnectorSetIterator: ...
    def GetEnumerator(self) -> IEnumerator: ...
    def Contains(self, item: Connector) -> bool: ...
    def Insert(self, item: Connector) -> bool: ...
    def Erase(self, item: Connector) -> int: ...


class ConnectorSetIterator(APIObject):
    def __init__(self): ...
    @property
    def Current(self) -> Object: ...
    def MoveNext(self) -> bool: ...
    def Reset(self) -> None: ...


class HostObject(Element):
    def FindInserts(self, addRectOpenings: bool, includeShadows: bool, includeEmbeddedWalls: bool, includeSharedEmbeddedInserts: bool) -> List[ElementId]: ...


class CeilingAndFloor(HostObject):


class CurtainSystemBase(HostObject):


class CurtainSystem(CurtainSystemBase):
    @property
    def CurtainGrids(self) -> CurtainGridSet: ...
    @property
    def CurtainSystemType(self) -> CurtainSystemType: ...
    @CurtainSystemType.setter
    def CurtainSystemType(self, curtainSystemType: CurtainSystemType) -> None: ...
    def AddCurtainGrid(self, face: Reference) -> None: ...
    def RemoveCurtainGrid(self, face: Reference) -> None: ...


class ViewDrafting(View):
    def Create(document: Document, viewFamilyTypeId: ElementId) -> ViewDrafting: ...


class ViewSheet(View):
    @property
    def SheetNumber(self) -> str: ...
    @SheetNumber.setter
    def SheetNumber(self, sheetNumber: str) -> None: ...
    @property
    def IsPlaceholder(self) -> bool: ...
    def ConvertToRealSheet(self, titleBlockTypeId: ElementId) -> None: ...
    def GetCurrentRevision(self) -> ElementId: ...
    def GetRevisionNumberOnSheet(self, revisionId: ElementId) -> str: ...
    def GetRevisionCloudNumberOnSheet(self, revisionCloudId: ElementId) -> str: ...
    def GetAllRevisionIds(self) -> List[ElementId]: ...
    def GetAdditionalRevisionIds(self) -> ICollection: ...
    def SetAdditionalRevisionIds(self, projectRevisionIds: ICollection) -> None: ...
    def CreatePlaceholder(aDoc: Document) -> ViewSheet: ...
    def Create(document: Document, titleBlockTypeId: ElementId) -> ViewSheet: ...
    def GetAllViewports(self) -> ICollection: ...
    def GetAllPlacedViews(self) -> ISet: ...
    def DeleteViewport(self, viewport: Viewport) -> None: ...


class ViewPlan(View):
    @property
    def AreaScheme(self) -> AreaScheme: ...
    def Create(document: Document, viewFamilyTypeId: ElementId, levelId: ElementId) -> ViewPlan: ...
    def CreateAreaPlan(document: Document, areaSchemeId: ElementId, levelId: ElementId) -> ViewPlan: ...
    def GetViewRange(self) -> PlanViewRange: ...
    def SetViewRange(self, planViewRange: PlanViewRange) -> None: ...
    def CheckPlanViewRangeValidity(self, planViewRange: PlanViewRange) -> List[PlanViewRangeError]: ...
    def GetUnderlayBaseLevel(self) -> ElementId: ...
    def GetUnderlayTopLevel(self) -> ElementId: ...
    def SetUnderlayBaseLevel(self, levelId: ElementId) -> None: ...
    def SetUnderlayRange(self, baseLevelId: ElementId, topLevelId: ElementId) -> None: ...
    def GetUnderlayOrientation(self) -> UnderlayOrientation: ...
    def SetUnderlayOrientation(self, uo: UnderlayOrientation) -> None: ...


class ReferenceableViewUtils:
    def GetReferencedViewId(document: Document, referenceId: ElementId) -> ElementId: ...
    def ChangeReferencedView(document: Document, referenceId: ElementId, desiredViewId: ElementId) -> None: ...


class ViewSection(View):
    def CreateSection(document: Document, viewFamilyTypeId: ElementId, sectionBox: BoundingBoxXYZ) -> ViewSection: ...
    def CreateDetail(document: Document, viewFamilyTypeId: ElementId, sectionBox: BoundingBoxXYZ) -> ViewSection: ...
    def CreateCallout(document: Document, parentViewId: ElementId, viewFamilyTypeId: ElementId, point1: XYZ, point2: XYZ) -> View: ...
    def IsParentViewValidForCallout(document: Document, parentViewId: ElementId) -> bool: ...
    def IsViewFamilyTypeValidForCallout(document: Document, viewFamilyTypeId: ElementId, parentViewId: ElementId) -> bool: ...
    def CreateReferenceCallout(document: Document, parentViewId: ElementId, viewIdToReference: ElementId, point1: XYZ, point2: XYZ) -> None: ...
    def CreateReferenceSection(document: Document, parentViewId: ElementId, viewIdToReference: ElementId, headPoint: XYZ, tailPoint: XYZ) -> None: ...
    def IsSplitSection(self) -> bool: ...


class DetailArc(DetailCurve):


class DetailEllipse(DetailCurve):


class DetailLine(DetailCurve):


class DetailNurbSpline(DetailCurve):


class Group(Element):
    @property
    def GroupType(self) -> GroupType: ...
    @GroupType.setter
    def GroupType(self, value: GroupType) -> None: ...
    @property
    def Location(self) -> Location: ...
    def UngroupMembers(self) -> ICollection: ...
    def GetMemberIds(self) -> List[ElementId]: ...
    @property
    def IsAttached(self) -> bool: ...
    @property
    def AttachedParentId(self) -> ElementId: ...
    def ShowAttachedDetailGroups(self, view: View, detailGroupTypeId: ElementId) -> None: ...
    def ShowAllAttachedDetailGroups(self, view: View) -> None: ...
    def HideAttachedDetailGroups(self, view: View, detailGroupTypeId: ElementId) -> None: ...
    def HideAllAttachedDetailGroups(self, view: View) -> None: ...
    def GetShownAttachedDetailGroupTypeIds(self, view: View) -> ISet: ...
    def GetAvailableAttachedDetailGroupTypeIds(self) -> ISet: ...
    def IsCompatibleAttachedDetailGroupType(self, view: View, detailGroupTypeId: ElementId) -> bool: ...


class GroupType(ElementType):
    @property
    def Groups(self) -> GroupSet: ...
    def GetAvailableAttachedDetailGroupTypeIds(self) -> ISet: ...


class RoofBase(HostObject):
    @property
    def RoofType(self) -> RoofType: ...
    @RoofType.setter
    def RoofType(self, pRoofType: RoofType) -> None: ...
    @property
    def EaveCuts(self) -> EaveCutterType: ...
    @EaveCuts.setter
    def EaveCuts(self, eaveCuts: EaveCutterType) -> None: ...
    @property
    def FasciaDepth(self) -> float: ...
    @FasciaDepth.setter
    def FasciaDepth(self, fasciaDepth: float) -> None: ...
    @property
    def SlabShapeEditor(self) -> SlabShapeEditor: ...


class ExtrusionRoof(RoofBase):
    def GetProfile(self) -> ModelCurveArray: ...
    @property
    def CurtainGrids(self) -> CurtainGridSet: ...


class HostedSweep(HostObject):
    @property
    def Length(self) -> float: ...
    @property
    def HorizontalOffset(self) -> float: ...
    @HorizontalOffset.setter
    def HorizontalOffset(self, value: float) -> None: ...
    @property
    def VerticalOffset(self) -> float: ...
    @VerticalOffset.setter
    def VerticalOffset(self, value: float) -> None: ...
    @property
    def Angle(self) -> float: ...
    @Angle.setter
    def Angle(self, value: float) -> None: ...
    @property
    def HorizontalFlipped(self) -> bool: ...
    @property
    def VerticalFlipped(self) -> bool: ...
    @property
    def ReferenceCurve(self, targetRef: Reference) -> Curve: ...
    def HorizontalFlip(self) -> None: ...
    def VerticalFlip(self) -> None: ...
    def RemoveSegment(self, targetRef: Reference) -> None: ...
    def SetEndPointParameter(self, targetRef: Reference, endIdx: int, param: float) -> bool: ...
    def GetEndPointParameter(self, targetRef: Reference, endIdx: int) -> float: ...
    def AddSegment(self, targetRef: Reference) -> None: ...


class MEPCurveType(HostObjAttributes):
    @property
    def Roughness(self) -> float: ...
    @Roughness.setter
    def Roughness(self, roughness: float) -> None: ...
    @property
    def PreferredJunctionType(self) -> JunctionType: ...
    @PreferredJunctionType.setter
    def PreferredJunctionType(self, junctionType: JunctionType) -> None: ...
    @property
    def Tee(self) -> FamilySymbol: ...
    @Tee.setter
    def Tee(self, familySymbol: FamilySymbol) -> None: ...
    @property
    def Tap(self) -> FamilySymbol: ...
    @Tap.setter
    def Tap(self, familySymbol: FamilySymbol) -> None: ...
    @property
    def Transition(self) -> FamilySymbol: ...
    @Transition.setter
    def Transition(self, familySymbol: FamilySymbol) -> None: ...
    @property
    def Union(self) -> FamilySymbol: ...
    @Union.setter
    def Union(self, familySymbol: FamilySymbol) -> None: ...
    @property
    def Cross(self) -> FamilySymbol: ...
    @Cross.setter
    def Cross(self, familySymbol: FamilySymbol) -> None: ...
    @property
    def Elbow(self) -> FamilySymbol: ...
    @Elbow.setter
    def Elbow(self, familySymbol: FamilySymbol) -> None: ...
    @property
    def MultiShapeTransition(self) -> FamilySymbol: ...
    @MultiShapeTransition.setter
    def MultiShapeTransition(self, familySymbol: FamilySymbol) -> None: ...
    @property
    def RoutingPreferenceManager(self) -> RoutingPreferenceManager: ...
    @property
    def Shape(self) -> ConnectorProfileType: ...


class Floor(CeilingAndFloor):
    @property
    def FloorType(self) -> FloorType: ...
    @FloorType.setter
    def FloorType(self, value: FloorType) -> None: ...
    @property
    def SpanDirectionAngle(self) -> float: ...
    @SpanDirectionAngle.setter
    def SpanDirectionAngle(self, angle: float) -> None: ...
    @property
    def SlabShapeEditor(self) -> SlabShapeEditor: ...
    def GetVerticalProjectionPoint(self, modelLocation: XYZ, floorFace: FloorFace) -> XYZ: ...
    def GetNormalAtVerticalProjectionPoint(self, modelLocation: XYZ, floorFace: FloorFace) -> XYZ: ...
    def GetSpanDirectionSymbolIds(self) -> ICollection: ...


class FootPrintRoof(RoofBase):
    @property
    def DefinesSlope(self, pCurve: ModelCurve) -> bool: ...
    @DefinesSlope.setter
    def DefinesSlope(self, pCurve: ModelCurve, definesSlope: bool) -> None: ...
    @property
    def SlopeAngle(self, pCurve: ModelCurve) -> float: ...
    @SlopeAngle.setter
    def SlopeAngle(self, pCurve: ModelCurve, slopeAngle: float) -> None: ...
    @property
    def Offset(self, pCurve: ModelCurve) -> float: ...
    @Offset.setter
    def Offset(self, pCurve: ModelCurve, offsetValue: float) -> None: ...
    @property
    def ExtendIntoWall(self, pCurve: ModelCurve) -> bool: ...
    @ExtendIntoWall.setter
    def ExtendIntoWall(self, pCurve: ModelCurve, extendIntoWall: bool) -> None: ...
    @property
    def Overhang(self, pCurve: ModelCurve) -> float: ...
    @Overhang.setter
    def Overhang(self, pCurve: ModelCurve, overhangValue: float) -> None: ...
    @property
    def CurtainGrids(self) -> CurtainGridSet: ...
    def GetProfiles(self) -> ModelCurveArrArray: ...


class Form(GenericForm):
    @property
    def ProfileCount(self) -> int: ...
    @property
    def ProfileCurveLoopCount(self, index: int) -> int: ...
    @property
    def CurveLoopReferencesOnProfile(self, profileIndex: int, curveLoopIndex: int) -> ReferenceArray: ...
    def GetProfileAndCurveLoopIndexFromReference(self, curveOrEdgeReference: Reference, profileIndex: int, curveLoopIndex: int) -> Tuple[int, int]: ...
    @property
    def PathCurveCount(self) -> int: ...
    @property
    def PathCurveReference(self, curveIndex: int) -> Reference: ...
    def GetPathCurveIndexByCurveReference(self, curveReference: Reference) -> int: ...
    @property
    def HasOneOrMoreReferenceProfiles(self) -> bool: ...
    @property
    def IsInXRayMode(self) -> bool: ...
    @IsInXRayMode.setter
    def IsInXRayMode(self, value: bool) -> None: ...
    @property
    def AreProfilesConstrained(self) -> bool: ...
    @AreProfilesConstrained.setter
    def AreProfilesConstrained(self, value: bool) -> None: ...
    def ConstrainProfiles(self, primaryProfileIndex: int) -> None: ...
    @property
    def HasOpenGeometry(self) -> bool: ...
    def IsVertexReference(self, vertexReference: Reference) -> bool: ...
    def IsEdgeReference(self, edgeReference: Reference) -> bool: ...
    def IsCurveReference(self, curveReference: Reference) -> bool: ...
    def IsFaceReference(self, faceReference: Reference) -> bool: ...
    def IsReferenceOnlyProfile(self, profileIndex: int) -> bool: ...
    def IsBeginningFace(self, faceReference: Reference) -> bool: ...
    def IsEndFace(self, faceReference: Reference) -> bool: ...
    def IsSideFace(self, faceReference: Reference) -> bool: ...
    def IsAutoCreaseEdge(self, edgeReference: Reference) -> bool: ...
    def IsProfileEdge(self, curveOrEdgeReference: Reference) -> bool: ...
    def IsConnectingEdge(self, edgeReference: Reference) -> bool: ...
    def GetControlPoints(self, curveOrEdgeOrFaceReference: Reference) -> ReferenceArray: ...
    def GetCurvesAndEdgesReference(self, pointReference: Reference) -> ReferenceArray: ...
    def CanManipulateSubElement(self, subElementReference: Reference) -> bool: ...
    def CanManipulateProfile(self, profileIndex: int) -> bool: ...
    def DeleteSubElement(self, subElementReference: Reference) -> None: ...
    def DeleteProfile(self, profileIndex: int) -> None: ...
    def MoveSubElement(self, subElementReference: Reference, offset: XYZ) -> None: ...
    def MoveProfile(self, profileIndex: int, offset: XYZ) -> None: ...
    def RotateSubElement(self, subElementReference: Reference, axis: Line, angle: float) -> None: ...
    def RotateProfile(self, profileIndex: int, axis: Line, angle: float) -> None: ...
    def ScaleSubElement(self, subElementReference: Reference, factor: float, origin: XYZ) -> None: ...
    def ScaleProfile(self, profileIndex: int, factor: float, origin: XYZ) -> None: ...
    @overload
    def AddEdge(self, startPointReference: Reference, endPointReference: Reference) -> None: ...
    @overload
    def AddEdge(self, startEdgeReference: Reference, startParam: float, endEdgeReference: Reference, endParam: float) -> None: ...
    @overload
    def AddEdge(self, faceReference: Reference, point: XYZ) -> None: ...
    def AddProfile(self, edgeReference: Reference, param: float) -> int: ...
    @property
    def TopOffset(self) -> float: ...
    @TopOffset.setter
    def TopOffset(self, value: float) -> None: ...
    @property
    def BaseOffset(self) -> float: ...
    @BaseOffset.setter
    def BaseOffset(self, value: float) -> None: ...
    @overload
    def Rehost(self, sketchPlane: SketchPlane, location: XYZ) -> None: ...
    @overload
    def Rehost(self, hostRef: Reference, location: XYZ) -> None: ...


class Grid(DatumPlane):
    @property
    def Curve(self) -> Curve: ...
    @property
    def IsCurved(self) -> bool: ...
    @overload
    def Create(document: Document, arc: Arc) -> Grid: ...
    @overload
    def Create(document: Document, line: Line) -> Grid: ...
    def SetVerticalExtents(self, bottom: float, top: float) -> None: ...
    def GetExtents(self) -> Outline: ...


class IndependentTag(Element):
    @property
    def MultiReferenceAnnotationId(self) -> ElementId: ...
    @property
    def TaggedElementId(self) -> LinkElementId: ...
    @property
    def TagText(self) -> str: ...
    @property
    def IsMaterialTag(self) -> bool: ...
    @property
    def IsMulticategoryTag(self) -> bool: ...
    @property
    def IsOrphaned(self) -> bool: ...
    @property
    def TaggedLocalElementId(self) -> ElementId: ...
    @property
    def TagOrientation(self) -> TagOrientation: ...
    @TagOrientation.setter
    def TagOrientation(self, orientation: TagOrientation) -> None: ...
    @property
    def TagHeadPosition(self) -> XYZ: ...
    @TagHeadPosition.setter
    def TagHeadPosition(self, headPosition: XYZ) -> None: ...
    @property
    def HasLeader(self) -> bool: ...
    @HasLeader.setter
    def HasLeader(self, leader: bool) -> None: ...
    @property
    def HasElbow(self) -> bool: ...
    @property
    def LeaderEndCondition(self) -> LeaderEndCondition: ...
    @LeaderEndCondition.setter
    def LeaderEndCondition(self, leaderendcondition: LeaderEndCondition) -> None: ...
    @property
    def LeaderElbow(self) -> XYZ: ...
    @LeaderElbow.setter
    def LeaderElbow(self, leaderElbow: XYZ) -> None: ...
    @property
    def LeaderEnd(self) -> XYZ: ...
    @LeaderEnd.setter
    def LeaderEnd(self, leaderElbow: XYZ) -> None: ...
    @overload
    def Create(document: Document, symId: ElementId, ownerDBViewId: ElementId, referenceToTag: Reference, addLeader: bool, tagOrientation: TagOrientation, pnt: XYZ) -> IndependentTag: ...
    @overload
    def Create(document: Document, ownerDBViewId: ElementId, referenceToTag: Reference, addLeader: bool, tagMode: TagMode, tagOrientation: TagOrientation, pnt: XYZ) -> IndependentTag: ...
    def GetTaggedLocalElement(self) -> Element: ...
    def CanLeaderEndConditionBeAssigned(self, leaderEndCondition: LeaderEndCondition) -> bool: ...
    def IsTaggedOnSubelement(self) -> bool: ...
    def GetTaggedReference(self) -> Reference: ...


class BeamSystem(Element):
    def GetBeamIds(self) -> ICollection: ...
    def BeamBelongsTo(beam: FamilyInstance) -> BeamSystem: ...
    def DropBeamSystem(beamSystem: BeamSystem) -> None: ...
    @property
    def Elevation(self) -> float: ...
    @Elevation.setter
    def Elevation(self, elevation: float) -> None: ...
    @property
    def Level(self) -> Level: ...
    @Level.setter
    def Level(self, level: Level) -> None: ...
    @property
    def BeamType(self) -> FamilySymbol: ...
    @BeamType.setter
    def BeamType(self, pBeamType: FamilySymbol) -> None: ...
    @property
    def BeamSystemType(self) -> BeamSystemType: ...
    @BeamSystemType.setter
    def BeamSystemType(self, pBeamSystemType: BeamSystemType) -> None: ...
    @property
    def Profile(self) -> CurveArray: ...
    @Profile.setter
    def Profile(self, profile: CurveArray) -> None: ...
    @property
    def LayoutRule(self) -> LayoutRule: ...
    @LayoutRule.setter
    def LayoutRule(self, pLayoutRule: LayoutRule) -> None: ...
    @property
    def Direction(self) -> XYZ: ...
    @overload
    def Create(document: Document, profile: List[Curve], level: Level, curveIndexForDirection: int, is3d: bool) -> BeamSystem: ...
    @overload
    def Create(document: Document, profile: List[Curve], level: Level, direction: XYZ, is3d: bool) -> BeamSystem: ...
    @overload
    def Create(document: Document, profile: List[Curve], sketchPlane: SketchPlane, direction: XYZ, is3d: bool) -> BeamSystem: ...
    @overload
    def Create(document: Document, profile: List[Curve], sketchPlane: SketchPlane, curveIndexForDirection: int) -> BeamSystem: ...


class LocationCurve(Location):
    @property
    def Curve(self) -> Curve: ...
    @Curve.setter
    def Curve(self, curve: Curve) -> None: ...
    @property
    def ElementsAtJoin(self, end: int) -> ElementArray: ...
    @ElementsAtJoin.setter
    def ElementsAtJoin(self, end: int, elements: ElementArray) -> None: ...
    @property
    def JoinType(self, end: int) -> JoinType: ...
    @JoinType.setter
    def JoinType(self, end: int, newType: JoinType) -> None: ...


class ModelArc(ModelCurve):


class ModelEllipse(ModelCurve):


class ModelHermiteSpline(ModelCurve):


class ModelLine(ModelCurve):


class ModelNurbSpline(ModelCurve):


class Opening(Element):
    @property
    def IsRectBoundary(self) -> bool: ...
    @property
    def BoundaryRect(self) -> List[XYZ]: ...
    @property
    def BoundaryCurves(self) -> CurveArray: ...
    @property
    def Host(self) -> Element: ...
    @property
    def IsTransparentIn3D(self) -> bool: ...
    @IsTransparentIn3D.setter
    def IsTransparentIn3D(self, value: bool) -> None: ...
    @property
    def IsTransparentInElevation(self) -> bool: ...
    @IsTransparentInElevation.setter
    def IsTransparentInElevation(self, value: bool) -> None: ...


class PlanCircuit(APIObject):
    @property
    def SideNum(self) -> int: ...
    @property
    def Area(self) -> float: ...
    @property
    def IsRoomLocated(self) -> bool: ...
    def GetPointInside(self) -> UV: ...


class PlanCircuitSet(APIObject):
    def __init__(self): ...
    def Clear(self) -> None: ...
    @property
    def Size(self) -> int: ...
    @property
    def IsEmpty(self) -> bool: ...
    def ForwardIterator(self) -> PlanCircuitSetIterator: ...
    def ReverseIterator(self) -> PlanCircuitSetIterator: ...
    def GetEnumerator(self) -> IEnumerator: ...
    def Contains(self, item: PlanCircuit) -> bool: ...
    def Insert(self, item: PlanCircuit) -> bool: ...
    def Erase(self, item: PlanCircuit) -> int: ...


class PlanCircuitSetIterator(APIObject):
    def __init__(self): ...
    @property
    def Current(self) -> Object: ...
    def MoveNext(self) -> bool: ...
    def Reset(self) -> None: ...


class MEPCurve(HostObject):
    @property
    def ConnectorManager(self) -> ConnectorManager: ...
    @property
    def Width(self) -> float: ...
    @property
    def Height(self) -> float: ...
    @property
    def Diameter(self) -> float: ...
    @property
    def LevelOffset(self) -> float: ...
    @LevelOffset.setter
    def LevelOffset(self, offset: float) -> None: ...
    @property
    def ReferenceLevel(self) -> Level: ...
    @ReferenceLevel.setter
    def ReferenceLevel(self, level: Level) -> None: ...
    @property
    def MEPSystem(self) -> MEPSystem: ...


class ReferencePlane(DatumPlane):
    @property
    def Name(self) -> str: ...
    @Name.setter
    def Name(self, value: str) -> None: ...
    @property
    def BubbleEnd(self) -> XYZ: ...
    @BubbleEnd.setter
    def BubbleEnd(self, newBubbleEnd: XYZ) -> None: ...
    @property
    def FreeEnd(self) -> XYZ: ...
    @FreeEnd.setter
    def FreeEnd(self, newFreeEnd: XYZ) -> None: ...
    @property
    def Normal(self) -> XYZ: ...
    @property
    def Direction(self) -> XYZ: ...
    @Direction.setter
    def Direction(self, newDir: XYZ) -> None: ...
    def GetPlane(self) -> Plane: ...
    def GetReference(self) -> Reference: ...
    def Flip(self) -> None: ...


class SlabEdge(HostedSweep):
    @property
    def SlabEdgeType(self) -> SlabEdgeType: ...
    @SlabEdgeType.setter
    def SlabEdgeType(self, value: SlabEdgeType) -> None: ...
    def AddSegment(self, targetRef: Reference) -> None: ...


class SpotDimension(Dimension):
    @property
    def SpotDimensionType(self) -> SpotDimensionType: ...
    @SpotDimensionType.setter
    def SpotDimensionType(self, newType: SpotDimensionType) -> None: ...
    @property
    def LeaderHasShoulder(self) -> bool: ...
    @LeaderHasShoulder.setter
    def LeaderHasShoulder(self, newValue: bool) -> None: ...
    @property
    def LeaderShoulderPosition(self) -> XYZ: ...
    @LeaderShoulderPosition.setter
    def LeaderShoulderPosition(self, newValue: XYZ) -> None: ...


class Wall(HostObject):
    @property
    def WallType(self) -> WallType: ...
    @WallType.setter
    def WallType(self, wallType: WallType) -> None: ...
    @property
    def CurtainGrid(self) -> CurtainGrid: ...
    @property
    def Width(self) -> float: ...
    @property
    def StructuralUsage(self) -> StructuralWallUsage: ...
    @StructuralUsage.setter
    def StructuralUsage(self, usage: StructuralWallUsage) -> None: ...
    @property
    def Flipped(self) -> bool: ...
    @property
    def IsStackedWall(self) -> bool: ...
    @property
    def IsStackedWallMember(self) -> bool: ...
    @property
    def StackedWallOwnerId(self) -> ElementId: ...
    @property
    def Orientation(self) -> XYZ: ...
    def GetStackedWallMemberIds(self) -> List[ElementId]: ...
    def Flip(self) -> None: ...
    @overload
    def Create(document: Document, profile: List[Curve], wallTypeId: ElementId, levelId: ElementId, structural: bool, normal: XYZ) -> Wall: ...
    @overload
    def Create(document: Document, profile: List[Curve], wallTypeId: ElementId, levelId: ElementId, structural: bool) -> Wall: ...
    @overload
    def Create(document: Document, profile: List[Curve], structural: bool) -> Wall: ...
    @overload
    def Create(document: Document, curve: Curve, wallTypeId: ElementId, levelId: ElementId, height: float, offset: float, flip: bool, structural: bool) -> Wall: ...
    @overload
    def Create(document: Document, curve: Curve, levelId: ElementId, structural: bool) -> Wall: ...


class WallFoundation(HostObject):
    @property
    def WallId(self) -> ElementId: ...
    def Create(document: Document, typeId: ElementId, wallId: ElementId) -> WallFoundation: ...


class ProjectInfo(Element):
    @property
    def IssueDate(self) -> str: ...
    @IssueDate.setter
    def IssueDate(self, valueString: str) -> None: ...
    @property
    def Status(self) -> str: ...
    @Status.setter
    def Status(self, valueString: str) -> None: ...
    @property
    def ClientName(self) -> str: ...
    @ClientName.setter
    def ClientName(self, valueString: str) -> None: ...
    @property
    def Address(self) -> str: ...
    @Address.setter
    def Address(self, valueString: str) -> None: ...
    @property
    def Name(self) -> str: ...
    @Name.setter
    def Name(self, valueString: str) -> None: ...
    @property
    def Number(self) -> str: ...
    @Number.setter
    def Number(self, valueString: str) -> None: ...
    @property
    def Author(self) -> str: ...
    @Author.setter
    def Author(self, valueString: str) -> None: ...
    @property
    def BuildingName(self) -> str: ...
    @BuildingName.setter
    def BuildingName(self, valueString: str) -> None: ...
    @property
    def OrganizationName(self) -> str: ...
    @OrganizationName.setter
    def OrganizationName(self, valueString: str) -> None: ...
    @property
    def OrganizationDescription(self) -> str: ...
    @OrganizationDescription.setter
    def OrganizationDescription(self, valueString: str) -> None: ...


class ProjectLocation(Instance):
    def GetProjectPosition(self, point: XYZ) -> ProjectPosition: ...
    def SetProjectPosition(self, point: XYZ, position: ProjectPosition) -> None: ...
    def GetSiteLocation(self) -> SiteLocation: ...
    def Duplicate(self, name: str) -> ProjectLocation: ...
    def IsProjectLocationNameUnique(document: Document, name: str, siteLocationId: ElementId) -> bool: ...
    def Create(document: Document, siteLocationId: ElementId, name: str) -> ProjectLocation: ...


class ProjectLocationSet(APIObject):
    def __init__(self): ...
    def Clear(self) -> None: ...
    @property
    def Size(self) -> int: ...
    @property
    def IsEmpty(self) -> bool: ...
    def ForwardIterator(self) -> ProjectLocationSetIterator: ...
    def ReverseIterator(self) -> ProjectLocationSetIterator: ...
    def GetEnumerator(self) -> IEnumerator: ...
    def Contains(self, item: ProjectLocation) -> bool: ...
    def Insert(self, item: ProjectLocation) -> bool: ...
    def Erase(self, item: ProjectLocation) -> int: ...


class ProjectLocationSetIterator(APIObject):
    def __init__(self): ...
    @property
    def Current(self) -> Object: ...
    def MoveNext(self) -> bool: ...
    def Reset(self) -> None: ...


class ElementFilter:
    @property
    def Inverted(self) -> bool: ...
    @property
    def IsValidObject(self) -> bool: ...
    @overload
    def PassesFilter(self, document: Document, id: ElementId) -> bool: ...
    @overload
    def PassesFilter(self, element: Element) -> bool: ...
    def Dispose(self) -> None: ...


class ElementQuickFilter(ElementFilter):


class ElementSlowFilter(ElementFilter):


class ExclusionFilter(ElementQuickFilter):
    def __init__(self, idsToExclude: ICollection): ...
    def GetIdsToExclude(self) -> ICollection: ...


class ElementIdSetFilter(ElementQuickFilter):
    def __init__(self, idsToInclude: ICollection): ...
    def GetIdsToInclude(self) -> ICollection: ...


class ElementWorksetFilter(ElementQuickFilter):
    @overload
    def __init__(self, worksetId: WorksetId, inverted: bool): ...
    @overload
    def __init__(self, worksetId: WorksetId): ...
    @property
    def WorksetId(self) -> WorksetId: ...


class ElementCategoryFilter(ElementQuickFilter):
    @overload
    def __init__(self, category: BuiltInCategory, inverted: bool): ...
    @overload
    def __init__(self, category: BuiltInCategory): ...
    @overload
    def __init__(self, categoryId: ElementId, inverted: bool): ...
    @overload
    def __init__(self, categoryId: ElementId): ...
    @property
    def CategoryId(self) -> ElementId: ...


class ElementMulticategoryFilter(ElementQuickFilter):
    @overload
    def __init__(self, categories: ICollection, inverted: bool): ...
    @overload
    def __init__(self, categories: ICollection): ...
    @overload
    def __init__(self, categoryIds: ICollection, inverted: bool): ...
    @overload
    def __init__(self, categoryIds: ICollection): ...
    def GetCategoryIds(self) -> ICollection: ...


class ElementMulticlassFilter(ElementQuickFilter):
    @overload
    def __init__(self, typeList: List[Type], inverted: bool): ...
    @overload
    def __init__(self, typeList: List[Type]): ...


class ElementClassFilter(ElementQuickFilter):
    @overload
    def __init__(self, type: Type, inverted: bool): ...
    @overload
    def __init__(self, type: Type): ...
    def GetElementClass(self) -> Type: ...


class ElementIsElementTypeFilter(ElementQuickFilter):
    @overload
    def __init__(self, inverted: bool): ...
    @overload
    def __init__(self): ...


class ElementOwnerViewFilter(ElementQuickFilter):
    @overload
    def __init__(self, viewId: ElementId, inverted: bool): ...
    @overload
    def __init__(self, viewId: ElementId): ...
    @property
    def ViewId(self) -> ElementId: ...


class ElementDesignOptionFilter(ElementQuickFilter):
    @overload
    def __init__(self, designOptionId: ElementId, inverted: bool): ...
    @overload
    def __init__(self, designOptionId: ElementId): ...
    @property
    def DesignOptionId(self) -> ElementId: ...


class ElementIsCurveDrivenFilter(ElementQuickFilter):
    @overload
    def __init__(self, inverted: bool): ...
    @overload
    def __init__(self): ...


class BoundingBoxIntersectsFilter(ElementQuickFilter):
    @overload
    def __init__(self, outline: Outline, tolerance: float, inverted: bool): ...
    @overload
    def __init__(self, outline: Outline, tolerance: float): ...
    @overload
    def __init__(self, outline: Outline, inverted: bool): ...
    @overload
    def __init__(self, outline: Outline): ...
    @property
    def Tolerance(self) -> float: ...
    @Tolerance.setter
    def Tolerance(self, tolerance: float) -> None: ...
    def GetBoundingBox(self) -> Outline: ...


class BoundingBoxIsInsideFilter(ElementQuickFilter):
    @overload
    def __init__(self, outline: Outline, tolerance: float, inverted: bool): ...
    @overload
    def __init__(self, outline: Outline, tolerance: float): ...
    @overload
    def __init__(self, outline: Outline, inverted: bool): ...
    @overload
    def __init__(self, outline: Outline): ...
    @property
    def Tolerance(self) -> float: ...
    @Tolerance.setter
    def Tolerance(self, tolerance: float) -> None: ...
    def GetBoundingBox(self) -> Outline: ...


class BoundingBoxContainsPointFilter(ElementQuickFilter):
    @overload
    def __init__(self, point: XYZ, tolerance: float, inverted: bool): ...
    @overload
    def __init__(self, point: XYZ, tolerance: float): ...
    @overload
    def __init__(self, point: XYZ, inverted: bool): ...
    @overload
    def __init__(self, point: XYZ): ...
    @property
    def Point(self) -> XYZ: ...
    @Point.setter
    def Point(self, point: XYZ) -> None: ...
    @property
    def Tolerance(self) -> float: ...
    @Tolerance.setter
    def Tolerance(self, tolerance: float) -> None: ...


class ElementLevelFilter(ElementSlowFilter):
    @overload
    def __init__(self, levelId: ElementId, inverted: bool): ...
    @overload
    def __init__(self, levelId: ElementId): ...
    @property
    def LevelId(self) -> ElementId: ...


class ElementParameterFilter(ElementSlowFilter):
    @overload
    def __init__(self, filterRules: List[FilterRule], inverted: bool): ...
    @overload
    def __init__(self, filterRules: List[FilterRule]): ...
    @overload
    def __init__(self, filterRule: FilterRule, inverted: bool): ...
    @overload
    def __init__(self, filterRule: FilterRule): ...
    def GetRules(self) -> List[FilterRule]: ...


class PrimaryDesignOptionMemberFilter(ElementSlowFilter):
    @overload
    def __init__(self, inverted: bool): ...
    @overload
    def __init__(self): ...


class ElementPhaseStatusFilter(ElementSlowFilter):
    @overload
    def __init__(self, phaseId: ElementId, phaseStatuses: ICollection, inverted: bool): ...
    @overload
    def __init__(self, phaseId: ElementId, phaseStatuses: ICollection): ...
    @overload
    def __init__(self, phaseId: ElementId, phaseStatus: ElementOnPhaseStatus, inverted: bool): ...
    @overload
    def __init__(self, phaseId: ElementId, phaseStatus: ElementOnPhaseStatus): ...
    @property
    def PhaseId(self) -> ElementId: ...
    def GetPhaseStatuses(self) -> ICollection: ...


class ExportFontKey:
    @overload
    def __init__(self, originalFontName: str): ...
    @overload
    def __init__(self): ...
    @overload
    def __init__(self, other: ExportFontKey): ...
    @property
    def OriginalFontName(self) -> str: ...
    @OriginalFontName.setter
    def OriginalFontName(self, originalFontName: str) -> None: ...
    @property
    def IsValidObject(self) -> bool: ...
    def Dispose(self) -> None: ...


class ExportFontInfo:
    @overload
    def __init__(self, destinationFontName: str): ...
    @overload
    def __init__(self): ...
    @overload
    def __init__(self, other: ExportFontInfo): ...
    @property
    def DestinationFontName(self) -> str: ...
    @DestinationFontName.setter
    def DestinationFontName(self, destinationFontName: str) -> None: ...
    @property
    def IsValidObject(self) -> bool: ...
    def Dispose(self) -> None: ...


class ExportFontTableIterator:
    @property
    def IsValidObject(self) -> bool: ...
    def MoveNext(self) -> bool: ...
    def IsDone(self) -> bool: ...
    def Reset(self) -> None: ...
    @property
    def Current(self) -> KeyValuePair: ...
    def Dispose(self) -> None: ...


class ExportFontTable:
    def __init__(self): ...
    def GetFontTableIterator(self) -> ExportFontTableIterator: ...
    @property
    def Item(self, fontKey: ExportFontKey) -> ExportFontInfo: ...
    @Item.setter
    def Item(self, FontKey: ExportFontKey, FontInfo: ExportFontInfo) -> None: ...
    @property
    def Count(self) -> int: ...
    @property
    def IsValidObject(self) -> bool: ...
    def ContainsKey(self, exportfontKey: ExportFontKey) -> bool: ...
    def GetExportFontInfo(self, exportFontKey: ExportFontKey) -> ExportFontInfo: ...
    def GetKeys(self) -> List[ExportFontKey]: ...
    def GetValues(self) -> List[ExportFontInfo]: ...
    def Add(self, exportFontKey: ExportFontKey, exportFontInfo: ExportFontInfo) -> None: ...
    def Remove(self, exportFontKey: ExportFontKey) -> None: ...
    def Clear(self) -> None: ...
    def GetEnumerator(self) -> IEnumerator: ...
    def Dispose(self) -> None: ...


class ExportLinetypeKey:
    @overload
    def __init__(self, originalLinetypeName: str): ...
    @overload
    def __init__(self): ...
    @overload
    def __init__(self, other: ExportLinetypeKey): ...
    @property
    def OriginalLinetypeName(self) -> str: ...
    @OriginalLinetypeName.setter
    def OriginalLinetypeName(self, originalLinetypeName: str) -> None: ...
    @property
    def IsValidObject(self) -> bool: ...
    def Dispose(self) -> None: ...


class ExportLinetypeInfo:
    @overload
    def __init__(self, destinationLinetypeName: str): ...
    @overload
    def __init__(self): ...
    @overload
    def __init__(self, other: ExportLinetypeInfo): ...
    @property
    def DestinationLinetypeName(self) -> str: ...
    @DestinationLinetypeName.setter
    def DestinationLinetypeName(self, destinationLinetypeName: str) -> None: ...
    @property
    def IsValidObject(self) -> bool: ...
    def Dispose(self) -> None: ...


class ExportLinetypeTableIterator:
    @property
    def IsValidObject(self) -> bool: ...
    def MoveNext(self) -> bool: ...
    def IsDone(self) -> bool: ...
    def Reset(self) -> None: ...
    @property
    def Current(self) -> KeyValuePair: ...
    def Dispose(self) -> None: ...


class ExportLinetypeTable:
    def __init__(self): ...
    def GetLinetypeTableIterator(self) -> ExportLinetypeTableIterator: ...
    @property
    def Item(self, linetypeKey: ExportLinetypeKey) -> ExportLinetypeInfo: ...
    @Item.setter
    def Item(self, LinetypeKey: ExportLinetypeKey, LinetypeInfo: ExportLinetypeInfo) -> None: ...
    @property
    def Count(self) -> int: ...
    @property
    def IsValidObject(self) -> bool: ...
    def ContainsKey(self, exportLinetypeKey: ExportLinetypeKey) -> bool: ...
    def GetExportLinetypeInfo(self, exportLinetypeKey: ExportLinetypeKey) -> ExportLinetypeInfo: ...
    def GetKeys(self) -> List[ExportLinetypeKey]: ...
    def GetValues(self) -> List[ExportLinetypeInfo]: ...
    def Add(self, exportLinetypeKey: ExportLinetypeKey, exportLinetypeInfo: ExportLinetypeInfo) -> None: ...
    def Remove(self, exportLinetypeKey: ExportLinetypeKey) -> None: ...
    def Clear(self) -> None: ...
    def GetEnumerator(self) -> IEnumerator: ...
    def Dispose(self) -> None: ...


class ExportLineweightKey:
    @overload
    def __init__(self, originalLineweight: int): ...
    @overload
    def __init__(self): ...
    @overload
    def __init__(self, other: ExportLineweightKey): ...
    @property
    def OriginalLineweight(self) -> int: ...
    @OriginalLineweight.setter
    def OriginalLineweight(self, originalLineweight: int) -> None: ...
    @property
    def IsValidObject(self) -> bool: ...
    def Dispose(self) -> None: ...


class ExportLineweightInfo:
    @overload
    def __init__(self, destinationLineweightName: str): ...
    @overload
    def __init__(self): ...
    @overload
    def __init__(self, other: ExportLineweightInfo): ...
    @property
    def DestinationLineweightName(self) -> str: ...
    @DestinationLineweightName.setter
    def DestinationLineweightName(self, destinationLineweightName: str) -> None: ...
    @property
    def IsValidObject(self) -> bool: ...
    def Dispose(self) -> None: ...


class ExportLineweightTableIterator:
    @property
    def IsValidObject(self) -> bool: ...
    def MoveNext(self) -> bool: ...
    def IsDone(self) -> bool: ...
    def Reset(self) -> None: ...
    @property
    def Current(self) -> KeyValuePair: ...
    def Dispose(self) -> None: ...


class ExportLineweightTable:
    def __init__(self): ...
    def GetLineweightTableIterator(self) -> ExportLineweightTableIterator: ...
    @property
    def Item(self, lineweightKey: ExportLineweightKey) -> ExportLineweightInfo: ...
    @Item.setter
    def Item(self, LineweightKey: ExportLineweightKey, LineweightInfo: ExportLineweightInfo) -> None: ...
    @property
    def Count(self) -> int: ...
    @property
    def IsValidObject(self) -> bool: ...
    def ContainsKey(self, exportLineweightKey: ExportLineweightKey) -> bool: ...
    def GetExportLineweightInfo(self, exportLineweightKey: ExportLineweightKey) -> ExportLineweightInfo: ...
    def GetKeys(self) -> List[ExportLineweightKey]: ...
    def GetValues(self) -> List[ExportLineweightInfo]: ...
    def Add(self, exportLineweightKey: ExportLineweightKey, exportLineweightInfo: ExportLineweightInfo) -> None: ...
    def Remove(self, exportLineweightKey: ExportLineweightKey) -> None: ...
    def Clear(self) -> None: ...
    def GetEnumerator(self) -> IEnumerator: ...
    def Dispose(self) -> None: ...


class ExportPatternKey:
    @overload
    def __init__(self, originalFillPatternType: FillPatternTarget, originalFillPatternName: str): ...
    @overload
    def __init__(self): ...
    @overload
    def __init__(self, other: ExportPatternKey): ...
    @property
    def OriginalFillPatternType(self) -> FillPatternTarget: ...
    @OriginalFillPatternType.setter
    def OriginalFillPatternType(self, originalFillPatternType: FillPatternTarget) -> None: ...
    @property
    def OriginalFillPatternName(self) -> str: ...
    @OriginalFillPatternName.setter
    def OriginalFillPatternName(self, originalFillPatternName: str) -> None: ...
    @property
    def IsValidObject(self) -> bool: ...
    def Dispose(self) -> None: ...


class ExportPatternInfo:
    @overload
    def __init__(self, destinationPatternName: str): ...
    @overload
    def __init__(self): ...
    @overload
    def __init__(self, other: ExportPatternInfo): ...
    @property
    def DestinationPatternName(self) -> str: ...
    @DestinationPatternName.setter
    def DestinationPatternName(self, destinationPatternName: str) -> None: ...
    @property
    def IsValidObject(self) -> bool: ...
    def Dispose(self) -> None: ...


class ExportPatternTableIterator:
    @property
    def IsValidObject(self) -> bool: ...
    def MoveNext(self) -> bool: ...
    def IsDone(self) -> bool: ...
    def Reset(self) -> None: ...
    @property
    def Current(self) -> KeyValuePair: ...
    def Dispose(self) -> None: ...


class ExportPatternTable:
    def __init__(self): ...
    def GetPatternTableIterator(self) -> ExportPatternTableIterator: ...
    @property
    def Item(self, patternKey: ExportPatternKey) -> ExportPatternInfo: ...
    @Item.setter
    def Item(self, PatternKey: ExportPatternKey, PatternInfo: ExportPatternInfo) -> None: ...
    @property
    def Count(self) -> int: ...
    @property
    def IsValidObject(self) -> bool: ...
    def ContainsKey(self, exportpatternKey: ExportPatternKey) -> bool: ...
    def GetExportPatternInfo(self, exportPatternKey: ExportPatternKey) -> ExportPatternInfo: ...
    def GetKeys(self) -> List[ExportPatternKey]: ...
    def GetValues(self) -> List[ExportPatternInfo]: ...
    def Add(self, exportPatternKey: ExportPatternKey, exportPatternInfo: ExportPatternInfo) -> None: ...
    def Remove(self, exportPatternKey: ExportPatternKey) -> None: ...
    def Clear(self) -> None: ...
    def GetEnumerator(self) -> IEnumerator: ...
    def Dispose(self) -> None: ...


class IExtension:
    @property
    def Extended(self, index: int) -> bool: ...
    @Extended.setter
    def Extended(self, index: int, extended: bool) -> None: ...
    @property
    def SymbolicExtended(self, index: int) -> bool: ...
    @SymbolicExtended.setter
    def SymbolicExtended(self, index: int, symbolicExtended: bool) -> None: ...
    @property
    def HasMiter(self, index: int) -> bool: ...
    @property
    def IsMiterLocked(self, index: int) -> bool: ...
    @IsMiterLocked.setter
    def IsMiterLocked(self, index: int, miterLocked: bool) -> None: ...


class Extrusion(GenericForm):
    @property
    def Sketch(self) -> Sketch: ...
    @property
    def StartOffset(self) -> float: ...
    @StartOffset.setter
    def StartOffset(self, startOffset: float) -> None: ...
    @property
    def EndOffset(self) -> float: ...
    @EndOffset.setter
    def EndOffset(self, endOffset: float) -> None: ...


class PlanarFace(Face):
    @property
    def Origin(self) -> XYZ: ...
    @property
    def FaceNormal(self) -> XYZ: ...
    @property
    def XVector(self) -> XYZ: ...
    @property
    def YVector(self) -> XYZ: ...


class ModelText(Element):
    @property
    def Text(self) -> str: ...
    @Text.setter
    def Text(self, text: str) -> None: ...
    @property
    def Location(self) -> Location: ...
    def GetVisibility(self) -> FamilyElementVisibility: ...
    def SetVisibility(self, visibility: FamilyElementVisibility) -> None: ...
    @property
    def Depth(self) -> float: ...
    @Depth.setter
    def Depth(self, depth: float) -> None: ...
    @property
    def HorizontalAlignment(self) -> HorizontalAlign: ...
    @HorizontalAlignment.setter
    def HorizontalAlignment(self, align: HorizontalAlign) -> None: ...
    @property
    def ModelTextType(self) -> ModelTextType: ...
    @ModelTextType.setter
    def ModelTextType(self, modelTextType: ModelTextType) -> None: ...
    @property
    def Subcategory(self) -> Category: ...
    @Subcategory.setter
    def Subcategory(self, subcategory: Category) -> None: ...


class ModelTextType(ElementType):


class Revolution(GenericForm):
    @property
    def Sketch(self) -> Sketch: ...
    @property
    def StartAngle(self) -> float: ...
    @StartAngle.setter
    def StartAngle(self, startAngle: float) -> None: ...
    @property
    def EndAngle(self) -> float: ...
    @EndAngle.setter
    def EndAngle(self, endAngle: float) -> None: ...
    @property
    def Axis(self) -> ModelLine: ...


class TilePattern(ElementType):
    @property
    def TilePatternType(self) -> TilePatternsBuiltIn: ...
    @property
    def TilesPerSeedNode(self) -> int: ...


class GridNode:
    def __init__(self, uIndex: int, vIndex: int): ...
    @property
    def UIndex(self) -> int: ...
    @UIndex.setter
    def UIndex(self, A_0: int) -> None: ...
    @property
    def VIndex(self) -> int: ...
    @VIndex.setter
    def VIndex(self, A_0: int) -> None: ...


class DividedSurface(Element):
    @property
    def Host(self) -> Element: ...
    @property
    def HostReference(self) -> Reference: ...
    @property
    def USpacingRule(self) -> SpacingRule: ...
    @property
    def VSpacingRule(self) -> SpacingRule: ...
    @property
    def AllGridRotation(self) -> float: ...
    @AllGridRotation.setter
    def AllGridRotation(self, angle: float) -> None: ...
    @property
    def BorderTile(self) -> BorderTile: ...
    @BorderTile.setter
    def BorderTile(self, A_0: BorderTile) -> None: ...
    @property
    def UPatternIndent(self) -> int: ...
    @UPatternIndent.setter
    def UPatternIndent(self, A_0: int) -> None: ...
    @property
    def VPatternIndent(self) -> int: ...
    @VPatternIndent.setter
    def VPatternIndent(self, A_0: int) -> None: ...
    @property
    def ComponentRotation(self) -> ComponentRotation: ...
    @ComponentRotation.setter
    def ComponentRotation(self, A_0: ComponentRotation) -> None: ...
    @property
    def IsComponentMirrored(self) -> bool: ...
    @IsComponentMirrored.setter
    def IsComponentMirrored(self, A_0: bool) -> None: ...
    @property
    def IsComponentFlipped(self) -> bool: ...
    @IsComponentFlipped.setter
    def IsComponentFlipped(self, A_0: bool) -> None: ...
    @property
    def NumberOfUGridlines(self) -> int: ...
    @property
    def NumberOfVGridlines(self) -> int: ...
    def GetGridNodeUV(self, gridNode: GridNode) -> UV: ...
    def GetGridNodeLocation(self, gridNode: GridNode) -> GridNodeLocation: ...
    def GetGridNodeReference(self, gridNode: GridNode) -> Reference: ...
    def GetGridSegmentReference(self, gridNode: GridNode, gridSegmentDirection: GridSegmentDirection) -> Reference: ...
    def IsSeedNode(self, gridNode: GridNode) -> bool: ...
    def GetTileReference(self, gridNode: GridNode, tileIndex: int) -> Reference: ...
    def GetTileFamilyInstance(self, gridNode: GridNode, tileIndex: int) -> FamilyInstance: ...
    def Create(document: Document, faceReference: Reference) -> DividedSurface: ...
    def CanBeDivided(document: Document, reference: Reference) -> bool: ...
    def GetReferencesWithDividedSurfaces(host: Element) -> List[Reference]: ...
    def GetDividedSurfaceForReference(document: Document, faceReference: Reference) -> DividedSurface: ...
    def GetAllIntersectionElements(self) -> ICollection: ...
    def AddIntersectionElement(self, newIntersectionElemId: ElementId) -> None: ...
    def RemoveIntersectionElement(self, referenceElemIdToRemove: ElementId) -> None: ...
    def RemoveAllIntersectionElements(self) -> None: ...
    def CanBeIntersectionElement(self, id: ElementId) -> bool: ...


class ReferenceArrayArray(APIObject):
    def __init__(self): ...
    def Clear(self) -> None: ...
    @property
    def Size(self) -> int: ...
    @property
    def IsEmpty(self) -> bool: ...
    def ForwardIterator(self) -> ReferenceArrayArrayIterator: ...
    def ReverseIterator(self) -> ReferenceArrayArrayIterator: ...
    def GetEnumerator(self) -> IEnumerator: ...
    @property
    def Item(self, index: int) -> ReferenceArray: ...
    @Item.setter
    def Item(self, index: int, item: ReferenceArray) -> None: ...
    def Append(self, item: ReferenceArray) -> None: ...
    def Insert(self, item: ReferenceArray, index: int) -> None: ...


class ReferenceArrayArrayIterator(APIObject):
    def __init__(self): ...
    @property
    def Current(self) -> Object: ...
    def MoveNext(self) -> bool: ...
    def Reset(self) -> None: ...


class FormArray(APIObject):
    def __init__(self): ...
    def Clear(self) -> None: ...
    @property
    def Size(self) -> int: ...
    @property
    def IsEmpty(self) -> bool: ...
    def ForwardIterator(self) -> FormArrayIterator: ...
    def ReverseIterator(self) -> FormArrayIterator: ...
    def GetEnumerator(self) -> IEnumerator: ...
    @property
    def Item(self, index: int) -> Form: ...
    @Item.setter
    def Item(self, index: int, item: Form) -> None: ...
    def Append(self, item: Form) -> None: ...
    def Insert(self, item: Form, index: int) -> None: ...


class FormArrayIterator(APIObject):
    def __init__(self): ...
    @property
    def Current(self) -> Object: ...
    def MoveNext(self) -> bool: ...
    def Reset(self) -> None: ...


class ExternalDefinition(Definition):
    @property
    def Name(self) -> str: ...
    @property
    def GUID(self) -> Guid: ...
    @property
    def ParameterType(self) -> ParameterType: ...
    @property
    def Visible(self) -> bool: ...
    @property
    def ParameterGroup(self) -> BuiltInParameterGroup: ...
    @property
    def OwnerGroup(self) -> DefinitionGroup: ...
    @OwnerGroup.setter
    def OwnerGroup(self, group: DefinitionGroup) -> None: ...
    @property
    def Description(self) -> str: ...
    @property
    def UserModifiable(self) -> bool: ...
    @property
    def HideWhenNoValue(self) -> bool: ...
    @HideWhenNoValue.setter
    def HideWhenNoValue(self, hideWhenNoValue: bool) -> None: ...
    @property
    def IsValidObject(self) -> bool: ...
    def Dispose(self) -> None: ...


class ExternalDefinitionCreationOptions:
    def __init__(self, name: str, type: ParameterType): ...
    @property
    def Name(self) -> str: ...
    @Name.setter
    def Name(self, name: str) -> None: ...
    @property
    def Type(self) -> ParameterType: ...
    @Type.setter
    def Type(self, e: ParameterType) -> None: ...
    @property
    def Visible(self) -> bool: ...
    @Visible.setter
    def Visible(self, visible: bool) -> None: ...
    @property
    def GUID(self) -> Guid: ...
    @GUID.setter
    def GUID(self, guid: Guid) -> None: ...
    @property
    def Description(self) -> str: ...
    @Description.setter
    def Description(self, description: str) -> None: ...
    @property
    def UserModifiable(self) -> bool: ...
    @UserModifiable.setter
    def UserModifiable(self, userModifiable: bool) -> None: ...
    @property
    def HideWhenNoValue(self) -> bool: ...
    @HideWhenNoValue.setter
    def HideWhenNoValue(self, hideWhenNoValue: bool) -> None: ...
    @property
    def IsValidObject(self) -> bool: ...
    def Dispose(self) -> None: ...


class FamilyType(APIObject):
    @property
    def Name(self) -> str: ...
    def AsString(self, familyParameter: FamilyParameter) -> str: ...
    def AsInteger(self, familyParameter: FamilyParameter) -> Nullable: ...
    def AsDouble(self, familyParameter: FamilyParameter) -> Nullable: ...
    def AsElementId(self, familyParameter: FamilyParameter) -> ElementId: ...
    def AsValueString(self, familyParameter: FamilyParameter) -> str: ...
    def HasValue(self, familyParameter: FamilyParameter) -> bool: ...


class FamilyTypeSet(APIObject):
    def __init__(self): ...
    def Clear(self) -> None: ...
    @property
    def Size(self) -> int: ...
    @property
    def IsEmpty(self) -> bool: ...
    def ForwardIterator(self) -> FamilyTypeSetIterator: ...
    def ReverseIterator(self) -> FamilyTypeSetIterator: ...
    def GetEnumerator(self) -> IEnumerator: ...
    def Contains(self, item: FamilyType) -> bool: ...
    def Insert(self, item: FamilyType) -> bool: ...
    def Erase(self, item: FamilyType) -> int: ...


class FamilyTypeSetIterator(APIObject):
    def __init__(self): ...
    @property
    def Current(self) -> Object: ...
    def MoveNext(self) -> bool: ...
    def Reset(self) -> None: ...


class FilteredElementIdIterator:
    @property
    def IsValidObject(self) -> bool: ...
    def GetCurrent(self) -> ElementId: ...
    def MoveNext(self) -> bool: ...
    def IsDone(self) -> bool: ...
    def Reset(self) -> None: ...
    @property
    def Current(self) -> ElementId: ...
    def Dispose(self) -> None: ...


class FilteredElementIterator:
    @property
    def IsValidObject(self) -> bool: ...
    def GetCurrent(self) -> Element: ...
    def MoveNext(self) -> bool: ...
    def IsDone(self) -> bool: ...
    def Reset(self) -> None: ...
    @property
    def Current(self) -> Element: ...
    def Dispose(self) -> None: ...


class FilteredElementCollector:
    @overload
    def __init__(self, document: Document, viewId: ElementId): ...
    @overload
    def __init__(self, document: Document, elementIds: ICollection): ...
    @overload
    def __init__(self, document: Document): ...
    def OfCategory(self, category: BuiltInCategory) -> FilteredElementCollector: ...
    def GetElementIdIterator(self) -> FilteredElementIdIterator: ...
    def GetElementIterator(self) -> FilteredElementIterator: ...
    @property
    def IsValidObject(self) -> bool: ...
    def WherePasses(self, filter: ElementFilter) -> FilteredElementCollector: ...
    def IntersectWith(self, other: FilteredElementCollector) -> FilteredElementCollector: ...
    def UnionWith(self, other: FilteredElementCollector) -> FilteredElementCollector: ...
    def OfClass(self, type: Type) -> FilteredElementCollector: ...
    def OfCategoryId(self, categoryId: ElementId) -> FilteredElementCollector: ...
    def WhereElementIsElementType(self) -> FilteredElementCollector: ...
    def WhereElementIsNotElementType(self) -> FilteredElementCollector: ...
    def OwnedByView(self, viewId: ElementId) -> FilteredElementCollector: ...
    def WhereElementIsViewIndependent(self) -> FilteredElementCollector: ...
    def ContainedInDesignOption(self, designOptionId: ElementId) -> FilteredElementCollector: ...
    def WhereElementIsCurveDriven(self) -> FilteredElementCollector: ...
    def Excluding(self, idsToExclude: ICollection) -> FilteredElementCollector: ...
    def GetElementCount(self) -> int: ...
    def ToElementIds(self) -> ICollection: ...
    def ToElements(self) -> List[Element]: ...
    def FirstElementId(self) -> ElementId: ...
    def FirstElement(self) -> Element: ...
    def IsViewValidForElementIteration(document: Document, viewId: ElementId) -> bool: ...
    def GetEnumerator(self) -> IEnumerator: ...
    def Dispose(self) -> None: ...


class FilteredWorksetIdIterator:
    @property
    def IsValidObject(self) -> bool: ...
    def GetCurrent(self) -> WorksetId: ...
    def MoveNext(self) -> bool: ...
    def IsDone(self) -> bool: ...
    def Reset(self) -> None: ...
    @property
    def Current(self) -> WorksetId: ...
    def Dispose(self) -> None: ...


class FilteredWorksetIterator:
    @property
    def IsValidObject(self) -> bool: ...
    def GetCurrent(self) -> Workset: ...
    def MoveNext(self) -> bool: ...
    def IsDone(self) -> bool: ...
    def Reset(self) -> None: ...
    @property
    def Current(self) -> Workset: ...
    def Dispose(self) -> None: ...


class FilteredWorksetCollector:
    def __init__(self, document: Document): ...
    def GetWorksetIdIterator(self) -> FilteredWorksetIdIterator: ...
    def GetWorksetIterator(self) -> FilteredWorksetIterator: ...
    @property
    def IsValidObject(self) -> bool: ...
    def WherePasses(self, filter: WorksetFilter) -> FilteredWorksetCollector: ...
    def OfKind(self, worksetKind: WorksetKind) -> FilteredWorksetCollector: ...
    def ToWorksetIds(self) -> ICollection: ...
    def ToWorksets(self) -> List[Workset]: ...
    def FirstWorksetId(self) -> WorksetId: ...
    def FirstWorkset(self) -> Workset: ...
    def GetEnumerator(self) -> IEnumerator: ...
    def Dispose(self) -> None: ...


class WorksetFilter:
    @property
    def Inverted(self) -> bool: ...
    @property
    def IncludeStandaloneWorksetsOnly(self) -> bool: ...
    @IncludeStandaloneWorksetsOnly.setter
    def IncludeStandaloneWorksetsOnly(self, includeStandaloneWorksetsOnly: bool) -> None: ...
    @property
    def IsValidObject(self) -> bool: ...
    def Dispose(self) -> None: ...


class WorksetKindFilter(WorksetFilter):
    @overload
    def __init__(self, worksetKind: WorksetKind, inverted: bool): ...
    @overload
    def __init__(self, worksetKind: WorksetKind): ...
    @property
    def WorksetKind(self) -> WorksetKind: ...


class GuidEnum:
    def __init__(self, guid: Guid): ...
    @property
    def Guid(self) -> Guid: ...
    def Equals(self, obj: Object) -> bool: ...
    def GetHashCode(self) -> int: ...


class PrintParameters(APIObject):
    @property
    def PageOrientation(self) -> PageOrientationType: ...
    @PageOrientation.setter
    def PageOrientation(self, ortype: PageOrientationType) -> None: ...
    @property
    def PaperSize(self) -> PaperSize: ...
    @PaperSize.setter
    def PaperSize(self, ps: PaperSize) -> None: ...
    @property
    def PaperSource(self) -> PaperSource: ...
    @PaperSource.setter
    def PaperSource(self, ps: PaperSource) -> None: ...
    @property
    def PaperPlacement(self) -> PaperPlacementType: ...
    @PaperPlacement.setter
    def PaperPlacement(self, pptype: PaperPlacementType) -> None: ...
    @property
    def MarginType(self) -> MarginType: ...
    @MarginType.setter
    def MarginType(self, mt: MarginType) -> None: ...
    @property
    def UserDefinedMarginX(self) -> float: ...
    @UserDefinedMarginX.setter
    def UserDefinedMarginX(self, value: float) -> None: ...
    @property
    def UserDefinedMarginY(self) -> float: ...
    @UserDefinedMarginY.setter
    def UserDefinedMarginY(self, value: float) -> None: ...
    @property
    def ZoomType(self) -> ZoomType: ...
    @ZoomType.setter
    def ZoomType(self, zt: ZoomType) -> None: ...
    @property
    def Zoom(self) -> int: ...
    @Zoom.setter
    def Zoom(self, zoom: int) -> None: ...
    @property
    def HiddenLineViews(self) -> HiddenLineViewsType: ...
    @HiddenLineViews.setter
    def HiddenLineViews(self, hlvt: HiddenLineViewsType) -> None: ...
    @property
    def RasterQuality(self) -> RasterQualityType: ...
    @RasterQuality.setter
    def RasterQuality(self, rqt: RasterQualityType) -> None: ...
    @property
    def ColorDepth(self) -> ColorDepthType: ...
    @ColorDepth.setter
    def ColorDepth(self, cdt: ColorDepthType) -> None: ...
    @property
    def ViewLinksinBlue(self) -> bool: ...
    @ViewLinksinBlue.setter
    def ViewLinksinBlue(self, vlb: bool) -> None: ...
    @property
    def HideReforWorkPlanes(self) -> bool: ...
    @HideReforWorkPlanes.setter
    def HideReforWorkPlanes(self, hrwp: bool) -> None: ...
    @property
    def HideUnreferencedViewTags(self) -> bool: ...
    @HideUnreferencedViewTags.setter
    def HideUnreferencedViewTags(self, huvt: bool) -> None: ...
    @property
    def HideScopeBoxes(self) -> bool: ...
    @HideScopeBoxes.setter
    def HideScopeBoxes(self, hsb: bool) -> None: ...
    @property
    def HideCropBoundaries(self) -> bool: ...
    @HideCropBoundaries.setter
    def HideCropBoundaries(self, hcb: bool) -> None: ...
    @property
    def ReplaceHalftoneWithThinLines(self) -> bool: ...
    @ReplaceHalftoneWithThinLines.setter
    def ReplaceHalftoneWithThinLines(self, rhwt: bool) -> None: ...
    @property
    def MaskCoincidentLines(self) -> bool: ...
    @MaskCoincidentLines.setter
    def MaskCoincidentLines(self, mcl: bool) -> None: ...


class Viewport(Element):
    @property
    def ViewId(self) -> ElementId: ...
    @property
    def SheetId(self) -> ElementId: ...
    @property
    def Rotation(self) -> ViewportRotation: ...
    @Rotation.setter
    def Rotation(self, viewportRotation: ViewportRotation) -> None: ...
    def Create(document: Document, viewSheetId: ElementId, viewId: ElementId, point: XYZ) -> Viewport: ...
    def CanAddViewToSheet(document: Document, viewSheetId: ElementId, viewId: ElementId) -> bool: ...
    def GetBoxOutline(self) -> Outline: ...
    def GetBoxCenter(self) -> XYZ: ...
    def SetBoxCenter(self, newCenterPoint: XYZ) -> None: ...
    def GetLabelOutline(self) -> Outline: ...


class PaperSize(APIObject):
    @property
    def Name(self) -> str: ...


class PaperSizeSet(APIObject):
    def __init__(self): ...
    def Clear(self) -> None: ...
    @property
    def Size(self) -> int: ...
    @property
    def IsEmpty(self) -> bool: ...
    def ForwardIterator(self) -> PaperSizeSetIterator: ...
    def ReverseIterator(self) -> PaperSizeSetIterator: ...
    def GetEnumerator(self) -> IEnumerator: ...
    def Contains(self, item: PaperSize) -> bool: ...
    def Insert(self, item: PaperSize) -> bool: ...
    def Erase(self, item: PaperSize) -> int: ...


class PaperSizeSetIterator(APIObject):
    def __init__(self): ...
    @property
    def Current(self) -> Object: ...
    def MoveNext(self) -> bool: ...
    def Reset(self) -> None: ...


class PaperSource(APIObject):
    @property
    def Name(self) -> str: ...


class PaperSourceSet(APIObject):
    def __init__(self): ...
    def Clear(self) -> None: ...
    @property
    def Size(self) -> int: ...
    @property
    def IsEmpty(self) -> bool: ...
    def ForwardIterator(self) -> PaperSourceSetIterator: ...
    def ReverseIterator(self) -> PaperSourceSetIterator: ...
    def GetEnumerator(self) -> IEnumerator: ...
    def Contains(self, item: PaperSource) -> bool: ...
    def Insert(self, item: PaperSource) -> bool: ...
    def Erase(self, item: PaperSource) -> int: ...


class PaperSourceSetIterator(APIObject):
    def __init__(self): ...
    @property
    def Current(self) -> Object: ...
    def MoveNext(self) -> bool: ...
    def Reset(self) -> None: ...


class ViewSheetSetting(APIObject):
    @property
    def CurrentViewSheetSet(self) -> IViewSheetSet: ...
    @CurrentViewSheetSet.setter
    def CurrentViewSheetSet(self, vss: IViewSheetSet) -> None: ...
    @property
    def AvailableViews(self) -> ViewSet: ...
    @property
    def InSession(self) -> InSessionViewSheetSet: ...
    def Save(self) -> bool: ...
    def SaveAs(self, newName: str) -> bool: ...
    def Rename(self, newName: str) -> bool: ...
    def Delete(self) -> bool: ...
    def Revert(self) -> None: ...


class FillPatternElement(Element):
    def GetFillPattern(self) -> FillPattern: ...
    def SetFillPattern(self, newFillPattern: FillPattern) -> None: ...
    def Create(document: Document, fillPattern: FillPattern) -> FillPatternElement: ...
    def GetFillPatternElementByName(document: Document, target: FillPatternTarget, name: str) -> FillPatternElement: ...


class LinePatternElement(Element):
    @overload
    def GetLinePattern(document: Document, elementId: ElementId) -> LinePattern: ...
    @overload
    def GetLinePattern(self) -> LinePattern: ...
    def GetSolidPatternId() -> ElementId: ...
    def SetLinePattern(self, newLinePattern: LinePattern) -> None: ...
    def Create(document: Document, linePattern: LinePattern) -> LinePatternElement: ...
    def GetLinePatternElementByName(document: Document, name: str) -> LinePatternElement: ...


class TilePatterns(APIObject):
    def GetTilePattern(self, tilePatternBuiltIn: TilePatternsBuiltIn) -> TilePattern: ...


class DetachFromCentralOption:
    DoNotDetach = 0
    DetachAndPreserveWorksets = 1
    DetachAndDiscardWorksets = 2
    ClearTransmittedSaveAsNewCentral = 3


class OpenForeignOption:
    Open = 0
    DoNotOpen = 1
    Prompt = 2


class FaceIntersectionFaceResult:
    Intersecting = 0
    NonIntersecting = 1


class ParametersOrder:
    Ascending = 0
    Descending = 1


class IFCVersion:
    Default = 0
    IFCBCA = 8
    IFC2x2 = 9
    IFC2x3 = 10
    IFCCOBIE = 17
    IFC2x3CV2 = 21
    IFC4 = 23
    IFC2x3FM = 24
    IFC4RV = 25
    IFC4DTV = 26
    IFC2x3BFM = 27


class DatumEnds:
    End0 = 0
    End1 = 1


class DatumExtentType:
    Model = 0
    ViewSpecific = 1


class WallKind:
    Basic = 0
    Curtain = 1
    Stacked = 2
    Unknown = -1


class WallFunction:
    Interior = 0
    Exterior = 1
    Foundation = 2
    Retaining = 3
    Soffit = 4
    Coreshaft = 5


class PlanViewRangeError:
    TopClipBelowCutPlane = 0
    BottomClipAboveCutPlane = 1
    ViewDepthAboveBottomClip = 2
    ViewDepthBelowTopClip = 3


class FloorFace:
    Top = 0
    Bottom = 1


class LeaderEndCondition:
    Attached = 0
    Free = 1


class TagOrientation:
    Horizontal = 0
    Vertical = 1


class TagMode:
    TM_ADDBY_CATEGORY = 0
    TM_ADDBY_MULTICATEGORY = 1
    TM_ADDBY_MATERIAL = 2


class JoinType:
    Abut = 0
    Miter = 1
    SquareOff = 2
    Extension = 3
    #None = -1


class FillPatternTarget:
    Drafting = 0
    Model = 1
    #None = 2


class FillPatternHostOrientation:
    ToView = 0
    AsText = 1
    ToHost = 2


class ColorDepthType:
    BlackLine = 0
    GrayScale = 1
    Color = 2


class HiddenLineViewsType:
    VectorProcessing = 0
    RasterProcessing = 1


class PageOrientationType:
    Portrait = 0
    Landscape = 1
    Auto = 2


class RasterQualityType:
    Low = 72
    Medium = 150
    High = 300
    Presentation = 600


class ZoomType:
    FitToPage = 0
    Zoom = 1


class ViewportRotation:
    #None = 0
    Clockwise = 1
    Counterclockwise = 2


class ParameterSet(APIObject):
    def __init__(self): ...
    def Clear(self) -> None: ...
    @property
    def Size(self) -> int: ...
    @property
    def IsEmpty(self) -> bool: ...
    def ForwardIterator(self) -> ParameterSetIterator: ...
    def ReverseIterator(self) -> ParameterSetIterator: ...
    def GetEnumerator(self) -> IEnumerator: ...
    def Contains(self, item: Parameter) -> bool: ...
    def Insert(self, item: Parameter) -> bool: ...
    def Erase(self, item: Parameter) -> int: ...


class ParameterSetIterator(APIObject):
    def __init__(self): ...
    @property
    def Current(self) -> Object: ...
    def MoveNext(self) -> bool: ...
    def Reset(self) -> None: ...


class Units:
    def __init__(self, unitSystem: UnitSystem): ...
    @property
    def DecimalSymbol(self) -> DecimalSymbol: ...
    @DecimalSymbol.setter
    def DecimalSymbol(self, decimalSymbol: DecimalSymbol) -> None: ...
    @property
    def DigitGroupingSymbol(self) -> DigitGroupingSymbol: ...
    @DigitGroupingSymbol.setter
    def DigitGroupingSymbol(self, digitGroupingSymbol: DigitGroupingSymbol) -> None: ...
    @property
    def DigitGroupingAmount(self) -> DigitGroupingAmount: ...
    @DigitGroupingAmount.setter
    def DigitGroupingAmount(self, digitGroupingAmount: DigitGroupingAmount) -> None: ...
    @property
    def IsValidObject(self) -> bool: ...
    @overload
    def GetFormatOptions(self, specTypeId: ForgeTypeId) -> FormatOptions: ...
    @overload
    def GetFormatOptions(self, unitType: UnitType) -> FormatOptions: ...
    @overload
    def SetFormatOptions(self, specTypeId: ForgeTypeId, options: FormatOptions) -> None: ...
    @overload
    def SetFormatOptions(self, unitType: UnitType, options: FormatOptions) -> None: ...
    def IsModifiableUnitType(unitType: UnitType) -> bool: ...
    def IsModifiableSpec(specTypeId: ForgeTypeId) -> bool: ...
    def GetModifiableUnitTypes() -> List[UnitType]: ...
    def GetModifiableSpecs() -> List[ForgeTypeId]: ...
    def Dispose(self) -> None: ...


class GlobalParametersManager:
    @property
    def IsValidObject(self) -> bool: ...
    def AreGlobalParametersAllowed(document: Document) -> bool: ...
    def GetAllGlobalParameters(document: Document) -> ISet: ...
    def FindByName(document: Document, name: str) -> ElementId: ...
    def IsValidGlobalParameter(document: Document, parameterId: ElementId) -> bool: ...
    def IsUniqueName(document: Document, name: str) -> bool: ...
    def GetGlobalParametersOrdered(document: Document) -> List[ElementId]: ...
    def SortParameters(document: Document, order: ParametersOrder) -> None: ...
    def MoveParameterUpOrder(document: Document, parameterId: ElementId) -> bool: ...
    def MoveParameterDownOrder(document: Document, parameterId: ElementId) -> bool: ...
    def Dispose(self) -> None: ...


class UnitUtils:
    @overload
    def Convert(value: float, currentUnitTypeId: ForgeTypeId, desiredUnitTypeId: ForgeTypeId) -> float: ...
    @overload
    def Convert(value: float, currentDisplayUnit: DisplayUnitType, desiredDisplayUnit: DisplayUnitType) -> float: ...
    @overload
    def ConvertFromInternalUnits(value: float, unitTypeId: ForgeTypeId) -> float: ...
    @overload
    def ConvertFromInternalUnits(value: float, displayUnit: DisplayUnitType) -> float: ...
    @overload
    def ConvertToInternalUnits(value: float, unitTypeId: ForgeTypeId) -> float: ...
    @overload
    def ConvertToInternalUnits(value: float, displayUnit: DisplayUnitType) -> float: ...
    def IsValidUnitType(unitTypeEnum: UnitType) -> bool: ...
    def GetValidUnitTypes() -> List[UnitType]: ...
    def GetSpecTypeId(unitTypeEnum: UnitType) -> ForgeTypeId: ...
    def IsSpec(specTypeId: ForgeTypeId) -> bool: ...
    def GetUnitType(specTypeId: ForgeTypeId) -> UnitType: ...
    def GetAllSpecs() -> List[ForgeTypeId]: ...
    @overload
    def IsValidDisplayUnit(unitType: UnitType, displayUnit: DisplayUnitType) -> bool: ...
    @overload
    def IsValidDisplayUnit(displayUnitEnum: DisplayUnitType) -> bool: ...
    @overload
    def GetValidDisplayUnits(unitType: UnitType) -> List[DisplayUnitType]: ...
    @overload
    def GetValidDisplayUnits() -> List[DisplayUnitType]: ...
    def GetAllUnits() -> List[ForgeTypeId]: ...
    def IsValidUnit(specTypeId: ForgeTypeId, unitTypeId: ForgeTypeId) -> bool: ...
    def GetValidUnits(specTypeId: ForgeTypeId) -> List[ForgeTypeId]: ...
    def GetUnitTypeId(displayUnitTypeEnum: DisplayUnitType) -> ForgeTypeId: ...
    def IsUnit(unitTypeId: ForgeTypeId) -> bool: ...
    def GetDisplayUnitType(unitTypeId: ForgeTypeId) -> DisplayUnitType: ...
    def GetSymbolTypeId(unitSymbolTypeEnum: UnitSymbolType) -> ForgeTypeId: ...
    def IsSymbol(symbolTypeId: ForgeTypeId) -> bool: ...
    def GetUnitSymbolType(symbolTypeId: ForgeTypeId) -> UnitSymbolType: ...
    @overload
    def GetUnitGroup(specTypeId: ForgeTypeId) -> UnitGroup: ...
    @overload
    def GetUnitGroup(unitType: UnitType) -> UnitGroup: ...
    @overload
    def GetTypeCatalogString(displayUnit: DisplayUnitType) -> str: ...
    @overload
    def GetTypeCatalogString(unitType: UnitType) -> str: ...
    def GetTypeCatalogStringForSpec(specTypeId: ForgeTypeId) -> str: ...
    def GetTypeCatalogStringForUnit(unitTypeId: ForgeTypeId) -> str: ...


class FormatOptions:
    @overload
    def __init__(self, other: FormatOptions): ...
    @overload
    def __init__(self, displayUnit: DisplayUnitType, unitSymbol: UnitSymbolType, accuracy: float): ...
    @overload
    def __init__(self, displayUnit: DisplayUnitType, accuracy: float): ...
    @overload
    def __init__(self, unitTypeId: ForgeTypeId, symbolTypeId: ForgeTypeId): ...
    @overload
    def __init__(self, displayUnit: DisplayUnitType, unitSymbol: UnitSymbolType): ...
    @overload
    def __init__(self, unitTypeId: ForgeTypeId): ...
    @overload
    def __init__(self, displayUnit: DisplayUnitType): ...
    @overload
    def __init__(self): ...
    @property
    def UseDefault(self) -> bool: ...
    @UseDefault.setter
    def UseDefault(self, useDefault: bool) -> None: ...
    @property
    def DisplayUnits(self) -> DisplayUnitType: ...
    @DisplayUnits.setter
    def DisplayUnits(self, displayUnit: DisplayUnitType) -> None: ...
    @property
    def UnitSymbol(self) -> UnitSymbolType: ...
    @UnitSymbol.setter
    def UnitSymbol(self, unitSymbol: UnitSymbolType) -> None: ...
    @property
    def Accuracy(self) -> float: ...
    @Accuracy.setter
    def Accuracy(self, accuracy: float) -> None: ...
    @property
    def SuppressTrailingZeros(self) -> bool: ...
    @SuppressTrailingZeros.setter
    def SuppressTrailingZeros(self, suppressTrailingZeros: bool) -> None: ...
    @property
    def SuppressLeadingZeros(self) -> bool: ...
    @SuppressLeadingZeros.setter
    def SuppressLeadingZeros(self, suppressLeadingZeros: bool) -> None: ...
    @property
    def SuppressSpaces(self) -> bool: ...
    @SuppressSpaces.setter
    def SuppressSpaces(self, suppressSpaces: bool) -> None: ...
    @property
    def UsePlusPrefix(self) -> bool: ...
    @UsePlusPrefix.setter
    def UsePlusPrefix(self, usePlusPrefix: bool) -> None: ...
    @property
    def UseDigitGrouping(self) -> bool: ...
    @UseDigitGrouping.setter
    def UseDigitGrouping(self, useDigitGrouping: bool) -> None: ...
    @property
    def RoundingMethod(self) -> RoundingMethod: ...
    @RoundingMethod.setter
    def RoundingMethod(self, roundingMethod: RoundingMethod) -> None: ...
    @property
    def IsValidObject(self) -> bool: ...
    def GetUnitTypeId(self) -> ForgeTypeId: ...
    def SetUnitTypeId(self, unitTypeId: ForgeTypeId) -> FormatOptions: ...
    def IsValidForUnitType(self, unitType: UnitType) -> bool: ...
    def IsValidForSpec(self, specTypeId: ForgeTypeId) -> bool: ...
    def GetSymbolTypeId(self) -> ForgeTypeId: ...
    def SetSymbolTypeId(self, symbolTypeId: ForgeTypeId) -> None: ...
    @overload
    def CanHaveUnitSymbol(self) -> bool: ...
    @overload
    def CanHaveUnitSymbol(displayUnit: DisplayUnitType) -> bool: ...
    @overload
    def CanHaveSymbol(self) -> bool: ...
    @overload
    def CanHaveSymbol(unitTypeId: ForgeTypeId) -> bool: ...
    @overload
    def IsValidUnitSymbol(self, unitSymbol: UnitSymbolType) -> bool: ...
    @overload
    def IsValidUnitSymbol(displayUnit: DisplayUnitType, unitSymbol: UnitSymbolType) -> bool: ...
    @overload
    def IsValidSymbol(self, symbolTypeId: ForgeTypeId) -> bool: ...
    @overload
    def IsValidSymbol(unitTypeId: ForgeTypeId, symbolTypeId: ForgeTypeId) -> bool: ...
    @overload
    def GetValidUnitSymbols(self) -> List[UnitSymbolType]: ...
    @overload
    def GetValidUnitSymbols(displayUnit: DisplayUnitType) -> List[UnitSymbolType]: ...
    @overload
    def GetValidSymbols(self) -> List[ForgeTypeId]: ...
    @overload
    def GetValidSymbols(unitTypeId: ForgeTypeId) -> List[ForgeTypeId]: ...
    @overload
    def IsValidAccuracy(self, accuracy: float) -> bool: ...
    @overload
    def IsValidAccuracy(unitTypeId: ForgeTypeId, accuracy: float) -> bool: ...
    @overload
    def IsValidAccuracy(displayUnit: DisplayUnitType, accuracy: float) -> bool: ...
    @overload
    def CanSuppressTrailingZeros(self) -> bool: ...
    @overload
    def CanSuppressTrailingZeros(unitTypeId: ForgeTypeId) -> bool: ...
    @overload
    def CanSuppressTrailingZeros(displayUnit: DisplayUnitType) -> bool: ...
    @overload
    def CanSuppressLeadingZeros(self) -> bool: ...
    @overload
    def CanSuppressLeadingZeros(unitTypeId: ForgeTypeId) -> bool: ...
    @overload
    def CanSuppressLeadingZeros(displayUnit: DisplayUnitType) -> bool: ...
    @overload
    def CanSuppressSpaces(self) -> bool: ...
    @overload
    def CanSuppressSpaces(unitTypeId: ForgeTypeId) -> bool: ...
    @overload
    def CanSuppressSpaces(displayUnit: DisplayUnitType) -> bool: ...
    @overload
    def CanUsePlusPrefix(self) -> bool: ...
    @overload
    def CanUsePlusPrefix(unitTypeId: ForgeTypeId) -> bool: ...
    @overload
    def CanUsePlusPrefix(displayUnit: DisplayUnitType) -> bool: ...
    def Dispose(self) -> None: ...


class ParameterMap(APIObject):
    def __init__(self): ...
    def Clear(self) -> None: ...
    @property
    def Size(self) -> int: ...
    @property
    def IsEmpty(self) -> bool: ...
    def ForwardIterator(self) -> ParameterMapIterator: ...
    def ReverseIterator(self) -> ParameterMapIterator: ...
    def GetEnumerator(self) -> IEnumerator: ...
    @property
    def Item(self, key: str) -> Parameter: ...
    @Item.setter
    def Item(self, key: str, item: Parameter) -> None: ...
    def Contains(self, key: str) -> bool: ...
    def Insert(self, key: str, item: Parameter) -> bool: ...
    def Erase(self, key: str) -> int: ...


class ParameterMapIterator(APIObject):
    def __init__(self): ...
    @property
    def Current(self) -> Object: ...
    def MoveNext(self) -> bool: ...
    def Reset(self) -> None: ...
    @property
    def Key(self) -> str: ...


class DefinitionGroup(APIObject):
    @property
    def Name(self) -> str: ...
    @property
    def Definitions(self) -> Definitions: ...


class DefinitionGroups:
    @property
    def Item(self, groupName: str) -> DefinitionGroup: ...
    def Create(self, name: str) -> DefinitionGroup: ...
    def Contains(self, definitionGroup: DefinitionGroup) -> bool: ...
    @property
    def IsEmpty(self) -> bool: ...
    @property
    def Size(self) -> int: ...
    def GetEnumerator(self) -> IEnumerator: ...
    def Dispose(self) -> None: ...


class Definitions:
    def __init__(self): ...
    @property
    def Item(self, name: str) -> Definition: ...
    def Create(self, option: ExternalDefinitionCreationOptions) -> Definition: ...
    def Contains(self, definition: Definition) -> bool: ...
    @property
    def IsEmpty(self) -> bool: ...
    @property
    def Size(self) -> int: ...
    def GetEnumerator(self) -> IEnumerator: ...
    def Dispose(self) -> None: ...


class ExternalDefinitions(Definitions):


class InternalDefinitions(Definitions):


class DecimalSymbol:
    Dot = 0
    Comma = 1


class DigitGroupingAmount:
    Two = 0
    Three = 1


class DigitGroupingSymbol:
    Dot = 0
    Comma = 1
    Space = 2
    Apostrophe = 3
    Tick = 3


class RoundingMethod:
    Nearest = 0
    Up = 1
    Down = 2


class UnitGroup:
    Common = 0
    Structural = 1
    HVAC = 2
    Electrical = 3
    Piping = 4
    Energy = 5
    Infrastructure = 6


class ConicalFace(Face):
    @property
    def Origin(self) -> XYZ: ...
    @property
    def Axis(self) -> XYZ: ...
    @property
    def Radius(self, index: int) -> XYZ: ...
    @property
    def HalfAngle(self) -> float: ...


class ClosestPointsPairBetweenTwoCurves:
    @overload
    def __init__(self): ...
    @overload
    def __init__(self, other: ClosestPointsPairBetweenTwoCurves): ...
    @property
    def XYZPointOnFirstCurve(self) -> XYZ: ...
    @XYZPointOnFirstCurve.setter
    def XYZPointOnFirstCurve(self, point: XYZ) -> None: ...
    @property
    def XYZPointOnSecondCurve(self) -> XYZ: ...
    @XYZPointOnSecondCurve.setter
    def XYZPointOnSecondCurve(self, point: XYZ) -> None: ...
    @property
    def ParameterOnFirstCurve(self) -> float: ...
    @ParameterOnFirstCurve.setter
    def ParameterOnFirstCurve(self, parameter: float) -> None: ...
    @property
    def ParameterOnSecondCurve(self) -> float: ...
    @ParameterOnSecondCurve.setter
    def ParameterOnSecondCurve(self, parameter: float) -> None: ...
    @property
    def Distance(self) -> float: ...
    @Distance.setter
    def Distance(self, distance: float) -> None: ...
    @property
    def IsValidObject(self) -> bool: ...
    def Dispose(self) -> None: ...


class IntersectionResult(APIObject):
    def __init__(self): ...
    @property
    def XYZPoint(self) -> XYZ: ...
    @property
    def UVPoint(self) -> UV: ...
    @property
    def Parameter(self) -> float: ...
    @property
    def Distance(self) -> float: ...
    @property
    def EdgeObject(self) -> Edge: ...
    @property
    def EdgeParameter(self) -> float: ...


class CylindricalFace(Face):
    @property
    def Origin(self) -> XYZ: ...
    @property
    def Axis(self) -> XYZ: ...
    @property
    def Radius(self, index: int) -> XYZ: ...


class CylindricalHelix(Curve):
    def Create(basePoint: XYZ, radius: float, xVector: XYZ, zVector: XYZ, pitch: float, startAngle: float, endAngle: float) -> CylindricalHelix: ...
    @property
    def BasePoint(self) -> XYZ: ...
    @property
    def Radius(self) -> float: ...
    @property
    def XVector(self) -> XYZ: ...
    @property
    def YVector(self) -> XYZ: ...
    @property
    def ZVector(self) -> XYZ: ...
    @property
    def Pitch(self) -> float: ...
    @property
    def IsRightHanded(self) -> bool: ...
    @property
    def Height(self) -> float: ...


class Edge(GeometryObject):
    def GetFace(self, index: int) -> Face: ...
    def Tessellate(self) -> List[XYZ]: ...
    def TessellateOnFace(self, face: Face) -> List[UV]: ...
    def Evaluate(self, param: float) -> XYZ: ...
    def EvaluateOnFace(self, param: float, face: Face) -> UV: ...
    def AsCurve(self) -> Curve: ...
    def AsCurveFollowingFace(self, faceForDir: Face) -> Curve: ...
    @overload
    def IsFlippedOnFace(self, face: Face) -> bool: ...
    @overload
    def IsFlippedOnFace(self, index: int) -> bool: ...
    @overload
    def GetCurveUV(self, index: int, transform: Transform2D) -> CurveUV: ...
    @overload
    def GetCurveUV(self, index: int) -> CurveUV: ...
    @property
    def Reference(self) -> Reference: ...
    def GetEndPointReference(self, index: int) -> Reference: ...
    @property
    def ApproximateLength(self) -> float: ...
    def ComputeDerivatives(self, parameter: float) -> Transform: ...


class CurveUV:
    @property
    def IsBound(self) -> bool: ...
    @property
    def IsValidObject(self) -> bool: ...
    def Create(curve3D: Curve) -> CurveUV: ...
    def As3DCurveInXYPlane(self) -> Curve: ...
    def Evaluate(self, parameter: float, normalized: bool) -> UV: ...
    def ComputeDerivatives(self, parameter: float, normalized: bool) -> List[UV]: ...
    def GetEndParameter(self, index: int) -> float: ...
    def Transform(self, trfUV: Transform2D) -> CurveUV: ...
    def Dispose(self) -> None: ...


class Transform2D:
    @overload
    def __init__(self, uVec: UV, vVec: UV, origin: UV): ...
    @overload
    def __init__(self, other: Transform2D): ...
    @property
    def Origin(self) -> UV: ...
    @Origin.setter
    def Origin(self, origin: UV) -> None: ...
    @property
    def IsIdentity(self) -> bool: ...
    @property
    def IsTranslation(self) -> bool: ...
    @property
    def IsConformal(self) -> bool: ...
    @property
    def Determinant(self) -> float: ...
    @property
    def BasisU(self) -> UV: ...
    @BasisU.setter
    def BasisU(self, basisV: UV) -> None: ...
    @property
    def BasisV(self) -> UV: ...
    @BasisV.setter
    def BasisV(self, basisV: UV) -> None: ...
    @property
    def HasReflection(self) -> bool: ...
    @property
    def Scale(self) -> float: ...
    @property
    def IsValidObject(self) -> bool: ...
    def AlmostEqual(self, right: Transform2D) -> bool: ...
    def Assign(self, from_: Transform2D) -> None: ...
    def SetToIdentity(self) -> Transform2D: ...
    def CreateIdentity() -> Transform2D: ...
    def Multiply(self, right: Transform2D) -> Transform2D: ...
    def OfPoint(self, point: UV) -> UV: ...
    def OfVector(self, vector: UV) -> UV: ...
    def PreScale(self, scale: float) -> Transform2D: ...
    def PostScale(self, scale: float) -> Transform2D: ...
    def GetInverse(self) -> Transform2D: ...
    def TransformUVDomainIfPossible(self, uvDomain: BoundingBoxUV) -> BoundingBoxUV: ...
    def Dispose(self) -> None: ...


class EdgeArray(APIObject):
    def __init__(self): ...
    def Clear(self) -> None: ...
    @property
    def Size(self) -> int: ...
    @property
    def IsEmpty(self) -> bool: ...
    def ForwardIterator(self) -> EdgeArrayIterator: ...
    def ReverseIterator(self) -> EdgeArrayIterator: ...
    def GetEnumerator(self) -> IEnumerator: ...
    @property
    def Item(self, index: int) -> Edge: ...
    @Item.setter
    def Item(self, index: int, item: Edge) -> None: ...
    def Append(self, item: Edge) -> None: ...
    def Insert(self, item: Edge, index: int) -> None: ...


class EdgeArrayIterator(APIObject):
    def __init__(self): ...
    @property
    def Current(self) -> Object: ...
    def MoveNext(self) -> bool: ...
    def Reset(self) -> None: ...


class EdgeArrayArray(APIObject):
    def __init__(self): ...
    def Clear(self) -> None: ...
    @property
    def Size(self) -> int: ...
    @property
    def IsEmpty(self) -> bool: ...
    def ForwardIterator(self) -> EdgeArrayArrayIterator: ...
    def ReverseIterator(self) -> EdgeArrayArrayIterator: ...
    def GetEnumerator(self) -> IEnumerator: ...
    @property
    def Item(self, index: int) -> EdgeArray: ...
    @Item.setter
    def Item(self, index: int, item: EdgeArray) -> None: ...
    def Append(self, item: EdgeArray) -> None: ...
    def Insert(self, item: EdgeArray, index: int) -> None: ...


class EdgeArrayArrayIterator(APIObject):
    def __init__(self): ...
    @property
    def Current(self) -> Object: ...
    def MoveNext(self) -> bool: ...
    def Reset(self) -> None: ...


class CurveLoop:
    def __init__(self): ...
    @property
    def IsValidObject(self) -> bool: ...
    def Create(curves: List[Curve]) -> CurveLoop: ...
    def Append(self, curve: Curve) -> None: ...
    def GetPlane(self) -> Plane: ...
    def HasPlane(self) -> bool: ...
    def GetExactLength(self) -> float: ...
    def IsRectangular(self, plane: Plane) -> bool: ...
    def GetRectangularWidth(self, plane: Plane) -> float: ...
    def GetRectangularHeight(self, plane: Plane) -> float: ...
    @overload
    def CreateViaThicken(curveLoop: CurveLoop, thickness: float, normal: XYZ) -> CurveLoop: ...
    @overload
    def CreateViaThicken(pCurve: Curve, thickness: float, normal: XYZ) -> CurveLoop: ...
    def CreateViaTransform(curveLoop: CurveLoop, transform: Transform) -> CurveLoop: ...
    def Transform(self, transform: Transform) -> None: ...
    def IsOpen(self) -> bool: ...
    def IsCounterclockwise(self, normal: XYZ) -> bool: ...
    def Flip(self) -> None: ...
    def CreateViaCopy(original: CurveLoop) -> CurveLoop: ...
    @overload
    def CreateViaOffset(original: CurveLoop, offsetDists: List[float], normal: XYZ) -> CurveLoop: ...
    @overload
    def CreateViaOffset(original: CurveLoop, offsetDist: float, normal: XYZ) -> CurveLoop: ...
    def GetCurveLoopIterator(self) -> CurveLoopIterator: ...
    def NumberOfCurves(self) -> int: ...
    def GetEnumerator(self) -> IEnumerator: ...
    def Dispose(self) -> None: ...


class CurveLoopIterator:
    @property
    def IsValidObject(self) -> bool: ...
    def MoveNext(self) -> bool: ...
    def Reset(self) -> None: ...
    @property
    def Current(self) -> Curve: ...
    def Dispose(self) -> None: ...


class FaceSecondDerivatives:
    @property
    def UUDerivative(self) -> XYZ: ...
    @property
    def VVDerivative(self) -> XYZ: ...
    @property
    def MixedDerivative(self) -> XYZ: ...
    @property
    def IsValidObject(self) -> bool: ...
    def Dispose(self) -> None: ...


class PolymeshTopology:
    @property
    def DistributionOfNormals(self) -> DistributionOfNormals: ...
    @property
    def NumberOfFacets(self) -> int: ...
    @property
    def NumberOfPoints(self) -> int: ...
    @property
    def NumberOfNormals(self) -> int: ...
    @property
    def NumberOfUVs(self) -> int: ...
    @property
    def IsValidObject(self) -> bool: ...
    def GetFacet(self, idx: int) -> PolymeshFacet: ...
    def GetFacets(self) -> List[PolymeshFacet]: ...
    def GetPoint(self, idx: int) -> XYZ: ...
    def GetPoints(self) -> List[XYZ]: ...
    def GetUV(self, idx: int) -> UV: ...
    def GetUVs(self) -> List[UV]: ...
    def GetNormal(self, idx: int) -> XYZ: ...
    def GetNormals(self) -> List[XYZ]: ...
    def Dispose(self) -> None: ...


class MeshTriangle:
    @property
    def Index(self, idx: int) -> UInt32: ...
    @property
    def Vertex(self, idx: int) -> XYZ: ...


class Mesh(GeometryObject):
    @property
    def NumTriangles(self) -> int: ...
    @property
    def Triangle(self, idx: int) -> MeshTriangle: ...
    @property
    def Vertices(self) -> List[XYZ]: ...
    @property
    def MaterialElementId(self) -> ElementId: ...
    @property
    def Transformed(self, transform: Transform) -> Mesh: ...
    @property
    def NumberOfNormals(self) -> int: ...
    @property
    def DistributionOfNormals(self) -> DistributionOfNormals: ...
    def GetNormal(self, idx: int) -> XYZ: ...
    def GetNormals(self) -> List[XYZ]: ...


class HermiteFace(Face):
    @property
    def Params(self, index: int) -> DoubleArray: ...
    @property
    def Points(self) -> List[XYZ]: ...
    @property
    def Tangents(self, index: int) -> List[XYZ]: ...
    @property
    def MixedDerivs(self) -> List[XYZ]: ...


class GeometryInstance(GeometryObject):
    @property
    def Transform(self) -> Transform: ...
    @property
    def Symbol(self) -> Element: ...
    @property
    def SymbolGeometry(self) -> GeometryElement: ...
    @overload
    def GetSymbolGeometry(self, transform: Transform) -> GeometryElement: ...
    @overload
    def GetSymbolGeometry(self) -> GeometryElement: ...
    @overload
    def GetInstanceGeometry(self, transform: Transform) -> GeometryElement: ...
    @overload
    def GetInstanceGeometry(self) -> GeometryElement: ...


class PolyLine(GeometryObject):
    @property
    def NumberOfCoordinates(self) -> int: ...
    def Evaluate(self, param: float) -> XYZ: ...
    def GetCoordinate(self, index: int) -> XYZ: ...
    def GetCoordinates(self) -> List[XYZ]: ...
    def GetOutline(self) -> Outline: ...
    def GetTransformed(self, transform: Transform) -> PolyLine: ...
    def Clone(self) -> PolyLine: ...
    def Create(coordinates: List[XYZ]) -> PolyLine: ...


class Outline:
    @overload
    def __init__(self, minimumPoint: XYZ, maximumPoint: XYZ): ...
    @overload
    def __init__(self, other: Outline): ...
    @property
    def MinimumPoint(self) -> XYZ: ...
    @MinimumPoint.setter
    def MinimumPoint(self, minimumPoint: XYZ) -> None: ...
    @property
    def MaximumPoint(self) -> XYZ: ...
    @MaximumPoint.setter
    def MaximumPoint(self, maximumPoint: XYZ) -> None: ...
    @property
    def IsEmpty(self) -> bool: ...
    @property
    def IsValidObject(self) -> bool: ...
    def Scale(self, scale: float) -> None: ...
    def IsScaleValid(self, scale: float) -> bool: ...
    def AddPoint(self, point: XYZ) -> None: ...
    def Intersects(self, outline: Outline, tolerance: float) -> bool: ...
    def Contains(self, point: XYZ, tolerance: float) -> bool: ...
    def ContainsOtherOutline(self, otherOutline: Outline, tolerance: float) -> bool: ...
    def GetDiagonalLength(self) -> float: ...
    def Dispose(self) -> None: ...


class Profile(GeometryObject):
    @property
    def Filled(self) -> bool: ...
    @Filled.setter
    def Filled(self, filled: bool) -> None: ...
    @property
    def Curves(self) -> CurveArray: ...
    @property
    def Transformed(self, transform: Transform) -> Profile: ...
    def Clone(self) -> Profile: ...


class RevolvedFace(Face):
    @property
    def Origin(self) -> XYZ: ...
    @property
    def Axis(self) -> XYZ: ...
    @property
    def Radius(self, index: int) -> XYZ: ...
    @property
    def Curve(self) -> Curve: ...


class RuledFace(Face):
    @property
    def Curve(self, index: int) -> Curve: ...
    @property
    def Point(self, index: int) -> XYZ: ...
    @property
    def RulingsAreParallel(self) -> bool: ...
    @property
    def IsExtruded(self) -> bool: ...


class TriangleInShellComponent:
    def __init__(self, other: TriangleInShellComponent): ...
    @property
    def VertexIndex0(self) -> int: ...
    @property
    def VertexIndex1(self) -> int: ...
    @property
    def VertexIndex2(self) -> int: ...
    @property
    def IsValidObject(self) -> bool: ...
    def Dispose(self) -> None: ...


class TriangulatedShellComponent:
    @property
    def IsClosed(self) -> bool: ...
    @property
    def VertexCount(self) -> int: ...
    @property
    def TriangleCount(self) -> int: ...
    @property
    def IsValidObject(self) -> bool: ...
    def GetVertex(self, vertexIndex: int) -> XYZ: ...
    def Clear(self) -> None: ...
    def GetTriangle(self, triangleIndex: int) -> TriangleInShellComponent: ...
    def Dispose(self) -> None: ...


class TriangulatedSolidOrShell:
    @property
    def ShellComponentCount(self) -> int: ...
    @property
    def IsValidObject(self) -> bool: ...
    def GetShellComponent(self, componentIndex: int) -> TriangulatedShellComponent: ...
    def Dispose(self) -> None: ...


class SolidOrShellTessellationControls:
    def __init__(self): ...
    @property
    def Accuracy(self) -> float: ...
    @Accuracy.setter
    def Accuracy(self, accuracy: float) -> None: ...
    @property
    def MinExternalAngleBetweenTriangles(self) -> float: ...
    @MinExternalAngleBetweenTriangles.setter
    def MinExternalAngleBetweenTriangles(self, minExternalAngleBetweenTriangles: float) -> None: ...
    @property
    def MinAngleInTriangle(self) -> float: ...
    @MinAngleInTriangle.setter
    def MinAngleInTriangle(self, minAngleInTriangle: float) -> None: ...
    @property
    def LevelOfDetail(self) -> float: ...
    @LevelOfDetail.setter
    def LevelOfDetail(self, levelOfDetail: float) -> None: ...
    @property
    def IsValidObject(self) -> bool: ...
    def UseLevelOfDetail(self) -> bool: ...
    def DisableLevelOfDetail(self) -> None: ...
    def Dispose(self) -> None: ...


class SolidCurveIntersectionOptions:
    def __init__(self): ...
    @property
    def ResultType(self) -> SolidCurveIntersectionMode: ...
    @ResultType.setter
    def ResultType(self, resultType: SolidCurveIntersectionMode) -> None: ...
    @property
    def IsValidObject(self) -> bool: ...
    def Dispose(self) -> None: ...


class CurveExtents:
    @property
    def StartParameter(self) -> float: ...
    @property
    def EndParameter(self) -> float: ...
    @property
    def IsValidObject(self) -> bool: ...
    def Dispose(self) -> None: ...


class SolidCurveIntersection:
    @property
    def ResultType(self) -> SolidCurveIntersectionMode: ...
    @property
    def SegmentCount(self) -> int: ...
    @property
    def IsValidObject(self) -> bool: ...
    def GetCurveSegment(self, index: int) -> Curve: ...
    def GetCurveSegmentExtents(self, index: int) -> CurveExtents: ...
    def GetEnumerator(self) -> IEnumerator: ...
    def Dispose(self) -> None: ...


class SolidGeometryOptions:
    def __init__(self, solidTag: int): ...
    @property
    def SolidTag(self) -> int: ...
    @SolidTag.setter
    def SolidTag(self, solidTag: int) -> None: ...
    @property
    def IsValidObject(self) -> bool: ...
    def Dispose(self) -> None: ...


class EdgeEndPoint:
    @overload
    def __init__(self, otherObject: EdgeEndPoint): ...
    @overload
    def __init__(self, edge: Edge, index: int): ...
    @property
    def Edge(self) -> Edge: ...
    @property
    def Index(self) -> int: ...
    @property
    def IsValidObject(self) -> bool: ...
    @overload
    def Equals(self, other: EdgeEndPoint) -> bool: ...
    def Evaluate(self) -> XYZ: ...
    def Dispose(self) -> None: ...


class SolidUtils:
    def Clone(solid: Solid) -> Solid: ...
    def CreateTransformed(solid: Solid, transform: Transform) -> Solid: ...
    def SplitVolumes(solid: Solid) -> List[Solid]: ...
    def TessellateSolidOrShell(solidOrShell: Solid, tessellationControls: SolidOrShellTessellationControls) -> TriangulatedSolidOrShell: ...
    def IsValidForTessellation(solidOrShell: Solid) -> bool: ...
    def FindAllEdgeEndPointsAtVertex(edgeEndPoint: EdgeEndPoint) -> List[EdgeEndPoint]: ...


class DistributionOfNormals:
    AtEachPoint = 0
    OnePerFace = 1
    OnEachFacet = 2


class SolidCurveIntersectionMode:
    CurveSegmentsInside = 0
    CurveSegmentsOutside = 1


class BoundarySegment:
    @property
    def LinkElementId(self) -> ElementId: ...
    @property
    def ElementId(self) -> ElementId: ...
    @property
    def IsValidObject(self) -> bool: ...
    def GetCurve(self) -> Curve: ...
    def Dispose(self) -> None: ...


class AreaScheme(Element):
    @property
    def IsGrossBuildingArea(self) -> bool: ...


class AreaTagType(FamilySymbol):


class AssemblyInstance(Element):
    @property
    def Location(self) -> Location: ...
    @property
    def NamingCategoryId(self) -> ElementId: ...
    @NamingCategoryId.setter
    def NamingCategoryId(self, namingCategoryId: ElementId) -> None: ...
    @property
    def AssemblyTypeName(self) -> str: ...
    @AssemblyTypeName.setter
    def AssemblyTypeName(self, nameStr: str) -> None: ...
    def Create(document: Document, assemblyMemberIds: ICollection, namingCategoryId: ElementId) -> AssemblyInstance: ...
    def PlaceInstance(document: Document, assemblyTypeId: ElementId, location: XYZ) -> AssemblyInstance: ...
    def AreElementsValidForAssembly(document: Document, assemblyMemberIds: ICollection, assemblyId: ElementId) -> bool: ...
    def CanRemoveElementsFromAssembly(assemblyInstance: AssemblyInstance, memberIds: ICollection) -> bool: ...
    def IsValidNamingCategory(document: Document, namingCategoryId: ElementId, assemblyMemberIds: ICollection) -> bool: ...
    def GetMemberIds(self) -> ICollection: ...
    def SetMemberIds(self, memberIds: ICollection) -> None: ...
    def AddMemberIds(self, memberIds: ICollection) -> None: ...
    def RemoveMemberIds(self, memberIds: ICollection) -> None: ...
    def AllowsAssemblyViewCreation(self) -> bool: ...
    def Disassemble(self) -> ICollection: ...
    def CompareAssemblyInstances(instance1: AssemblyInstance, instance2: AssemblyInstance) -> AssemblyDifference: ...
    def GetCenter(self) -> XYZ: ...
    def GetTransform(self) -> Transform: ...
    def SetTransform(self, trf: Transform) -> None: ...


class LayoutRule(APIObject):


class LayoutRuleFixedDistance(LayoutRule):
    def __init__(self, spacing: float, justifyType: BeamSystemJustifyType): ...
    @property
    def Spacing(self) -> float: ...
    @Spacing.setter
    def Spacing(self, spacing: float) -> None: ...
    @property
    def JustifyType(self) -> BeamSystemJustifyType: ...
    @JustifyType.setter
    def JustifyType(self, justifyType: BeamSystemJustifyType) -> None: ...


class LayoutRuleFixedNumber(LayoutRule):
    def __init__(self, numberOfLines: int): ...
    @property
    def NumberOfLines(self) -> int: ...
    @NumberOfLines.setter
    def NumberOfLines(self, numberOfLines: int) -> None: ...


class LayoutRuleMaximumSpacing(LayoutRule):
    def __init__(self, spacing: float): ...
    @property
    def Spacing(self) -> float: ...
    @Spacing.setter
    def Spacing(self, spacing: float) -> None: ...


class LayoutRuleClearSpacing(LayoutRule):
    def __init__(self, spacing: float, justifyType: BeamSystemJustifyType): ...
    @property
    def Spacing(self) -> float: ...
    @Spacing.setter
    def Spacing(self, spacing: float) -> None: ...
    @property
    def JustifyType(self) -> BeamSystemJustifyType: ...
    @JustifyType.setter
    def JustifyType(self, justifyType: BeamSystemJustifyType) -> None: ...


class SketchBase(Element):


class Sketch(SketchBase):
    @property
    def Profile(self) -> CurveArrArray: ...
    @property
    def SketchPlane(self) -> SketchPlane: ...


class GeomCombinationSet(APIObject):
    def __init__(self): ...
    def Clear(self) -> None: ...
    @property
    def Size(self) -> int: ...
    @property
    def IsEmpty(self) -> bool: ...
    def ForwardIterator(self) -> GeomCombinationSetIterator: ...
    def ReverseIterator(self) -> GeomCombinationSetIterator: ...
    def GetEnumerator(self) -> IEnumerator: ...
    def Contains(self, item: GeomCombination) -> bool: ...
    def Insert(self, item: GeomCombination) -> bool: ...
    def Erase(self, item: GeomCombination) -> int: ...


class GeomCombinationSetIterator(APIObject):
    def __init__(self): ...
    @property
    def Current(self) -> Object: ...
    def MoveNext(self) -> bool: ...
    def Reset(self) -> None: ...


class CurtainCell(APIObject):
    @property
    def PlanarizedCurveLoops(self) -> CurveArrArray: ...
    @property
    def CurveLoops(self) -> CurveArrArray: ...


class CurtainGrid(APIObject):
    @property
    def Grid1Justification(self) -> CurtainGridAlignType: ...
    @Grid1Justification.setter
    def Grid1Justification(self, newType: CurtainGridAlignType) -> None: ...
    @property
    def Grid1Angle(self) -> float: ...
    @Grid1Angle.setter
    def Grid1Angle(self, value: float) -> None: ...
    @property
    def Grid1Offset(self) -> float: ...
    @Grid1Offset.setter
    def Grid1Offset(self, value: float) -> None: ...
    @property
    def Grid2Justification(self) -> CurtainGridAlignType: ...
    @Grid2Justification.setter
    def Grid2Justification(self, newType: CurtainGridAlignType) -> None: ...
    @property
    def Grid2Angle(self) -> float: ...
    @Grid2Angle.setter
    def Grid2Angle(self, value: float) -> None: ...
    @property
    def Grid2Offset(self) -> float: ...
    @Grid2Offset.setter
    def Grid2Offset(self, value: float) -> None: ...
    @property
    def NumULines(self) -> int: ...
    @property
    def NumVLines(self) -> int: ...
    @property
    def NumPanels(self) -> int: ...
    def GetPanelIds(self) -> ICollection: ...
    def GetUnlockedPanelIds(self) -> ICollection: ...
    def GetMullionIds(self) -> ICollection: ...
    def GetUnlockedMullionIds(self) -> ICollection: ...
    def GetUGridLineIds(self) -> ICollection: ...
    def GetVGridLineIds(self) -> ICollection: ...
    def GetCurtainCells(self) -> ICollection: ...
    def ChangePanelType(self, panel: Element, newSymbol: ElementType) -> Element: ...
    def AddGridLine(self, isUGridLine: bool, position: XYZ, oneSegmentOnly: bool) -> CurtainGridLine: ...
    def GetPanel(self, uGridLineId: ElementId, vGridLineId: ElementId) -> Panel: ...
    def GetCell(self, uGridLineId: ElementId, vGridLineId: ElementId) -> CurtainCell: ...


class CurtainGridLine(HostObject):
    @property
    def Lock(self) -> bool: ...
    @Lock.setter
    def Lock(self, lock: bool) -> None: ...
    @property
    def IsUGridLine(self) -> bool: ...
    @property
    def FullCurve(self) -> Curve: ...
    @property
    def AllSegmentCurves(self) -> CurveArray: ...
    @property
    def SkippedSegmentCurves(self) -> CurveArray: ...
    @property
    def ExistingSegmentCurves(self) -> CurveArray: ...
    def RemoveSegment(self, curve: Curve) -> None: ...
    def AddSegment(self, curve: Curve) -> None: ...
    def AddAllSegments(self) -> None: ...
    def AddMullions(self, segment: Curve, mullionType: MullionType, oneSegmentOnly: bool) -> ElementSet: ...


class Mullion(FamilyInstance):
    @property
    def Lock(self) -> bool: ...
    @Lock.setter
    def Lock(self, lock: bool) -> None: ...
    @property
    def Lockable(self) -> bool: ...
    @property
    def MullionType(self) -> MullionType: ...
    @MullionType.setter
    def MullionType(self, newType: MullionType) -> None: ...
    @property
    def LocationCurve(self) -> Curve: ...
    def JoinMullion(self) -> None: ...
    def BreakMullion(self) -> None: ...


class Panel(FamilyInstance):
    @property
    def Lockable(self) -> bool: ...
    @property
    def PanelType(self) -> PanelType: ...
    @PanelType.setter
    def PanelType(self, A_0: PanelType) -> None: ...
    @property
    def Transform(self) -> Transform: ...
    def GetRefGridLines(self, uGridLineId: ElementId, vGridLineId: ElementId) -> Tuple[ElementId, ElementId]: ...
    def FindHostPanel(self) -> ElementId: ...


class ElementTransformUtils:
    def CanMirrorElements(ADoc: Document, elemIds: ICollection) -> bool: ...
    def CanMirrorElement(ADoc: Document, elemId: ElementId) -> bool: ...
    def MoveElements(document: Document, elementsToMove: ICollection, translation: XYZ) -> None: ...
    def MoveElement(document: Document, elementToMove: ElementId, translation: XYZ) -> None: ...
    @overload
    def CopyElements(sourceView: View, elementsToCopy: ICollection, destinationView: View, additionalTransform: Transform, options: CopyPasteOptions) -> ICollection: ...
    @overload
    def CopyElements(sourceDocument: Document, elementsToCopy: ICollection, destinationDocument: Document, transform: Transform, options: CopyPasteOptions) -> ICollection: ...
    @overload
    def CopyElements(document: Document, elementsToCopy: ICollection, translation: XYZ) -> ICollection: ...
    def CopyElement(document: Document, elementToCopy: ElementId, translation: XYZ) -> ICollection: ...
    def MirrorElements(document: Document, elementsToMirror: ICollection, plane: Plane, mirrorCopies: bool) -> List[ElementId]: ...
    def MirrorElement(document: Document, elementToMirror: ElementId, plane: Plane) -> None: ...
    def RotateElements(document: Document, elementsToRotate: ICollection, axis: Line, angle: float) -> None: ...
    def RotateElement(document: Document, elementToRotate: ElementId, axis: Line, angle: float) -> None: ...
    def GetTransformFromViewToView(sourceView: View, destinationView: View) -> Transform: ...


class CurtainGridSet(APIObject):
    def __init__(self): ...
    def Clear(self) -> None: ...
    @property
    def Size(self) -> int: ...
    @property
    def IsEmpty(self) -> bool: ...
    def ForwardIterator(self) -> CurtainGridSetIterator: ...
    def ReverseIterator(self) -> CurtainGridSetIterator: ...
    def GetEnumerator(self) -> IEnumerator: ...
    def Contains(self, item: CurtainGrid) -> bool: ...
    def Insert(self, item: CurtainGrid) -> bool: ...
    def Erase(self, item: CurtainGrid) -> int: ...


class CurtainGridSetIterator(APIObject):
    def __init__(self): ...
    @property
    def Current(self) -> Object: ...
    def MoveNext(self) -> bool: ...
    def Reset(self) -> None: ...


class SpacingRule(APIObject):
    @property
    def Layout(self) -> SpacingRuleLayout: ...
    def SetLayoutNone(self) -> None: ...
    def SetLayoutFixedDistance(self, distance: float, just: SpacingRuleJustification, gridlinesRotation: float, offset: float) -> None: ...
    def SetLayoutFixedNumber(self, number: int, just: SpacingRuleJustification, gridlinesRotation: float, offset: float) -> None: ...
    def SetLayoutMaximumSpacing(self, distance: float, just: SpacingRuleJustification, gridlinesRotation: float, offset: float) -> None: ...
    def SetLayoutMinimumSpacing(self, distance: float, just: SpacingRuleJustification, gridlinesRotation: float, offset: float) -> None: ...
    @property
    def Distance(self) -> float: ...
    @Distance.setter
    def Distance(self, A_0: float) -> None: ...
    @property
    def Number(self) -> int: ...
    @Number.setter
    def Number(self, A_0: int) -> None: ...
    @property
    def Justification(self) -> SpacingRuleJustification: ...
    @Justification.setter
    def Justification(self, A_0: SpacingRuleJustification) -> None: ...
    @property
    def GridlinesRotation(self) -> float: ...
    @GridlinesRotation.setter
    def GridlinesRotation(self, angle: float) -> None: ...
    @property
    def Offset(self) -> float: ...
    @Offset.setter
    def Offset(self, A_0: float) -> None: ...
    @property
    def HasBeltMeasurement(self) -> bool: ...
    @property
    def BeltMeasurement(self) -> float: ...
    @BeltMeasurement.setter
    def BeltMeasurement(self, beltMeasurement: float) -> None: ...


class DesignOption(Element):
    @property
    def IsPrimary(self) -> bool: ...
    def GetActiveDesignOptionId(document: Document) -> ElementId: ...


class ChangeType:
    @property
    def IsValidObject(self) -> bool: ...
    def ConcatenateChangeTypes(changeType1: ChangeType, changeType2: ChangeType) -> ChangeType: ...
    def IsIdentical(self, changeType: ChangeType) -> bool: ...
    def Contains(self, changeType: ChangeType) -> bool: ...
    def Dispose(self) -> None: ...


class FamilyPointPlacementReference(APIObject):
    @property
    def Name(self) -> str: ...
    @property
    def Location(self) -> Transform: ...
    @property
    def PointReference(self) -> Reference: ...


class FamilyPointLocation(APIObject):
    @property
    def Name(self) -> str: ...
    @property
    def IsValidObject(self) -> bool: ...
    def GetLocation(self) -> Transform: ...


class ModelCurveArrArray(APIObject):
    def __init__(self): ...
    def Clear(self) -> None: ...
    @property
    def Size(self) -> int: ...
    @property
    def IsEmpty(self) -> bool: ...
    def ForwardIterator(self) -> ModelCurveArrArrayIterator: ...
    def ReverseIterator(self) -> ModelCurveArrArrayIterator: ...
    def GetEnumerator(self) -> IEnumerator: ...
    @property
    def Item(self, index: int) -> ModelCurveArray: ...
    @Item.setter
    def Item(self, index: int, item: ModelCurveArray) -> None: ...
    def Append(self, item: ModelCurveArray) -> None: ...
    def Insert(self, item: ModelCurveArray, index: int) -> None: ...


class ModelCurveArrArrayIterator(APIObject):
    def __init__(self): ...
    @property
    def Current(self) -> Object: ...
    def MoveNext(self) -> bool: ...
    def Reset(self) -> None: ...


class Path3d(SketchBase):
    @property
    def NumCurveLoops(self) -> int: ...
    @property
    def AllCurveLoops(self) -> CurveArrArray: ...
    @property
    def CurveLoop(self, index: int) -> CurveArray: ...


class GroupSet(APIObject):
    def __init__(self): ...
    def Clear(self) -> None: ...
    @property
    def Size(self) -> int: ...
    @property
    def IsEmpty(self) -> bool: ...
    def ForwardIterator(self) -> GroupSetIterator: ...
    def ReverseIterator(self) -> GroupSetIterator: ...
    def GetEnumerator(self) -> IEnumerator: ...
    def Contains(self, item: Group) -> bool: ...
    def Insert(self, item: Group) -> bool: ...
    def Erase(self, item: Group) -> int: ...


class GroupSetIterator(APIObject):
    def __init__(self): ...
    @property
    def Current(self) -> Object: ...
    def MoveNext(self) -> bool: ...
    def Reset(self) -> None: ...


class WallSweepInfo:
    @overload
    def __init__(self, type: WallSweepType, vertical: bool): ...
    @overload
    def __init__(self, fixed: bool, type: WallSweepType): ...
    @property
    def Distance(self) -> float: ...
    @Distance.setter
    def Distance(self, distance: float) -> None: ...
    @property
    def WallOffset(self) -> float: ...
    @WallOffset.setter
    def WallOffset(self, wallOffset: float) -> None: ...
    @property
    def DefaultSetback(self) -> float: ...
    @DefaultSetback.setter
    def DefaultSetback(self, defaultSetback: float) -> None: ...
    @property
    def ProfileId(self) -> ElementId: ...
    @ProfileId.setter
    def ProfileId(self, profileId: ElementId) -> None: ...
    @property
    def MaterialId(self) -> ElementId: ...
    @MaterialId.setter
    def MaterialId(self, materialId: ElementId) -> None: ...
    @property
    def Id(self) -> int: ...
    @Id.setter
    def Id(self, id: int) -> None: ...
    @property
    def WallSide(self) -> WallSide: ...
    @WallSide.setter
    def WallSide(self, wallSide: WallSide) -> None: ...
    @property
    def WallSweepType(self) -> WallSweepType: ...
    @WallSweepType.setter
    def WallSweepType(self, wallSweepType: WallSweepType) -> None: ...
    @property
    def DistanceMeasuredFrom(self) -> DistanceMeasuredFrom: ...
    @DistanceMeasuredFrom.setter
    def DistanceMeasuredFrom(self, distanceMeasuredFrom: DistanceMeasuredFrom) -> None: ...
    @property
    def WallSweepOrientation(self) -> WallSweepOrientation: ...
    @WallSweepOrientation.setter
    def WallSweepOrientation(self, wallSweepOrientation: WallSweepOrientation) -> None: ...
    @property
    def IsProfileFlipped(self) -> bool: ...
    @IsProfileFlipped.setter
    def IsProfileFlipped(self, isProfileFlipped: bool) -> None: ...
    @property
    def IsCutByInserts(self) -> bool: ...
    @IsCutByInserts.setter
    def IsCutByInserts(self, isCutByInserts: bool) -> None: ...
    @property
    def CutsWall(self) -> bool: ...
    @CutsWall.setter
    def CutsWall(self, cutsWall: bool) -> None: ...
    @property
    def IsVertical(self) -> bool: ...
    @property
    def IsFixed(self) -> bool: ...
    @property
    def IsValidObject(self) -> bool: ...
    def IsEqual(self, toCompare: WallSweepInfo) -> bool: ...
    def Dispose(self) -> None: ...


class CompoundStructureLayer:
    @overload
    def __init__(self, width: float, function: MaterialFunctionAssignment, materialId: ElementId): ...
    @overload
    def __init__(self, cs: CompoundStructureLayer): ...
    @overload
    def __init__(self): ...
    @property
    def Width(self) -> float: ...
    @Width.setter
    def Width(self, width: float) -> None: ...
    @property
    def Function(self) -> MaterialFunctionAssignment: ...
    @Function.setter
    def Function(self, function: MaterialFunctionAssignment) -> None: ...
    @property
    def DeckEmbeddingType(self) -> StructDeckEmbeddingType: ...
    @DeckEmbeddingType.setter
    def DeckEmbeddingType(self, deckEmbeddingType: StructDeckEmbeddingType) -> None: ...
    @property
    def MaterialId(self) -> ElementId: ...
    @MaterialId.setter
    def MaterialId(self, materialId: ElementId) -> None: ...
    @property
    def DeckProfileId(self) -> ElementId: ...
    @DeckProfileId.setter
    def DeckProfileId(self, deckProfileId: ElementId) -> None: ...
    @property
    def LayerId(self) -> int: ...
    @property
    def LayerCapFlag(self) -> bool: ...
    @LayerCapFlag.setter
    def LayerCapFlag(self, layerCapFlag: bool) -> None: ...
    @property
    def IsValidObject(self) -> bool: ...
    def Dispose(self) -> None: ...


class CompoundStructure:
    @property
    def IsEmpty(self) -> bool: ...
    @property
    def LayerCount(self) -> int: ...
    @property
    def IsVerticallyCompound(self) -> bool: ...
    @property
    def HasStructuralDeck(self) -> bool: ...
    @property
    def EndCap(self) -> EndCapCondition: ...
    @EndCap.setter
    def EndCap(self, endCap: EndCapCondition) -> None: ...
    @property
    def OpeningWrapping(self) -> OpeningWrappingCondition: ...
    @OpeningWrapping.setter
    def OpeningWrapping(self, wrapping: OpeningWrappingCondition) -> None: ...
    @property
    def VariableLayerIndex(self) -> int: ...
    @VariableLayerIndex.setter
    def VariableLayerIndex(self, variableLayerIndex: int) -> None: ...
    @property
    def StructuralMaterialIndex(self) -> int: ...
    @StructuralMaterialIndex.setter
    def StructuralMaterialIndex(self, layerIndex: int) -> None: ...
    @property
    def SampleHeight(self) -> float: ...
    @SampleHeight.setter
    def SampleHeight(self, newSampleHeight: float) -> None: ...
    @property
    def CutoffHeight(self) -> float: ...
    @CutoffHeight.setter
    def CutoffHeight(self, cutOffHeight: float) -> None: ...
    @property
    def MinimumSampleHeight(self) -> float: ...
    @property
    def IsValidObject(self) -> bool: ...
    def GetLayers(self) -> List[CompoundStructureLayer]: ...
    def IsEqual(self, otherStructure: CompoundStructure) -> bool: ...
    def IsVerticallyHomogeneous(self) -> bool: ...
    def IsValid(self, doc: Document) -> Tuple[bool, IDictionary, IDictionary]: ...
    def GetSimpleCompoundStructure(self, wallHeight: float, distAboveBase: float) -> CompoundStructure: ...
    def DeleteLayer(self, layerIdx: int) -> bool: ...
    def SetMaterialId(self, layerIdx: int, materialId: ElementId) -> None: ...
    def GetMaterialId(self, layerIdx: int) -> ElementId: ...
    def GetLayerWidth(self, layerIdx: int) -> float: ...
    def SetLayerWidth(self, layerIdx: int, width: float) -> None: ...
    def CanLayerWidthBeNonZero(self, layerIdx: int) -> bool: ...
    @overload
    def GetWidth(self) -> float: ...
    @overload
    def GetWidth(self, regionId: int) -> float: ...
    def GetLayerFunction(self, layerIdx: int) -> MaterialFunctionAssignment: ...
    def SetLayerFunction(self, layerIdx: int, function: MaterialFunctionAssignment) -> None: ...
    def IsStructuralDeck(self, layerIdx: int) -> bool: ...
    def GetDeckProfileId(self, layerIdx: int) -> ElementId: ...
    def SetDeckProfileId(self, layerIdx: int, profileId: ElementId) -> None: ...
    def GetDeckEmbeddingType(self, layerIdx: int) -> StructDeckEmbeddingType: ...
    def SetDeckEmbeddingType(self, layerIdx: int, embedType: StructDeckEmbeddingType) -> None: ...
    def SetLayers(self, layers: List[CompoundStructureLayer]) -> None: ...
    def SetLayer(self, layerIdx: int, layer: CompoundStructureLayer) -> None: ...
    def ParticipatesInWrapping(self, layerIdx: int) -> bool: ...
    def SetParticipatesInWrapping(self, layerIdx: int, participatesInWrapping: bool) -> None: ...
    def GetNumberOfShellLayers(self, shellLayerType: ShellLayerType) -> int: ...
    def SetNumberOfShellLayers(self, shellLayerType: ShellLayerType, numLayers: int) -> None: ...
    def IsCoreLayer(self, layerIdx: int) -> bool: ...
    def IsLayerValid(self, layerIdx: int, layer: CompoundStructureLayer) -> bool: ...
    def IsValidSampleHeight(self, height: float) -> bool: ...
    def GetRegionsAssociatedToLayer(self, layerIdx: int) -> List[int]: ...
    def GetLayerAssociatedToRegion(self, regionId: int) -> int: ...
    def AssociateRegionWithLayer(self, regionId: int, layerIdx: int) -> None: ...
    def GetRegionIds(self) -> List[int]: ...
    def GetSegmentIds(self) -> List[int]: ...
    def IsValidRegionId(self, regionId: int) -> bool: ...
    def IsSimpleRegion(self, regionId: int) -> bool: ...
    def IsRectangularRegion(self, regionId: int) -> bool: ...
    def IsValidSegmentId(self, segmentId: int) -> bool: ...
    def GetAdjacentRegions(self, segmentId: int) -> List[int]: ...
    def GetSegmentOrientation(self, segmentId: int) -> RectangularGridSegmentOrientation: ...
    def GetRegionEnvelope(self, regionId: int) -> BoundingBoxUV: ...
    def GetSegmentCoordinate(self, segmentId: int) -> float: ...
    def GetSegmentEndPoints(self, segmentId: int, regionId: int) -> Tuple[UV, UV]: ...
    def MergeRegionsAdjacentToSegment(self, segmentId: int, layerIdxForMergedRegion: int) -> int: ...
    @overload
    def SplitRegion(self, gridUV: UV, splitDirection: RectangularGridSegmentOrientation) -> int: ...
    @overload
    def SplitRegion(self, gridUV: UV, splitDirection: RectangularGridSegmentOrientation) -> Tuple[int, int]: ...
    def FindEnclosingRegionAndSegments(self, gridUV: UV, splitDirection: RectangularGridSegmentOrientation) -> Tuple[int, int, int]: ...
    def GetExtendableRegionIds(self, top: bool) -> List[int]: ...
    def SetExtendableRegionIds(self, top: bool, regionIds: List[int]) -> None: ...
    def GetRegionsAlongLevel(self, height: float) -> List[int]: ...
    def ChangeRegionWidth(self, regionId: int, newWidth: float) -> bool: ...
    def GetWallSweepsInfo(self, wallSweepType: WallSweepType) -> List[WallSweepInfo]: ...
    def AddWallSweep(self, wallSweepInfo: WallSweepInfo) -> None: ...
    def RemoveWallSweep(self, wallSweepType: WallSweepType, id: int) -> None: ...
    def ClearWallSweeps(self, wallSweepType: WallSweepType) -> None: ...
    def GetPreviousNonZeroLayerIndex(self, thisIdx: int) -> int: ...
    def GetCoreBoundaryLayerIndex(self, shellLayerType: ShellLayerType) -> int: ...
    def GetOffsetForLocationLine(self, wallLocationLine: WallLocationLine) -> float: ...
    def GetFirstCoreLayerIndex(self) -> int: ...
    def GetLastCoreLayerIndex(self) -> int: ...
    def CreateSimpleCompoundStructure(layers: List[CompoundStructureLayer]) -> CompoundStructure: ...
    @overload
    def CreateSingleLayerCompoundStructure(sampleHeight: float, layerFunction: MaterialFunctionAssignment, width: float, materialId: ElementId) -> CompoundStructure: ...
    @overload
    def CreateSingleLayerCompoundStructure(layerFunction: MaterialFunctionAssignment, width: float, materialId: ElementId) -> CompoundStructure: ...
    def GetMinimumLayerThickness() -> float: ...
    def CanLayerBeVariable(self, variableLayerIndex: int) -> bool: ...
    def CanLayerBeStructuralMaterial(self, layerIndex: int) -> bool: ...
    def Dispose(self) -> None: ...


class OptionalFunctionalityUtils:
    def IsGraphicsAvailable() -> bool: ...
    def IsFBXExportAvailable() -> bool: ...
    def IsDWGExportAvailable() -> bool: ...
    def IsDXFExportAvailable() -> bool: ...
    def IsDWGImportLinkAvailable() -> bool: ...
    def IsDWFExportAvailable() -> bool: ...
    def IsDGNExportAvailable() -> bool: ...
    def IsDGNImportLinkAvailable() -> bool: ...
    def IsSATImportLinkAvailable() -> bool: ...
    def IsSKPImportLinkAvailable() -> bool: ...
    def IsShapeImporterAvailable() -> bool: ...
    def IsIFCAvailable() -> bool: ...
    def IsNavisworksExporterAvailable() -> bool: ...
    def IsPDFImportAvailable() -> bool: ...


class ImageType(ElementType):
    def GetImage(self) -> Bitmap: ...
    @property
    def PageNumber(self) -> int: ...
    @property
    def WidthInPixels(self) -> int: ...
    @property
    def HeightInPixels(self) -> int: ...
    @property
    def ExternalResourceType() -> ExternalResourceType: ...
    @property
    def Path(self) -> str: ...
    @property
    def PathType(self) -> PathType: ...
    @property
    def IsViewImage(self) -> bool: ...
    @property
    def Source(self) -> ImageTypeSource: ...
    @property
    def Status(self) -> ImageTypeStatus: ...
    @property
    def Width(self) -> float: ...
    @property
    def Height(self) -> float: ...
    @property
    def Resolution(self) -> float: ...
    @overload
    def Create(document: Document, options: ImageTypeOptions) -> ImageType: ...
    @overload
    def Create(document: Document, imagePath: str) -> ImageType: ...
    def CanReload(self) -> bool: ...
    def Reload(self) -> None: ...
    def IsLoadedFromFile(self) -> bool: ...
    @overload
    def ReloadFrom(self, options: ImageTypeOptions) -> None: ...
    @overload
    def ReloadFrom(self, imagePath: str) -> None: ...
    def Unload(self) -> None: ...


class ImportInstance(Instance):
    def GetVisibility(self) -> FamilyElementVisibility: ...
    def SetVisibility(self, visibility: FamilyElementVisibility) -> None: ...
    @property
    def IsLinked(self) -> bool: ...
    @overload
    def Create(document: Document, DBView: View, resourceReference: ExternalResourceReference, options: SKPImportOptions) -> Tuple[ImportInstance, LinkLoadResult]: ...
    @overload
    def Create(document: Document, DBView: View, resourceReference: ExternalResourceReference, options: SATImportOptions) -> Tuple[ImportInstance, LinkLoadResult]: ...
    @overload
    def Create(document: Document, DBView: View, resourceReference: ExternalResourceReference, options: DGNImportOptions) -> Tuple[ImportInstance, LinkLoadResult]: ...
    @overload
    def Create(document: Document, typeId: ElementId, DBView: View) -> ImportInstance: ...
    @overload
    def Create(document: Document, DBView: View, resourceReference: ExternalResourceReference, options: DWGImportOptions) -> Tuple[ImportInstance, LinkLoadResult]: ...
    @overload
    def Create(document: Document, DBView: View, path: str, options: DWGImportOptions) -> Tuple[ImportInstance, LinkLoadResult]: ...


class LinearArray(BaseArray):
    @property
    def NumMembers(self) -> int: ...
    @NumMembers.setter
    def NumMembers(self, value: int) -> None: ...
    def GetOriginalMemberIds(self) -> ICollection: ...
    def GetCopiedMemberIds(self) -> ICollection: ...
    @overload
    def Create(aDoc: Document, dBView: View, id: ElementId, count: int, translationToAnchorMember: XYZ, anchorMember: ArrayAnchorMember) -> LinearArray: ...
    @overload
    def Create(aDoc: Document, dBView: View, ids: ICollection, count: int, translationToAnchorMember: XYZ, anchorMember: ArrayAnchorMember) -> LinearArray: ...
    def ArrayElementsWithoutAssociation(aDoc: Document, dBView: View, ids: ICollection, count: int, translationToAnchorMember: XYZ, anchorMember: ArrayAnchorMember) -> ICollection: ...
    def ArrayElementWithoutAssociation(aDoc: Document, dBView: View, id: ElementId, count: int, translationToAnchorMember: XYZ, anchorMember: ArrayAnchorMember) -> ICollection: ...
    def IsValidArraySize(count: int) -> bool: ...
    def IsElementArrayable(aDoc: Document, id: ElementId) -> bool: ...


class RadialArray(BaseArray):
    @property
    def NumMembers(self) -> int: ...
    @NumMembers.setter
    def NumMembers(self, value: int) -> None: ...
    def GetOriginalMemberIds(self) -> ICollection: ...
    def GetCopiedMemberIds(self) -> ICollection: ...
    @overload
    def Create(aDoc: Document, dBView: View, id: ElementId, count: int, axis: Line, angle: float, anchorMember: ArrayAnchorMember) -> RadialArray: ...
    @overload
    def Create(aDoc: Document, dBView: View, ids: ICollection, count: int, axis: Line, angle: float, anchorMember: ArrayAnchorMember) -> RadialArray: ...
    def ArrayElementsWithoutAssociation(aDoc: Document, dBView: View, ids: ICollection, count: int, axis: Line, angle: float, anchorMember: ArrayAnchorMember) -> ICollection: ...
    def ArrayElementWithoutAssociation(aDoc: Document, dBView: View, id: ElementId, count: int, axis: Line, angle: float, anchorMember: ArrayAnchorMember) -> ICollection: ...
    def IsValidArraySize(count: int) -> bool: ...
    def IsRotationAngleValid(angle: float) -> bool: ...


class SchedulableField:
    @overload
    def __init__(self, fieldType: ScheduleFieldType, parameterId: ElementId): ...
    @overload
    def __init__(self, fieldType: ScheduleFieldType): ...
    @overload
    def __init__(self): ...
    def Equals(self, obj: Object) -> bool: ...
    def GetHashCode(self) -> int: ...
    def op_Equality(first: SchedulableField, second: SchedulableField) -> bool: ...
    def op_Inequality(first: SchedulableField, second: SchedulableField) -> bool: ...
    @property
    def FieldType(self) -> ScheduleFieldType: ...
    @FieldType.setter
    def FieldType(self, fieldType: ScheduleFieldType) -> None: ...
    @property
    def ParameterId(self) -> ElementId: ...
    @ParameterId.setter
    def ParameterId(self, parameterId: ElementId) -> None: ...
    @property
    def IsValidObject(self) -> bool: ...
    def GetName(self, document: Document) -> str: ...
    def Dispose(self) -> None: ...


class Subelement:
    @property
    def Category(self) -> Category: ...
    @property
    def TypeId(self) -> ElementId: ...
    @property
    def Document(self) -> Document: ...
    @property
    def Element(self) -> Element: ...
    @property
    def UniqueId(self) -> str: ...
    @property
    def IsValidObject(self) -> bool: ...
    def Create(aDoc: Document, reference: Reference) -> Subelement: ...
    def IsValidType(self, typeId: ElementId) -> bool: ...
    def GetValidTypes(self) -> ISet: ...
    def ChangeTypeId(self, typeId: ElementId) -> None: ...
    def GetAllParameters(self) -> List[ElementId]: ...
    def GetParameterValue(self, parameterId: ElementId) -> ParameterValue: ...
    def SetParameterValue(self, parameterId: ElementId, pValue: ParameterValue) -> None: ...
    def IsParameterModifiable(self, parameterId: ElementId) -> bool: ...
    def GetGeometryObject(self, dbView: View) -> GeometryObject: ...
    def GetBoundingBox(self, dbView: View) -> BoundingBoxXYZ: ...
    def GetReference(self) -> Reference: ...
    def HasParameter(self, parameterId: ElementId) -> bool: ...
    def IsValidSubelementReference(aDoc: Document, reference: Reference) -> bool: ...
    def CanHaveTypeAssigned(self) -> bool: ...
    def Dispose(self) -> None: ...


class SpacingRuleJustification:
    Center = 2
    Beginning = 4
    End = 5


class SpacingRuleLayout:
    #None = 0
    FixedDistance = 1
    FixedNumber = 2
    MaximumSpacing = 3
    MinimumSpacing = 5


class ChangePriority:
    GridsLevelsReferencePlanes = 0
    Masses = 1
    FloorsRoofsStructuralWalls = 2
    Structure = 3
    InteriorWalls = 4
    DoorsOpeningsWindows = 5
    MEPFixtures = 6
    RoomsSpacesZones = 7
    MEPCalculations = 8
    FreeStandingComponents = 9
    Connections = 10
    Rebar = 11
    MEPAccessoriesFittingsSegmentsWires = 12
    MEPSystems = 13
    Views = 14
    DetailComponents = 15
    Annotations = 16


class PartType:
    Normal = 0
    DuctMounted = 1
    JunctionBox = 2
    AttachesTo = 3
    BreaksInto = 4
    Elbow = 5
    Tee = 6
    Transition = 7
    Cross = 8
    Cap = 9
    TapPerpendicular = 10
    TapAdjustable = 11
    Offset = 12
    Union = 13
    PanelBoard = 14
    Transformer = 15
    SwitchBoard = 16
    OtherPanel = 17
    EquipmentSwitch = 18
    Switch = 19
    ValveBreaksInto = 20
    SpudPerpendicular = 21
    SpudAdjustable = 22
    Damper = 23
    Wye = 24
    LateralTee = 25
    LateralCross = 26
    Pants = 27
    MultiPort = 28
    ValveNormal = 29
    JunctionBoxTee = 30
    JunctionBoxCross = 31
    PipeFlange = 32
    JunctionBoxElbow = 34
    ChannelCableTrayElbow = 35
    ChannelCableTrayVerticalElbow = 36
    ChannelCableTrayCross = 37
    ChannelCableTrayTee = 38
    ChannelCableTrayTransition = 39
    ChannelCableTrayUnion = 40
    ChannelCableTrayOffset = 41
    ChannelCableTrayMultiPort = 42
    LadderCableTrayElbow = 43
    LadderCableTrayVerticalElbow = 44
    LadderCableTrayCross = 45
    LadderCableTrayTee = 46
    LadderCableTrayTransition = 47
    LadderCableTrayUnion = 48
    LadderCableTrayOffset = 49
    LadderCableTrayMultiPort = 50
    InlineSensor = 51
    Sensor = 52
    EndCap = 53
    HandrailBracketHardware = 54
    PanelBracketHardware = 55
    TerminationHardware = 56
    Rails = 57
    Handrails = 58
    TopRails = 59
    PipeMechanicalCoupling = 60
    Undefined = -1


class EndCapCondition:
    #None = 0
    Exterior = 1
    Interior = 2
    NoEndCap = 3


class OpeningWrappingCondition:
    #None = 0
    Exterior = 1
    Interior = 2
    ExteriorAndInterior = 3


class CompoundStructureError:
    BadShellOrder = 0
    CoreTooThin = 1
    MembraneTooThick = 3
    NonmembraneTooThin = 4
    BadShellsStructure = 5
    ThinOuterLayer = 6
    VerticalUnusedLayer = 7
    VerticalWrongOrderLayer = 8
    VerticalWrongOrderCoreExterior = 9
    VerticalWrongOrderCoreInterior = 10
    VerticalWrongOrderMembrane = 11
    DeckCantBoundAbove = 12
    DeckCantBoundBelow = 13
    VarThickLayerCantBeZero = 14
    InvalidMaterialId = 15
    ExtensibleRegionsNotContiguousAlongTop = 16
    ExtensibleRegionsNotContiguousAlongBottom = 17
    InvalidProfileId = 18


class MaterialFunctionAssignment:
    #None = 0
    Structure = 1
    Substrate = 2
    Insulation = 3
    Finish1 = 4
    Finish2 = 5
    Membrane = 100
    StructuralDeck = 200


class StructDeckEmbeddingType:
    MergeWithLayerAbove = 0
    Standalone = 1
    Invalid = -1


class ShellLayerType:
    Interior = 0
    Exterior = 1


class RectangularGridSegmentOrientation:
    Vertical = 0
    Horizontal = 1


class WallLocationLine:
    WallCenterline = 0
    CoreCenterline = 1
    FinishFaceExterior = 2
    FinishFaceInterior = 3
    CoreExterior = 4
    CoreInterior = 5


class WallSweepType:
    Sweep = 0
    Reveal = 1


class WallSide:
    Exterior = 0
    Interior = 1


class DistanceMeasuredFrom:
    Base = 0
    Top = 1


class WallSweepOrientation:
    Horizontal = 0
    Perpendicular = 1


class LinkedFileStatus:
    Loaded = 0
    Unloaded = 1
    Imported = 2
    NotFound = 3
    CanBeUpgraded = 4
    InClosedWorkset = 5
    LocallyUnloaded = 6
    Invalid = -1


class PathType:
    Relative = 0
    Absolute = 1
    Server = 2
    Content = 3


class AttachmentType:
    Overlay = 2
    Attachment = 3


class TransmittedModelOptions:
    SaveAsNewCentral = 0
    KeepAsTransmitted = 1
    CancelOperation = 2


class LinkLoadResultType:
    Uninitialized = 0
    LinkLoaded = 1
    LinkNotFound = 2
    LinkNotOpenable = 3
    LinkOpenAsHost = 4
    SameModelAsHost = 5
    SameCentralModelAsHost = 6
    LinkNotLoadedOtherError = 7
    LinkMayBeUpgraded = 8
    ExternalServerMissing = 9
    LinkExists = 10
    CouldNotChangeViewReference = 12
    UsedExisting = 13


class SaveModifiedLinksOptions:
    SaveLinks = 0
    DoNotSaveLinks = 1
    DisableSharedPositioning = 2


class SaveModifiedLinksOptionsForUnloadLocally:
    SaveLinks = 0
    DoNotSaveLinks = 1


class ImageTypeSource:
    Link = 0
    Import = 1
    Internal = 2


class ImageTypeStatus:
    Unknown = 0
    Loaded = 1
    FailedToLoad = 2
    Unloaded = 3
    Imported = 4
    Generated = 5


class ArrayAnchorMember:
    Second = 0
    Last = 1


class ScheduleFieldType:
    Instance = 0
    ElementType = 1
    Count = 2
    ViewBased = 4
    Formula = 5
    Percentage = 6
    Room = 7
    FromRoom = 8
    ToRoom = 9
    ProjectInfo = 10
    Material = 11
    MaterialQuantity = 12
    RevitLinkInstance = 13
    RevitLinkType = 14
    StructuralMaterial = 15
    Space = 16
    Analytical = 17
    PhysicalType = 18
    PhysicalInstance = 19
    CombinedParameter = 20


class SunAndShadowSettings(Element):
    @property
    def Visible(self) -> bool: ...
    @Visible.setter
    def Visible(self, visibility: bool) -> None: ...
    @property
    def Azimuth(self) -> float: ...
    @Azimuth.setter
    def Azimuth(self, azimuth: float) -> None: ...
    @property
    def Altitude(self) -> float: ...
    @Altitude.setter
    def Altitude(self, altitude: float) -> None: ...
    @property
    def SunAndShadowType(self) -> SunAndShadowType: ...
    @SunAndShadowType.setter
    def SunAndShadowType(self, type: SunAndShadowType) -> None: ...
    @property
    def ActiveFrameTime(self) -> DateTime: ...
    @property
    def StartDateAndTime(self) -> DateTime: ...
    @StartDateAndTime.setter
    def StartDateAndTime(self, time: DateTime) -> None: ...
    @property
    def EndDateAndTime(self) -> DateTime: ...
    @EndDateAndTime.setter
    def EndDateAndTime(self, time: DateTime) -> None: ...
    @property
    def ActiveFrame(self) -> float: ...
    @ActiveFrame.setter
    def ActiveFrame(self, frame: float) -> None: ...
    @property
    def NumberOfFrames(self) -> float: ...
    @property
    def GroundPlaneLevelId(self) -> ElementId: ...
    @GroundPlaneLevelId.setter
    def GroundPlaneLevelId(self, level: ElementId) -> None: ...
    @property
    def SunriseToSunset(self) -> bool: ...
    @SunriseToSunset.setter
    def SunriseToSunset(self, sunriseToSunset: bool) -> None: ...
    @property
    def UsesGroundPlane(self) -> bool: ...
    @UsesGroundPlane.setter
    def UsesGroundPlane(self, groundPlane: bool) -> None: ...
    @property
    def RelativeToView(self) -> bool: ...
    @RelativeToView.setter
    def RelativeToView(self, relativeToView: bool) -> None: ...
    @property
    def TimeInterval(self) -> SunStudyTimeInterval: ...
    @TimeInterval.setter
    def TimeInterval(self, interval: SunStudyTimeInterval) -> None: ...
    @property
    def GroundPlaneHeight(self) -> float: ...
    @property
    def Latitude(self) -> float: ...
    @property
    def Longitude(self) -> float: ...
    @property
    def TimeZone(self) -> float: ...
    @property
    def UsesDST(self) -> bool: ...
    @property
    def ProjectLocationName(self) -> str: ...
    @property
    def ProjectLocationId(self) -> ElementId: ...
    @property
    def SharesSettings(self) -> bool: ...
    @SharesSettings.setter
    def SharesSettings(self, sharedSetting: bool) -> None: ...
    def GetMatchingPreset(self) -> str: ...
    def GetFrameTime(self, frame: float) -> DateTime: ...
    def GetFrameAltitude(self, frame: float) -> float: ...
    def GetFrameAzimuth(self, frame: float) -> float: ...
    def GetSunrise(self, date: DateTime) -> DateTime: ...
    def GetSunset(self, date: DateTime) -> DateTime: ...
    def IsAfterStartDateAndTime(self, time: DateTime) -> bool: ...
    def IsBeforeEndDateAndTime(self, time: DateTime) -> bool: ...
    def IsFrameValid(self, frame: float) -> bool: ...
    def IsGroundPlaneLevelValid(self, levelId: ElementId) -> bool: ...
    def IsTimeIntervalValid(self, interval: SunStudyTimeInterval) -> bool: ...
    def CalculateTimeZone(latitude: float, longitude: float) -> float: ...
    def FitToModel(self) -> None: ...
    def GetActiveSunAndShadowSettings(aDocument: Document) -> Element: ...


class SunAndShadowType:
    StillImage = 0
    OneDayStudy = 1
    MultiDayStudy = 2
    Lighting = 3


class SunStudyTimeInterval:
    Minutes15 = 0
    Minutes30 = 1
    Minutes45 = 2
    Hour = 3
    Day = 4
    Week = 5
    Month = 6


class SiteLocation(ElementType):
    def ConvertToProjectTime(self, inputTime: DateTime) -> DateTime: ...
    def ConvertFromProjectTime(self, projectTime: DateTime) -> DateTime: ...
    @property
    def Latitude(self) -> float: ...
    @Latitude.setter
    def Latitude(self, latitude: float) -> None: ...
    @property
    def Longitude(self) -> float: ...
    @Longitude.setter
    def Longitude(self, longitude: float) -> None: ...
    @property
    def TimeZone(self) -> float: ...
    @TimeZone.setter
    def TimeZone(self, timeZone: float) -> None: ...
    @property
    def PlaceName(self) -> str: ...
    @PlaceName.setter
    def PlaceName(self, placeName: str) -> None: ...
    @property
    def WeatherStationName(self) -> str: ...
    @property
    def Elevation(self) -> float: ...
    @property
    def GeoCoordinateSystemId(self) -> str: ...
    @property
    def GeoCoordinateSystemDefinition(self) -> str: ...
    def SetGeoCoordinateSystem(self, coordSystem: str) -> None: ...
    def IsCompatibleWith(self, otherSiteLocation: SiteLocation) -> bool: ...


class ConnectorElement(Element):
    @property
    def CoordinateSystem(self) -> Transform: ...
    @property
    def Origin(self) -> XYZ: ...
    @property
    def Domain(self) -> Domain: ...
    @property
    def Shape(self) -> ConnectorProfileType: ...
    @property
    def Width(self) -> float: ...
    @property
    def Height(self) -> float: ...
    @property
    def Radius(self) -> float: ...
    @property
    def IsPrimary(self) -> bool: ...
    @property
    def SystemClassification(self) -> MEPSystemClassification: ...
    @SystemClassification.setter
    def SystemClassification(self, systemType: MEPSystemClassification) -> None: ...
    @property
    def Direction(self) -> XYZ: ...
    def GetLinkedConnectorElement(self) -> ConnectorElement: ...
    def SetLinkedConnectorElement(self, otherConnector: ConnectorElement) -> None: ...
    @overload
    def CreatePipeConnector(document: Document, pipeSystemType: PipeSystemType, planarFace: Reference, edge: Edge) -> ConnectorElement: ...
    @overload
    def CreatePipeConnector(document: Document, pipeSystemType: PipeSystemType, planarFace: Reference) -> ConnectorElement: ...
    @overload
    def CreateDuctConnector(document: Document, ductSystemType: DuctSystemType, profileShape: ConnectorProfileType, planarFace: Reference, edge: Edge) -> ConnectorElement: ...
    @overload
    def CreateDuctConnector(document: Document, ductSystemType: DuctSystemType, profileShape: ConnectorProfileType, planarFace: Reference) -> ConnectorElement: ...
    @overload
    def CreateElectricalConnector(document: Document, electricalSystemType: ElectricalSystemType, planarFace: Reference, edge: Edge) -> ConnectorElement: ...
    @overload
    def CreateElectricalConnector(document: Document, electricalSystemType: ElectricalSystemType, planarFace: Reference) -> ConnectorElement: ...
    @overload
    def CreateConduitConnector(document: Document, planarFace: Reference, edge: Edge) -> ConnectorElement: ...
    @overload
    def CreateConduitConnector(document: Document, planarFace: Reference) -> ConnectorElement: ...
    @overload
    def CreateCableTrayConnector(document: Document, planarFace: Reference, edge: Edge) -> ConnectorElement: ...
    @overload
    def CreateCableTrayConnector(document: Document, planarFace: Reference) -> ConnectorElement: ...
    def AssignAsPrimary(self) -> None: ...
    def IsSystemClassificationValid(self, systemClassification: MEPSystemClassification) -> bool: ...
    def FlipDirection(self) -> None: ...


class Construction:
    @property
    def Id(self) -> str: ...
    @property
    def Name(self) -> str: ...


class ScheduleFieldId:
    def __init__(self, id: int): ...
    @property
    def IntegerValue(self) -> int: ...
    def Equals(self, obj: Object) -> bool: ...
    def GetHashCode(self) -> int: ...
    def ToString(self) -> str: ...
    def op_Equality(first: ScheduleFieldId, second: ScheduleFieldId) -> bool: ...
    def op_Inequality(first: ScheduleFieldId, second: ScheduleFieldId) -> bool: ...
    @property
    def InvalidScheduleFieldId() -> ScheduleFieldId: ...


class WorksetId:
    def __init__(self, id: int): ...
    @property
    def IntegerValue(self) -> int: ...
    def ToString(self) -> str: ...
    def Equals(self, obj: Object) -> bool: ...
    def GetHashCode(self) -> int: ...
    @property
    def InvalidWorksetId() -> WorksetId: ...
    def Compare(self, id: WorksetId) -> int: ...
    def op_Equality(first: WorksetId, second: WorksetId) -> bool: ...
    def op_Inequality(first: WorksetId, second: WorksetId) -> bool: ...
    def op_LessThan(WorksetId1: WorksetId, WorksetId2: WorksetId) -> bool: ...
    def op_GreaterThan(WorksetId1: WorksetId, WorksetId2: WorksetId) -> bool: ...
    def op_LessThanOrEqual(WorksetId1: WorksetId, WorksetId2: WorksetId) -> bool: ...
    def op_GreaterThanOrEqual(WorksetId1: WorksetId, WorksetId2: WorksetId) -> bool: ...


class IExternalDBApplication:
    def OnStartup(self, application: ControlledApplication) -> ExternalDBApplicationResult: ...
    def OnShutdown(self, application: ControlledApplication) -> ExternalDBApplicationResult: ...


class ExternalDBApplicationResult:
    Succeeded = 0
    Failed = -1


class ATFBaseExportOptions:
    @property
    def ViewId(self) -> ElementId: ...
    @ViewId.setter
    def ViewId(self, viewId: ElementId) -> None: ...
    @property
    def IsValidObject(self) -> bool: ...
    def Dispose(self) -> None: ...


class AdaptiveComponentFamilyUtils:
    def IsAdaptiveComponentFamily(family: Family) -> bool: ...
    def IsAdaptivePoint(doc: Document, refPointId: ElementId) -> bool: ...
    def IsAdaptivePlacementPoint(doc: Document, refPointId: ElementId) -> bool: ...
    def IsAdaptiveShapeHandlePoint(doc: Document, refPointId: ElementId) -> bool: ...
    def GetNumberOfAdaptivePoints(family: Family) -> int: ...
    def GetNumberOfPlacementPoints(family: Family) -> int: ...
    def GetNumberOfShapeHandlePoints(family: Family) -> int: ...
    def MakeAdaptivePoint(doc: Document, refPointId: ElementId, type: AdaptivePointType) -> None: ...
    def GetPlacementNumber(doc: Document, refPointId: ElementId) -> int: ...
    def SetPlacementNumber(doc: Document, refPointId: ElementId, placementNumber: int) -> None: ...
    def GetPointOrientationType(doc: Document, refPointId: ElementId) -> AdaptivePointOrientationType: ...
    def SetPointOrientationType(doc: Document, refPointId: ElementId, orientationType: AdaptivePointOrientationType) -> None: ...
    def GetPointConstraintType(doc: Document, refPointId: ElementId) -> AdaptivePointConstraintType: ...
    def SetPointConstraintType(doc: Document, refPointId: ElementId, constraintType: AdaptivePointConstraintType) -> None: ...


class AdaptiveComponentInstanceUtils:
    def IsAdaptiveFamilySymbol(famSymb: FamilySymbol) -> bool: ...
    def HasAdaptiveFamilySymbol(famInst: FamilyInstance) -> bool: ...
    def IsAdaptiveComponentInstance(famInst: FamilyInstance) -> bool: ...
    def CreateAdaptiveComponentInstance(doc: Document, famSymb: FamilySymbol) -> FamilyInstance: ...
    def MoveAdaptiveComponentInstance(famInst: FamilyInstance, trf: Transform, unHost: bool) -> None: ...
    def GetInstancePointElementRefIds(famInst: FamilyInstance) -> List[ElementId]: ...
    def GetInstancePlacementPointElementRefIds(famInst: FamilyInstance) -> List[ElementId]: ...
    def GetInstanceShapeHandlePointElementRefIds(famInst: FamilyInstance) -> List[ElementId]: ...
    def IsInstanceFlipped(famInst: FamilyInstance) -> bool: ...
    def SetInstanceFlipped(famInst: FamilyInstance, flip: bool) -> None: ...


class ThermalProperties(APIObject):
    @property
    def Absorptance(self) -> float: ...
    @Absorptance.setter
    def Absorptance(self, absorptance: float) -> None: ...
    @property
    def Roughness(self) -> int: ...
    @Roughness.setter
    def Roughness(self, roughness: int) -> None: ...
    @property
    def HeatTransferCoefficient(self) -> float: ...
    @property
    def ThermalResistance(self) -> float: ...
    @property
    def ThermalMass(self) -> float: ...
    @property
    def IsValidObject(self) -> bool: ...


class AngularDimension(Dimension):
    def Create(document: Document, dbView: View, arc: Arc, references: List[Reference], dimensionStyle: DimensionType) -> AngularDimension: ...
    def SetAngularRadius(self, radius: float) -> None: ...


class AppearanceAssetElement(Element):
    def GetAppearanceAssetElementByName(doc: Document, name: str) -> AppearanceAssetElement: ...
    def Create(document: Document, name: str, asset: Asset) -> AppearanceAssetElement: ...
    def Duplicate(self, name: str) -> AppearanceAssetElement: ...
    def SetRenderingAsset(self, asset: Asset) -> None: ...
    def GetRenderingAsset(self) -> Asset: ...


class FailureDefinitionRegistry:
    @property
    def IsValidObject(self) -> bool: ...
    def FindFailureDefinition(self, id: FailureDefinitionId) -> FailureDefinitionAccessor: ...
    def ListAllFailureDefinitions(self) -> List[FailureDefinitionAccessor]: ...
    def Dispose(self) -> None: ...


class IFailuresProcessor:
    def ProcessFailures(self, data: FailuresAccessor) -> FailureProcessingResult: ...
    def Dismiss(self, document: Document) -> None: ...


class IOpenFromCloudCallback:
    def OnOpenConflict(self, scenario: OpenConflictScenario) -> OpenConflictResult: ...


class DefaultOpenFromCloudCallback:
    def __init__(self): ...
    @property
    def IsValidObject(self) -> bool: ...
    def OnOpenConflict(self, scenario: OpenConflictScenario) -> OpenConflictResult: ...
    def Dispose(self) -> None: ...


class KeyBasedTreeEntryTable(Element):
    def ServerSupports(self, extRef: ExternalResourceReference) -> bool: ...
    def LoadFrom(self, desiredResourceReference: ExternalResourceReference, loadResults: KeyBasedTreeEntriesLoadResults) -> ExternalResourceLoadStatus: ...
    def Reload(self, loadResults: KeyBasedTreeEntriesLoadResults) -> ExternalResourceLoadStatus: ...
    def GetKeyBasedTreeEntries(self) -> KeyBasedTreeEntries: ...


class AssemblyCodeTable(KeyBasedTreeEntryTable):
    def GetAssemblyCodeTable(doc: Document) -> AssemblyCodeTable: ...


class AssemblyDifference:
    @property
    def IsValidObject(self) -> bool: ...
    def Dispose(self) -> None: ...


class AssemblyDifferenceNone(AssemblyDifference):


class AssemblyDifferenceNamingCategory(AssemblyDifference):
    @property
    def NamingCategoryId1(self) -> ElementId: ...
    @property
    def NamingCategoryId2(self) -> ElementId: ...


class AssemblyDifferenceMemberCount(AssemblyDifference):
    @property
    def Count1(self) -> int: ...
    @property
    def Count2(self) -> int: ...


class AssemblyDifferenceConfiguration(AssemblyDifference):


class AssemblyDifferenceMemberDifference(AssemblyDifference):
    @property
    def MemberId1(self) -> ElementId: ...
    @property
    def MemberId2(self) -> ElementId: ...
    @property
    def MemberDifference(self) -> AssemblyMemberDifference: ...


class AssemblyMemberDifference:
    @property
    def IsValidObject(self) -> bool: ...
    def Dispose(self) -> None: ...


class AssemblyMemberDifferentGeometry(AssemblyMemberDifference):


class AssemblyMemberDifferentCategory(AssemblyMemberDifference):
    @property
    def CategoryId1(self) -> ElementId: ...
    @property
    def CategoryId2(self) -> ElementId: ...


class AssemblyMemberDifferentType(AssemblyMemberDifference):
    @property
    def TypeId1(self) -> ElementId: ...
    @property
    def TypeId2(self) -> ElementId: ...


class AssemblyMemberDifferentParameters(AssemblyMemberDifference):


class AssemblyType(ElementType):


class AssemblyViewUtils:
    @overload
    def Create3DOrthographic(document: Document, assemblyInstanceId: ElementId, viewTemplateId: ElementId, isAssigned: bool) -> View3D: ...
    @overload
    def Create3DOrthographic(document: Document, assemblyInstanceId: ElementId) -> View3D: ...
    @overload
    def CreateDetailSection(document: Document, assemblyInstanceId: ElementId, direction: AssemblyDetailViewOrientation, viewTemplateId: ElementId, isAssigned: bool) -> ViewSection: ...
    @overload
    def CreateDetailSection(document: Document, assemblyInstanceId: ElementId, direction: AssemblyDetailViewOrientation) -> ViewSection: ...
    @overload
    def CreateSingleCategorySchedule(document: Document, assemblyInstanceId: ElementId, scheduleCategoryId: ElementId, viewTemplateId: ElementId, isAssigned: bool) -> ViewSchedule: ...
    @overload
    def CreateSingleCategorySchedule(document: Document, assemblyInstanceId: ElementId, scheduleCategoryId: ElementId) -> ViewSchedule: ...
    @overload
    def CreatePartList(document: Document, assemblyInstanceId: ElementId, viewTemplateId: ElementId, isAssigned: bool) -> ViewSchedule: ...
    @overload
    def CreatePartList(document: Document, assemblyInstanceId: ElementId) -> ViewSchedule: ...
    @overload
    def CreateMaterialTakeoff(document: Document, assemblyInstanceId: ElementId, viewTemplateId: ElementId, isAssigned: bool) -> ViewSchedule: ...
    @overload
    def CreateMaterialTakeoff(document: Document, assemblyInstanceId: ElementId) -> ViewSchedule: ...
    def CreateSheet(document: Document, assemblyInstanceId: ElementId, titleBlockId: ElementId) -> ViewSheet: ...
    def AcquireAssemblyViews(document: Document, sourceAssemblyInstanceId: ElementId, targetAssemblyInstanceId: ElementId) -> None: ...


class TableMergedCell:
    @overload
    def __init__(self, top: int, left: int, bottom: int, right: int): ...
    @overload
    def __init__(self): ...
    @property
    def Top(self) -> int: ...
    @Top.setter
    def Top(self, top: int) -> None: ...
    @property
    def Left(self) -> int: ...
    @Left.setter
    def Left(self, left: int) -> None: ...
    @property
    def Bottom(self) -> int: ...
    @Bottom.setter
    def Bottom(self, bottom: int) -> None: ...
    @property
    def Right(self) -> int: ...
    @Right.setter
    def Right(self, right: int) -> None: ...
    @property
    def IsValidObject(self) -> bool: ...
    def Dispose(self) -> None: ...


class TableCellStyleOverrideOptions:
    @overload
    def __init__(self, other: TableCellStyleOverrideOptions): ...
    @overload
    def __init__(self): ...
    @property
    def Font(self) -> bool: ...
    @Font.setter
    def Font(self, font: bool) -> None: ...
    @property
    def FontSize(self) -> bool: ...
    @FontSize.setter
    def FontSize(self, fontSize: bool) -> None: ...
    @property
    def FontColor(self) -> bool: ...
    @FontColor.setter
    def FontColor(self, fontColor: bool) -> None: ...
    @property
    def BackgroundColor(self) -> bool: ...
    @BackgroundColor.setter
    def BackgroundColor(self, backgroundColor: bool) -> None: ...
    @property
    def BorderTopLineStyle(self) -> bool: ...
    @BorderTopLineStyle.setter
    def BorderTopLineStyle(self, borderTopLineStyle: bool) -> None: ...
    @property
    def BorderBottomLineStyle(self) -> bool: ...
    @BorderBottomLineStyle.setter
    def BorderBottomLineStyle(self, borderBottomLineStyle: bool) -> None: ...
    @property
    def BorderLeftLineStyle(self) -> bool: ...
    @BorderLeftLineStyle.setter
    def BorderLeftLineStyle(self, borderLeftLineStyle: bool) -> None: ...
    @property
    def BorderRightLineStyle(self) -> bool: ...
    @BorderRightLineStyle.setter
    def BorderRightLineStyle(self, borderRightLineStyle: bool) -> None: ...
    @property
    def HorizontalAlignment(self) -> bool: ...
    @HorizontalAlignment.setter
    def HorizontalAlignment(self, horizontalAlignment: bool) -> None: ...
    @property
    def VerticalAlignment(self) -> bool: ...
    @VerticalAlignment.setter
    def VerticalAlignment(self, verticalAlignment: bool) -> None: ...
    @property
    def Bold(self) -> bool: ...
    @Bold.setter
    def Bold(self, bold: bool) -> None: ...
    @property
    def Italics(self) -> bool: ...
    @Italics.setter
    def Italics(self, italics: bool) -> None: ...
    @property
    def Underline(self) -> bool: ...
    @Underline.setter
    def Underline(self, underline: bool) -> None: ...
    @property
    def TextOrientation(self) -> bool: ...
    @TextOrientation.setter
    def TextOrientation(self, textOrientation: bool) -> None: ...
    @property
    def BorderLineStyle(self) -> bool: ...
    @BorderLineStyle.setter
    def BorderLineStyle(self, borderLineStyle: bool) -> None: ...
    @property
    def IsValidObject(self) -> bool: ...
    def SetAllOverrides(self, bOverride: bool) -> None: ...
    def Dispose(self) -> None: ...


class TableCellStyle:
    @overload
    def __init__(self, other: TableCellStyle): ...
    @overload
    def __init__(self): ...
    @property
    def FontName(self) -> str: ...
    @FontName.setter
    def FontName(self, fontName: str) -> None: ...
    @property
    def TextSize(self) -> float: ...
    @TextSize.setter
    def TextSize(self, textSize: float) -> None: ...
    @property
    def TextColor(self) -> Color: ...
    @TextColor.setter
    def TextColor(self, textColor: Color) -> None: ...
    @property
    def BackgroundColor(self) -> Color: ...
    @BackgroundColor.setter
    def BackgroundColor(self, backgroundColor: Color) -> None: ...
    @property
    def SheetBackgroundColor(self) -> Color: ...
    @property
    def TextOrientation(self) -> int: ...
    @TextOrientation.setter
    def TextOrientation(self, textOrientation: int) -> None: ...
    @property
    def BorderTopLineStyle(self) -> ElementId: ...
    @BorderTopLineStyle.setter
    def BorderTopLineStyle(self, borderTopLineStyle: ElementId) -> None: ...
    @property
    def BorderBottomLineStyle(self) -> ElementId: ...
    @BorderBottomLineStyle.setter
    def BorderBottomLineStyle(self, borderBottomLineStyle: ElementId) -> None: ...
    @property
    def BorderLeftLineStyle(self) -> ElementId: ...
    @BorderLeftLineStyle.setter
    def BorderLeftLineStyle(self, borderLeftLineStyle: ElementId) -> None: ...
    @property
    def BorderRightLineStyle(self) -> ElementId: ...
    @BorderRightLineStyle.setter
    def BorderRightLineStyle(self, borderRightLineStyle: ElementId) -> None: ...
    @property
    def IsOverridden(self) -> bool: ...
    @property
    def IsEnabled(self) -> bool: ...
    @IsEnabled.setter
    def IsEnabled(self, bState: bool) -> None: ...
    @property
    def IsReadOnly(self) -> bool: ...
    @IsReadOnly.setter
    def IsReadOnly(self, bState: bool) -> None: ...
    @property
    def IsFontBold(self) -> bool: ...
    @IsFontBold.setter
    def IsFontBold(self, bState: bool) -> None: ...
    @property
    def IsFontItalic(self) -> bool: ...
    @IsFontItalic.setter
    def IsFontItalic(self, bState: bool) -> None: ...
    @property
    def IsFontUnderline(self) -> bool: ...
    @IsFontUnderline.setter
    def IsFontUnderline(self, bState: bool) -> None: ...
    @property
    def IsInactivePhaseload(self) -> bool: ...
    @IsInactivePhaseload.setter
    def IsInactivePhaseload(self, bState: bool) -> None: ...
    @property
    def FontHorizontalAlignment(self) -> HorizontalAlignmentStyle: ...
    @FontHorizontalAlignment.setter
    def FontHorizontalAlignment(self, style: HorizontalAlignmentStyle) -> None: ...
    @property
    def FontVerticalAlignment(self) -> VerticalAlignmentStyle: ...
    @FontVerticalAlignment.setter
    def FontVerticalAlignment(self, style: VerticalAlignmentStyle) -> None: ...
    @property
    def IsValidObject(self) -> bool: ...
    def ResetOverride(self) -> None: ...
    def GetCellStyleOverrideOptions(self) -> TableCellStyleOverrideOptions: ...
    def SetCellStyleOverrideOptions(self, helper: TableCellStyleOverrideOptions) -> None: ...
    def Dispose(self) -> None: ...


class TableCellCombinedParameterData:
    @property
    def SampleValue(self) -> str: ...
    @SampleValue.setter
    def SampleValue(self, sampleValue: str) -> None: ...
    @property
    def Prefix(self) -> str: ...
    @Prefix.setter
    def Prefix(self, prefix: str) -> None: ...
    @property
    def Suffix(self) -> str: ...
    @Suffix.setter
    def Suffix(self, suffix: str) -> None: ...
    @property
    def Separator(self) -> str: ...
    @Separator.setter
    def Separator(self, separator: str) -> None: ...
    @property
    def CategoryId(self) -> ElementId: ...
    @CategoryId.setter
    def CategoryId(self, categoryId: ElementId) -> None: ...
    @property
    def ParamId(self) -> ElementId: ...
    @ParamId.setter
    def ParamId(self, paramId: ElementId) -> None: ...
    @property
    def IsValidObject(self) -> bool: ...
    def Create() -> TableCellCombinedParameterData: ...
    def Dispose(self) -> None: ...


class TableCellCalculatedValueData:
    @property
    def IsValidObject(self) -> bool: ...
    def GetName(self) -> str: ...
    def Dispose(self) -> None: ...


class TableSectionData:
    @property
    def HideSection(self) -> bool: ...
    @HideSection.setter
    def HideSection(self, hideSection: bool) -> None: ...
    @property
    def NumberOfColumns(self) -> int: ...
    @NumberOfColumns.setter
    def NumberOfColumns(self, nValue: int) -> None: ...
    @property
    def FirstColumnNumber(self) -> int: ...
    @property
    def LastColumnNumber(self) -> int: ...
    @property
    def FirstRowNumber(self) -> int: ...
    @property
    def LastRowNumber(self) -> int: ...
    @property
    def NumberOfRows(self) -> int: ...
    @NumberOfRows.setter
    def NumberOfRows(self, nValue: int) -> None: ...
    @property
    def NeedsRefresh(self) -> bool: ...
    @NeedsRefresh.setter
    def NeedsRefresh(self, needsRefresh: bool) -> None: ...
    @property
    def IsValidObject(self) -> bool: ...
    def IsDataOutOfDate(self) -> bool: ...
    def RefreshData(self) -> bool: ...
    def IsValidColumnNumber(self, nCol: int) -> bool: ...
    def IsValidRowNumber(self, nRow: int) -> bool: ...
    def InsertImage(self, nRow: int, nColumn: int, imageSymbolId: ElementId) -> None: ...
    def IsValidImageSymbolId(self, imageSymbolId: ElementId) -> bool: ...
    def CanInsertRow(self, nIndex: int) -> bool: ...
    def CanRemoveRow(self, nIndex: int) -> bool: ...
    def InsertRow(self, nIndex: int) -> None: ...
    def RemoveRow(self, nIndex: int) -> None: ...
    def CanInsertColumn(self, nIndex: int) -> bool: ...
    def CanRemoveColumn(self, nIndex: int) -> bool: ...
    def InsertColumn(self, index: int) -> None: ...
    def RemoveColumn(self, nIndex: int) -> None: ...
    def GetColumnWidth(self, nCol: int) -> float: ...
    def GetColumnWidthInPixels(self, nCol: int) -> int: ...
    def SetColumnWidth(self, nCol: int, width: float) -> None: ...
    def SetColumnWidthInPixels(self, nCol: int, width: int) -> None: ...
    def GetRowHeight(self, nRow: int) -> float: ...
    def GetRowHeightInPixels(self, nRow: int) -> int: ...
    def SetRowHeight(self, nRow: int, height: float) -> None: ...
    def SetRowHeightInPixels(self, nRow: int, height: int) -> None: ...
    def GetCellText(self, nRow: int, nCol: int) -> str: ...
    def SetCellText(self, nRow: int, nCol: int, text: str) -> None: ...
    def GetMergedCell(self, nRow: int, nCol: int) -> TableMergedCell: ...
    def SetMergedCell(self, nRow: int, nCol: int, mergedCell: TableMergedCell) -> None: ...
    def MergeCells(self, mergedCell: TableMergedCell) -> None: ...
    def GetTableCellStyle(self, nRow: int, nCol: int) -> TableCellStyle: ...
    def AllowOverrideCellStyle(self, nRow: int, nCol: int) -> bool: ...
    @overload
    def SetCellStyle(self, Style: TableCellStyle) -> None: ...
    @overload
    def SetCellStyle(self, nCol: int, Style: TableCellStyle) -> None: ...
    @overload
    def SetCellStyle(self, nRow: int, nCol: int, Style: TableCellStyle) -> None: ...
    @overload
    def IsCellOverridden(self, nCol: int) -> bool: ...
    @overload
    def IsCellOverridden(self, nRow: int, nCol: int) -> bool: ...
    @overload
    def ResetCellOverride(self, nCol: int) -> None: ...
    @overload
    def ResetCellOverride(self, nRow: int, nCol: int) -> None: ...
    def ClearCell(self, nRow: int, nCol: int) -> None: ...
    @overload
    def GetCellType(self, nCol: int) -> CellType: ...
    @overload
    def GetCellType(self, nRow: int, nCol: int) -> CellType: ...
    @overload
    def SetCellType(self, nCol: int, type: CellType) -> None: ...
    @overload
    def SetCellType(self, nRow: int, nCol: int, type: CellType) -> None: ...
    @overload
    def GetCellFormatOptions(self, nCol: int, ccda: Document) -> FormatOptions: ...
    @overload
    def GetCellFormatOptions(self, nRow: int, nCol: int, ccda: Document) -> FormatOptions: ...
    def IsCellFormattable(self, nRow: int, nCol: int) -> bool: ...
    def GetCellUnitType(self, nRow: int, nCol: int) -> UnitType: ...
    def GetCellSpec(self, nRow: int, nCol: int) -> ForgeTypeId: ...
    def SetCellFormatOptions(self, nRow: int, nCol: int, options: FormatOptions) -> None: ...
    @overload
    def GetCellParamId(self, nCol: int) -> ElementId: ...
    @overload
    def GetCellParamId(self, nRow: int, nCol: int) -> ElementId: ...
    @overload
    def GetCellCategoryId(self, nCol: int) -> ElementId: ...
    @overload
    def GetCellCategoryId(self, nRow: int, nCol: int) -> ElementId: ...
    @overload
    def IsAcceptableParamIdAndCategoryId(self, nRow: int, paramId: ElementId, categoryId: ElementId) -> bool: ...
    @overload
    def IsAcceptableParamIdAndCategoryId(self, paramId: ElementId, categoryId: ElementId) -> bool: ...
    @overload
    def SetCellParamIdAndCategoryId(self, nCol: int, paramId: ElementId, categoryId: ElementId) -> None: ...
    @overload
    def SetCellParamIdAndCategoryId(self, nRow: int, nCol: int, paramId: ElementId, categoryId: ElementId) -> None: ...
    @overload
    def GetCellCalculatedValue(self, nCol: int) -> TableCellCalculatedValueData: ...
    @overload
    def GetCellCalculatedValue(self, nRow: int, nCol: int) -> TableCellCalculatedValueData: ...
    @overload
    def SetCellCalculatedValue(self, nCol: int, pCalcValue: TableCellCalculatedValueData) -> None: ...
    @overload
    def SetCellCalculatedValue(self, nRow: int, nCol: int, pCalcValue: TableCellCalculatedValueData) -> None: ...
    @overload
    def GetCellCombinedParameters(self, nCol: int) -> List[TableCellCombinedParameterData]: ...
    @overload
    def GetCellCombinedParameters(self, nRow: int, nCol: int) -> List[TableCellCombinedParameterData]: ...
    @overload
    def SetCellCombinedParameters(self, nCol: int, paramData: List[TableCellCombinedParameterData]) -> None: ...
    @overload
    def SetCellCombinedParameters(self, nRow: int, nCol: int, paramData: List[TableCellCombinedParameterData]) -> None: ...
    def Dispose(self) -> None: ...


class TableData:
    @property
    def FreezeColumnsAndRows(self) -> bool: ...
    @FreezeColumnsAndRows.setter
    def FreezeColumnsAndRows(self, freezeColumnsAndRows: bool) -> None: ...
    @property
    def ZoomLevel(self) -> int: ...
    @ZoomLevel.setter
    def ZoomLevel(self, zoomLevel: int) -> None: ...
    @property
    def NumberOfSections(self) -> int: ...
    @property
    def WidthInPixels(self) -> int: ...
    @property
    def Width(self) -> float: ...
    @Width.setter
    def Width(self, nNewWidth: float) -> None: ...
    @property
    def IsValidObject(self) -> bool: ...
    def IsEqual(self, OtherElem: TableData) -> bool: ...
    @overload
    def GetSectionData(self, nIndex: int) -> TableSectionData: ...
    @overload
    def GetSectionData(self, sectionType: SectionType) -> TableSectionData: ...
    def IsValidZoomLevel(self, zoomLevel: int) -> bool: ...
    def Dispose(self) -> None: ...


class TableView(View):
    @property
    def TargetId(self) -> ElementId: ...
    @TargetId.setter
    def TargetId(self, targetId: ElementId) -> None: ...
    @property
    def MaximumGridWidth(self) -> int: ...
    @property
    def MinimumColumnWidth(self) -> int: ...
    @property
    def MinimumRowHeight(self) -> int: ...
    @property
    def MaximumColumnWidth(self) -> int: ...
    @property
    def MaximumRowHeight(self) -> int: ...
    def IsValidSectionType(self, sectionType: SectionType) -> bool: ...
    def GetAvailableParameterCategories(self, sectionType: SectionType, row: int) -> List[ElementId]: ...
    def GetAvailableParameters(cda: Document, categoryId: ElementId) -> List[ElementId]: ...
    def GetCellText(self, sectionType: SectionType, row: int, column: int) -> str: ...
    def GetCalculatedValueName(self, sectionType: SectionType, row: int, column: int) -> str: ...
    def GetCalculatedValueText(self, sectionType: SectionType, row: int, column: int) -> str: ...


class ViewSchedule(TableView):
    @property
    def TitleTextTypeId(self) -> ElementId: ...
    @TitleTextTypeId.setter
    def TitleTextTypeId(self, titleTextTypeId: ElementId) -> None: ...
    @property
    def HeaderTextTypeId(self) -> ElementId: ...
    @HeaderTextTypeId.setter
    def HeaderTextTypeId(self, headerTextTypeId: ElementId) -> None: ...
    @property
    def BodyTextTypeId(self) -> ElementId: ...
    @BodyTextTypeId.setter
    def BodyTextTypeId(self, bodyTextTypeId: ElementId) -> None: ...
    @property
    def Definition(self) -> ScheduleDefinition: ...
    @property
    def EmbeddedDefinition(self) -> ScheduleDefinition: ...
    @property
    def KeyScheduleParameterName(self) -> str: ...
    @KeyScheduleParameterName.setter
    def KeyScheduleParameterName(self, parameterName: str) -> None: ...
    @property
    def ImageRowHeight(self) -> float: ...
    @ImageRowHeight.setter
    def ImageRowHeight(self, imageRowHeight: float) -> None: ...
    @property
    def HasStripedRows(self) -> bool: ...
    @HasStripedRows.setter
    def HasStripedRows(self, hasStripedRows: bool) -> None: ...
    @property
    def UseStripedRowsOnSheets(self) -> bool: ...
    @UseStripedRowsOnSheets.setter
    def UseStripedRowsOnSheets(self, useStripedRowsOnSheets: bool) -> None: ...
    @property
    def IsHeaderFrozen() -> bool: ...
    @IsHeaderFrozen.setter
    def IsHeaderFrozen(isHeaderFrozen: bool) -> None: ...
    @property
    def IsTitleblockRevisionSchedule(self) -> bool: ...
    @property
    def IsInternalKeynoteSchedule(self) -> bool: ...
    @overload
    def CreateSchedule(document: Document, categoryId: ElementId, areaSchemeId: ElementId) -> ViewSchedule: ...
    @overload
    def CreateSchedule(document: Document, categoryId: ElementId) -> ViewSchedule: ...
    def CreateKeySchedule(document: Document, categoryId: ElementId) -> ViewSchedule: ...
    def CreateMaterialTakeoff(document: Document, categoryId: ElementId) -> ViewSchedule: ...
    def CreateViewList(document: Document) -> ViewSchedule: ...
    def CreateSheetList(document: Document) -> ViewSchedule: ...
    def CreateKeynoteLegend(document: Document) -> ViewSchedule: ...
    def CreateRevisionSchedule(document: Document) -> ViewSchedule: ...
    def CreateNoteBlock(document: Document, familyId: ElementId) -> ViewSchedule: ...
    def IsValidCategoryForSchedule(categoryId: ElementId) -> bool: ...
    def IsValidCategoryForKeySchedule(categoryId: ElementId) -> bool: ...
    def IsValidCategoryForMaterialTakeoff(categoryId: ElementId) -> bool: ...
    def IsValidFamilyForNoteBlock(document: Document, familyId: ElementId) -> bool: ...
    def GetValidCategoriesForSchedule() -> ICollection: ...
    def GetValidCategoriesForKeySchedule() -> ICollection: ...
    def GetValidCategoriesForMaterialTakeoff() -> ICollection: ...
    def GetValidFamiliesForNoteBlock(document: Document) -> ICollection: ...
    @overload
    def GetDefaultNameForSchedule(document: Document, categoryId: ElementId, areaSchemeId: ElementId) -> str: ...
    @overload
    def GetDefaultNameForSchedule(document: Document, categoryId: ElementId) -> str: ...
    def GetDefaultNameForKeySchedule(document: Document, categoryId: ElementId) -> str: ...
    def GetDefaultParameterNameForKeySchedule(document: Document, categoryId: ElementId) -> str: ...
    def GetDefaultNameForMaterialTakeoff(document: Document, categoryId: ElementId) -> str: ...
    def GetDefaultNameForViewList(document: Document) -> str: ...
    def GetDefaultNameForSheetList(document: Document) -> str: ...
    def GetDefaultNameForKeynoteLegend(document: Document) -> str: ...
    def GetDefaultNameForRevisionSchedule(document: Document) -> str: ...
    def GetDefaultNameForNoteBlock(document: Document) -> str: ...
    def IsDataOutOfDate(self) -> bool: ...
    def RefreshData(self) -> bool: ...
    def CanGroupHeaders(self, top: int, left: int, bottom: int, right: int) -> bool: ...
    def GroupHeaders(self, top: int, left: int, bottom: int, right: int, caption: str) -> None: ...
    def CanUngroupHeaders(self, top: int, left: int, bottom: int, right: int) -> bool: ...
    def UngroupHeaders(self, top: int, left: int, bottom: int, right: int) -> None: ...
    def RestoreImageSize(self) -> None: ...
    def HasImageField(self) -> bool: ...
    def GetStripedRowsColor(self, index: StripedRowPattern) -> Color: ...
    def SetStripedRowsColor(self, index: StripedRowPattern, color: Color) -> None: ...
    def Export(self, folder: str, name: str, options: ViewScheduleExportOptions) -> None: ...
    def IsValidTextTypeId(self, textTypeId: ElementId) -> bool: ...
    def GetTableData(self) -> TableData: ...


class HomeCamera:
    def __init__(self, other: HomeCamera): ...
    @property
    def EyePosition(self) -> XYZ: ...
    @property
    def Center(self) -> XYZ: ...
    @property
    def UpDirection(self) -> XYZ: ...
    @property
    def Pivot(self) -> XYZ: ...
    @property
    def LeftAngleOfFieldOfView(self) -> float: ...
    @property
    def RightAngleOfFieldOfView(self) -> float: ...
    @property
    def TopAngleOfFieldOfView(self) -> float: ...
    @property
    def BottomAngleOfFieldOfView(self) -> float: ...
    @property
    def OrthogonalProjectionWidth(self) -> float: ...
    @property
    def OrthogonalProjectionHeight(self) -> float: ...
    @property
    def ViewId(self) -> ElementId: ...
    @property
    def IsValidObject(self) -> bool: ...
    def Dispose(self) -> None: ...


class ViewNavigationToolSettings(Element):
    def GetViewNavigationToolSettings(pADoc: Document) -> ViewNavigationToolSettings: ...
    def IsHomeCameraSet(self) -> bool: ...
    def GetHomeCamera(self) -> HomeCamera: ...


class FailureResolution:
    @property
    def IsValidObject(self) -> bool: ...
    def Dispose(self) -> None: ...


class DeleteElements(FailureResolution):
    @overload
    def Create(document: Document, id: ElementId) -> FailureResolution: ...
    @overload
    def Create(document: Document, ids: List[ElementId]) -> FailureResolution: ...
    @overload
    def Create(document: Document, ids: ISet) -> FailureResolution: ...


class AdaptivePointConstraintType:
    #None = 0
    Plane_YZ = 1
    Plane_ZX = 2
    Plane_XY = 3
    Axis_X = 4
    Axis_Y = 5
    Axis_Z = 6


class AdaptivePointOrientationType:
    ToHost = 2
    ToHostAndLoopSystem = 3
    ToGlobalZthenHost = 6
    ToGlobalXYZ = 7
    ToInstanceZthenHost = 8
    ToInstance = 9


class AdaptivePointType:
    ReferencePoint = 0
    PlacementPoint = 1
    ShapeHandlePoint = 2


class AllowedValues:
    NonNegative = 0
    All = 1
    Positive = 2


class OpenConflictScenario:
    Rollback = 0
    Relinquished = 1
    OutOfDate = 2
    VersionArchived = 3


class OpenConflictResult:
    KeepLocalChanges = 0
    DiscardLocalChangesAndOpenLatestVersion = 1
    Cancel = 2
    DetachFromCentral = 3


class ExternalResourceLoadStatus:
    Success = 0
    Failure = 1
    Uninitialized = 2
    ResourceAlreadyCurrent = 3
    CannotFindServer = 4
    ServerThrewException = 5


class LoadOperationType:
    Automatic = 0
    Explicit = 1


class ResourceVersionStatus:
    Current = 0
    OutOfDate = 1
    Unknown = 2


class AssemblyDetailViewOrientation:
    HorizontalDetail = 0
    DetailSectionA = 1
    DetailSectionB = 2
    ElevationTop = 3
    ElevationBottom = 4
    ElevationLeft = 5
    ElevationRight = 6
    ElevationFront = 7
    ElevationBack = 8


class StripedRowPattern:
    FirstRow = 0
    SecondRow = 1


class HorizontalAlignmentStyle:
    Left = 0
    Center = 1
    Right = 2


class VerticalAlignmentStyle:
    Top = 0
    Middle = 4
    Bottom = 8


class SectionType:
    Header = 0
    Body = 1
    Summary = 2
    Footer = 3
    #None = -1


class CellType:
    Text = 0
    Graphic = 1
    Parameter = 2
    Inherited = 3
    CombinedParameter = 4
    CalculatedValue = 5
    ParameterText = 6


class ShapeBuilder:
    @property
    def IsValidObject(self) -> bool: ...
    def Dispose(self) -> None: ...


class BRepBuilderGeometryId:
    def __init__(self, other: BRepBuilderGeometryId): ...
    @property
    def IsValidObject(self) -> bool: ...
    def InvalidGeometryId() -> BRepBuilderGeometryId: ...
    def Dispose(self) -> None: ...


class BRepBuilder(ShapeBuilder):
    def __init__(self, geomType: BRepType): ...
    def AddFace(self, surfaceGeom: BRepBuilderSurfaceGeometry, bFaceIsReversed: bool) -> BRepBuilderGeometryId: ...
    def FinishFace(self, faceId: BRepBuilderGeometryId) -> None: ...
    def SetFaceMaterialId(self, faceId: BRepBuilderGeometryId, materialId: ElementId) -> None: ...
    def AddLoop(self, faceId: BRepBuilderGeometryId) -> BRepBuilderGeometryId: ...
    def FinishLoop(self, loopId: BRepBuilderGeometryId) -> None: ...
    def AddEdge(self, edgeGeom: BRepBuilderEdgeGeometry) -> BRepBuilderGeometryId: ...
    def AddCoEdge(self, loopId: BRepBuilderGeometryId, edgeId: BRepBuilderGeometryId, bCoEdgeIsReversed: bool) -> BRepBuilderGeometryId: ...
    def Finish(self) -> BRepBuilderOutcome: ...
    def GetResult(self) -> Solid: ...
    def CanAddGeometry(self) -> bool: ...
    def IsResultAvailable(self) -> bool: ...
    def IsPermittedSurfaceType(surface: Surface) -> bool: ...
    def IsValidFaceId(self, faceId: BRepBuilderGeometryId) -> bool: ...
    def IsValidLoopId(self, loopId: BRepBuilderGeometryId) -> bool: ...
    def IsValidEdgeId(self, edgeId: BRepBuilderGeometryId) -> bool: ...
    def AllowRemovalOfProblematicFaces(self) -> None: ...
    def RemovedSomeFaces(self) -> bool: ...
    def SetAllowShortEdges(self) -> None: ...


class BRepBuilderEdgeGeometry:
    @property
    def IsValidObject(self) -> bool: ...
    @overload
    def Create(startPoint: XYZ, endPoint: XYZ) -> BRepBuilderEdgeGeometry: ...
    @overload
    def Create(curve: Curve) -> BRepBuilderEdgeGeometry: ...
    def Dispose(self) -> None: ...


class BRepBuilderSurfaceGeometry:
    @property
    def IsValidObject(self) -> bool: ...
    def Create(surface: Surface, surfaceEnvelope: BoundingBoxUV) -> BRepBuilderSurfaceGeometry: ...
    @overload
    def CreateNURBSSurface(degreeU: int, degreeV: int, knotsU: List[float], knotsV: List[float], controlPoints: List[XYZ], weights: List[float], bReverseOrientation: bool, surfaceEnvelope: BoundingBoxUV) -> BRepBuilderSurfaceGeometry: ...
    @overload
    def CreateNURBSSurface(degreeU: int, degreeV: int, knotsU: List[float], knotsV: List[float], controlPoints: List[XYZ], bReverseOrientation: bool, surfaceEnvelope: BoundingBoxUV) -> BRepBuilderSurfaceGeometry: ...
    def Dispose(self) -> None: ...


class BasicFileInfo:
    @property
    def IsWorkshared(self) -> bool: ...
    @property
    def IsLocal(self) -> bool: ...
    @property
    def IsCentral(self) -> bool: ...
    @property
    def IsInProgress(self) -> bool: ...
    @property
    def IsCreatedLocal(self) -> bool: ...
    @property
    def IsSavedInCurrentVersion(self) -> bool: ...
    @property
    def IsSavedInLaterVersion(self) -> bool: ...
    @property
    def Format(self) -> str: ...
    @property
    def LanguageWhenSaved(self) -> LanguageType: ...
    @property
    def Username(self) -> str: ...
    @property
    def CentralPath(self) -> str: ...
    @property
    def AllLocalChangesSavedToCentral(self) -> bool: ...
    @property
    def LatestCentralVersion(self) -> int: ...
    @property
    def LatestCentralEpisodeGUID(self) -> Guid: ...
    @property
    def IsValidObject(self) -> bool: ...
    def GetDocumentVersion(self) -> DocumentVersion: ...
    def Extract(file: str) -> BasicFileInfo: ...
    def Dispose(self) -> None: ...


class DocumentVersion:
    @property
    def VersionGUID(self) -> Guid: ...
    @property
    def NumberOfSaves(self) -> int: ...
    @property
    def IsValidObject(self) -> bool: ...
    def IsEqual(self, other: DocumentVersion) -> bool: ...
    def Dispose(self) -> None: ...


class SolidOptions:
    def __init__(self, materialId: ElementId, graphicsStyleId: ElementId): ...
    @property
    def MaterialId(self) -> ElementId: ...
    @MaterialId.setter
    def MaterialId(self, materialId: ElementId) -> None: ...
    @property
    def GraphicsStyleId(self) -> ElementId: ...
    @GraphicsStyleId.setter
    def GraphicsStyleId(self, graphicsStyleId: ElementId) -> None: ...
    @property
    def ExtraFaceAndEdgeHistoryKey(self) -> int: ...
    @ExtraFaceAndEdgeHistoryKey.setter
    def ExtraFaceAndEdgeHistoryKey(self, extraFaceAndEdgeHistoryKey: int) -> None: ...
    @property
    def IsValidObject(self) -> bool: ...
    def Dispose(self) -> None: ...


class GeometryCreationUtilities:
    @overload
    def CreateExtrusionGeometry(profileLoops: List[CurveLoop], extrusionDir: XYZ, extrusionDist: float, solidOptions: SolidOptions) -> Solid: ...
    @overload
    def CreateExtrusionGeometry(profileLoops: List[CurveLoop], extrusionDir: XYZ, extrusionDist: float) -> Solid: ...
    @overload
    def CreateRevolvedGeometry(coordinateFrame: Frame, profileLoops: List[CurveLoop], startAngle: float, endAngle: float, solidOptions: SolidOptions) -> Solid: ...
    @overload
    def CreateRevolvedGeometry(coordinateFrame: Frame, profileLoops: List[CurveLoop], startAngle: float, endAngle: float) -> Solid: ...
    @overload
    def CreateSweptGeometry(sweepPath: CurveLoop, pathAttachmentCrvIdx: int, pathAttachmentParam: float, profileLoops: List[CurveLoop], solidOptions: SolidOptions) -> Solid: ...
    @overload
    def CreateSweptGeometry(sweepPath: CurveLoop, pathAttachmentCrvIdx: int, pathAttachmentParam: float, profileLoops: List[CurveLoop]) -> Solid: ...
    @overload
    def CreateSweptBlendGeometry(pathCurve: Curve, pathParams: List[float], profileLoops: List[CurveLoop], vertexPairs: List[VertexPair], solidOptions: SolidOptions) -> Solid: ...
    @overload
    def CreateSweptBlendGeometry(pathCurve: Curve, pathParams: List[float], profileLoops: List[CurveLoop], vertexPairs: List[VertexPair]) -> Solid: ...
    @overload
    def CreateBlendGeometry(firstLoop: CurveLoop, secondLoop: CurveLoop, vertexPairs: ICollection, solidOptions: SolidOptions) -> Solid: ...
    @overload
    def CreateBlendGeometry(firstLoop: CurveLoop, secondLoop: CurveLoop, vertexPairs: ICollection) -> Solid: ...
    def CreateLoftGeometry(profileLoops: List[CurveLoop], solidOptions: SolidOptions) -> Solid: ...
    @overload
    def CreateFixedReferenceSweptGeometry(sweepPath: CurveLoop, pathAttachmentCrvIdx: int, pathAttachmentParam: float, profileLoops: List[CurveLoop], fixedReferenceDirection: XYZ, solidOptions: SolidOptions) -> Solid: ...
    @overload
    def CreateFixedReferenceSweptGeometry(sweepPath: CurveLoop, pathAttachmentCrvIdx: int, pathAttachmentParam: float, profileLoops: List[CurveLoop], fixedReferenceDirection: XYZ) -> Solid: ...


class FolderItemInfo:
    @property
    def ElementId(self) -> ElementId: ...
    @property
    def Name(self) -> str: ...
    @property
    def IsValidObject(self) -> bool: ...
    def Dispose(self) -> None: ...


class BrowserOrganization(ElementType):
    @property
    def SortingParameterId(self) -> ElementId: ...
    @property
    def SortingOrder(self) -> SortingOrder: ...
    def AreFiltersSatisfied(self, elementId: ElementId) -> bool: ...
    def GetFolderItems(self, elementId: ElementId) -> List[FolderItemInfo]: ...
    def GetCurrentBrowserOrganizationForViews(document: Document) -> BrowserOrganization: ...
    def GetCurrentBrowserOrganizationForSheets(document: Document) -> BrowserOrganization: ...
    def GetCurrentBrowserOrganizationForSchedules(document: Document) -> BrowserOrganization: ...


class BuildingPadType(HostObjAttributes):
    @property
    def ThermalProperties(self) -> ThermalProperties: ...
    def CreateDefault(document: Document) -> BuildingPadType: ...


class FilterRule:
    @property
    def IsValidObject(self) -> bool: ...
    def ElementPasses(self, element: Element) -> bool: ...
    def GetRuleParameter(self) -> ElementId: ...
    def Dispose(self) -> None: ...


class FilterInverseRule(FilterRule):
    def __init__(self, innerRule: FilterRule): ...
    def GetInnerRule(self) -> FilterRule: ...
    def SetInnerRule(self, innerRule: FilterRule) -> None: ...


class FilterableValueProvider:
    @property
    def IsValidObject(self) -> bool: ...
    def GetStringValue(self, element: Element) -> str: ...
    def IsStringValueSupported(self, element: Element) -> bool: ...
    def GetDoubleValue(self, element: Element) -> float: ...
    def IsDoubleValueSupported(self, element: Element) -> bool: ...
    def GetIntegerValue(self, element: Element) -> int: ...
    def IsIntegerValueSupported(self, element: Element) -> bool: ...
    def GetElementIdValue(self, element: Element) -> ElementId: ...
    def IsElementIdValueSupported(self, element: Element) -> bool: ...
    def GetAssociatedGlobalParameterValue(self, element: Element) -> ElementId: ...
    def Dispose(self) -> None: ...


class ParameterValueProvider(FilterableValueProvider):
    def __init__(self, parameter: ElementId): ...
    @property
    def Parameter(self) -> ElementId: ...
    @Parameter.setter
    def Parameter(self, parameter: ElementId) -> None: ...


class FilterValueRule(FilterRule):


class FilterStringRuleEvaluator:
    @property
    def IsValidObject(self) -> bool: ...
    def Evaluate(self, lhs: str, rhs: str, caseSensitive: bool) -> bool: ...
    def Dispose(self) -> None: ...


class FilterStringBeginsWith(FilterStringRuleEvaluator):
    def __init__(self): ...


class FilterStringEndsWith(FilterStringRuleEvaluator):
    def __init__(self): ...


class FilterStringContains(FilterStringRuleEvaluator):
    def __init__(self): ...


class FilterStringEquals(FilterStringRuleEvaluator):
    def __init__(self): ...


class FilterStringGreater(FilterStringRuleEvaluator):
    def __init__(self): ...


class FilterStringGreaterOrEqual(FilterStringRuleEvaluator):
    def __init__(self): ...


class FilterStringLess(FilterStringRuleEvaluator):
    def __init__(self): ...


class FilterStringLessOrEqual(FilterStringRuleEvaluator):
    def __init__(self): ...


class FilterStringRule(FilterValueRule):
    def __init__(self, valueProvider: FilterableValueProvider, evaluator: FilterStringRuleEvaluator, ruleString: str, caseSensitive: bool): ...
    @property
    def RuleString(self) -> str: ...
    @RuleString.setter
    def RuleString(self, ruleString: str) -> None: ...
    def GetEvaluator(self) -> FilterStringRuleEvaluator: ...
    def SetEvaluator(self, evaluator: FilterStringRuleEvaluator) -> None: ...


class FilterNumericRuleEvaluator:
    @property
    def IsValidObject(self) -> bool: ...
    @overload
    def Evaluate(self, lhs: int, rhs: int) -> bool: ...
    @overload
    def Evaluate(self, lhs: float, rhs: float, epsilon: float) -> bool: ...
    def Dispose(self) -> None: ...


class FilterNumericLess(FilterNumericRuleEvaluator):
    def __init__(self): ...


class FilterNumericLessOrEqual(FilterNumericRuleEvaluator):
    def __init__(self): ...


class FilterNumericGreater(FilterNumericRuleEvaluator):
    def __init__(self): ...


class FilterNumericGreaterOrEqual(FilterNumericRuleEvaluator):
    def __init__(self): ...


class FilterNumericEquals(FilterNumericRuleEvaluator):
    def __init__(self): ...


class FilterNumericValueRule(FilterValueRule):
    def GetEvaluator(self) -> FilterNumericRuleEvaluator: ...
    def SetEvaluator(self, evaluator: FilterNumericRuleEvaluator) -> None: ...


class FilterDoubleRule(FilterNumericValueRule):
    def __init__(self, valueProvider: FilterableValueProvider, evaluator: FilterNumericRuleEvaluator, ruleValue: float, epsilon: float): ...
    @property
    def RuleValue(self) -> float: ...
    @RuleValue.setter
    def RuleValue(self, ruleValue: float) -> None: ...
    @property
    def Epsilon(self) -> float: ...
    @Epsilon.setter
    def Epsilon(self, epsilon: float) -> None: ...


class FilterIntegerRule(FilterNumericValueRule):
    def __init__(self, valueProvider: FilterableValueProvider, evaluator: FilterNumericRuleEvaluator, ruleValue: int): ...
    @property
    def RuleValue(self) -> int: ...
    @RuleValue.setter
    def RuleValue(self, ruleValue: int) -> None: ...


class FilterElementIdRule(FilterNumericValueRule):
    def __init__(self, valueProvider: FilterableValueProvider, evaluator: FilterNumericRuleEvaluator, ruleValue: ElementId): ...
    @property
    def RuleValue(self) -> ElementId: ...
    @RuleValue.setter
    def RuleValue(self, ruleValue: ElementId) -> None: ...


class FilterGlobalParameterAssociationRule(FilterNumericValueRule):
    def __init__(self, valueProvider: FilterableValueProvider, evaluator: FilterNumericRuleEvaluator, ruleValue: ElementId): ...
    @property
    def RuleValue(self) -> ElementId: ...
    @RuleValue.setter
    def RuleValue(self, ruleValue: ElementId) -> None: ...


class FilterCategoryRule(FilterRule):
    def __init__(self, categories: ICollection): ...
    def GetCategories(self) -> ICollection: ...
    def SetCategories(self, categories: ICollection) -> bool: ...
    def AllCategoriesFilterable(categories: ICollection) -> bool: ...


class CurveElementFilter(ElementSlowFilter):
    @overload
    def __init__(self, curveElementType: CurveElementType, inverted: bool): ...
    @overload
    def __init__(self, curveElementType: CurveElementType): ...
    @property
    def CurveElementType(self) -> CurveElementType: ...


class ElementStructuralTypeFilter(ElementQuickFilter):
    @overload
    def __init__(self, structuralType: StructuralType, inverted: bool): ...
    @overload
    def __init__(self, structuralType: StructuralType): ...
    @property
    def StructuralType(self) -> StructuralType: ...


class FamilySymbolFilter(ElementQuickFilter):
    def __init__(self, familyId: ElementId): ...
    @property
    def FamilyId(self) -> ElementId: ...


class FamilyInstanceFilter(ElementSlowFilter):
    def __init__(self, document: Document, familySymbolId: ElementId): ...
    @property
    def FamilySymbolId(self) -> ElementId: ...


class PartMakerMethodToDivideVolumes:
    @property
    def ProfileMatch(self) -> PartEdgeConditionOrientation: ...
    @ProfileMatch.setter
    def ProfileMatch(self, profileMatch: PartEdgeConditionOrientation) -> None: ...
    @property
    def DivisionGap(self) -> float: ...
    @DivisionGap.setter
    def DivisionGap(self, divisionGap: float) -> None: ...
    @property
    def ProfileOffset(self) -> float: ...
    @ProfileOffset.setter
    def ProfileOffset(self, profileOffset: float) -> None: ...
    @property
    def ProfileType(self) -> ElementId: ...
    @ProfileType.setter
    def ProfileType(self, profileType: ElementId) -> None: ...
    @property
    def ProfileFlipAcross(self) -> bool: ...
    @ProfileFlipAcross.setter
    def ProfileFlipAcross(self, profileFlipAcross: bool) -> None: ...
    @property
    def ProfileFlipAlong(self) -> bool: ...
    @ProfileFlipAlong.setter
    def ProfileFlipAlong(self, profileFlipAlong: bool) -> None: ...
    @property
    def DivisionRuleId(self) -> ElementId: ...
    @DivisionRuleId.setter
    def DivisionRuleId(self, divisionRuleId: ElementId) -> None: ...
    @property
    def UConstDivisionIndent(self) -> int: ...
    @UConstDivisionIndent.setter
    def UConstDivisionIndent(self, uConstDivisionIndent: int) -> None: ...
    @property
    def VConstDivisionIndent(self) -> int: ...
    @VConstDivisionIndent.setter
    def VConstDivisionIndent(self, vConstDivisionIndent: int) -> None: ...
    @property
    def DivisionRotationAngle(self) -> float: ...
    @DivisionRotationAngle.setter
    def DivisionRotationAngle(self, divisionRotationAngle: float) -> None: ...
    @property
    def DivisionPatternMirror(self) -> bool: ...
    @DivisionPatternMirror.setter
    def DivisionPatternMirror(self, divisionPatternMirror: bool) -> None: ...
    @property
    def IsValidObject(self) -> bool: ...
    def GetSketchCurves(self) -> Tuple[List[Curve]]: ...
    def GetPlaneOfSketch(self) -> Plane: ...
    def GetSplitRefsOffsets(self) -> IDictionary: ...
    @overload
    def IsElementValidIntersectingReference(document: Document, elementId: ElementId) -> bool: ...
    @overload
    def IsElementValidIntersectingReference(self, elementId: ElementId) -> bool: ...
    @overload
    def AreElementsValidIntersectingReferences(document: Document, elementIds: ICollection) -> bool: ...
    @overload
    def AreElementsValidIntersectingReferences(self, elementIds: ICollection) -> bool: ...
    def IsValidSketchPlane(document: Document, sketchPlaneId: ElementId) -> bool: ...
    def UsesReference(self, intersectingReference: ElementId) -> bool: ...
    def SetOffsetForIntersectingReference(self, intersectingReference: ElementId, offset: float) -> None: ...
    def GetOffsetForIntersectingReference(self, intersectingReference: ElementId) -> float: ...
    def AddIntersectingReference(self, intersectingReference: ElementId, offset: float) -> bool: ...
    def RemoveIntersectingReference(self, intersectingReference: ElementId) -> bool: ...
    @overload
    def CanBeDivisionProfile(self, familyId: ElementId) -> bool: ...
    @overload
    def CanBeDivisionProfile(familyId: ElementId, familyDocument: Document) -> bool: ...
    def Dispose(self) -> None: ...


class BRepType:
    OpenShell = 0
    Solid = 1
    Void = 2


class BRepBuilderState:
    InvalidState = 0
    AcceptingData = 1
    Completed = 2


class BRepBuilderOutcome:
    Success = 0
    Failure = 1


class SortingOrder:
    Ascending = 1
    Descending = 2


class BrowserOrganizationType:
    Views = 0
    Sheets = 1
    Families = 2
    Schedules = 3


class PartEdgeConditionOrientation:
    Complement = 0
    Mirrored = 1
    MirroredAndRotated = 2


class LinkOperations:
    @property
    def IsValidObject(self) -> bool: ...
    def SetOnLocalLinkSharedCoordinatesSavedCallback(self, onLocalLinkSharedCoordinatesSaved: IOnLocalLinkSharedCoordinatesSavedCallback) -> None: ...
    def Dispose(self) -> None: ...


class CADLinkOperations(LinkOperations):


class CADLinkOptions:
    @overload
    def __init__(self, preserveOverrides: bool, viewId: ElementId): ...
    @overload
    def __init__(self, other: CADLinkOptions): ...
    @property
    def PreserveOverrides(self) -> bool: ...
    @PreserveOverrides.setter
    def PreserveOverrides(self, preserveOverrides: bool) -> None: ...
    @property
    def ViewId(self) -> ElementId: ...
    @ViewId.setter
    def ViewId(self, viewId: ElementId) -> None: ...
    @property
    def IsValidObject(self) -> bool: ...
    def Dispose(self) -> None: ...


class MEPSize:
    def __init__(self, nominalDiameter: float, innerDiameter: float, outerDiameter: float, usedInSizeLists: bool, usedInSizing: bool): ...
    @property
    def NominalDiameter(self) -> float: ...
    @property
    def InnerDiameter(self) -> float: ...
    @property
    def OuterDiameter(self) -> float: ...
    @property
    def UsedInSizeLists(self) -> bool: ...
    @property
    def UsedInSizing(self) -> bool: ...
    @property
    def IsValidObject(self) -> bool: ...
    def Dispose(self) -> None: ...


class CancellationListener:
    @property
    def IsValidObject(self) -> bool: ...
    def IsCancelled(self) -> bool: ...
    def Dispose(self) -> None: ...


class Ceiling(CeilingAndFloor):


class CeilingType(HostObjAttributes):
    @property
    def ThermalProperties(self) -> ThermalProperties: ...


class KeyBasedTreeEntry:
    @property
    def Key(self) -> str: ...
    @property
    def ParentKey(self) -> str: ...
    @property
    def IsValidObject(self) -> bool: ...
    def GetChildrenKeys(self) -> List[str]: ...
    def Dispose(self) -> None: ...


class KeyBasedTreeEntriesIterator:
    @property
    def IsValidObject(self) -> bool: ...
    def MoveNext(self) -> bool: ...
    def IsDone(self) -> bool: ...
    def Reset(self) -> None: ...
    @property
    def Current(self) -> KeyBasedTreeEntry: ...
    def Dispose(self) -> None: ...


class KeyBasedTreeEntries:
    @property
    def IsValidObject(self) -> bool: ...
    def FindEntry(self, key: str) -> KeyBasedTreeEntry: ...
    def GetKeyBasedTreeEntriesIterator(self) -> KeyBasedTreeEntriesIterator: ...
    def GetEnumerator(self) -> IEnumerator: ...
    def Dispose(self) -> None: ...


class ClassificationEntry(KeyBasedTreeEntry):
    def __init__(self, key: str, parentKey: str, description: str, level: int, categoryId: ElementId): ...
    @property
    def Level(self) -> int: ...
    @property
    def CategoryId(self) -> ElementId: ...
    @property
    def Description(self) -> str: ...
    def HasBadLevel(self) -> bool: ...
    def HasBadCategoryId(self) -> bool: ...
    def HasInvalidKey(self) -> bool: ...


class ClassificationEntries(KeyBasedTreeEntries):
    def LoadClassificationEntriesFromFile(filePath: str, loadContent: KeyBasedTreeEntriesLoadContent) -> bool: ...


class IExternalResourceServer:
    def SupportsExternalResourceType(self, type: ExternalResourceType) -> bool: ...
    def LoadResource(self, loadRequestId: Guid, resourceType: ExternalResourceType, desiredResource: ExternalResourceReference, loadContext: ExternalResourceLoadContext, loadResults: ExternalResourceLoadContent) -> None: ...
    def IsResourceWellFormed(self, extRef: ExternalResourceReference) -> bool: ...
    def GetInSessionPath(self, reference: ExternalResourceReference, originalDisplayPath: str) -> str: ...
    def GetResourceVersionStatus(self, reference: ExternalResourceReference) -> ResourceVersionStatus: ...
    def AreSameResources(self, reference1: IDictionary, reference2: IDictionary) -> bool: ...
    def SetupBrowserData(self, browseData: ExternalResourceBrowserData) -> None: ...
    def GetIconPath(self) -> str: ...
    def GetShortName(self) -> str: ...
    def GetTypeSpecificServerOperations(self, extensions: ExternalResourceServerExtensions) -> None: ...
    def GetInformationLink(self) -> str: ...


class ExternalResourceLoadContent:
    @property
    def Version(self) -> str: ...
    @Version.setter
    def Version(self, version: str) -> None: ...
    @property
    def LoadStatus(self) -> ExternalResourceLoadStatus: ...
    @LoadStatus.setter
    def LoadStatus(self, loadStatus: ExternalResourceLoadStatus) -> None: ...
    @property
    def IsValidObject(self) -> bool: ...
    def Dispose(self) -> None: ...


class KeyBasedTreeEntriesLoadContent(ExternalResourceLoadContent):
    def AddEntry(self, entry: KeyBasedTreeEntry) -> bool: ...
    def BuildEntries(self) -> None: ...
    def GetEntries(self) -> KeyBasedTreeEntries: ...
    def GetLoadResults(self) -> KeyBasedTreeEntriesLoadResults: ...
    def Reset(self) -> None: ...
    def IsEntriesBuilt(content: KeyBasedTreeEntriesLoadContent) -> bool: ...
    def CanAddEntry(self, entry: KeyBasedTreeEntry) -> bool: ...


class ColorOptions:
    @property
    def BackgroundColor(self) -> Color: ...
    @BackgroundColor.setter
    def BackgroundColor(self, value: Color) -> None: ...
    @property
    def SelectionColor(self) -> Color: ...
    @SelectionColor.setter
    def SelectionColor(self, value: Color) -> None: ...
    @property
    def SelectionSemitransparent(self) -> bool: ...
    @SelectionSemitransparent.setter
    def SelectionSemitransparent(self, value: bool) -> None: ...
    @property
    def PreselectionColor(self) -> Color: ...
    @PreselectionColor.setter
    def PreselectionColor(self, value: Color) -> None: ...
    @property
    def AlertColor(self) -> Color: ...
    @AlertColor.setter
    def AlertColor(self, value: Color) -> None: ...
    @property
    def CalculatingColor(self) -> Color: ...
    @CalculatingColor.setter
    def CalculatingColor(self, value: Color) -> None: ...
    @property
    def EditingColor(self) -> Color: ...
    @EditingColor.setter
    def EditingColor(self, value: Color) -> None: ...
    @property
    def IsValidObject(self) -> bool: ...
    def GetColorOptions() -> ColorOptions: ...
    def Dispose(self) -> None: ...


class ColorWithTransparency:
    @overload
    def __init__(self, red: UInt32, green: UInt32, blue: UInt32, transparency: UInt32): ...
    @overload
    def __init__(self): ...
    @property
    def IsValidObject(self) -> bool: ...
    def GetColor(self) -> Color: ...
    def SetColor(self, color: Color) -> None: ...
    def GetRed(self) -> UInt32: ...
    def SetRed(self, red: UInt32) -> None: ...
    def GetGreen(self) -> UInt32: ...
    def SetGreen(self, green: UInt32) -> None: ...
    def GetBlue(self) -> UInt32: ...
    def SetBlue(self, blue: UInt32) -> None: ...
    def GetTransparency(self) -> UInt32: ...
    def SetTransparency(self, transparency: UInt32) -> None: ...
    def Dispose(self) -> None: ...


class ColumnAttachment:
    @property
    def AttachOffset(self) -> float: ...
    @AttachOffset.setter
    def AttachOffset(self, attachOffset: float) -> None: ...
    @property
    def TargetId(self) -> ElementId: ...
    @property
    def BaseOrTop(self) -> int: ...
    @property
    def Justification(self) -> ColumnAttachmentJustification: ...
    @property
    def CutStyle(self) -> ColumnAttachmentCutStyle: ...
    @property
    def IsValidObject(self) -> bool: ...
    def IsValidColumn(familyInstance: FamilyInstance) -> bool: ...
    @overload
    def IsValidTarget(forSlantedColumn: bool, target: Element) -> bool: ...
    @overload
    def IsValidTarget(column: FamilyInstance, target: Element) -> bool: ...
    def AddColumnAttachment(doc: Document, column: FamilyInstance, target: Element, baseOrTop: int, cutColumnStyle: ColumnAttachmentCutStyle, justification: ColumnAttachmentJustification, attachOffset: float) -> None: ...
    @overload
    def GetColumnAttachment(column: FamilyInstance, targetId: ElementId) -> ColumnAttachment: ...
    @overload
    def GetColumnAttachment(column: FamilyInstance, baseOrTop: int) -> ColumnAttachment: ...
    @overload
    def RemoveColumnAttachment(column: FamilyInstance, targetId: ElementId) -> None: ...
    @overload
    def RemoveColumnAttachment(column: FamilyInstance, baseOrTop: int) -> None: ...
    def SetJustification(self, justification: ColumnAttachmentJustification) -> None: ...
    def Dispose(self) -> None: ...


class RepeatingReferenceSource:
    @property
    def DimensionCount(self) -> int: ...
    @property
    def IsValidObject(self) -> bool: ...
    def HasRepeatingReferenceSource(document: Document, elementId: ElementId) -> bool: ...
    def GetDefaultRepeatingReferenceSource(document: Document, elementId: ElementId) -> RepeatingReferenceSource: ...
    def GetBounds(self) -> RepeaterBounds: ...
    def GetReference(self, coordinates: RepeaterCoordinates) -> Reference: ...
    def Dispose(self) -> None: ...


class ComponentRepeater(Element):
    @property
    def DefaultFamilyType(self) -> ElementId: ...
    @DefaultFamilyType.setter
    def DefaultFamilyType(self, typeId: ElementId) -> None: ...
    @property
    def DimensionCount(self) -> int: ...
    def IsTypeValidForRepeater(self, typeId: ElementId) -> bool: ...
    def CanElementBeRepeated(ADoc: Document, elementId: ElementId) -> bool: ...
    def RepeatElements(document: Document, elementIds: ICollection) -> List[ComponentRepeater]: ...
    def RemoveRepeaters(document: Document, elementIds: ISet) -> ISet: ...
    def GetEnumerator(self) -> IEnumerator: ...


class ComponentRepeaterIterator:
    @property
    def IsValidObject(self) -> bool: ...
    def MoveNext(self) -> bool: ...
    def IsDone(self) -> bool: ...
    def Reset(self) -> None: ...
    def GetCurrent(self) -> ComponentRepeaterSlot: ...
    @property
    def Current(self) -> ComponentRepeaterSlot: ...
    def Dispose(self) -> None: ...


class ComponentRepeaterSlot(Element):
    @property
    def IsEmpty(self) -> bool: ...
    @property
    def IsDefault(self) -> bool: ...
    @property
    def FamilyType(self) -> ElementId: ...
    @FamilyType.setter
    def FamilyType(self, typeId: ElementId) -> None: ...
    def IsTypeValidForSlot(self, typeId: ElementId) -> bool: ...
    def MakeEmpty(self) -> None: ...
    def MakeDefault(self) -> None: ...


class ConicalSurface(Surface):
    @property
    def Axis(self) -> XYZ: ...
    @property
    def XDir(self) -> XYZ: ...
    @property
    def YDir(self) -> XYZ: ...
    @property
    def Origin(self) -> XYZ: ...
    @property
    def HalfAngle(self) -> float: ...
    def Create(frameOfReference: Frame, halfAngle: float) -> ConicalSurface: ...
    def GetFrameOfReference(self) -> Frame: ...
    def IsValidConeAngle(halfAngle: float) -> bool: ...


class Frame:
    @overload
    def __init__(self, origin: XYZ, vec1: XYZ, vec2: XYZ, vec3: XYZ): ...
    @overload
    def __init__(self): ...
    @property
    def Origin(self) -> XYZ: ...
    @Origin.setter
    def Origin(self, basePoint: XYZ) -> None: ...
    @property
    def BasisX(self) -> XYZ: ...
    @BasisX.setter
    def BasisX(self, firstBaseVector: XYZ) -> None: ...
    @property
    def BasisY(self) -> XYZ: ...
    @BasisY.setter
    def BasisY(self, secondBaseVector: XYZ) -> None: ...
    @property
    def BasisZ(self) -> XYZ: ...
    @BasisZ.setter
    def BasisZ(self, thirdBaseVector: XYZ) -> None: ...
    @property
    def IsValidObject(self) -> bool: ...
    def CanDefineRevitGeometry(frameOfReference: Frame) -> bool: ...
    def Transform(self, trf: Transform) -> None: ...
    def IsOrthogonal(self) -> bool: ...
    def IsOrthonormal(self) -> bool: ...
    def IsRightHanded(self) -> bool: ...
    def Dispose(self) -> None: ...


class FabricationConnectorInfo:
    @property
    def BodyConnectorId(self) -> int: ...
    @BodyConnectorId.setter
    def BodyConnectorId(self, bodyConnectorId: int) -> None: ...
    @property
    def IsBodyConnectorLocked(self) -> bool: ...
    @IsBodyConnectorLocked.setter
    def IsBodyConnectorLocked(self, lockIt: bool) -> None: ...
    @property
    def FabricationIndex(self) -> int: ...
    @property
    def DoubleWallConnectorId(self) -> int: ...
    @DoubleWallConnectorId.setter
    def DoubleWallConnectorId(self, doubleWallConnectorId: int) -> None: ...
    @property
    def IsDoubleWallConnectorLocked(self) -> bool: ...
    @IsDoubleWallConnectorLocked.setter
    def IsDoubleWallConnectorLocked(self, lockIt: bool) -> None: ...
    @property
    def IsValidObject(self) -> bool: ...
    def IsValid(self) -> bool: ...
    def HasDoubleWallConnector(self) -> bool: ...
    def Dispose(self) -> None: ...


class MEPConnectorInfo:
    @property
    def IsPrimary(self) -> bool: ...
    @property
    def IsSecondary(self) -> bool: ...
    @property
    def LinkedConnector(self) -> Connector: ...
    @property
    def IsValidObject(self) -> bool: ...
    def Dispose(self) -> None: ...


class InternalOrigin(Element):
    @property
    def Position(self) -> XYZ: ...
    @property
    def SharedPosition(self) -> XYZ: ...
    def Get(document: Document) -> InternalOrigin: ...


class CopyPasteOptions:
    def __init__(self): ...
    @property
    def IsValidObject(self) -> bool: ...
    def GetDuplicateTypeNamesHandler(self) -> IDuplicateTypeNamesHandler: ...
    def SetDuplicateTypeNamesHandler(self, handler: IDuplicateTypeNamesHandler) -> None: ...
    def Dispose(self) -> None: ...


class DuplicateTypeNamesHandlerArgs:
    @property
    def Document(self) -> Document: ...
    @property
    def IsValidObject(self) -> bool: ...
    def GetTypeIds(self) -> ICollection: ...
    def Dispose(self) -> None: ...


class IDuplicateTypeNamesHandler:
    def OnDuplicateTypeNamesFound(self, args: DuplicateTypeNamesHandlerArgs) -> DuplicateTypeAction: ...


class CurveByPointsUtils:
    @property
    def IsValidObject(self) -> bool: ...
    def GetProjectionType(curveElem: CurveElement) -> CurveProjectionType: ...
    def SetProjectionType(curveElem: CurveElement, value: CurveProjectionType) -> None: ...
    def GetSketchOnSurface(curveElem: CurveElement) -> bool: ...
    def SetSketchOnSurface(curveElem: CurveElement, sketchOnSurface: bool) -> None: ...
    def ValidateCurveElementIdArrayForFaceRegions(document: Document, curveElemIds: List[ElementId]) -> bool: ...
    def AddCurvesToFaceRegion(document: Document, curveElemIds: List[ElementId]) -> None: ...
    def GetHostFace(curveElem: CurveElement) -> Reference: ...
    def GetFaceRegions(cda: Document, referenceOfFace: Reference) -> List[Reference]: ...
    def CreateRectangle(document: Document, startPoint: ReferencePoint, endPoint: ReferencePoint, projectionType: CurveProjectionType, boundaryReferenceLines: bool, boundaryCurvesFollowSurface: bool) -> Tuple[List[ElementId], List[ElementId]]: ...
    def CreateArcThroughPoints(document: Document, startPoint: ReferencePoint, endPoint: ReferencePoint, interiorPoint: ReferencePoint) -> CurveElement: ...
    def Dispose(self) -> None: ...


class CustomExporter:
    def __init__(self, document: Document, context: IExportContext): ...
    @property
    def ShouldStopOnError(self) -> bool: ...
    @ShouldStopOnError.setter
    def ShouldStopOnError(self, shouldStopOnError: bool) -> None: ...
    @property
    def IncludeGeometricObjects(self) -> bool: ...
    @IncludeGeometricObjects.setter
    def IncludeGeometricObjects(self, includeGeometricObjects: bool) -> None: ...
    @property
    def Export2DGeometricObjectsIncludingPatternLines(self) -> bool: ...
    @Export2DGeometricObjectsIncludingPatternLines.setter
    def Export2DGeometricObjectsIncludingPatternLines(self, export2DGeometricObjectsIncludingPatternLines: bool) -> None: ...
    @property
    def Export2DIncludingAnnotationObjects(self) -> bool: ...
    @Export2DIncludingAnnotationObjects.setter
    def Export2DIncludingAnnotationObjects(self, export2DIncludingAnnotationObjects: bool) -> None: ...
    @property
    def Export2DForceDisplayStyle(self) -> DisplayStyle: ...
    @Export2DForceDisplayStyle.setter
    def Export2DForceDisplayStyle(self, export2DForceDisplayStyle: DisplayStyle) -> None: ...
    @property
    def IsValidObject(self) -> bool: ...
    @overload
    def Export(self, viewIds: List[ElementId]) -> None: ...
    @overload
    def Export(self, view: View) -> None: ...
    def IsRenderingSupported() -> bool: ...
    def Dispose(self) -> None: ...


class IExportContext:
    def Start(self) -> bool: ...
    def Finish(self) -> None: ...
    def IsCanceled(self) -> bool: ...
    def OnViewBegin(self, node: ViewNode) -> RenderNodeAction: ...
    def OnViewEnd(self, elementId: ElementId) -> None: ...
    def OnElementBegin(self, elementId: ElementId) -> RenderNodeAction: ...
    def OnElementEnd(self, elementId: ElementId) -> None: ...
    def OnInstanceBegin(self, node: InstanceNode) -> RenderNodeAction: ...
    def OnInstanceEnd(self, node: InstanceNode) -> None: ...
    def OnLinkBegin(self, node: LinkNode) -> RenderNodeAction: ...
    def OnLinkEnd(self, node: LinkNode) -> None: ...
    def OnFaceBegin(self, node: FaceNode) -> RenderNodeAction: ...
    def OnFaceEnd(self, node: FaceNode) -> None: ...
    def OnRPC(self, node: RPCNode) -> None: ...
    def OnLight(self, node: LightNode) -> None: ...
    def OnMaterial(self, node: MaterialNode) -> None: ...
    def OnPolymesh(self, node: PolymeshTopology) -> None: ...


class IPhotoRenderContext:


class IExportContextBase:
    def OnCurve(self, node: CurveNode) -> RenderNodeAction: ...
    def OnPolyline(self, node: PolylineNode) -> RenderNodeAction: ...
    def OnLineSegment(self, segment: LineSegment) -> None: ...
    def OnPolylineSegments(self, segments: PolylineSegments) -> None: ...
    def OnText(self, node: TextNode) -> None: ...


class IModelExportContext:
    def OnPoint(self, node: PointNode) -> RenderNodeAction: ...


class IExportContext2D:
    def OnElementBegin2D(self, node: ElementNode) -> RenderNodeAction: ...
    def OnElementEnd2D(self, node: ElementNode) -> None: ...
    def OnFaceEdge2D(self, node: FaceEdgeNode) -> RenderNodeAction: ...
    def OnFaceSilhouette2D(self, node: FaceSilhouetteNode) -> RenderNodeAction: ...


class CylindricalSurface(Surface):
    @property
    def Axis(self) -> XYZ: ...
    @property
    def XDir(self) -> XYZ: ...
    @property
    def YDir(self) -> XYZ: ...
    @property
    def Origin(self) -> XYZ: ...
    @property
    def Radius(self) -> float: ...
    def Create(frameOfReference: Frame, radius: float) -> CylindricalSurface: ...
    def GetFrameOfReference(self) -> Frame: ...


class CheckoutStatus:
    OwnedByCurrentUser = 0
    OwnedByOtherUser = 1
    NotOwned = 2


class ColumnAttachmentJustification:
    Minimum = 0
    Midpoint = 1
    Maximum = 2
    Tangent = 3


class ColumnAttachmentCutStyle:
    CutColumn = 0
    CutTarget = 1
    #None = 2


class DuplicateTypeAction:
    UseDestinationTypes = 1
    Abort = 2


class CurveProjectionType:
    FromTopDown = 0
    ParallelToLevel = 1
    FollowSurfaceUV = 2


class RenderNodeAction:
    Proceed = 0
    Skip = 1


class OverrideGraphicSettings:
    @overload
    def __init__(self, overrideGraphicSettings: OverrideGraphicSettings): ...
    @overload
    def __init__(self): ...
    @property
    def Halftone(self) -> bool: ...
    @property
    def DetailLevel(self) -> ViewDetailLevel: ...
    @property
    def ProjectionLineWeight(self) -> int: ...
    @property
    def ProjectionLineColor(self) -> Color: ...
    @property
    def ProjectionLinePatternId(self) -> ElementId: ...
    @property
    def Transparency(self) -> int: ...
    @property
    def CutLineWeight(self) -> int: ...
    @property
    def CutLineColor(self) -> Color: ...
    @property
    def CutLinePatternId(self) -> ElementId: ...
    @property
    def IsSurfaceForegroundPatternVisible(self) -> bool: ...
    @property
    def IsSurfaceBackgroundPatternVisible(self) -> bool: ...
    @property
    def IsCutForegroundPatternVisible(self) -> bool: ...
    @property
    def IsCutBackgroundPatternVisible(self) -> bool: ...
    @property
    def SurfaceForegroundPatternColor(self) -> Color: ...
    @property
    def SurfaceBackgroundPatternColor(self) -> Color: ...
    @property
    def CutForegroundPatternColor(self) -> Color: ...
    @property
    def CutBackgroundPatternColor(self) -> Color: ...
    @property
    def SurfaceForegroundPatternId(self) -> ElementId: ...
    @property
    def SurfaceBackgroundPatternId(self) -> ElementId: ...
    @property
    def CutForegroundPatternId(self) -> ElementId: ...
    @property
    def CutBackgroundPatternId(self) -> ElementId: ...
    @property
    def InvalidPenNumber() -> int: ...
    @property
    def IsValidObject(self) -> bool: ...
    def SetHalftone(self, halftone: bool) -> OverrideGraphicSettings: ...
    def SetDetailLevel(self, detailLevel: ViewDetailLevel) -> OverrideGraphicSettings: ...
    def SetProjectionLineWeight(self, lineWeight: int) -> OverrideGraphicSettings: ...
    def SetProjectionLineColor(self, color: Color) -> OverrideGraphicSettings: ...
    def SetProjectionLinePatternId(self, linePatternId: ElementId) -> OverrideGraphicSettings: ...
    def SetSurfaceTransparency(self, transparency: int) -> OverrideGraphicSettings: ...
    def SetCutLineWeight(self, lineWeight: int) -> OverrideGraphicSettings: ...
    def SetCutLineColor(self, color: Color) -> OverrideGraphicSettings: ...
    def SetCutLinePatternId(self, linePatternId: ElementId) -> OverrideGraphicSettings: ...
    def SetSurfaceForegroundPatternVisible(self, fillPatternVisible: bool) -> OverrideGraphicSettings: ...
    def SetSurfaceBackgroundPatternVisible(self, fillPatternVisible: bool) -> OverrideGraphicSettings: ...
    def SetCutForegroundPatternVisible(self, fillPatternVisible: bool) -> OverrideGraphicSettings: ...
    def SetCutBackgroundPatternVisible(self, fillPatternVisible: bool) -> OverrideGraphicSettings: ...
    def SetSurfaceForegroundPatternColor(self, color: Color) -> OverrideGraphicSettings: ...
    def SetSurfaceBackgroundPatternColor(self, color: Color) -> OverrideGraphicSettings: ...
    def SetCutForegroundPatternColor(self, color: Color) -> OverrideGraphicSettings: ...
    def SetCutBackgroundPatternColor(self, color: Color) -> OverrideGraphicSettings: ...
    def SetSurfaceForegroundPatternId(self, fillPatternId: ElementId) -> OverrideGraphicSettings: ...
    def SetSurfaceBackgroundPatternId(self, fillPatternId: ElementId) -> OverrideGraphicSettings: ...
    def SetCutForegroundPatternId(self, fillPatternId: ElementId) -> OverrideGraphicSettings: ...
    def SetCutBackgroundPatternId(self, fillPatternId: ElementId) -> OverrideGraphicSettings: ...
    def Dispose(self) -> None: ...


class TemporaryViewModes(APIObject):
    @property
    def PreviewFamilyVisibility(self) -> PreviewFamilyVisibilityMode: ...
    @PreviewFamilyVisibility.setter
    def PreviewFamilyVisibility(self, state: PreviewFamilyVisibilityMode) -> None: ...
    @property
    def PreviewFamilyVisibilityDefaultOnState() -> bool: ...
    @PreviewFamilyVisibilityDefaultOnState.setter
    def PreviewFamilyVisibilityDefaultOnState(state: bool) -> None: ...
    @property
    def PreviewFamilyVisibilityDefaultUncutState() -> bool: ...
    @PreviewFamilyVisibilityDefaultUncutState.setter
    def PreviewFamilyVisibilityDefaultUncutState(state: bool) -> None: ...
    @property
    def RevealConstraints(self) -> bool: ...
    @RevealConstraints.setter
    def RevealConstraints(self, state: bool) -> None: ...
    @property
    def WorksharingDisplay(self) -> WorksharingDisplayMode: ...
    @WorksharingDisplay.setter
    def WorksharingDisplay(self, state: WorksharingDisplayMode) -> None: ...
    @property
    def RevealHiddenElements(self) -> bool: ...
    @RevealHiddenElements.setter
    def RevealHiddenElements(self, state: bool) -> None: ...
    @property
    def CustomTitle(self) -> str: ...
    @CustomTitle.setter
    def CustomTitle(self, value: str) -> None: ...
    @property
    def CustomColor(self) -> Color: ...
    @CustomColor.setter
    def CustomColor(self, value: Color) -> None: ...
    @property
    def IsValidObject(self) -> bool: ...
    def GetCaption(self, mode: TemporaryViewMode) -> str: ...
    def IsModeActive(self, mode: TemporaryViewMode) -> bool: ...
    def DeactivateMode(self, mode: TemporaryViewMode) -> None: ...
    def DeactivateAllModes(self) -> None: ...
    def IsModeAvailable(self, mode: TemporaryViewMode) -> bool: ...
    def IsModeEnabled(self, mode: TemporaryViewMode) -> bool: ...
    def IsValidState(self, state: PreviewFamilyVisibilityMode) -> bool: ...
    def RemoveCustomization(self) -> None: ...
    def IsCustomized(self) -> bool: ...


class TransformWithBoundary:
    def __init__(self, other: TransformWithBoundary): ...
    @property
    def IsValidObject(self) -> bool: ...
    def Dispose(self) -> None: ...


class ViewCropRegionShapeManager:
    @property
    def CanHaveShape(self) -> bool: ...
    @property
    def CanBeSplit(self) -> bool: ...
    @property
    def Split(self) -> bool: ...
    @property
    def ShapeSet(self) -> bool: ...
    @property
    def NumberOfSplitRegions(self) -> int: ...
    @property
    def IsSplitHorizontally(self) -> bool: ...
    @property
    def IsSplitVertically(self) -> bool: ...
    @property
    def CanHaveAnnotationCrop(self) -> bool: ...
    @property
    def TopAnnotationCropOffset(self) -> float: ...
    @TopAnnotationCropOffset.setter
    def TopAnnotationCropOffset(self, offset: float) -> None: ...
    @property
    def BottomAnnotationCropOffset(self) -> float: ...
    @BottomAnnotationCropOffset.setter
    def BottomAnnotationCropOffset(self, offset: float) -> None: ...
    @property
    def LeftAnnotationCropOffset(self) -> float: ...
    @LeftAnnotationCropOffset.setter
    def LeftAnnotationCropOffset(self, offset: float) -> None: ...
    @property
    def RightAnnotationCropOffset(self) -> float: ...
    @RightAnnotationCropOffset.setter
    def RightAnnotationCropOffset(self, offset: float) -> None: ...
    @property
    def IsValidObject(self) -> bool: ...
    def IsCropRegionShapeValid(self, boundary: CurveLoop) -> bool: ...
    def SetCropShape(self, boundary: CurveLoop) -> None: ...
    def RemoveCropRegionShape(self) -> None: ...
    def RemoveSplit(self) -> None: ...
    def RemoveSplitRegion(self, regionIndex: int) -> None: ...
    def SplitRegionVertically(self, regionIndex: int, topPart: float, bottomPart: float) -> None: ...
    def SplitRegionHorizontally(self, regionIndex: int, leftPart: float, rightPart: float) -> None: ...
    def GetSplitRegionMinimum(self, regionIndex: int) -> float: ...
    def GetSplitRegionMaximum(self, regionIndex: int) -> float: ...
    def GetSplitRegionOffset(self, regionIndex: int) -> XYZ: ...
    def GetCropShape(self) -> List[CurveLoop]: ...
    def GetAnnotationCropShape(self) -> CurveLoop: ...
    def Dispose(self) -> None: ...


class ViewDisplayBackground:
    @property
    def Type(self) -> ViewDisplayBackgroundType: ...
    @property
    def GroundColor(self) -> Color: ...
    @property
    def BackgroundColor(self) -> Color: ...
    @property
    def SkyColor(self) -> Color: ...
    @property
    def ImagePath(self) -> str: ...
    @property
    def ImageFlags(self) -> ViewDisplayBackgroundImageFlags: ...
    @property
    def HorizontalImageOffset(self) -> float: ...
    @property
    def VerticalImageOffset(self) -> float: ...
    @property
    def HorizontalImageScale(self) -> float: ...
    @property
    def VerticalImageScale(self) -> float: ...
    @property
    def IsValidObject(self) -> bool: ...
    def CreateGradient(skyColor: Color, horizonColor: Color, groundColor: Color) -> ViewDisplayBackground: ...
    def CreateImage(imagePath: str, flags: ViewDisplayBackgroundImageFlags, imageOffsets: UV, imageScales: UV) -> ViewDisplayBackground: ...
    def CreateSky() -> ViewDisplayBackground: ...
    def Dispose(self) -> None: ...


class ViewDisplayDepthCueing:
    @property
    def EnableDepthCueing(self) -> bool: ...
    @EnableDepthCueing.setter
    def EnableDepthCueing(self, enableDepthCueing: bool) -> None: ...
    @property
    def StartPercentage(self) -> int: ...
    @property
    def EndPercentage(self) -> int: ...
    @property
    def FadeTo(self) -> int: ...
    @FadeTo.setter
    def FadeTo(self, fadeTo: int) -> None: ...
    @property
    def IsValidObject(self) -> bool: ...
    def SetStartEndPercentages(self, startPercentage: int, endPercentage: int) -> None: ...
    def Dispose(self) -> None: ...


class ViewDisplaySketchyLines:
    @property
    def Jitter(self) -> int: ...
    @Jitter.setter
    def Jitter(self, jitter: int) -> None: ...
    @property
    def EnableSketchyLines(self) -> bool: ...
    @EnableSketchyLines.setter
    def EnableSketchyLines(self, enableSketchyLines: bool) -> None: ...
    @property
    def Extension(self) -> int: ...
    @Extension.setter
    def Extension(self, extension: int) -> None: ...
    @property
    def IsValidObject(self) -> bool: ...
    def Dispose(self) -> None: ...


class ViewDisplayModel:
    @property
    def Transparency(self) -> int: ...
    @Transparency.setter
    def Transparency(self, transparency: int) -> None: ...
    @property
    def EnableSilhouettes(self) -> bool: ...
    @EnableSilhouettes.setter
    def EnableSilhouettes(self, enableSilhouettes: bool) -> None: ...
    @property
    def SilhouetteEdgesGStyleId(self) -> ElementId: ...
    @SilhouetteEdgesGStyleId.setter
    def SilhouetteEdgesGStyleId(self, silhouetteEdgesGStyleId: ElementId) -> None: ...
    @property
    def ShowHiddenLines(self) -> ShowHiddenLinesValues: ...
    @ShowHiddenLines.setter
    def ShowHiddenLines(self, ShowHiddenLines: ShowHiddenLinesValues) -> None: ...
    @property
    def SmoothEdges(self) -> bool: ...
    @SmoothEdges.setter
    def SmoothEdges(self, smoothEdges: bool) -> None: ...
    @property
    def IsValidObject(self) -> bool: ...
    def Dispose(self) -> None: ...


class RenderingQualitySettings:
    @property
    def RenderingQuality(self) -> RenderingQuality: ...
    @RenderingQuality.setter
    def RenderingQuality(self, value: RenderingQuality) -> None: ...
    @property
    def LightAndMaterialAccuracyMode(self) -> LightAndMaterialAccuracyMode: ...
    @LightAndMaterialAccuracyMode.setter
    def LightAndMaterialAccuracyMode(self, value: LightAndMaterialAccuracyMode) -> None: ...
    @property
    def RenderDuration(self) -> RenderDuration: ...
    @RenderDuration.setter
    def RenderDuration(self, value: RenderDuration) -> None: ...
    @property
    def RenderLevel(self) -> int: ...
    @RenderLevel.setter
    def RenderLevel(self, value: int) -> None: ...
    @property
    def RenderTime(self) -> int: ...
    @RenderTime.setter
    def RenderTime(self, value: int) -> None: ...
    @property
    def IsValidObject(self) -> bool: ...
    def IsValidRenderLevel(self, value: int) -> bool: ...
    def IsValidRenderTime(self, value: int) -> bool: ...
    def IsCustomQuality(self) -> bool: ...
    def Dispose(self) -> None: ...


class BackgroundSettings:
    @property
    def IsValidObject(self) -> bool: ...
    def Dispose(self) -> None: ...


class SkyBackgroundSettings(BackgroundSettings):


class ColorBackgroundSettings(BackgroundSettings):
    @property
    def Color(self) -> Color: ...
    @Color.setter
    def Color(self, color: Color) -> None: ...


class GradientBackgroundSettings(BackgroundSettings):
    @property
    def SkyColor(self) -> Color: ...
    @SkyColor.setter
    def SkyColor(self, skyColor: Color) -> None: ...
    @property
    def HorizonColor(self) -> Color: ...
    @HorizonColor.setter
    def HorizonColor(self, horizonColor: Color) -> None: ...
    @property
    def GroundColor(self) -> Color: ...
    @GroundColor.setter
    def GroundColor(self, groundColor: Color) -> None: ...


class ImageBackgroundSettings(BackgroundSettings):
    @property
    def FilePath(self) -> str: ...
    @FilePath.setter
    def FilePath(self, path: str) -> None: ...
    @property
    def BackgroundImageFit(self) -> BackgroundImageFit: ...
    @BackgroundImageFit.setter
    def BackgroundImageFit(self, imageFit: BackgroundImageFit) -> None: ...
    @property
    def OffsetWidth(self) -> float: ...
    @OffsetWidth.setter
    def OffsetWidth(self, width: float) -> None: ...
    @property
    def OffsetHeight(self) -> float: ...
    @OffsetHeight.setter
    def OffsetHeight(self, height: float) -> None: ...


class RenderingImageExposureSettings:
    @property
    def ExposureValue(self) -> float: ...
    @ExposureValue.setter
    def ExposureValue(self, exposureValue: float) -> None: ...
    @property
    def Highlights(self) -> float: ...
    @Highlights.setter
    def Highlights(self, highlights: float) -> None: ...
    @property
    def Shadows(self) -> float: ...
    @Shadows.setter
    def Shadows(self, shadows: float) -> None: ...
    @property
    def WhitePoint(self) -> float: ...
    @WhitePoint.setter
    def WhitePoint(self, whitePoint: float) -> None: ...
    @property
    def Saturation(self) -> float: ...
    @Saturation.setter
    def Saturation(self, saturation: float) -> None: ...
    @property
    def IsValidObject(self) -> bool: ...
    def Dispose(self) -> None: ...


class RenderingSettings:
    @property
    def UsesRegionRendering(self) -> bool: ...
    @UsesRegionRendering.setter
    def UsesRegionRendering(self, UsesRegionRendering: bool) -> None: ...
    @property
    def BackgroundStyle(self) -> BackgroundStyle: ...
    @BackgroundStyle.setter
    def BackgroundStyle(self, background: BackgroundStyle) -> None: ...
    @property
    def ResolutionTarget(self) -> ResolutionTarget: ...
    @ResolutionTarget.setter
    def ResolutionTarget(self, value: ResolutionTarget) -> None: ...
    @property
    def PrinterResolution(self) -> PrinterResolution: ...
    @PrinterResolution.setter
    def PrinterResolution(self, value: PrinterResolution) -> None: ...
    @property
    def LightingSource(self) -> LightingSource: ...
    @LightingSource.setter
    def LightingSource(self, value: LightingSource) -> None: ...
    @property
    def ResolutionValue(self) -> int: ...
    @property
    def IsValidObject(self) -> bool: ...
    def GetBackgroundSettings(self) -> BackgroundSettings: ...
    def SetBackgroundSettings(self, background: BackgroundSettings) -> None: ...
    def GetRenderingImageExposureSettings(self) -> RenderingImageExposureSettings: ...
    def SetRenderingImageExposureSettings(self, exposure: RenderingImageExposureSettings) -> None: ...
    def GetRenderingQualitySettings(self) -> RenderingQualitySettings: ...
    def SetRenderingQualitySettings(self, settings: RenderingQualitySettings) -> None: ...
    def GetRenderingRegionOutline(self) -> Outline: ...
    def Dispose(self) -> None: ...


class PlanViewRange:
    @property
    def Unlimited() -> ElementId: ...
    @property
    def LevelAbove() -> ElementId: ...
    @property
    def LevelBelow() -> ElementId: ...
    @property
    def Current() -> ElementId: ...
    @property
    def IsValidObject(self) -> bool: ...
    def GetLevelId(self, planViewPlane: PlanViewPlane) -> ElementId: ...
    def SetLevelId(self, planViewPlane: PlanViewPlane, id: ElementId) -> None: ...
    def GetOffset(self, planViewPlane: PlanViewPlane) -> float: ...
    def SetOffset(self, planViewPlane: PlanViewPlane, offset: float) -> None: ...
    def Dispose(self) -> None: ...


class ImageView(ViewDrafting):
    @property
    def ImageInstanceId(self) -> ElementId: ...
    def Create(document: Document, options: ImageTypeOptions) -> ImageView: ...


class ImageTypeOptions:
    @overload
    def __init__(self, resourceReference: ExternalResourceReference, sourceType: ImageTypeSource): ...
    @overload
    def __init__(self, path: str, useRelativePath: bool, sourceType: ImageTypeSource): ...
    @overload
    def __init__(self, path: str, useRelativePath: bool): ...
    @overload
    def __init__(self, path: str): ...
    @overload
    def __init__(self): ...
    @property
    def Path(self) -> str: ...
    @property
    def PageNumber(self) -> int: ...
    @PageNumber.setter
    def PageNumber(self, pageNumber: int) -> None: ...
    @property
    def Resolution(self) -> float: ...
    @Resolution.setter
    def Resolution(self, resolution: float) -> None: ...
    @property
    def SourceType(self) -> ImageTypeSource: ...
    @SourceType.setter
    def SourceType(self, sourceType: ImageTypeSource) -> None: ...
    @property
    def IsValidObject(self) -> bool: ...
    @overload
    def SetPath(self, path: str, useRelativePath: bool) -> None: ...
    @overload
    def SetPath(self, path: str) -> None: ...
    def SetExternalResourceReference(self, resourceReference: ExternalResourceReference) -> None: ...
    def IsValid(self, document: Document) -> bool: ...
    def Dispose(self) -> None: ...


class ScheduleDefinition:
    @property
    def CategoryId(self) -> ElementId: ...
    @property
    def AreaSchemeId(self) -> ElementId: ...
    @property
    def FamilyId(self) -> ElementId: ...
    @property
    def IsKeySchedule(self) -> bool: ...
    @property
    def IsMaterialTakeoff(self) -> bool: ...
    @property
    def IncludeLinkedFiles(self) -> bool: ...
    @IncludeLinkedFiles.setter
    def IncludeLinkedFiles(self, includeLinkedFiles: bool) -> None: ...
    @property
    def IsItemized(self) -> bool: ...
    @IsItemized.setter
    def IsItemized(self, isItemized: bool) -> None: ...
    @property
    def EmbeddedDefinition(self) -> ScheduleDefinition: ...
    @property
    def HasEmbeddedSchedule(self) -> bool: ...
    @property
    def IsEmbedded(self) -> bool: ...
    @property
    def ShowGrandTotal(self) -> bool: ...
    @ShowGrandTotal.setter
    def ShowGrandTotal(self, showGrandTotal: bool) -> None: ...
    @property
    def ShowGrandTotalTitle(self) -> bool: ...
    @ShowGrandTotalTitle.setter
    def ShowGrandTotalTitle(self, showGrandTotalTitle: bool) -> None: ...
    @property
    def ShowGrandTotalCount(self) -> bool: ...
    @ShowGrandTotalCount.setter
    def ShowGrandTotalCount(self, showGrandTotalCount: bool) -> None: ...
    @property
    def GrandTotalTitle(self) -> str: ...
    @GrandTotalTitle.setter
    def GrandTotalTitle(self, grandTotalTitle: str) -> None: ...
    @property
    def ShowTitle(self) -> bool: ...
    @ShowTitle.setter
    def ShowTitle(self, showTitle: bool) -> None: ...
    @property
    def ShowHeaders(self) -> bool: ...
    @ShowHeaders.setter
    def ShowHeaders(self, showHeaders: bool) -> None: ...
    @property
    def ShowGridLines(self) -> bool: ...
    @ShowGridLines.setter
    def ShowGridLines(self, showGridLines: bool) -> None: ...
    @property
    def IsValidObject(self) -> bool: ...
    def CanIncludeLinkedFiles(self) -> bool: ...
    def AddEmbeddedSchedule(self, categoryId: ElementId) -> None: ...
    def RemoveEmbeddedSchedule(self) -> None: ...
    def CanHaveEmbeddedSchedule(self) -> bool: ...
    def IsValidCategoryForEmbeddedSchedule(self, categoryId: ElementId) -> bool: ...
    def GetValidCategoriesForEmbeddedSchedule(self) -> ICollection: ...
    def GetFieldCount(self) -> int: ...
    @overload
    def AddField(self, fieldType: ScheduleFieldType, parameterId: ElementId) -> ScheduleField: ...
    @overload
    def AddField(self, fieldType: ScheduleFieldType) -> ScheduleField: ...
    @overload
    def AddField(self, schedulableField: SchedulableField) -> ScheduleField: ...
    @overload
    def InsertField(self, fieldType: ScheduleFieldType, parameterId: ElementId, index: int) -> ScheduleField: ...
    @overload
    def InsertField(self, fieldType: ScheduleFieldType, index: int) -> ScheduleField: ...
    @overload
    def InsertField(self, schedulableField: SchedulableField, index: int) -> ScheduleField: ...
    def IsValidCombinedParameters(self, data: List[TableCellCombinedParameterData]) -> bool: ...
    def InsertCombinedParameterField(self, data: List[TableCellCombinedParameterData], fieldName: str, index: int) -> ScheduleField: ...
    @overload
    def RemoveField(self, fieldId: ScheduleFieldId) -> None: ...
    @overload
    def RemoveField(self, index: int) -> None: ...
    def ClearFields(self) -> None: ...
    @overload
    def GetField(self, fieldId: ScheduleFieldId) -> ScheduleField: ...
    @overload
    def GetField(self, index: int) -> ScheduleField: ...
    def GetFieldOrder(self) -> List[ScheduleFieldId]: ...
    def SetFieldOrder(self, fieldIds: List[ScheduleFieldId]) -> None: ...
    def GetFieldId(self, index: int) -> ScheduleFieldId: ...
    def GetFieldIndex(self, fieldId: ScheduleFieldId) -> int: ...
    def IsValidFieldIndex(self, index: int) -> bool: ...
    def IsValidFieldId(self, fieldId: ScheduleFieldId) -> bool: ...
    def GetSortGroupFieldCount(self) -> int: ...
    def AddSortGroupField(self, sortGroupField: ScheduleSortGroupField) -> None: ...
    def InsertSortGroupField(self, sortGroupField: ScheduleSortGroupField, index: int) -> None: ...
    def RemoveSortGroupField(self, index: int) -> None: ...
    def ClearSortGroupFields(self) -> None: ...
    def GetSortGroupField(self, index: int) -> ScheduleSortGroupField: ...
    def SetSortGroupField(self, index: int, sortGroupField: ScheduleSortGroupField) -> None: ...
    def GetSortGroupFields(self) -> List[ScheduleSortGroupField]: ...
    def SetSortGroupFields(self, sortGroupFields: List[ScheduleSortGroupField]) -> None: ...
    def CanSortByField(self, fieldId: ScheduleFieldId) -> bool: ...
    def GetFilterCount(self) -> int: ...
    def AddFilter(self, filter: ScheduleFilter) -> None: ...
    def InsertFilter(self, filter: ScheduleFilter, index: int) -> None: ...
    def RemoveFilter(self, index: int) -> None: ...
    def ClearFilters(self) -> None: ...
    def GetFilter(self, index: int) -> ScheduleFilter: ...
    def SetFilter(self, index: int, filter: ScheduleFilter) -> None: ...
    def GetFilters(self) -> List[ScheduleFilter]: ...
    def SetFilters(self, filters: List[ScheduleFilter]) -> None: ...
    def CanFilter(self) -> bool: ...
    def CanFilterByParameterExistence(self, fieldId: ScheduleFieldId) -> bool: ...
    def CanFilterByValue(self, fieldId: ScheduleFieldId) -> bool: ...
    def CanFilterByValuePresence(self, fieldId: ScheduleFieldId) -> bool: ...
    def CanFilterBySubstring(self, fieldId: ScheduleFieldId) -> bool: ...
    def CanFilterByGlobalParameters(self, fieldId: ScheduleFieldId) -> bool: ...
    def GetSchedulableFields(self) -> List[SchedulableField]: ...
    def IsSchedulableField(self, schedulableField: SchedulableField) -> bool: ...
    def Dispose(self) -> None: ...


class ViewScheduleExportOptions:
    @overload
    def __init__(self): ...
    @overload
    def __init__(self, other: ViewScheduleExportOptions): ...
    @property
    def TextQualifier(self) -> ExportTextQualifier: ...
    @TextQualifier.setter
    def TextQualifier(self, textQualifier: ExportTextQualifier) -> None: ...
    @property
    def ColumnHeaders(self) -> ExportColumnHeaders: ...
    @ColumnHeaders.setter
    def ColumnHeaders(self, columnHeaders: ExportColumnHeaders) -> None: ...
    @property
    def FieldDelimiter(self) -> str: ...
    @FieldDelimiter.setter
    def FieldDelimiter(self, fieldDelimiter: str) -> None: ...
    @property
    def HeadersFootersBlanks(self) -> bool: ...
    @HeadersFootersBlanks.setter
    def HeadersFootersBlanks(self, headersFootersBlanks: bool) -> None: ...
    @property
    def Title(self) -> bool: ...
    @Title.setter
    def Title(self, title: bool) -> None: ...
    @property
    def IsValidObject(self) -> bool: ...
    def Dispose(self) -> None: ...


class ViewFamilyType(ElementType):
    @property
    def PlanViewDirection(self) -> PlanViewDirection: ...
    @PlanViewDirection.setter
    def PlanViewDirection(self, planViewDirection: PlanViewDirection) -> None: ...
    @property
    def DefaultTemplateId(self) -> ElementId: ...
    @DefaultTemplateId.setter
    def DefaultTemplateId(self, val: ElementId) -> None: ...
    @property
    def ViewFamily(self) -> ViewFamily: ...
    def IsValidDefaultTemplate(self, templateId: ElementId) -> bool: ...


class Part(Element):
    @property
    def OriginalCategoryId(self) -> ElementId: ...
    @OriginalCategoryId.setter
    def OriginalCategoryId(self, OriginalCategoryId: ElementId) -> None: ...
    @property
    def Excluded(self) -> bool: ...
    @Excluded.setter
    def Excluded(self, excluded: bool) -> None: ...
    @property
    def PartMaker(self) -> PartMaker: ...
    def CanOffsetFace(self, face: Face) -> bool: ...
    def SetFaceOffset(self, face: Face, offset: float) -> None: ...
    def GetFaceOffset(self, face: Face) -> float: ...
    def ResetPartShape(self) -> None: ...
    def ResetFaceOffset(self, face: Face) -> None: ...
    def GetSourceElementIds(self) -> ICollection: ...
    def GetSourceElementOriginalCategoryIds(self) -> ICollection: ...


class PartMaker(Element):
    def IsSourceElement(self, elemId: ElementId) -> bool: ...
    def GetSourceElementIds(self) -> ICollection: ...
    def SetSourceElementIds(self, sourceElementIds: ICollection) -> None: ...


class DataConversionMonitorScope:
    def __init__(self, IDCM: IDataConversionMonitor): ...
    @property
    def IsValidObject(self) -> bool: ...
    def Dispose(self) -> None: ...


class IDataConversionMonitor:
    def ProcessMessage(self, messageId: DataExchangeMessageId, messageSeverity: DataExchangeMessageSeverity, entityIds: List[str]) -> bool: ...
    def GetVerbosity(self) -> DataExchangeMessageVerbosity: ...


class DefaultDivideSettings(Element):
    @property
    def PathLayout(self) -> SpacingRuleLayout: ...
    @PathLayout.setter
    def PathLayout(self, pathLayout: SpacingRuleLayout) -> None: ...
    @property
    def PathNumber(self) -> int: ...
    @PathNumber.setter
    def PathNumber(self, pathNumber: int) -> None: ...
    @property
    def PathDistance(self) -> float: ...
    @PathDistance.setter
    def PathDistance(self, pathDistance: float) -> None: ...
    @property
    def PathMeasurementType(self) -> DividedPathMeasurementType: ...
    @PathMeasurementType.setter
    def PathMeasurementType(self, pathMeasurementType: DividedPathMeasurementType) -> None: ...
    def GetDefaultDivideSettings(cda: Document) -> DefaultDivideSettings: ...
    def GetSurfaceLayout(self, gridlines: UVGridlineType) -> SpacingRuleLayout: ...
    def SetSurfaceLayout(self, gridlines: UVGridlineType, layout: SpacingRuleLayout) -> None: ...
    def GetSurfaceNumber(self, gridlines: UVGridlineType) -> int: ...
    def SetSurfaceNumber(self, gridlines: UVGridlineType, number: int) -> None: ...
    def GetSurfaceDistance(self, gridlines: UVGridlineType) -> float: ...
    def SetSurfaceDistance(self, gridlines: UVGridlineType, distance: float) -> None: ...


class DetailElementOrderUtils:
    @overload
    def BringToFront(pDocument: Document, pDBView: View, detailElementIds: ICollection) -> None: ...
    @overload
    def BringToFront(pDocument: Document, pDBView: View, detailElementId: ElementId) -> None: ...
    @overload
    def BringForward(pDocument: Document, pDBView: View, detailElementIds: ICollection) -> None: ...
    @overload
    def BringForward(pDocument: Document, pDBView: View, detailElementId: ElementId) -> None: ...
    @overload
    def SendToBack(pDocument: Document, pDBView: View, detailElementIds: ICollection) -> None: ...
    @overload
    def SendToBack(pDocument: Document, pDBView: View, detailElementId: ElementId) -> None: ...
    @overload
    def SendBackward(pDocument: Document, pDBView: View, detailElementIds: ICollection) -> None: ...
    @overload
    def SendBackward(pDocument: Document, pDBView: View, detailElementId: ElementId) -> None: ...
    def IsDetailElement(pDocument: Document, pDBView: View, detailElementId: ElementId) -> bool: ...
    def AreDetailElements(pDocument: Document, pDBView: View, detailElementIds: ICollection) -> bool: ...


class DimensionEqualityLabelFormatting:
    def __init__(self, leadingSpaces: int, prefix: str, labelType: LabelType, suffix: str, formatOptions: FormatOptions): ...
    @property
    def LabelType(self) -> LabelType: ...
    @property
    def LeadingSpaces(self) -> int: ...
    @LeadingSpaces.setter
    def LeadingSpaces(self, leadingSpaces: int) -> None: ...
    @property
    def Prefix(self) -> str: ...
    @Prefix.setter
    def Prefix(self, prefix: str) -> None: ...
    @property
    def Suffix(self) -> str: ...
    @Suffix.setter
    def Suffix(self, suffix: str) -> None: ...
    @property
    def IsValidObject(self) -> bool: ...
    def GetFormatOptions(self) -> FormatOptions: ...
    def SetFormatOptions(self, formatOptions: FormatOptions) -> None: ...
    def IsValidFormatOptions(self) -> bool: ...
    def Dispose(self) -> None: ...


class OrdinateDimensionSetting:
    def __init__(self): ...
    @property
    def DimensionLineLength(self) -> float: ...
    @DimensionLineLength.setter
    def DimensionLineLength(self, dimensionLineLength: float) -> None: ...
    @property
    def DimensionLineStyle(self) -> OrdinateDimensionLineStyle: ...
    @DimensionLineStyle.setter
    def DimensionLineStyle(self, dimensionLineStyle: OrdinateDimensionLineStyle) -> None: ...
    @property
    def TextOrientation(self) -> OrdinateTextOrientation: ...
    @TextOrientation.setter
    def TextOrientation(self, textOrientation: OrdinateTextOrientation) -> None: ...
    @property
    def TextPosition(self) -> OrdinateTextPosition: ...
    @TextPosition.setter
    def TextPosition(self, textPosition: OrdinateTextPosition) -> None: ...
    @property
    def OriginVisibility(self) -> OrdinateOriginVisibility: ...
    @OriginVisibility.setter
    def OriginVisibility(self, originVisibility: OrdinateOriginVisibility) -> None: ...
    @property
    def OriginTickMarkId(self) -> ElementId: ...
    @OriginTickMarkId.setter
    def OriginTickMarkId(self, originTickMarkId: ElementId) -> None: ...
    @property
    def IsValidObject(self) -> bool: ...
    def Dispose(self) -> None: ...


class Rectangle:
    @overload
    def __init__(self, left: int, top: int, right: int, bottom: int): ...
    @overload
    def __init__(self): ...
    @overload
    def __init__(self, other: Rectangle): ...
    @property
    def Left(self) -> int: ...
    @Left.setter
    def Left(self, left: int) -> None: ...
    @property
    def Top(self) -> int: ...
    @Top.setter
    def Top(self, top: int) -> None: ...
    @property
    def Right(self) -> int: ...
    @Right.setter
    def Right(self, right: int) -> None: ...
    @property
    def Bottom(self) -> int: ...
    @Bottom.setter
    def Bottom(self, bottom: int) -> None: ...
    @property
    def IsValidObject(self) -> bool: ...
    def IsNormalized(self) -> bool: ...
    def Dispose(self) -> None: ...


class DirectShape(Element):
    @property
    def TypeId(self) -> ElementId: ...
    @property
    def ApplicationId(self) -> str: ...
    @ApplicationId.setter
    def ApplicationId(self, appId: str) -> None: ...
    @property
    def ApplicationDataId(self) -> str: ...
    @ApplicationDataId.setter
    def ApplicationDataId(self, dataId: str) -> None: ...
    def CreateElement(document: Document, categoryId: ElementId) -> DirectShape: ...
    def CreateGeometryInstance(document: Document, definition_id: str, trf: Transform) -> List[GeometryObject]: ...
    def CreateElementInstance(document: Document, typeId: ElementId, categoryId: ElementId, definitionId: str, trf: Transform) -> DirectShape: ...
    def SetTypeId(self, typeId: ElementId) -> None: ...
    def SetName(self, name: str) -> None: ...
    @overload
    def SetShape(self, pBuilder: ShapeBuilder) -> None: ...
    @overload
    def SetShape(self, pGeomArr: List[GeometryObject], viewType: DirectShapeTargetViewType) -> None: ...
    @overload
    def SetShape(self, pGeomArr: List[GeometryObject]) -> None: ...
    @overload
    def AppendShape(self, ShapeBuilder: ShapeBuilder) -> None: ...
    @overload
    def AppendShape(self, pGeomArr: List[GeometryObject], viewType: DirectShapeTargetViewType) -> None: ...
    @overload
    def AppendShape(self, pGeomArr: List[GeometryObject]) -> None: ...
    def AreOptionsValid(self, options: DirectShapeOptions) -> bool: ...
    def AreOptionsValidForTransientDirectShape(self, options: DirectShapeOptions) -> bool: ...
    def SetOptions(self, options: DirectShapeOptions) -> None: ...
    def GetOptions(self) -> DirectShapeOptions: ...
    def IsValidCategoryId(categoryId: ElementId, doc: Document) -> bool: ...
    def IsSupportedDocument(document: Document) -> bool: ...
    def IsValidTypeId(self, typeId: ElementId) -> bool: ...
    def IsValidGeometry(self, Geom: Solid) -> bool: ...
    @overload
    def IsValidShape(self, shape: List[GeometryObject], viewType: DirectShapeTargetViewType) -> bool: ...
    @overload
    def IsValidShape(self, shape: List[GeometryObject]) -> bool: ...
    def CanCreateParts(self) -> bool: ...


class DirectShapeOptions:
    @property
    def ReferencingOption(self) -> DirectShapeReferencingOption: ...
    @ReferencingOption.setter
    def ReferencingOption(self, ReferencingOption: DirectShapeReferencingOption) -> None: ...
    @property
    def RoomBoundingOption(self) -> DirectShapeRoomBoundingOption: ...
    @property
    def IsValidObject(self) -> bool: ...
    def Dispose(self) -> None: ...


class DirectShapeLibrary:
    @property
    def IsValidObject(self) -> bool: ...
    def GetDirectShapeLibrary(ADoc: Document) -> DirectShapeLibrary: ...
    @overload
    def AddDefinition(self, id: str, GNodes: List[GeometryObject]) -> None: ...
    @overload
    def AddDefinition(self, id: str, GNode: GeometryObject) -> None: ...
    def AddDefinitionType(self, id: str, typeId: ElementId) -> None: ...
    def FindDefinition(self, id: str) -> List[GeometryObject]: ...
    def FindDefinitionType(self, id: str) -> ElementId: ...
    def Contains(self, id: str) -> bool: ...
    def ContainsType(self, name: str) -> bool: ...
    def Reset(self) -> None: ...
    def Dispose(self) -> None: ...


class DirectShapeType(ElementType):
    @overload
    def Create(document: Document, name: str, categoryId: ElementId, options: DirectShapeTypeOptions) -> DirectShapeType: ...
    @overload
    def Create(document: Document, name: str, categoryId: ElementId) -> DirectShapeType: ...
    @overload
    def SetShape(self, pBuilder: ShapeBuilder) -> None: ...
    @overload
    def SetShape(self, pGeomArr: List[GeometryObject]) -> None: ...
    @overload
    def AppendShape(self, ShapeBuilder: ShapeBuilder) -> None: ...
    @overload
    def AppendShape(self, pGeomArr: List[GeometryObject], viewType: DirectShapeTargetViewType) -> None: ...
    @overload
    def AppendShape(self, pGeomArr: List[GeometryObject]) -> None: ...
    @overload
    def IsValidShape(self, shape: List[GeometryObject], viewType: DirectShapeTargetViewType) -> bool: ...
    @overload
    def IsValidShape(self, shape: List[GeometryObject]) -> bool: ...
    def CanCreateParts(self) -> bool: ...
    def AreOptionsValid(self, options: DirectShapeTypeOptions) -> bool: ...
    def SetOptions(self, options: DirectShapeTypeOptions) -> None: ...
    def GetOptions(self) -> DirectShapeTypeOptions: ...


class DirectShapeTypeOptions:
    def __init__(self): ...
    @property
    def AllowDuplicateNames(self) -> bool: ...
    @AllowDuplicateNames.setter
    def AllowDuplicateNames(self, AllowDuplicateNames: bool) -> None: ...
    @property
    def IsValidObject(self) -> bool: ...
    def IsEqualTo(self, other: DirectShapeTypeOptions) -> bool: ...
    def IsValid(self) -> bool: ...
    def Dispose(self) -> None: ...


class DisplacementElement(Element):
    @property
    def ParentId(self) -> ElementId: ...
    def Create(document: Document, elementsToDisplace: ICollection, displacement: XYZ, ownerDBView: View, parentDisplacementElement: DisplacementElement) -> DisplacementElement: ...
    def ResetDisplacedElements(self) -> None: ...
    def IsElementDisplacedInView(view: View, id: ElementId) -> bool: ...
    def GetDisplacementElementId(view: View, id: ElementId) -> ElementId: ...
    def CanCategoryBeDisplaced(categoryId: ElementId) -> bool: ...
    def IsAllowedAsDisplacedElement(element: Element) -> bool: ...
    def IsValidAsParentInView(view: View, parent: DisplacementElement) -> bool: ...
    @overload
    def CanElementsBeDisplaced(view: View, elementIds: ICollection) -> bool: ...
    @overload
    def CanElementsBeDisplaced(view: View, elementIds: ICollection) -> Tuple[bool, ElementId]: ...
    def GetAdditionalElementsToDisplace(document: Document, view: View, idToDisplace: ElementId) -> ICollection: ...
    def IsNotEmpty(elementIds: ICollection) -> bool: ...
    def GetDisplacementElementIds(view: View) -> ICollection: ...
    @overload
    def GetDisplacedElementIds(self) -> ICollection: ...
    @overload
    def GetDisplacedElementIds(view: View) -> ICollection: ...
    def GetDisplacedElementIdsFromAllChildren(self) -> ICollection: ...
    def SetDisplacedElementIds(self, displacedElemIds: ICollection) -> None: ...
    def CanElementsBeAddedToDisplacementSet(self, toDisplace: ICollection) -> bool: ...
    def GetRelativeDisplacement(self) -> XYZ: ...
    def SetRelativeDisplacement(self, displacement: XYZ) -> None: ...
    def GetAbsoluteDisplacement(self) -> XYZ: ...
    def RemoveDisplacedElement(self, ElemToRemove: Element) -> None: ...
    def GetChildren(self) -> List[DisplacementElement]: ...


class DisplacementPath(Element):
    @property
    def AncestorIdx(self) -> int: ...
    @AncestorIdx.setter
    def AncestorIdx(self, ancestorIdx: int) -> None: ...
    @property
    def PathStyle(self) -> DisplacementPathStyle: ...
    @PathStyle.setter
    def PathStyle(self, pathStyle: DisplacementPathStyle) -> None: ...
    def Create(aDoc: Document, displacementElement: DisplacementElement, reference: Reference, param: float) -> ElementId: ...
    def IsValidParam(param: float) -> bool: ...
    def IsValidReference(displacementElement: DisplacementElement, reference: Reference) -> bool: ...
    def SetAnchorPoint(self, displacementElement: DisplacementElement, reference: Reference, param: float) -> None: ...


class DividedPath(Element):
    @property
    def MeasurementType(self) -> DividedPathMeasurementType: ...
    @MeasurementType.setter
    def MeasurementType(self, measurementType: DividedPathMeasurementType) -> None: ...
    @property
    def FixedNumberOfPoints(self) -> int: ...
    @FixedNumberOfPoints.setter
    def FixedNumberOfPoints(self, fixedNumberOfPoints: int) -> None: ...
    @property
    def Distance(self) -> float: ...
    @Distance.setter
    def Distance(self, distance: float) -> None: ...
    @property
    def MinimumDistance(self) -> float: ...
    @MinimumDistance.setter
    def MinimumDistance(self, minimumDistance: float) -> None: ...
    @property
    def MaximumDistance(self) -> float: ...
    @MaximumDistance.setter
    def MaximumDistance(self, maximumDistance: float) -> None: ...
    @property
    def BeginningIndent(self) -> float: ...
    @BeginningIndent.setter
    def BeginningIndent(self, beginningIndent: float) -> None: ...
    @property
    def EndIndent(self) -> float: ...
    @EndIndent.setter
    def EndIndent(self, endIndent: float) -> None: ...
    @property
    def DisplayNodes(self) -> bool: ...
    @DisplayNodes.setter
    def DisplayNodes(self, displayNodes: bool) -> None: ...
    @property
    def DisplayNodeNumbers(self) -> bool: ...
    @DisplayNodeNumbers.setter
    def DisplayNodeNumbers(self, displayNodeNumbers: bool) -> None: ...
    @property
    def TotalPathLength(self) -> float: ...
    @property
    def IsClosedLoop(self) -> bool: ...
    @property
    def IsCyclical(self) -> bool: ...
    @property
    def SpacingRuleLayout(self) -> SpacingRuleLayout: ...
    @SpacingRuleLayout.setter
    def SpacingRuleLayout(self, layout: SpacingRuleLayout) -> None: ...
    @property
    def SpacingRuleJustification(self) -> SpacingRuleJustification: ...
    @SpacingRuleJustification.setter
    def SpacingRuleJustification(self, justification: SpacingRuleJustification) -> None: ...
    @property
    def NumberOfPoints(self) -> int: ...
    @property
    def Flipped(self) -> bool: ...
    @property
    def DisplayReferenceCurves(self) -> bool: ...
    @DisplayReferenceCurves.setter
    def DisplayReferenceCurves(self, displayReferenceCurves: bool) -> None: ...
    @overload
    def Create(document: Document, curveReferences: List[Reference], intersectors: ICollection) -> DividedPath: ...
    @overload
    def Create(document: Document, curveReferences: List[Reference]) -> DividedPath: ...
    def SeparateReferencesIntoConnectedReferences(document: Document, curveReferences: List[Reference]) -> List[Reference]: ...
    def IsCurveReferenceValid(document: Document, curveReference: Reference) -> bool: ...
    def AreCurveReferencesConnected(document: Document, curveReferences: List[Reference]) -> bool: ...
    def IsIntersectorValidForCreation(document: Document, intersector: ElementId) -> bool: ...
    def IsValidSpacingRuleLayout(self, layout: SpacingRuleLayout) -> bool: ...
    def IsValidMeasurementType(self, measurementType: DividedPathMeasurementType) -> bool: ...
    def IsValidFixedNumberOfPoints(fixedNumberOfPoints: int) -> bool: ...
    def IsValidBeginningIndent(self, beginningIndent: float) -> bool: ...
    def IsValidEndIndent(self, endIndent: float) -> bool: ...
    def IsValidSpacingRuleJustification(self, justification: SpacingRuleJustification) -> bool: ...
    def GetIntersectingElements(self) -> ICollection: ...
    def SetIntersectingElements(self, intersectors: ICollection) -> None: ...
    def IsIntersectorValidForDividedPath(self, intersector: ElementId) -> bool: ...
    def Flip(self) -> None: ...


class DocumentPreviewSettings:
    @property
    def IsViewUpdateForced(self) -> bool: ...
    @property
    def PreviewViewId(self) -> ElementId: ...
    @PreviewViewId.setter
    def PreviewViewId(self, previewViewId: ElementId) -> None: ...
    @property
    def IsValidObject(self) -> bool: ...
    def ForceViewUpdate(self, forceViewUpdate: bool) -> None: ...
    def IsViewIdValidForPreview(self, viewId: ElementId) -> bool: ...
    def Dispose(self) -> None: ...


class FailureMessage:
    def __init__(self, id: FailureDefinitionId): ...
    @property
    def IsValidObject(self) -> bool: ...
    def SetFailingElements(self, idsToShow: ICollection) -> FailureMessage: ...
    def SetFailingElement(self, id: ElementId) -> FailureMessage: ...
    def SetAdditionalElement(self, additionalElement: ElementId) -> FailureMessage: ...
    def SetAdditionalElements(self, additionalElements: ICollection) -> FailureMessage: ...
    def GetFailingElements(self) -> ICollection: ...
    def GetAdditionalElements(self) -> ICollection: ...
    def AddResolution(self, type: FailureResolutionType, resolution: FailureResolution) -> FailureMessage: ...
    def GetSeverity(self) -> FailureSeverity: ...
    def GetDescriptionText(self) -> str: ...
    def GetFailureDefinitionId(self) -> FailureDefinitionId: ...
    def GetDefaultResolutionCaption(self) -> str: ...
    def HasResolutions(self) -> bool: ...
    def HasResolutionOfType(self, type: FailureResolutionType) -> bool: ...
    def Dispose(self) -> None: ...


class FailureMessageAccessor:
    @property
    def IsValidObject(self) -> bool: ...
    def GetFailureDefinitionId(self) -> FailureDefinitionId: ...
    def GetSeverity(self) -> FailureSeverity: ...
    def GetDescriptionText(self) -> str: ...
    def HasResolutions(self) -> bool: ...
    def HasResolutionOfType(self, type: FailureResolutionType) -> bool: ...
    def GetDefaultResolutionCaption(self) -> str: ...
    def GetFailingElementIds(self) -> ICollection: ...
    def GetNumberOfResolutions(self) -> int: ...
    def GetAdditionalElementIds(self) -> ICollection: ...
    def SetCurrentResolutionType(self, resolutionType: FailureResolutionType) -> None: ...
    def GetCurrentResolutionType(self) -> FailureResolutionType: ...
    def CloneFailureMessage(self) -> FailureMessage: ...
    def ShouldMergeWithMessage(self, messageToMergeWith: FailureMessageAccessor) -> bool: ...
    def Dispose(self) -> None: ...


class FailureMessageKey:
    def __init__(self): ...
    def op_Equality(first: FailureMessageKey, second: FailureMessageKey) -> bool: ...
    def op_Inequality(first: FailureMessageKey, second: FailureMessageKey) -> bool: ...
    def Equals(self, obj: Object) -> bool: ...
    def GetHashCode(self) -> int: ...
    @property
    def IsValidObject(self) -> bool: ...
    def IsValid(self) -> bool: ...
    def IsEqual(self, other: FailureMessageKey) -> bool: ...
    def Dispose(self) -> None: ...


class GBXMLExportOptions:
    def __init__(self): ...
    @property
    def ExportEnergyModelType(self) -> ExportEnergyModelType: ...
    @ExportEnergyModelType.setter
    def ExportEnergyModelType(self, exportEnergyModelType: ExportEnergyModelType) -> None: ...
    @property
    def Encoding(self) -> str: ...
    @property
    def ExportAnalyticalSystems(self) -> bool: ...
    @ExportAnalyticalSystems.setter
    def ExportAnalyticalSystems(self, exportAnalyticalSystems: bool) -> None: ...
    @property
    def IsValidObject(self) -> bool: ...
    def Dispose(self) -> None: ...


class ImageExportOptions:
    def __init__(self): ...
    @property
    def ZoomType(self) -> ZoomFitType: ...
    @ZoomType.setter
    def ZoomType(self, zoomType: ZoomFitType) -> None: ...
    @property
    def Zoom(self) -> int: ...
    @Zoom.setter
    def Zoom(self, zoom: int) -> None: ...
    @property
    def PixelSize(self) -> int: ...
    @PixelSize.setter
    def PixelSize(self, pixelSize: int) -> None: ...
    @property
    def ImageResolution(self) -> ImageResolution: ...
    @ImageResolution.setter
    def ImageResolution(self, imageResolution: ImageResolution) -> None: ...
    @property
    def ShadowViewsFileType(self) -> ImageFileType: ...
    @ShadowViewsFileType.setter
    def ShadowViewsFileType(self, shadowViewsFileType: ImageFileType) -> None: ...
    @property
    def HLRandWFViewsFileType(self) -> ImageFileType: ...
    @HLRandWFViewsFileType.setter
    def HLRandWFViewsFileType(self, hLRandWFViewsFileType: ImageFileType) -> None: ...
    @property
    def FitDirection(self) -> FitDirectionType: ...
    @FitDirection.setter
    def FitDirection(self, fitDirection: FitDirectionType) -> None: ...
    @property
    def ViewName(self) -> str: ...
    @ViewName.setter
    def ViewName(self, viewName: str) -> None: ...
    @property
    def FilePath(self) -> str: ...
    @FilePath.setter
    def FilePath(self, filePath: str) -> None: ...
    @property
    def ShouldCreateWebSite(self) -> bool: ...
    @ShouldCreateWebSite.setter
    def ShouldCreateWebSite(self, shouldCreateWebSite: bool) -> None: ...
    @property
    def ExportRange(self) -> ExportRange: ...
    @ExportRange.setter
    def ExportRange(self, exportRange: ExportRange) -> None: ...
    @property
    def IsValidObject(self) -> bool: ...
    def IsValidForSaveToProjectAsImage(options: ImageExportOptions, doc: Document) -> bool: ...
    def IsValidFileName(filePath: str) -> bool: ...
    def GetFileName(aDoc: Document, dbViewId: ElementId) -> str: ...
    def SetViewsAndSheets(self, viewsAndSheets: List[ElementId]) -> None: ...
    def GetViewsAndSheets(self) -> List[ElementId]: ...
    def Dispose(self) -> None: ...


class ITransientElementMaker:
    def Execute(self) -> None: ...


class NavisworksExportOptions:
    def __init__(self): ...
    @property
    def ExportParts(self) -> bool: ...
    @ExportParts.setter
    def ExportParts(self, exportParts: bool) -> None: ...
    @property
    def ExportElementIds(self) -> bool: ...
    @ExportElementIds.setter
    def ExportElementIds(self, exportElementIds: bool) -> None: ...
    @property
    def Parameters(self) -> NavisworksParameters: ...
    @Parameters.setter
    def Parameters(self, parameters: NavisworksParameters) -> None: ...
    @property
    def ExportLinks(self) -> bool: ...
    @ExportLinks.setter
    def ExportLinks(self, exportLinks: bool) -> None: ...
    @property
    def ExportRoomAsAttribute(self) -> bool: ...
    @ExportRoomAsAttribute.setter
    def ExportRoomAsAttribute(self, exportRoomAsAttribute: bool) -> None: ...
    @property
    def ExportUrls(self) -> bool: ...
    @ExportUrls.setter
    def ExportUrls(self, exportUrls: bool) -> None: ...
    @property
    def Coordinates(self) -> NavisworksCoordinates: ...
    @Coordinates.setter
    def Coordinates(self, coordinates: NavisworksCoordinates) -> None: ...
    @property
    def ExportScope(self) -> NavisworksExportScope: ...
    @ExportScope.setter
    def ExportScope(self, exportScope: NavisworksExportScope) -> None: ...
    @property
    def ViewId(self) -> ElementId: ...
    @ViewId.setter
    def ViewId(self, viewId: ElementId) -> None: ...
    @property
    def ExportRoomGeometry(self) -> bool: ...
    @ExportRoomGeometry.setter
    def ExportRoomGeometry(self, exportRoomGeometry: bool) -> None: ...
    @property
    def FindMissingMaterials(self) -> bool: ...
    @FindMissingMaterials.setter
    def FindMissingMaterials(self, findMissingMaterials: bool) -> None: ...
    @property
    def ConvertElementProperties(self) -> bool: ...
    @ConvertElementProperties.setter
    def ConvertElementProperties(self, convertElementProperties: bool) -> None: ...
    @property
    def DivideFileIntoLevels(self) -> bool: ...
    @DivideFileIntoLevels.setter
    def DivideFileIntoLevels(self, divideFileIntoLevels: bool) -> None: ...
    @property
    def FacetingFactor(self) -> float: ...
    @FacetingFactor.setter
    def FacetingFactor(self, facetingFactor: float) -> None: ...
    @property
    def ConvertLights(self) -> bool: ...
    @ConvertLights.setter
    def ConvertLights(self, convertLights: bool) -> None: ...
    @property
    def ConvertLinkedCADFormats(self) -> bool: ...
    @ConvertLinkedCADFormats.setter
    def ConvertLinkedCADFormats(self, convertLinkedCADFormats: bool) -> None: ...
    @property
    def IsValidObject(self) -> bool: ...
    def GetSelectedElementIds(self) -> ICollection: ...
    def SetSelectedElementIds(self, ids: ICollection) -> None: ...
    def Dispose(self) -> None: ...


class ReloadLatestOptions:
    def __init__(self): ...
    @property
    def IsValidObject(self) -> bool: ...
    def Dispose(self) -> None: ...


class SaveAsOptions:
    def __init__(self): ...
    @property
    def OverwriteExistingFile(self) -> bool: ...
    @OverwriteExistingFile.setter
    def OverwriteExistingFile(self, overwriteExistingFile: bool) -> None: ...
    @property
    def PreviewViewId(self) -> ElementId: ...
    @PreviewViewId.setter
    def PreviewViewId(self, previewViewId: ElementId) -> None: ...
    @property
    def MaximumBackups(self) -> int: ...
    @MaximumBackups.setter
    def MaximumBackups(self, maximumBackups: int) -> None: ...
    @property
    def Compact(self) -> bool: ...
    @Compact.setter
    def Compact(self, compact: bool) -> None: ...
    @property
    def IsValidObject(self) -> bool: ...
    def GetWorksharingOptions(self) -> WorksharingSaveAsOptions: ...
    def SetWorksharingOptions(self, worksharingOptions: WorksharingSaveAsOptions) -> None: ...
    def Dispose(self) -> None: ...


class SaveOptions:
    def __init__(self): ...
    @property
    def PreviewViewId(self) -> ElementId: ...
    @PreviewViewId.setter
    def PreviewViewId(self, previewViewId: ElementId) -> None: ...
    @property
    def Compact(self) -> bool: ...
    @Compact.setter
    def Compact(self, compact: bool) -> None: ...
    @property
    def IsValidObject(self) -> bool: ...
    def Dispose(self) -> None: ...


class STLExportOptions(ATFBaseExportOptions):
    @overload
    def __init__(self, resolutionType: STLExportResolution): ...
    @overload
    def __init__(self): ...
    @property
    def ExportBinary(self) -> bool: ...
    @ExportBinary.setter
    def ExportBinary(self, exportBinary: bool) -> None: ...
    @property
    def TargetUnit(self) -> ExportUnit: ...
    @TargetUnit.setter
    def TargetUnit(self, targetUnit: ExportUnit) -> None: ...
    @property
    def ExportColor(self) -> bool: ...
    @ExportColor.setter
    def ExportColor(self, exportColor: bool) -> None: ...
    @property
    def SurfaceTolerance(self) -> float: ...
    @SurfaceTolerance.setter
    def SurfaceTolerance(self, surfaceTolerance: float) -> None: ...
    @property
    def NormalTolerance(self) -> float: ...
    @NormalTolerance.setter
    def NormalTolerance(self, normalTolerance: float) -> None: ...
    @property
    def MaxEdgeLength(self) -> float: ...
    @MaxEdgeLength.setter
    def MaxEdgeLength(self, maxEdgeLength: float) -> None: ...
    @property
    def GridAspectRatio(self) -> float: ...
    @GridAspectRatio.setter
    def GridAspectRatio(self, gridAspectRatio: float) -> None: ...
    def IsValidForSurfaceTolerance(value: float) -> bool: ...
    def IsSurfaceToleranceSet(self) -> bool: ...
    def IsValidForNormalTolerance(value: float) -> bool: ...
    def IsNormalToleranceSet(self) -> bool: ...
    def IsValidForMaxEdgeLength(value: float) -> bool: ...
    def IsMaxEdgeLengthSet(self) -> bool: ...
    def IsValidForGridAspectRatio(value: float) -> bool: ...
    def IsGridAspectRatioSet(self) -> bool: ...
    def SetTessellationSettings(self, resolutionType: STLExportResolution) -> None: ...


class RelinquishOptions:
    def __init__(self, relinquishEverything: bool): ...
    @property
    def StandardWorksets(self) -> bool: ...
    @StandardWorksets.setter
    def StandardWorksets(self, standardWorksets: bool) -> None: ...
    @property
    def FamilyWorksets(self) -> bool: ...
    @FamilyWorksets.setter
    def FamilyWorksets(self, familyWorksets: bool) -> None: ...
    @property
    def ViewWorksets(self) -> bool: ...
    @ViewWorksets.setter
    def ViewWorksets(self, viewWorksets: bool) -> None: ...
    @property
    def UserWorksets(self) -> bool: ...
    @UserWorksets.setter
    def UserWorksets(self, userWorksets: bool) -> None: ...
    @property
    def CheckedOutElements(self) -> bool: ...
    @CheckedOutElements.setter
    def CheckedOutElements(self, checkedOutElements: bool) -> None: ...
    @property
    def IsValidObject(self) -> bool: ...
    def Dispose(self) -> None: ...


class SynchronizeWithCentralOptions:
    def __init__(self): ...
    @property
    def SaveLocalBefore(self) -> bool: ...
    @SaveLocalBefore.setter
    def SaveLocalBefore(self, saveLocalBefore: bool) -> None: ...
    @property
    def Compact(self) -> bool: ...
    @Compact.setter
    def Compact(self, compact: bool) -> None: ...
    @property
    def Comment(self) -> str: ...
    @Comment.setter
    def Comment(self, comment: str) -> None: ...
    @property
    def SaveLocalAfter(self) -> bool: ...
    @SaveLocalAfter.setter
    def SaveLocalAfter(self, saveLocalAfter: bool) -> None: ...
    @property
    def RelinquishProjectStandardWorksets(self) -> bool: ...
    @property
    def RelinquishFamilyWorksets(self) -> bool: ...
    @property
    def RelinquishViewWorksets(self) -> bool: ...
    @property
    def RelinquishUserCreatedWorksets(self) -> bool: ...
    @property
    def RelinquishBorrowedElements(self) -> bool: ...
    @property
    def SaveLocalFile(self) -> bool: ...
    @property
    def IsValidObject(self) -> bool: ...
    def GetRelinquishOptions(self) -> RelinquishOptions: ...
    def SetRelinquishOptions(self, relinquishOptions: RelinquishOptions) -> None: ...
    def Dispose(self) -> None: ...


class TransactWithCentralOptions:
    def __init__(self): ...
    @property
    def IsValidObject(self) -> bool: ...
    def SetLockCallback(self, lockCallback: ICentralLockedCallback) -> None: ...
    def GetLockCallback(self) -> ICentralLockedCallback: ...
    def Dispose(self) -> None: ...


class WorksetTable:
    @property
    def IsValidObject(self) -> bool: ...
    @overload
    def GetWorkset(self, guid: Guid) -> Workset: ...
    @overload
    def GetWorkset(self, id: WorksetId) -> Workset: ...
    def GetActiveWorksetId(self) -> WorksetId: ...
    def SetActiveWorksetId(self, worksetId: WorksetId) -> None: ...
    def RenameWorkset(aDoc: Document, worksetId: WorksetId, name: str) -> None: ...
    def IsWorksetNameUnique(aDoc: Document, name: str) -> bool: ...
    def Dispose(self) -> None: ...


class DocumentValidation:
    def CanDeleteElement(document: Document, elementId: ElementId) -> bool: ...


class OverridePermissions:
    ViewDetailLevel = 1
    Halftone = 2
    CutLines = 3
    CutFills = 4
    ProjectionLines = 5
    ProjectionFills = 6
    Surfaces = 7


class PointCloudColorMode:
    NoOverride = 0
    FixedColor = 1
    Elevation = 2
    Intensity = 3
    Normals = 4


class PreviewFamilyVisibilityMode:
    Off = 0
    On = 1
    Uncut = 2


class ViewDisplayEdges:
    #None = 0
    Simple = 1


class ViewDisplayBackgroundType:
    #None = 256
    Gradient = 257
    Image = 258
    SunAndClouds = 512


class ViewDisplayBackgroundImageFlags:
    #None = 0
    FitToScreen = 1
    FixedAspectRatio = 2
    UseTiling = 4


class ShowHiddenLinesValues:
    #None = 0
    ByDiscipline = 1
    All = 2


class BackgroundImageFit:
    #None = 0
    Vertical = 41
    Horizontal = 42
    Stretch = 43


class ResolutionTarget:
    Screen = 0
    Printer = 1


class PrinterResolution:
    Low = 0
    Medium = 1
    High = 2
    VeryHigh = 3


class LightingSource:
    ExteriorSun = 21
    ExteriorSunAndArtificial = 22
    ExteriorArtificial = 23
    InteriorSun = 24
    InteriorSunAndArtificial = 25
    InteriorArtificial = 26


class RenderingQuality:
    Draft = 11
    Medium = 13
    High = 14
    VeryHigh = 15
    Custom = 16


class LightAndMaterialAccuracyMode:
    Simplified = 1
    Advanced = 2


class RenderDuration:
    ByLevel = 0
    ByTime = 1
    UntilSatisfactory = 2


class BackgroundStyle:
    SkyNoClouds = 0
    SkyVeryFewClouds = 1
    SkyFewClouds = 2
    SkyCloudy = 3
    SkyVeryCloudy = 4
    Color = 5
    Image = 6
    Transparent = 7


class PlanViewPlane:
    CutPlane = 0
    TopClipPlane = 1
    BottomClipPlane = 2
    ViewDepthPlane = 3
    UnderlayBottom = 4


class ExportColumnHeaders:
    #None = 0
    OneRow = 1
    MultipleRows = 2


class ExportTextQualifier:
    #None = 0
    Quote = 1
    DoubleQuote = 2


class PlanViewDirection:
    Down = 0
    Up = 1
    Undefined = -1


class ViewFamily:
    Invalid = 101
    ThreeDimensional = 102
    Walkthrough = 103
    ImageView = 104
    Schedule = 105
    CostReport = 106
    Sheet = 107
    Drafting = 108
    FloorPlan = 109
    AreaPlan = 110
    CeilingPlan = 111
    Section = 112
    Detail = 113
    Elevation = 114
    LoadsReport = 115
    PressureLossReport = 116
    Legend = 117
    PanelSchedule = 118
    GraphicalColumnSchedule = 119
    StructuralPlan = 120
    SystemsAnalysisReport = 121


class DataExchangeMessageSeverity:
    Info = 0
    Warning = 1
    Error = 2
    FatalError = 3


class DataExchangeMessageId:
    #None = 0
    UnitOfProgressCompleted = 1
    ObjectCreated = 2
    UnexpectedResult = 3
    InvalidSourceObject = 4
    InvalidDataSet = 5
    GenericError = 6
    ObjectNotSupported = 7
    ObjectNotConverted = 8
    InvalidRenderingStyle = 9
    EmptyObject = 10


class DataExchangeMessageVerbosity:
    Minimal = 0
    Default = 1
    Verbose = 2


class DividedPathMeasurementType:
    ChordLength = 0
    SegmentLength = 1


class UVGridlineType:
    U = 0
    V = 1


class LabelType:
    NumberOfWitnessLines = 0
    NumberOfSegments = 1
    LengthOfSegment = 2
    TotalLength = 3


class OrdinateDimensionLineStyle:
    #None = 0
    Continuous = 1
    Segmented = 2


class OrdinateTextOrientation:
    ParallelToDimensionLine = 0
    ParallelToWitnessLine = 1


class OrdinateTextPosition:
    EndOfWitnessLine = 0
    NextToWitnessLine = 1


class OrdinateOriginVisibility:
    #None = 0
    WitnessLineWithText = 1
    WitnessLineOnly = 2


class DirectShapeTargetViewType:
    Undefined = 0
    Default = 1
    Plan = 2


class DirectShapeRoomBoundingOption:
    NotApplicable = 0
    SetByParameter = 1


class DirectShapeReferencingOption:
    NotReferenceable = 0
    Referenceable = 1


class DisplacementPathStyle:
    Straight = 0
    Jogged = 1


class FailureResolutionType:
    Invalid = 0
    Default = 1
    CreateElements = 2
    DeleteElements = 3
    SkipElements = 4
    MoveElements = 5
    FixElements = 6
    DetachElements = 7
    QuitEditMode = 8
    UnlockConstraints = 9
    SetValue = 10
    SaveDocument = 11
    ShowElements = 12
    Others = 100000


class FailureSeverity:
    #None = 0
    Warning = 1
    Error = 2
    DocumentCorruption = 3


class ExportEnergyModelType:
    SpatialElement = 0
    BuildingElement = 1


class ExportRange:
    CurrentView = 0
    VisibleRegionOfCurrentView = 1
    SetOfViews = 2


class ImageFileType:
    BMP = 0
    JPEGLossless = 1
    JPEGMedium = 2
    JPEGSmallest = 3
    PNG = 4
    TARGA = 5
    TIFF = 6


class FitDirectionType:
    Horizontal = 0
    Vertical = 1


class ZoomFitType:
    FitToPage = 0
    Zoom = 1


class ImageResolution:
    DPI_72 = 0
    DPI_150 = 1
    DPI_300 = 2
    DPI_600 = 3


class NavisworksParameters:
    #None = 0
    Elements = 1
    All = 2


class NavisworksCoordinates:
    Internal = 0
    Shared = 1


class NavisworksExportScope:
    Model = 0
    View = 1
    SelectedElements = 2


class STLExportResolution:
    Custom = 0
    Fine = 1
    Medium = 2
    Coarse = 3


class DoorEvacuationExitType:
    ExteriorExit = 0
    InteriorExit = 1
    InteriorPassage = 2
    #None = 3


class EditScope:
    @property
    def IsActive(self) -> bool: ...
    @property
    def IsValidObject(self) -> bool: ...
    def Cancel(self) -> None: ...
    def Commit(self, failurePreprocessor: IFailuresPreprocessor) -> None: ...
    def Dispose(self) -> None: ...


class IFailuresPreprocessor:
    def PreprocessFailures(self, failuresAccessor: FailuresAccessor) -> FailureProcessingResult: ...


class ExternalResourceReference:
    @overload
    def __init__(self, other: ExternalResourceReference): ...
    @overload
    def __init__(self, serverId: Guid, referenceInformation: IDictionary, version: str, inSessionPath: str): ...
    @property
    def ServerId(self) -> Guid: ...
    @property
    def Version(self) -> str: ...
    @property
    def InSessionPath(self) -> str: ...
    @property
    def IsValidObject(self) -> bool: ...
    def CreateLocalResource(doc: Document, resourceType: ExternalResourceType, path: ModelPath, pathType: PathType) -> ExternalResourceReference: ...
    def GetReferenceInformation(self) -> IDictionary: ...
    def IsValidReference(self, resourceType: ExternalResourceType) -> bool: ...
    def GetResourceVersionStatus(self) -> ResourceVersionStatus: ...
    def GetResourceShortDisplayName(self) -> str: ...
    def HasValidDisplayPath(self) -> bool: ...
    def Dispose(self) -> None: ...


class ExternalResourceType(GuidEnum):
    def __init__(self, guid: Guid): ...
    def op_Equality(first: ExternalResourceType, second: ExternalResourceType) -> bool: ...
    def op_Inequality(first: ExternalResourceType, second: ExternalResourceType) -> bool: ...


class ExternalResourceMatchOptions:
    def __init__(self, resourceType: ExternalResourceType): ...
    @property
    def ResourceType(self) -> ExternalResourceType: ...
    @property
    def IsValidObject(self) -> bool: ...
    def Dispose(self) -> None: ...


class ExternalFileReference:
    @property
    def PathType(self) -> PathType: ...
    @property
    def ExternalFileReferenceType(self) -> ExternalFileReferenceType: ...
    @property
    def IsValidObject(self) -> bool: ...
    def GetPath(self) -> ModelPath: ...
    def GetAbsolutePath(self) -> ModelPath: ...
    def GetLinkedFileStatus(self) -> LinkedFileStatus: ...
    def GetReferencingId(self) -> ElementId: ...
    def IsValidExternalFileReference(data: ExternalFileReference) -> bool: ...
    def IsValidPathTypeForExternalFileReference(self, pathType: PathType) -> bool: ...
    def Dispose(self) -> None: ...


class ElementIntersectsFilter(ElementSlowFilter):
    def IsCategorySupported(element: Element) -> bool: ...
    def IsElementSupported(element: Element) -> bool: ...


class ElementIntersectsElementFilter(ElementIntersectsFilter):
    @overload
    def __init__(self, element: Element, inverted: bool): ...
    @overload
    def __init__(self, element: Element): ...
    def GetElement(self) -> Element: ...


class ElementIntersectsSolidFilter(ElementIntersectsFilter):
    @overload
    def __init__(self, solid: Solid, inverted: bool): ...
    @overload
    def __init__(self, solid: Solid): ...
    def GetSolid(self) -> Solid: ...


class ElementLogicalFilter(ElementFilter):
    def GetFilters(self) -> List[ElementFilter]: ...
    def SetFilters(self, filters: List[ElementFilter]) -> None: ...


class LogicalAndFilter(ElementLogicalFilter):
    @overload
    def __init__(self, filters: List[ElementFilter]): ...
    @overload
    def __init__(self, filter1: ElementFilter, filter2: ElementFilter): ...


class LogicalOrFilter(ElementLogicalFilter):
    @overload
    def __init__(self, filters: List[ElementFilter]): ...
    @overload
    def __init__(self, filter1: ElementFilter, filter2: ElementFilter): ...


class ElementRecord:
    @property
    def WorksetId(self) -> WorksetId: ...
    @property
    def IsValidObject(self) -> bool: ...
    def GetId(self) -> ElementId: ...
    def GetCategoryId(self) -> ElementId: ...
    def IsAnElementType(self) -> bool: ...
    def GetOwnerViewId(self) -> ElementId: ...
    def GetDesignOptionId(self) -> ElementId: ...
    def IsCurveDriven(self) -> bool: ...
    def HasBoundingBox(self) -> bool: ...
    def GetBoundingBox(self) -> Outline: ...
    def Dispose(self) -> None: ...


class ExportDGNSettings(Element):
    @overload
    def Create(document: Document, name: str, options: DGNExportOptions) -> ExportDGNSettings: ...
    @overload
    def Create(document: Document, name: str) -> ExportDGNSettings: ...
    def GetDGNExportOptions(self) -> DGNExportOptions: ...
    def SetDGNExportOptions(self, options: DGNExportOptions) -> None: ...
    def ListNames(aDoc: Document) -> List[str]: ...
    def GetActivePredefinedSettings(aDoc: Document) -> ExportDGNSettings: ...
    def FindByName(aDoc: Document, name: str) -> ExportDGNSettings: ...


class ExportDWGSettings(Element):
    @overload
    def Create(document: Document, name: str, options: DXFExportOptions) -> ExportDWGSettings: ...
    @overload
    def Create(document: Document, name: str, options: DWGExportOptions) -> ExportDWGSettings: ...
    @overload
    def Create(document: Document, name: str) -> ExportDWGSettings: ...
    def GetDWGExportOptions(self) -> DWGExportOptions: ...
    def GetDXFExportOptions(self) -> DXFExportOptions: ...
    def SetDWGExportOptions(self, options: DWGExportOptions) -> None: ...
    def SetDXFExportOptions(self, options: DXFExportOptions) -> None: ...
    def FindByName(aDoc: Document, name: str) -> ExportDWGSettings: ...
    def ListNames(aDoc: Document) -> List[str]: ...
    def GetActivePredefinedSettings(aDoc: Document) -> ExportDWGSettings: ...


class ExportUtils:
    @overload
    def GetExportId(subelement: Subelement) -> Guid: ...
    @overload
    def GetExportId(document: Document, elementId: ElementId) -> Guid: ...
    def GetGBXMLDocumentId(document: Document) -> Guid: ...
    def GetNurbsSurfaceDataForFace(face: Face) -> NurbsSurfaceData: ...
    def GetNurbsSurfaceDataForSurface(surface: Surface) -> NurbsSurfaceData: ...


class NurbsSurfaceData:
    def __init__(self, other: NurbsSurfaceData): ...
    @property
    def DegreeU(self) -> int: ...
    @property
    def DegreeV(self) -> int: ...
    @property
    def IsRational(self) -> bool: ...
    @property
    def ReverseOrientation(self) -> bool: ...
    @property
    def IsValidObject(self) -> bool: ...
    def Create(degreeU: int, degreeV: int, knotsU: List[float], knotsV: List[float], controlPoints: List[XYZ], weights: List[float], bReverseOrientation: bool) -> NurbsSurfaceData: ...
    def IsValid(self) -> bool: ...
    def GetKnotsU(self) -> List[float]: ...
    def GetKnotsV(self) -> List[float]: ...
    def GetControlPoints(self) -> List[XYZ]: ...
    def GetWeights(self) -> List[float]: ...
    def Dispose(self) -> None: ...


class ExternalFileUtils:
    def IsExternalFileReference(aDoc: Document, elemId: ElementId) -> bool: ...
    def GetExternalFileReference(aDoc: Document, elemId: ElementId) -> ExternalFileReference: ...
    def GetAllExternalFileReferences(aDoc: Document) -> ICollection: ...
    def GetFileBasedTempFolder(filename: str) -> str: ...


class ExternalResourceBrowserData:
    def __init__(self, document: Document, serverId: Guid, folderPath: str, matchOptions: ExternalResourceMatchOptions): ...
    @property
    def ServerId(self) -> Guid: ...
    @property
    def FolderPath(self) -> str: ...
    @property
    def IsValidObject(self) -> bool: ...
    @overload
    def AddResource(self, resourceName: str, version: str, referenceInformation: IDictionary) -> None: ...
    @overload
    def AddResource(self, resourceName: str, version: str) -> None: ...
    @overload
    def AddResource(self, resourceName: str, referenceInformation: IDictionary) -> None: ...
    @overload
    def AddResource(self, resourceName: str) -> None: ...
    @overload
    def AddSubFolder(self, folderName: str, iconPath: str) -> None: ...
    @overload
    def AddSubFolder(self, folderName: str) -> None: ...
    def GetMatchOptions(self) -> ExternalResourceMatchOptions: ...
    def GetResources(self) -> List[ExternalResourceReference]: ...
    def GetSubFoldersData(self) -> List[ExternalResourceSubFolder]: ...
    def IsValidResourceName(self, resourceName: str) -> bool: ...
    def IsValidFolderName(self, folderName: str) -> bool: ...
    def GetCallingDocumentModelPath(self) -> ModelPath: ...
    def CallingDocumentHasModelPath(self) -> bool: ...
    def Dispose(self) -> None: ...


class ExternalResourceSubFolder:
    @overload
    def __init__(self, folderName: str, iconPath: str): ...
    @overload
    def __init__(self): ...
    @property
    def FolderName(self) -> str: ...
    @FolderName.setter
    def FolderName(self, folderName: str) -> None: ...
    @property
    def IconPath(self) -> str: ...
    @IconPath.setter
    def IconPath(self, iconPath: str) -> None: ...
    @property
    def IsValidObject(self) -> bool: ...
    def Dispose(self) -> None: ...


class ExternalResourceLoadContext:
    @property
    def LoadOperationType(self) -> LoadOperationType: ...
    @property
    def IsValidObject(self) -> bool: ...
    def GetCurrentlyLoadedReference(self) -> ExternalResourceReference: ...
    def GetCallingDocumentModelPath(self) -> ModelPath: ...
    def CallingDocumentHasModelPath(self) -> bool: ...
    def Dispose(self) -> None: ...


class ExternalResourceLoadData:
    @property
    def ErrorsReported(self) -> bool: ...
    @ErrorsReported.setter
    def ErrorsReported(self, errorsReported: bool) -> None: ...
    @property
    def ExternalResourceType(self) -> ExternalResourceType: ...
    @property
    def LoadStatus(self) -> ExternalResourceLoadStatus: ...
    @property
    def IsValidObject(self) -> bool: ...
    def GetExternalResourceReference(self) -> ExternalResourceReference: ...
    def GetLoadContent(self) -> ExternalResourceLoadContent: ...
    def GetLoadRequestId(self) -> Guid: ...
    def GetLoadContext(self) -> ExternalResourceLoadContext: ...
    def Dispose(self) -> None: ...


class FailureDefinitionId(GuidEnum):
    def __init__(self, guid: Guid): ...
    def op_Equality(first: FailureDefinitionId, second: FailureDefinitionId) -> bool: ...
    def op_Inequality(first: FailureDefinitionId, second: FailureDefinitionId) -> bool: ...


class ExternalResourceServerExtensions:
    @property
    def IsValidObject(self) -> bool: ...
    def GetRevitLinkOperations(self) -> RevitLinkOperations: ...
    def GetCADLinkOperations(self) -> CADLinkOperations: ...
    def Dispose(self) -> None: ...


class RevitLinkOperations(LinkOperations):
    def SetGetLocalPathForOpenCallback(self, makeLocalCopyForOpen: IGetLocalPathForOpenCallback) -> None: ...


class ExternalResourceServerUtils:
    def IsValidShortName(serverId: Guid, serverName: str) -> bool: ...
    def ServerSupportsKeynotes(extRef: ExternalResourceReference) -> bool: ...
    def ServerSupportsAssemblyCodeData(extRef: ExternalResourceReference) -> bool: ...
    def ServerSupportsRevitLinks(extRef: ExternalResourceReference) -> bool: ...
    def ServerSupportsCADLinks(extRef: ExternalResourceReference) -> bool: ...
    def ServerSupportsIFCLinks(extRef: ExternalResourceReference) -> bool: ...


class ExternalResourceServiceUtils:
    def GetServersByType(type: ExternalResourceType) -> List[IExternalResourceServer]: ...


class ExternalResourceTypes:


class BuiltInExternalResourceTypes:
    @property
    def AssemblyCodeTable() -> ExternalResourceType: ...
    @property
    def CADLink() -> ExternalResourceType: ...
    @property
    def DWFMarkup() -> ExternalResourceType: ...
    @property
    def DecalBumpMap() -> ExternalResourceType: ...
    @property
    def DecalCutOut() -> ExternalResourceType: ...
    @property
    def DecalMap() -> ExternalResourceType: ...
    @property
    def FabricationConfiguration() -> ExternalResourceType: ...
    @property
    def IFCLink() -> ExternalResourceType: ...
    @property
    def Image() -> ExternalResourceType: ...
    @property
    def KeynoteTable() -> ExternalResourceType: ...
    @property
    def PointCloud() -> ExternalResourceType: ...
    @property
    def RevitLink() -> ExternalResourceType: ...
    @property
    def TopographyLink() -> ExternalResourceType: ...


class ExternalResourceUtils:
    @overload
    def GetAllExternalResourceReferences(document: Document, resourceType: ExternalResourceType) -> ISet: ...
    @overload
    def GetAllExternalResourceReferences(document: Document) -> ISet: ...


class ExtrusionAnalyzer:
    @property
    def ExtrusionDirection(self) -> XYZ: ...
    @property
    def StartParameter(self) -> float: ...
    @property
    def EndParameter(self) -> float: ...
    @property
    def IsValidObject(self) -> bool: ...
    def Create(solidGeometry: Solid, plane: Plane, direction: XYZ) -> ExtrusionAnalyzer: ...
    def GetExtrusionBase(self) -> Face: ...
    def CalculateFaceAlignment(self) -> IDictionary: ...
    def Dispose(self) -> None: ...


class ExternalFileReferenceType:
    #None = 0
    RevitLink = 1
    CADLink = 2
    DWFMarkup = 3
    KeynoteTable = 4
    Decal = 5
    Material = 6
    AssemblyCodeTable = 7


class MaterialPropertyPathType:
    General = 0
    Transparency = 1
    Cutouts = 2
    Bump = 3
    FinishBumps = 4
    ReliefPattern = 5
    Weathering = 6


class ExternalResourceUIBrowseResultType:
    Success = 0
    FolderNotFound = 1
    ResourceNotFound = 2


class ExtrusionAnalyzerFaceAlignment:
    FullyAligned = 0
    PartiallyAligned = 1
    Unaligned = 2


class FabricationAncillaryUsage:
    @property
    def Type(self) -> FabricationAncillaryType: ...
    @property
    def UsageType(self) -> FabricationAncillaryUsageType: ...
    @property
    def AncillaryId(self) -> int: ...
    @property
    def AncillaryWidthOrDiameter(self) -> float: ...
    @property
    def AncillaryDepth(self) -> float: ...
    @property
    def Quantity(self) -> float: ...
    @property
    def Length(self) -> float: ...
    @property
    def ProductCode(self) -> str: ...
    @property
    def IsValidObject(self) -> bool: ...
    def Dispose(self) -> None: ...


class FabricationConfigurationInfo:
    @property
    def Name(self) -> str: ...
    @property
    def IsLocked(self) -> bool: ...
    @property
    def CloudId(self) -> str: ...
    @property
    def CloudVersion(self) -> int: ...
    @property
    def IsConnected(self) -> bool: ...
    @property
    def GUID(self) -> Guid: ...
    @property
    def Version(self) -> float: ...
    @property
    def Description(self) -> str: ...
    @property
    def UnitSystem(self) -> UnitSystem: ...
    @property
    def Path(self) -> str: ...
    @property
    def IsCloudConfiguration(self) -> bool: ...
    @property
    def IsValidObject(self) -> bool: ...
    def IsValid(self) -> bool: ...
    def GetProfiles(self) -> List[str]: ...
    def FindSourceFabricationConfiguration(fabricationConfiguration: FabricationConfigurationInfo) -> FabricationConfigurationInfo: ...
    def GetAllFabricationConfigurations() -> List[FabricationConfigurationInfo]: ...
    def Dispose(self) -> None: ...


class ConnectionValidationWarning:
    def __init__(self, resolution: ConnectionResolution, reason: ConnectionWarning, part1: ElementId, part2: ElementId): ...
    @property
    def Resolution(self) -> ConnectionResolution: ...
    @property
    def Reason(self) -> ConnectionWarning: ...
    @property
    def IsValidObject(self) -> bool: ...
    def GetParts(self) -> ISet: ...
    def Dispose(self) -> None: ...


class ConnectionValidationInfo:
    def __init__(self): ...
    @property
    def IsValidObject(self) -> bool: ...
    def ManyWarnings(self) -> int: ...
    def IsValidWarningIndex(self, index: int) -> bool: ...
    def GetWarning(self, index: int) -> ConnectionValidationWarning: ...
    def Dispose(self) -> None: ...


class FabricationVersionInfo:
    @property
    def Version(self) -> int: ...
    @property
    def Reason(self) -> str: ...
    @property
    def IsValidObject(self) -> bool: ...
    def Dispose(self) -> None: ...


class ReloadSwapOutInfo:
    @property
    def Part(self) -> ElementId: ...
    @property
    def WasSwapped(self) -> bool: ...
    @property
    def PreviousVersion(self) -> int: ...
    @property
    def CurrentVersion(self) -> int: ...
    @property
    def IsValidObject(self) -> bool: ...
    def Dispose(self) -> None: ...


class ConfigurationReloadInfo:
    def __init__(self): ...
    @property
    def Disconnects(self) -> int: ...
    @property
    def ProfileNotAvailable(self) -> bool: ...
    @property
    def OutOfDatePartCount(self) -> int: ...
    @property
    def IsValidObject(self) -> bool: ...
    def GetCustomDataChangedElements(self) -> ISet: ...
    def GetConnectivityValidation(self) -> ConnectionValidationInfo: ...
    def GetOutOfDatePartStatus(self, index: int) -> ReloadSwapOutInfo: ...
    def Dispose(self) -> None: ...


class FabricationConfiguration(Element):
    def GetFabricationConfiguration(doc: Document) -> FabricationConfiguration: ...
    def HasValidConfiguration(self) -> bool: ...
    def GetFabricationConfigurationInfo(self) -> FabricationConfigurationInfo: ...
    def CanBeSwapped(self) -> bool: ...
    def ReloadConfiguration(self) -> ConfigurationReloadInfo: ...
    @overload
    def SetConfiguration(self, fabricationConfigurationInfo: FabricationConfigurationInfo, profile: str) -> None: ...
    @overload
    def SetConfiguration(self, fabricationConfigurationInfo: FabricationConfigurationInfo) -> None: ...
    def GetProfile(self) -> str: ...
    def GetAllServices(self) -> List[FabricationService]: ...
    def GetAllLoadedServices(self) -> List[FabricationService]: ...
    def GetAllUsedServices(self) -> List[FabricationService]: ...
    def GetAllUsedItemFiles(self) -> List[FabricationItemFile]: ...
    def LoadServices(self, serviceIds: List[int]) -> List[int]: ...
    def LoadItemFiles(self, itemFiles: List[FabricationItemFile]) -> List[FabricationItemFile]: ...
    def CanUnloadItemFiles(self, itemFiles: List[FabricationItemFile]) -> bool: ...
    def AreItemFilesLoaded(self, itemFiles: List[FabricationItemFile]) -> bool: ...
    def UnloadServices(self, serviceIds: List[int]) -> None: ...
    def UnloadItemFiles(self, itemFiles: List[FabricationItemFile]) -> None: ...
    def GetService(self, serviceId: int) -> FabricationService: ...
    def GetAllSpecifications(self, part: FabricationPart) -> List[int]: ...
    def LocateSpecification(self, group: str, name: str) -> int: ...
    def GetSpecificationName(self, specId: int) -> str: ...
    def GetSpecificationGroup(self, specId: int) -> str: ...
    def GetAllDampers(self) -> List[int]: ...
    def GetDamperName(self, damperId: int) -> str: ...
    def DamperExists(self, damperId: int) -> bool: ...
    def GetAllPartStatuses(self) -> List[int]: ...
    def GetPartStatusDescription(self, statusId: int) -> str: ...
    def CustomDataExists(self, customDataId: int) -> bool: ...
    def GetAllPartCustomData(self) -> List[int]: ...
    def GetPartCustomDataName(self, customDataId: int) -> str: ...
    def GetPartCustomDataType(self, customDataId: int) -> FabricationCustomDataType: ...
    def GetAllInsulationSpecifications(self, pFabPart: FabricationPart) -> List[int]: ...
    def LocateInsulationSpecification(self, group: str, name: str) -> int: ...
    def GetInsulationSpecificationName(self, specId: int) -> str: ...
    def GetInsulationSpecificationGroup(self, specId: int) -> str: ...
    def GetAllMaterials(self, part: FabricationPart) -> List[int]: ...
    def LocateMaterial(self, group: str, name: str) -> int: ...
    def GetMaterialGroup(self, materialId: int) -> str: ...
    def GetMaterialName(self, materialId: int) -> str: ...
    def GetMaterialAbbreviation(self, materialId: int) -> str: ...
    def GetSpecificationAbbreviation(self, specificationId: int) -> str: ...
    def GetInsulationSpecificationAbbreviation(self, insulationSpecificationId: int) -> str: ...
    def GetAllFabricationConnectorDefinitions(self, domain: ConnectorDomainType, shape: ConnectorProfileType) -> List[int]: ...
    def LocateFabricationConnector(self, group: str, name: str, domain: ConnectorDomainType, shape: ConnectorProfileType) -> int: ...
    def GetFabricationConnectorName(self, fabricationConnectorId: int) -> str: ...
    def GetFabricationConnectorGroup(self, fabricationConnectorId: int) -> str: ...
    def GetFabricationConnectorShape(self, fabricationConnectorId: int) -> ConnectorProfileType: ...
    def GetFabricationConnectorDomain(self, fabricationConnectorId: int) -> ConnectorDomainType: ...
    def AncillaryExists(self, ancillaryId: int) -> bool: ...
    def GetAncillaries(self, type: FabricationAncillaryType, includeKits: bool, filterKits: bool) -> List[int]: ...
    def GetAncillaryName(self, ancillaryId: int) -> str: ...
    def GetAncillaryGroup(self, ancillaryId: int) -> str: ...
    def GetAncillaryGroupName(self, ancillaryId: int) -> str: ...
    def IsAncillaryKit(self, ancillaryId: int) -> bool: ...
    def GetServiceTypeName(self, serviceTypeId: int) -> str: ...
    def GetItemFolders(self) -> List[FabricationItemFolder]: ...
    def GetAllLoadedItemFiles(self) -> List[FabricationItemFile]: ...


class FabricationItemFolder:
    @property
    def Name(self) -> str: ...
    @property
    def IsValidObject(self) -> bool: ...
    def GetSubFolders(self) -> List[FabricationItemFolder]: ...
    def GetItemFiles(self) -> List[FabricationItemFile]: ...
    def Dispose(self) -> None: ...


class FabricationPart(Element):
    def IsSameAs(self, part: FabricationPart, ignoreFields: List[FabricationPartCompareType]) -> bool: ...
    def GetInsulationLiningGeometry(self) -> GeometryElement: ...
    @property
    def ProductListEntry(self) -> int: ...
    @ProductListEntry.setter
    def ProductListEntry(self, productEntryIndex: int) -> None: ...
    @property
    def TopOfPartElevation(self) -> float: ...
    @property
    def BottomOfPartElevation(self) -> float: ...
    @property
    def ServiceAbbreviation(self) -> str: ...
    @property
    def HasDoubleWall(self) -> bool: ...
    @property
    def HasInsulation(self) -> bool: ...
    @property
    def HasLining(self) -> bool: ...
    @property
    def Slope(self) -> float: ...
    @property
    def Size(self) -> str: ...
    @property
    def OverallSize(self) -> str: ...
    @property
    def FreeSize(self) -> str: ...
    @property
    def Weight(self) -> float: ...
    @property
    def InsulationType(self) -> str: ...
    @property
    def InsulationThickness(self) -> float: ...
    @property
    def InsulationArea(self) -> float: ...
    @property
    def LiningType(self) -> str: ...
    @property
    def LiningThickness(self) -> float: ...
    @property
    def LiningArea(self) -> float: ...
    @property
    def SheetMetalArea(self) -> float: ...
    @property
    def MaterialThickness(self) -> float: ...
    @property
    def DoubleWallMaterial(self) -> int: ...
    @property
    def DoubleWallMaterialThickness(self) -> float: ...
    @property
    def DoubleWallMaterialArea(self) -> float: ...
    @property
    def CutType(self) -> int: ...
    @property
    def ServiceName(self) -> str: ...
    @property
    def IsBoughtOut(self) -> bool: ...
    @property
    def Notes(self) -> str: ...
    @Notes.setter
    def Notes(self, notes: str) -> None: ...
    @property
    def Alias(self) -> str: ...
    @property
    def Vendor(self) -> str: ...
    @property
    def VendorCode(self) -> str: ...
    @property
    def ProductName(self) -> str: ...
    @property
    def ProductShortDescription(self) -> str: ...
    @property
    def ProductLongDescription(self) -> str: ...
    @property
    def ProductFinishDescription(self) -> str: ...
    @property
    def ProductSpecificationDescription(self) -> str: ...
    @property
    def ProductMaterialDescription(self) -> str: ...
    @property
    def ProductSizeDescription(self) -> str: ...
    @property
    def ProductDataRange(self) -> str: ...
    @property
    def ProductOriginalEquipmentManufacture(self) -> str: ...
    @property
    def ProductInstallType(self) -> str: ...
    @property
    def LevelOffset(self) -> float: ...
    @property
    def Origin(self) -> XYZ: ...
    @property
    def CenterlineLength(self) -> float: ...
    @property
    def ProductCode(self) -> str: ...
    @property
    def ServiceId(self) -> int: ...
    @ServiceId.setter
    def ServiceId(self, serviceId: int) -> None: ...
    @property
    def Specification(self) -> int: ...
    @Specification.setter
    def Specification(self, specId: int) -> None: ...
    @property
    def InsulationSpecification(self) -> int: ...
    @InsulationSpecification.setter
    def InsulationSpecification(self, specId: int) -> None: ...
    @property
    def Material(self) -> int: ...
    @Material.setter
    def Material(self, materialId: int) -> None: ...
    @property
    def ItemNumber(self) -> str: ...
    @ItemNumber.setter
    def ItemNumber(self, itemNumber: str) -> None: ...
    @property
    def ItemCustomId(self) -> int: ...
    @property
    def DomainType(self) -> ConnectorDomainType: ...
    @property
    def ConnectorManager(self) -> ConnectorManager: ...
    @property
    def ValidationStatus(self) -> ValidationStatus: ...
    @property
    def HangerRodKit(self) -> int: ...
    @HangerRodKit.setter
    def HangerRodKit(self, newId: int) -> None: ...
    @property
    def PartStatus(self) -> int: ...
    @PartStatus.setter
    def PartStatus(self, newId: int) -> None: ...
    @property
    def PartGuid(self) -> Guid: ...
    @property
    def SpoolName(self) -> str: ...
    @SpoolName.setter
    def SpoolName(self, spoolName: str) -> None: ...
    @property
    def GeometryChecksum(self) -> AssetPropertyUInt64: ...
    @property
    def ServiceType(self) -> int: ...
    def GetVersionHistory(self) -> List[FabricationVersionInfo]: ...
    @overload
    def Create(document: Document, itemFile: FabricationItemFile, levelId: ElementId) -> FabricationPart: ...
    @overload
    def Create(document: Document, button: FabricationServiceButton, condition: int, levelId: ElementId) -> FabricationPart: ...
    @overload
    def Create(document: Document, button: FabricationServiceButton, width: float, depth: float, levelId: ElementId) -> FabricationPart: ...
    @overload
    def CreateHanger(document: Document, button: FabricationServiceButton, condition: int, levelId: ElementId) -> FabricationPart: ...
    @overload
    def CreateHanger(document: Document, button: FabricationServiceButton, condition: int, hostId: ElementId, hostConnector: Connector, distance: float, attachToStructure: bool) -> FabricationPart: ...
    @overload
    def CreateHanger(document: Document, button: FabricationServiceButton, hostId: ElementId, hostConnector: Connector, distance: float, attachToStructure: bool) -> FabricationPart: ...
    def GetHostedInfo(self) -> FabricationHostedInfo: ...
    def GetRodInfo(self) -> FabricationRodInfo: ...
    def IsProductListEntryCompatibleSize(self, productEntry: int) -> bool: ...
    def StretchAndFit(document: Document, stretchConnector: Connector, target: FabricationPartRouteEnd) -> Tuple[FabricationPartFitResult, ISet]: ...
    def SaveAsFabricationJob(document: Document, ids: ISet, filename: str, saveOptions: FabricationSaveJobOptions) -> ISet: ...
    def CanASlopeBeApplied(self) -> bool: ...
    def GetTransform(self) -> Transform: ...
    def SetPositionByEnd(self, connector: Connector, position: XYZ) -> None: ...
    def GetDimensions(self) -> List[FabricationDimensionDefinition]: ...
    def GetDimensionValue(self, dim: FabricationDimensionDefinition) -> float: ...
    def SetDimensionValue(self, dim: FabricationDimensionDefinition, newValue: float) -> None: ...
    def IsDimensionCalculated(self, dim: FabricationDimensionDefinition) -> bool: ...
    def GetDimensionCalculatedOptions(self, dim: FabricationDimensionDefinition) -> List[str]: ...
    def GetCalculatedDimensionValue(self, dim: FabricationDimensionDefinition) -> str: ...
    def SetCalculatedDimensionValue(self, dim: FabricationDimensionDefinition, value: str) -> None: ...
    def CanAdjustEndLength(self, partConn: Connector) -> bool: ...
    def AdjustEndLength(self, partConn: Connector, lengthToAdjust: float, totalLengthOnly: bool) -> float: ...
    def IsAStraight(self) -> bool: ...
    def IsAHanger(self) -> bool: ...
    def IsATap(self) -> bool: ...
    def IsProductList(self) -> bool: ...
    def GetProductListEntryName(self, index: int) -> str: ...
    def GetProductListEntryCount(self) -> int: ...
    def OptimizeLengths(doc: Document, partIds: ISet) -> ISet: ...
    def Reposition(doc: Document, partId: ElementId) -> None: ...
    def CanSplitStraight(self, position: XYZ) -> bool: ...
    @overload
    def SplitStraight(self, position: XYZ) -> ElementId: ...
    @overload
    def SplitStraight(self, document: Document, partId: ElementId, position: XYZ) -> ElementId: ...
    def ConnectAndCouple(doc: Document, partConn: Connector, toConn: Connector) -> bool: ...
    def AlignPartByConnectors(doc: Document, partConn: Connector, toConn: Connector, axisRotation: float) -> bool: ...
    def AlignPartByConnectorToConnector(document: Document, connector: Connector, fixedConnector: Connector, rotation: float, slope: float, justification: FabricationPartJustification) -> bool: ...
    def AlignPartByInsertionPoint(document: Document, partId: ElementId, position: XYZ, rotation: float, rotationPerpendicular: float, slope: float, justification: FabricationPartJustification, trf: Transform) -> bool: ...
    def AlignPartByConnector(document: Document, connector: Connector, position: XYZ, rotation: float, rotationPerpendicular: float, slope: float, justification: FabricationPartJustification, trf: Transform) -> bool: ...
    def AlignPartByInsertionPointAndCutInToStraight(document: Document, straightId: ElementId, partId: ElementId, position: XYZ, rotation: float, slope: float, flip: bool) -> bool: ...
    def RotateConnectedTap(doc: Document, tap: FabricationPart, primaryAxisRotateBy: float, secondaryAxisRotateBy: float) -> None: ...
    def PlaceAsTap(doc: Document, tapPartConn: Connector, hostPartConn: Connector, distance: float, axisRotation: float, secondaryAxisRotation: float) -> None: ...
    def PlaceFittingAsCutIn(doc: Document, straightId: ElementId, fittingId: ElementId, position: XYZ, fittingConn: Connector, axisRotation: float) -> bool: ...
    def RotateConnectedPartByConnector(doc: Document, conn: Connector, axisRotationBy: float) -> None: ...
    def HasNoConnections(self) -> bool: ...
    def HasCustomData(self, customId: int) -> bool: ...
    def GetPartCustomDataText(self, customId: int) -> str: ...
    def GetPartCustomDataInteger(self, customId: int) -> int: ...
    def GetPartCustomDataReal(self, customId: int) -> float: ...
    def SetPartCustomDataText(self, customId: int, value: str) -> None: ...
    def SetPartCustomDataInteger(self, customId: int, value: int) -> None: ...
    def SetPartCustomDataReal(self, customId: int, value: float) -> None: ...
    def AddPartCustomData(self, customId: int) -> bool: ...
    def RemovePartCustomData(self, customId: int) -> bool: ...
    def GetPartAncillaryUsage(self) -> List[FabricationAncillaryUsage]: ...


class FabricationService:
    @property
    def Name(self) -> str: ...
    @property
    def Abbreviation(self) -> str: ...
    @property
    def FabricationSystemName(self) -> str: ...
    @property
    def GroupCount(self) -> int: ...
    @property
    def ServiceId(self) -> int: ...
    @property
    def IsValidObject(self) -> bool: ...
    def IsValidGroupIndex(self, groupIndex: int) -> bool: ...
    def GetGroupName(self, group: int) -> str: ...
    def IsCompatibleWith(self, otherService: FabricationService) -> bool: ...
    def IsGroupExcluded(self, groupIndex: int) -> bool: ...
    def SetServiceGroupExclusions(self, excludedGroups: List[int]) -> bool: ...
    def ResetServiceExclusionOverrides(self) -> None: ...
    def OverrideServiceButtonExclusion(self, groupIndex: int, buttonIndex: int, exclude: bool) -> None: ...
    def GetButtonCount(self, group: int) -> int: ...
    def IsValidButtonIndex(self, groupIndex: int, buttonIndex: int) -> bool: ...
    def GetButton(self, groupIndex: int, buttonIndex: int) -> FabricationServiceButton: ...
    def Dispose(self) -> None: ...


class FabricationDimensionDefinition:
    @property
    def Name(self) -> str: ...
    @property
    def Type(self) -> FabricationDimensionType: ...
    @property
    def UnitType(self) -> FabricationDimensionUnitType: ...
    @property
    def IsModifiable(self) -> bool: ...
    @property
    def IsValidObject(self) -> bool: ...
    def Dispose(self) -> None: ...


class FabricationHostedInfo:
    @property
    def HostId(self) -> ElementId: ...
    @property
    def IsValidObject(self) -> bool: ...
    @overload
    def PlaceOnHost(self, hostId: ElementId, hostConnector: Connector, distance: float, axisRotation: float) -> None: ...
    @overload
    def PlaceOnHost(self, hostId: ElementId, hostConnector: Connector, distance: float) -> None: ...
    def GetBearerCenterline(self) -> Line: ...
    def DisconnectFromHost(self) -> None: ...
    def Dispose(self) -> None: ...


class FabricationRodInfo:
    @property
    def CanRodsBeHosted(self) -> bool: ...
    @CanRodsBeHosted.setter
    def CanRodsBeHosted(self, allowHosting: bool) -> None: ...
    @property
    def RodCount(self) -> int: ...
    @property
    def IsAttachedToStructure(self) -> bool: ...
    @property
    def IsValidObject(self) -> bool: ...
    def GetRodAttachedElementId(self, rodIndex: int) -> LinkElementId: ...
    def GetRodEndPosition(self, rodIndex: int) -> XYZ: ...
    def SetRodEndPosition(self, rodIndex: int, position: XYZ) -> None: ...
    def AttachToStructure(self) -> None: ...
    def AttachToHanger(self, hangerId: ElementId, rodIndex: int, position: XYZ) -> None: ...
    def IsRodLockedWithHost(self, rodIndex: int) -> bool: ...
    def SetRodLockedWithHost(self, rodIndex: int, locked: bool) -> None: ...
    def GetBearerExtension(self, rodIndex: int) -> float: ...
    def SetBearerExtension(self, rodIndex: int, length: float) -> None: ...
    def SetRodStructureExtension(self, rodIndex: int, extension: float) -> bool: ...
    def GetRodStructureExtension(self, rodIndex: int) -> float: ...
    def SetRodLength(self, rodIndex: int, newLength: float) -> bool: ...
    def GetRodLength(self, rodIndex: int) -> float: ...
    def Dispose(self) -> None: ...


class FabricationPartType(ElementType):
    def Create(document: Document, button: FabricationServiceButton, condition: int) -> FabricationPartType: ...
    def Lookup(document: Document, button: FabricationServiceButton, condition: int) -> ElementId: ...


class FaceSplitter(Element):
    @property
    def SplitElementId(self) -> ElementId: ...
    def GetBoundaries(self) -> List[CurveLoop]: ...


class FaceWall(HostObject):
    def Create(document: Document, wallType: ElementId, locationLine: WallLocationLine, faceReference: Reference) -> FaceWall: ...
    def IsWallTypeValidForFaceWall(document: Document, wallType: ElementId) -> bool: ...
    def IsValidFaceReferenceForFaceWall(document: Document, faceReference: Reference) -> bool: ...


class TriOrQuadFacet:
    @property
    def NumberOfVertices(self) -> int: ...
    @property
    def Normal(self) -> XYZ: ...
    @property
    def IsValidObject(self) -> bool: ...
    def GetVertexIndex(self, index: int) -> int: ...
    def Dispose(self) -> None: ...


class TriangulationInterface:
    @property
    def IsValidObject(self) -> bool: ...
    def Dispose(self) -> None: ...


class TriangulationInterfaceForTriangulatedSolidOrShell(TriangulationInterface):
    def __init__(self, externalTriangulatedSolidOrShell: TriangulatedSolidOrShell): ...


class TriangulationInterfaceForTriangulatedShellComponent(TriangulationInterface):
    def __init__(self, externalTriangulatedShellComponent: TriangulatedShellComponent): ...


class FacetingUtils:
    def ConvertTrianglesToQuads(triangulation: TriangulationInterface) -> List[TriOrQuadFacet]: ...


class FailureDefinition:
    @property
    def Severity(self) -> FailureSeverity: ...
    @property
    def IsValidObject(self) -> bool: ...
    def CreateFailureDefinition(id: FailureDefinitionId, severity: FailureSeverity, messageString: str) -> FailureDefinition: ...
    def AddResolutionType(self, type: FailureResolutionType, caption: str, classOfResolution: Type) -> FailureDefinition: ...
    def SetDefaultResolutionType(self, type: FailureResolutionType) -> FailureDefinition: ...
    def GetDescriptionText(self) -> str: ...
    def GetApplicableResolutionTypes(self) -> List[FailureResolutionType]: ...
    def GetResolutionCaption(self, type: FailureResolutionType) -> str: ...
    def GetDefaultResolutionType(self) -> FailureResolutionType: ...
    def HasResolutions(self) -> bool: ...
    def IsResolutionApplicable(self, type: FailureResolutionType) -> bool: ...
    def Dispose(self) -> None: ...


class FailureDefinitionAccessor:
    @property
    def IsValidObject(self) -> bool: ...
    def GetId(self) -> FailureDefinitionId: ...
    def GetSeverity(self) -> FailureSeverity: ...
    def GetApplicableResolutionTypes(self) -> List[FailureResolutionType]: ...
    def GetDescriptionText(self) -> str: ...
    def GetResolutionCaption(self, type: FailureResolutionType) -> str: ...
    def SetDefaultResolutionType(self, type: FailureResolutionType) -> None: ...
    def GetDefaultResolutionType(self) -> FailureResolutionType: ...
    def HasResolutions(self) -> bool: ...
    def IsResolutionApplicable(self, type: FailureResolutionType) -> bool: ...
    def Dispose(self) -> None: ...


class BuiltInFailures:


class AlignmentFailures:
    @property
    def AlignmentCheckStationLabels() -> FailureDefinitionId: ...


class AnalyticalModelFailures:
    @property
    def AdjustCurveTooShort() -> FailureDefinitionId: ...
    @property
    def AdjustEdgeTooShort() -> FailureDefinitionId: ...
    @property
    def AdjustEdgeTooShortErr() -> FailureDefinitionId: ...
    @property
    def AdjustEdgeTooShortWarn() -> FailureDefinitionId: ...
    @property
    def AnalyticalBeamSlabWarning() -> FailureDefinitionId: ...
    @property
    def AnalyticalDiscrepancyWarning() -> FailureDefinitionId: ...
    @property
    def AnalyticalGapWarning() -> FailureDefinitionId: ...
    @property
    def AnalyticalLinkJoinedNodes() -> FailureDefinitionId: ...
    @property
    def AnalyticalLinkNotConnected() -> FailureDefinitionId: ...
    @property
    def AnalyticalMemberInstability() -> FailureDefinitionId: ...
    @property
    def AnalyticalModelInstability() -> FailureDefinitionId: ...
    @property
    def AnalyticalModelIsIncorrect() -> FailureDefinitionId: ...
    @property
    def AnalyticalPhysicalCheckDone() -> FailureDefinitionId: ...
    @property
    def AnalyticalSupportCycleWarning() -> FailureDefinitionId: ...
    @property
    def AnalyticalTopBottomPlanesReversed() -> FailureDefinitionId: ...
    @property
    def AutoDetectIgnoreLeaderWarning() -> FailureDefinitionId: ...
    @property
    def BoundaryLinesIntersect() -> FailureDefinitionId: ...
    @property
    def CannotCreateAnalyticalGeometry() -> FailureDefinitionId: ...
    @property
    def CannotKeepAnalyticalAdjustment() -> FailureDefinitionId: ...
    @property
    def CannotMakeAnalyticalGeometry() -> FailureDefinitionId: ...
    @property
    def CannotSlantAnalyticalWallError() -> FailureDefinitionId: ...
    @property
    def LoadsMayBeNotUpToDate() -> FailureDefinitionId: ...
    @property
    def ProjectionPlaneInvalidWall() -> FailureDefinitionId: ...
    @property
    def ProjectionPlanesNotIntersect() -> FailureDefinitionId: ...
    @property
    def ProjectionPlanesParallel() -> FailureDefinitionId: ...
    @property
    def StructAnalyticalErrorProjection() -> FailureDefinitionId: ...
    @property
    def StructWallAnalyticalErrorAlign() -> FailureDefinitionId: ...
    @property
    def StructWallAnalyticalErrorConversion() -> FailureDefinitionId: ...
    @property
    def StructuralElementMayNotBeSupported() -> FailureDefinitionId: ...
    @property
    def SupportCheckDone() -> FailureDefinitionId: ...
    @property
    def WallAMLostAdjustmentReference() -> FailureDefinitionId: ...


class ArrayFailures:
    @property
    def ArrayMixedModAndViewSpecElemsCorruption() -> FailureDefinitionId: ...
    @property
    def ArrayMixedModAndViewSpecElemsWarning() -> FailureDefinitionId: ...
    @property
    def ArrayingNotSupportedForElements() -> FailureDefinitionId: ...
    @property
    def CannotCreateArraySelectionIsGrouped() -> FailureDefinitionId: ...
    @property
    def ConstraintsNotSatisfied() -> FailureDefinitionId: ...
    @property
    def CouldntFindNewHostsForElements() -> FailureDefinitionId: ...
    @property
    def IdenticalGeometryCopiesInArray() -> FailureDefinitionId: ...
    @property
    def RadiusTooSmall() -> FailureDefinitionId: ...


class AssemblyFailures:
    @property
    def AddedElementsNotSamePhaseAsAssembly() -> FailureDefinitionId: ...
    @property
    def AssemblyDeleteTypeWarn() -> FailureDefinitionId: ...
    @property
    def AssemblyDidNotMatchRequestedTypeWarn() -> FailureDefinitionId: ...
    @property
    def AssemblyDisassembleInstanceWarn() -> FailureDefinitionId: ...
    @property
    def AssemblyInheritTypeWarn() -> FailureDefinitionId: ...
    @property
    def AssemblyInvalidMember() -> FailureDefinitionId: ...
    @property
    def AssemblyNewTypeWarn() -> FailureDefinitionId: ...
    @property
    def AssemblyRenameTypeWarn() -> FailureDefinitionId: ...
    @property
    def CouldNotAcquireAssemblyViews() -> FailureDefinitionId: ...
    @property
    def CouldNotChangeTypeOfAssembly() -> FailureDefinitionId: ...
    @property
    def DeleteAssemblyInstWithViewsWarn() -> FailureDefinitionId: ...
    @property
    def DeleteShopDrawingsWarn() -> FailureDefinitionId: ...
    @property
    def ElementsNotAllowedAreNotAddedToAssembly() -> FailureDefinitionId: ...
    @property
    def IneligibleElementsInAssembly() -> FailureDefinitionId: ...
    @property
    def MixedPhasesInAssembly() -> FailureDefinitionId: ...
    @property
    def NoElementsAddedtoNewAssembly() -> FailureDefinitionId: ...
    @property
    def NoElementsLeftInExistingAssembly() -> FailureDefinitionId: ...
    @property
    def NoEligibleElementsInAssembly() -> FailureDefinitionId: ...
    @property
    def SomeElementsPreventAssemblyTypeChange() -> FailureDefinitionId: ...


class AutoJoinFailures:
    @property
    def DesignOptionAndWorksetViolation() -> FailureDefinitionId: ...
    @property
    def DesignOptionCannotReference() -> FailureDefinitionId: ...
    @property
    def OtherNonEditJoinFailure() -> FailureDefinitionId: ...
    @property
    def UnexpectedJoinFailure() -> FailureDefinitionId: ...
    @property
    def Unknown() -> FailureDefinitionId: ...
    @property
    def WorksetJoinWarn() -> FailureDefinitionId: ...


class AutoRouteFailures:
    @property
    def AttemptToConnectNonSlopingElementToSlopedPipeError() -> FailureDefinitionId: ...
    @property
    def AttemptToConnectNonSlopingElementToSlopedPipeWarning() -> FailureDefinitionId: ...
    @property
    def DesignOptionConflictError() -> FailureDefinitionId: ...
    @property
    def DesignOptionConflictWarning() -> FailureDefinitionId: ...
    @property
    def DistributionTypeInvalid() -> FailureDefinitionId: ...
    @property
    def ElementHasFlowCalculation() -> FailureDefinitionId: ...
    @property
    def ElementHasOpenConnection() -> FailureDefinitionId: ...
    @property
    def FailToDoCompatiblePhaseError() -> FailureDefinitionId: ...
    @property
    def FailToDoCompatiblePhaseWarning() -> FailureDefinitionId: ...
    @property
    def FailToIntersectParallelSegmentsError() -> FailureDefinitionId: ...
    @property
    def FailToIntersectParallelSegmentsWarning() -> FailureDefinitionId: ...
    @property
    def FailedDowngradeCrossToElbow() -> FailureDefinitionId: ...
    @property
    def FailedDowngradeCrossToTee() -> FailureDefinitionId: ...
    @property
    def FailedDowngradeTeeToCross() -> FailureDefinitionId: ...
    @property
    def FittingParamsCauseGeometryToFailError() -> FailureDefinitionId: ...
    @property
    def FittingParamsCauseGeometryToFailWarning() -> FailureDefinitionId: ...
    @property
    def HighlightedElementDisconnected() -> FailureDefinitionId: ...
    @property
    def InappropriateSlopeForPipe() -> FailureDefinitionId: ...
    @property
    def MismatchedSystemClassificationHasSystemWarning() -> FailureDefinitionId: ...
    @property
    def MismatchedSystemClassificationNoSystemWarning() -> FailureDefinitionId: ...
    @property
    def MismatchedSystemTypeWarning() -> FailureDefinitionId: ...
    @property
    def NoAutoRouteSolutionFoundError() -> FailureDefinitionId: ...
    @property
    def NoAutoRouteSolutionFoundWarning() -> FailureDefinitionId: ...
    @property
    def NoFittingInProjectError() -> FailureDefinitionId: ...
    @property
    def NoFittingInProjectWarning() -> FailureDefinitionId: ...
    @property
    def NoFittingInRoutingError() -> FailureDefinitionId: ...
    @property
    def NoFittingLoadedInProjectError() -> FailureDefinitionId: ...
    @property
    def NoSolutionInView() -> FailureDefinitionId: ...
    @property
    def NoValidSolutionAtSelectedPoint() -> FailureDefinitionId: ...
    @property
    def NotAllPartsWereConvertedCannotAddPlaceholderWarning() -> FailureDefinitionId: ...
    @property
    def NotAllPartsWereConvertedPlaceholdersWereAddedWarning() -> FailureDefinitionId: ...
    @property
    def NotEnoughRoomForFittingsError() -> FailureDefinitionId: ...
    @property
    def NotEnoughRoomForFittingsWarning() -> FailureDefinitionId: ...
    @property
    def OverrideFabricationPartFailed() -> FailureDefinitionId: ...
    @property
    def SegmentDrawnFromWrongSideError() -> FailureDefinitionId: ...
    @property
    def SegmentDrawnFromWrongSideWarning() -> FailureDefinitionId: ...
    @property
    def SegmentsAngleTooGreatError() -> FailureDefinitionId: ...
    @property
    def SegmentsAngleTooGreatWarning() -> FailureDefinitionId: ...
    @property
    def SolutionIsOppositeToConnectionError() -> FailureDefinitionId: ...
    @property
    def SolutionIsOppositeToConnectionWarning() -> FailureDefinitionId: ...
    @property
    def SpecifiedAnglesNotCompatibleWithLayoutError() -> FailureDefinitionId: ...
    @property
    def SpecifiedAnglesNotCompatibleWithLayoutWarning() -> FailureDefinitionId: ...
    @property
    def UnableToMakeConnectionInDirection() -> FailureDefinitionId: ...
    @property
    def UtilizationCoefficientOutOfRange() -> FailureDefinitionId: ...
    @property
    def ZeroLengthSegmentError() -> FailureDefinitionId: ...
    @property
    def ZeroLengthSegmentWarning() -> FailureDefinitionId: ...


class BeamFailures:
    @property
    def CannotBendBeamType() -> FailureDefinitionId: ...


class BeamSystemFailures:
    @property
    def BeamSystemEdgeBeamTooWide() -> FailureDefinitionId: ...
    @property
    def BeamSystemHasTooManyBeams() -> FailureDefinitionId: ...
    @property
    def BeamSystemTagBadView() -> FailureDefinitionId: ...


class BendFailures:
    @property
    def BendAngleIsUnacceptable() -> FailureDefinitionId: ...
    @property
    def DeleteMiddleBendNotAllowed() -> FailureDefinitionId: ...
    @property
    def DeleteSegmentInBankNotAllowed() -> FailureDefinitionId: ...
    @property
    def NotBentControl() -> FailureDefinitionId: ...
    @property
    def NotBentDetailComponent() -> FailureDefinitionId: ...
    @property
    def NotBentFilledRegion() -> FailureDefinitionId: ...
    @property
    def NotBentImage() -> FailureDefinitionId: ...
    @property
    def NotBentImport() -> FailureDefinitionId: ...
    @property
    def NotBentMaskingRegion() -> FailureDefinitionId: ...
    @property
    def NotBentModelLine() -> FailureDefinitionId: ...
    @property
    def NotBentOpening() -> FailureDefinitionId: ...
    @property
    def NotBentRefLine() -> FailureDefinitionId: ...
    @property
    def NotBentRefPlane() -> FailureDefinitionId: ...
    @property
    def NotBentSharedFamily() -> FailureDefinitionId: ...
    @property
    def NotBentSymbol() -> FailureDefinitionId: ...
    @property
    def NotBentSymbolicLine() -> FailureDefinitionId: ...


class BlendFailures:
    @property
    def CannotDrawBlend() -> FailureDefinitionId: ...


class ColorFillFailures:
    @property
    def OnlyOneColorFillNonPlan() -> FailureDefinitionId: ...
    @property
    def SymtemColorFillLegendNotAllowed() -> FailureDefinitionId: ...


class ColumnFailures:
    @property
    def ColumnAndTargetAreConcrete() -> FailureDefinitionId: ...
    @property
    def ColumnBaseAboveTopError() -> FailureDefinitionId: ...
    @property
    def ColumnBaseAboveTopFailure() -> FailureDefinitionId: ...
    @property
    def ColumnJoinNonhitFailure() -> FailureDefinitionId: ...
    @property
    def ColumnTopBelowBaseError() -> FailureDefinitionId: ...
    @property
    def ColumnTopBelowBaseFailure() -> FailureDefinitionId: ...
    @property
    def ColumnZeroHeightError() -> FailureDefinitionId: ...
    @property
    def ColumnZeroHeightFailure() -> FailureDefinitionId: ...


class ColumnInsideWallFailures:
    @property
    def ColumnInsideWall() -> FailureDefinitionId: ...
    @property
    def CopingWarningExtension() -> FailureDefinitionId: ...
    @property
    def CopingWarningIgnored() -> FailureDefinitionId: ...
    @property
    def CopingWarningMedium() -> FailureDefinitionId: ...
    @property
    def CopingWarningOffset() -> FailureDefinitionId: ...
    @property
    def StartCutShadowJoin() -> FailureDefinitionId: ...
    @property
    def StopCutShadowJoin() -> FailureDefinitionId: ...


class ComponentRepeaterFailures:
    @property
    def ComponentRepeater_InvalidFamilyOnReload() -> FailureDefinitionId: ...
    @property
    def ComponentRepeater_ThereIsOnlyOneInstanceInThisRepeater() -> FailureDefinitionId: ...


class ComponentRepeaterSlotFailures:
    @property
    def ComponentRepeaterSlot_InvalidFamilyOnReload() -> FailureDefinitionId: ...


class ConnectorFailures:
    @property
    def AirTerminalCenterNotAligned() -> FailureDefinitionId: ...
    @property
    def AllElementsRemovedFromCircuitGroup() -> FailureDefinitionId: ...
    @property
    def DisconnectedElements() -> FailureDefinitionId: ...
    @property
    def ElementAssignedToDefaultSystem() -> FailureDefinitionId: ...
    @property
    def ElementHasMultipleConnectors() -> FailureDefinitionId: ...
    @property
    def ElementsAreDisconnected() -> FailureDefinitionId: ...
    @property
    def ElementsConnectedToParent() -> FailureDefinitionId: ...
    @property
    def ElementsNeedToBeDisconnected() -> FailureDefinitionId: ...
    @property
    def ExistsForSelectedElement() -> FailureDefinitionId: ...
    @property
    def FittingMustBeOnDuct() -> FailureDefinitionId: ...
    @property
    def FittingMustBeOnDuctWarn() -> FailureDefinitionId: ...
    @property
    def FittingMustBeOnPipe() -> FailureDefinitionId: ...
    @property
    def FittingMustBeOnPipeWarn() -> FailureDefinitionId: ...
    @property
    def InvalidConnectionRef() -> FailureDefinitionId: ...
    @property
    def InvalidConnector() -> FailureDefinitionId: ...
    @property
    def InvalidLoadClassificationValue() -> FailureDefinitionId: ...
    @property
    def InvalidPowerFactorValue() -> FailureDefinitionId: ...
    @property
    def JointGenderMismatch() -> FailureDefinitionId: ...
    @property
    def JointShapeMismatch() -> FailureDefinitionId: ...
    @property
    def JointSizeMismatch() -> FailureDefinitionId: ...
    @property
    def JointTypeMismatch() -> FailureDefinitionId: ...
    @property
    def LayoutConnector() -> FailureDefinitionId: ...
    @property
    def MismatchNoAvailableConnector() -> FailureDefinitionId: ...
    @property
    def MultipleNetwork() -> FailureDefinitionId: ...
    @property
    def NetworkValidityError() -> FailureDefinitionId: ...
    @property
    def NetworkValidityErrorWasDisconnected() -> FailureDefinitionId: ...
    @property
    def NoLossDefined() -> FailureDefinitionId: ...
    @property
    def NoSupportKCoefficientTable() -> FailureDefinitionId: ...
    @property
    def NotAllowedToModifyGroupElementsError() -> FailureDefinitionId: ...
    @property
    def NotAllowedToModifyGroupElementsWarning() -> FailureDefinitionId: ...
    @property
    def OpenConnector() -> FailureDefinitionId: ...
    @property
    def RbsNetworkValidityError() -> FailureDefinitionId: ...
    @property
    def RemoveConnectorLinkWarn() -> FailureDefinitionId: ...
    @property
    def RemoveConnectorLinksWarn() -> FailureDefinitionId: ...
    @property
    def ShapesNotMatch() -> FailureDefinitionId: ...
    @property
    def SizingCalculationFlowOnlyWarn() -> FailureDefinitionId: ...
    @property
    def SizingCalculationNoneWarn() -> FailureDefinitionId: ...
    @property
    def SizingFailed() -> FailureDefinitionId: ...
    @property
    def UnconnectedCircuit() -> FailureDefinitionId: ...
    @property
    def UnconnectedDevice() -> FailureDefinitionId: ...
    @property
    def UndefinedConnector() -> FailureDefinitionId: ...


class ConstraintFailures:
    @property
    def UndeletedConstraints() -> FailureDefinitionId: ...
    @property
    def UndeletedConstraintsEQ() -> FailureDefinitionId: ...
    @property
    def UndeletedConstraintsInGroup() -> FailureDefinitionId: ...
    @property
    def UndeletedConstraintsLabel() -> FailureDefinitionId: ...


class ConversionFailures:
    @property
    def CannotConvertPercentToDouble() -> FailureDefinitionId: ...
    @property
    def CannotConvertTempToDouble() -> FailureDefinitionId: ...
    @property
    def CannotConvertToDouble() -> FailureDefinitionId: ...
    @property
    def UndefinedFluidUnit() -> FailureDefinitionId: ...
    @property
    def UndefinedTemperatureUnit() -> FailureDefinitionId: ...


class CopyMonitorFailures:
    @property
    def AlreadyCopiedAndStopWatch() -> FailureDefinitionId: ...
    @property
    def AlreadyWatched() -> FailureDefinitionId: ...
    @property
    def CannotCopyCuttingInsert() -> FailureDefinitionId: ...
    @property
    def CannotMoveHostedFixtureViaCopyMonitor() -> FailureDefinitionId: ...
    @property
    def CopyWatchAlert() -> FailureDefinitionId: ...
    @property
    def GridDeletedSameName() -> FailureDefinitionId: ...
    @property
    def LevelDeletedSameName() -> FailureDefinitionId: ...


class CopyPasteFailures:
    @property
    def CannotCopyAttachedType() -> FailureDefinitionId: ...
    @property
    def CannotCopyAttachedTypeWarn() -> FailureDefinitionId: ...
    @property
    def CannotCopyBetweenFamilyAndProjectCorruption() -> FailureDefinitionId: ...
    @property
    def CannotCopyBetweenFamilyAndProjectError() -> FailureDefinitionId: ...
    @property
    def CannotCopyCurtainWallGridLines() -> FailureDefinitionId: ...
    @property
    def CannotCopyDependentView() -> FailureDefinitionId: ...
    @property
    def CannotCopyDetails() -> FailureDefinitionId: ...
    @property
    def CannotCopyDueToBackgroundCalculation() -> FailureDefinitionId: ...
    @property
    def CannotCopyDuplicates() -> FailureDefinitionId: ...
    @property
    def CannotCopyElevationArrow() -> FailureDefinitionId: ...
    @property
    def CannotCopyElevationArrowWarn() -> FailureDefinitionId: ...
    @property
    def CannotCopyFamilyName() -> FailureDefinitionId: ...
    @property
    def CannotCopyFromProjectAndLink() -> FailureDefinitionId: ...
    @property
    def CannotCopyGridLines() -> FailureDefinitionId: ...
    @property
    def CannotCopyGridLinesWarn() -> FailureDefinitionId: ...
    @property
    def CannotCopyImportInstancesAcrossProjects() -> FailureDefinitionId: ...
    @property
    def CannotCopyIncompleteElement() -> FailureDefinitionId: ...
    @property
    def CannotCopyIncompleteElementWarn() -> FailureDefinitionId: ...
    @property
    def CannotCopyJoinedGeometry() -> FailureDefinitionId: ...
    @property
    def CannotCopyJoinedGeometryWarn() -> FailureDefinitionId: ...
    @property
    def CannotCopyLocked() -> FailureDefinitionId: ...
    @property
    def CannotCopyLockedWarn() -> FailureDefinitionId: ...
    @property
    def CannotCopyMassing() -> FailureDefinitionId: ...
    @property
    def CannotCopyMassingWarn() -> FailureDefinitionId: ...
    @property
    def CannotCopyMullions() -> FailureDefinitionId: ...
    @property
    def CannotCopyMullionsError() -> FailureDefinitionId: ...
    @property
    def CannotCopyMullionsWarn() -> FailureDefinitionId: ...
    @property
    def CannotCopyMultipleSketchParents() -> FailureDefinitionId: ...
    @property
    def CannotCopyMustBeUnique() -> FailureDefinitionId: ...
    @property
    def CannotCopyMustBeUniqueViewport() -> FailureDefinitionId: ...
    @property
    def CannotCopyMustBeUniqueViewportWarn() -> FailureDefinitionId: ...
    @property
    def CannotCopyMustBeUniqueWarn() -> FailureDefinitionId: ...
    @property
    def CannotCopyNestedLinks() -> FailureDefinitionId: ...
    @property
    def CannotCopyNoAttachedParent() -> FailureDefinitionId: ...
    @property
    def CannotCopyNoAttachedParentWarn() -> FailureDefinitionId: ...
    @property
    def CannotCopyNoParents() -> FailureDefinitionId: ...
    @property
    def CannotCopyNoReferences() -> FailureDefinitionId: ...
    @property
    def CannotCopyRevolveAxis() -> FailureDefinitionId: ...
    @property
    def CannotCopyRevolveAxisWarn() -> FailureDefinitionId: ...
    @property
    def CannotCopySelectedPick() -> FailureDefinitionId: ...
    @property
    def CannotCopySelection() -> FailureDefinitionId: ...
    @property
    def CannotCopySketchGrid() -> FailureDefinitionId: ...
    @property
    def CannotCopySketchGridWarn() -> FailureDefinitionId: ...
    @property
    def CannotCopySunAndShadowSettings() -> FailureDefinitionId: ...
    @property
    def CannotCopySunAndShadowSettingsWarn() -> FailureDefinitionId: ...
    @property
    def CannotCopyWallPanels() -> FailureDefinitionId: ...
    @property
    def CannotCopyWallPanelsWarn() -> FailureDefinitionId: ...
    @property
    def CannotCopyZone() -> FailureDefinitionId: ...
    @property
    def CannotCopyZoneWarn() -> FailureDefinitionId: ...
    @property
    def CannotDuplicate() -> FailureDefinitionId: ...
    @property
    def CannotDuplicateDesignOption() -> FailureDefinitionId: ...
    @property
    def CannotDuplicateInOption() -> FailureDefinitionId: ...
    @property
    def CannotDuplicateInOptionWarn() -> FailureDefinitionId: ...
    @property
    def CannotDuplicateType() -> FailureDefinitionId: ...
    @property
    def CannotDuplicateWarn() -> FailureDefinitionId: ...
    @property
    def CannotFinalizeClusterInconsistency() -> FailureDefinitionId: ...
    @property
    def CannotFinalizeOrphanSerf() -> FailureDefinitionId: ...
    @property
    def CannotPasteAlignedAny() -> FailureDefinitionId: ...
    @property
    def CannotPasteAlignedCorruption() -> FailureDefinitionId: ...
    @property
    def CannotPasteAlignedError() -> FailureDefinitionId: ...
    @property
    def CannotPasteAlignedSomeLevels() -> FailureDefinitionId: ...
    @property
    def CannotPasteAssemblyView() -> FailureDefinitionId: ...
    @property
    def CannotPasteCircularLinks() -> FailureDefinitionId: ...
    @property
    def CannotPasteCurtainGridLine() -> FailureDefinitionId: ...
    @property
    def CannotPasteDifferentViewSpecificElements() -> FailureDefinitionId: ...
    @property
    def CannotPasteElemInViewError() -> FailureDefinitionId: ...
    @property
    def CannotPasteInSketch() -> FailureDefinitionId: ...
    @property
    def CannotPasteInView() -> FailureDefinitionId: ...
    @property
    def CannotPasteInViewError() -> FailureDefinitionId: ...
    @property
    def CannotPasteModelPlusViewSpecificElementsIntoView() -> FailureDefinitionId: ...
    @property
    def CannotPasteNoLevelAbove() -> FailureDefinitionId: ...
    @property
    def CannotPasteNoLevelBelow() -> FailureDefinitionId: ...
    @property
    def CannotPasteNoWorkplane() -> FailureDefinitionId: ...
    @property
    def CannotPasteRoomsInNonPlanViews() -> FailureDefinitionId: ...
    @property
    def CannotPasteToSheet() -> FailureDefinitionId: ...
    @property
    def CannotPasteViewSpecElemsFromDiffViews() -> FailureDefinitionId: ...
    @property
    def CannotPasteViewSpecificElementsIntoPerspectiveView() -> FailureDefinitionId: ...
    @property
    def CannotTransferProjectStandards() -> FailureDefinitionId: ...
    @property
    def CantCopyBetweenModelAndAnnotFam() -> FailureDefinitionId: ...
    @property
    def CantCopyElemsToInplaceFam() -> FailureDefinitionId: ...
    @property
    def CantCopyFrom2dTo3dFam() -> FailureDefinitionId: ...
    @property
    def CantCopyFrom3dTo2dFam() -> FailureDefinitionId: ...
    @property
    def CantCopyFromDetailToProfileFam() -> FailureDefinitionId: ...
    @property
    def CantCopyLevelsOrRefPlanesToNonMassFamily() -> FailureDefinitionId: ...
    @property
    def CantCopyStairsLevelHeightNotMatchInMS() -> FailureDefinitionId: ...
    @property
    def CantCopySymbolicElementToSelfOrientingFamily() -> FailureDefinitionId: ...
    @property
    def CopingColumnBeamFailure() -> FailureDefinitionId: ...
    @property
    def CopyImposterContentError() -> FailureDefinitionId: ...
    @property
    def CopyImposterContentWarn() -> FailureDefinitionId: ...
    @property
    def CopyImposterLightError() -> FailureDefinitionId: ...
    @property
    def CopyImposterLightWarn() -> FailureDefinitionId: ...
    @property
    def ElementRenamedOnPaste() -> FailureDefinitionId: ...
    @property
    def FinalizedElementsWillBeDeleted() -> FailureDefinitionId: ...
    @property
    def FinalizedElementsWillBeDeletedWarn() -> FailureDefinitionId: ...
    @property
    def FinalizedElementsWillBeModified() -> FailureDefinitionId: ...
    @property
    def FinalizedElementsWillBeModifiedWarn() -> FailureDefinitionId: ...
    @property
    def LostReference() -> FailureDefinitionId: ...
    @property
    def NoSketchPlane() -> FailureDefinitionId: ...
    @property
    def PasteInvisibleInView() -> FailureDefinitionId: ...
    @property
    def SomeElementsNotCopiedWarn() -> FailureDefinitionId: ...


class CreationFailures:
    @property
    def CannotCreateCornice() -> FailureDefinitionId: ...
    @property
    def CannotCreateCorniceError() -> FailureDefinitionId: ...
    @property
    def CannotCreateCorniceIntegral() -> FailureDefinitionId: ...
    @property
    def CannotCreateCorniceIntegralError() -> FailureDefinitionId: ...
    @property
    def CannotCreateCorniceIntegralWarn() -> FailureDefinitionId: ...
    @property
    def CannotCreateCorniceWarn() -> FailureDefinitionId: ...
    @property
    def CannotCreateCurtainGrid() -> FailureDefinitionId: ...
    @property
    def CannotCreateCutout() -> FailureDefinitionId: ...
    @property
    def CannotCreateCutoutError() -> FailureDefinitionId: ...
    @property
    def CannotCreateCutoutWarn() -> FailureDefinitionId: ...
    @property
    def CannotCreateElementInFamily() -> FailureDefinitionId: ...
    @property
    def CannotCreateElementInView() -> FailureDefinitionId: ...
    @property
    def CannotCreateExplicitCrease() -> FailureDefinitionId: ...
    @property
    def CannotCreateFascia() -> FailureDefinitionId: ...
    @property
    def CannotCreateFasciaError() -> FailureDefinitionId: ...
    @property
    def CannotCreateFasciaWarn() -> FailureDefinitionId: ...
    @property
    def CannotCreateGutter() -> FailureDefinitionId: ...
    @property
    def CannotCreateGutterError() -> FailureDefinitionId: ...
    @property
    def CannotCreateGutterWarn() -> FailureDefinitionId: ...
    @property
    def CannotCreateMullion() -> FailureDefinitionId: ...
    @property
    def CannotCreateMullionError() -> FailureDefinitionId: ...
    @property
    def CannotCreateMullionReference() -> FailureDefinitionId: ...
    @property
    def CannotCreateMullionReferenceNoGeometry() -> FailureDefinitionId: ...
    @property
    def CannotCreateNewDesignOption() -> FailureDefinitionId: ...
    @property
    def CannotCreateOldCornerMullion() -> FailureDefinitionId: ...
    @property
    def CannotCreateOpening() -> FailureDefinitionId: ...
    @property
    def CannotCreateOpeningCutOut() -> FailureDefinitionId: ...
    @property
    def CannotCreateOpeningRectangularArcWall() -> FailureDefinitionId: ...
    @property
    def CannotCreateReveal() -> FailureDefinitionId: ...
    @property
    def CannotCreateRevealError() -> FailureDefinitionId: ...
    @property
    def CannotCreateRevealIntegral() -> FailureDefinitionId: ...
    @property
    def CannotCreateRevealIntegralError() -> FailureDefinitionId: ...
    @property
    def CannotCreateRevealIntegralWarn() -> FailureDefinitionId: ...
    @property
    def CannotCreateRevealWarn() -> FailureDefinitionId: ...
    @property
    def CannotCreateSlabEdge() -> FailureDefinitionId: ...
    @property
    def CannotCreateSlabEdgeError() -> FailureDefinitionId: ...
    @property
    def CannotCreateSlabEdgeWarn() -> FailureDefinitionId: ...
    @property
    def CannotCreateSystemPanel() -> FailureDefinitionId: ...
    @property
    def CannotCreateThis() -> FailureDefinitionId: ...
    @property
    def CannotDrawProfileRoof() -> FailureDefinitionId: ...
    @property
    def CannotDrawRoof() -> FailureDefinitionId: ...
    @property
    def CannotDrawRoofError() -> FailureDefinitionId: ...
    @property
    def CannotDrawRoofWall() -> FailureDefinitionId: ...
    @property
    def CannotDrawSingularSlantedWall() -> FailureDefinitionId: ...
    @property
    def CannotDrawSingularSlantedWallError() -> FailureDefinitionId: ...
    @property
    def CannotDrawWalls() -> FailureDefinitionId: ...
    @property
    def CannotDrawWallsError() -> FailureDefinitionId: ...
    @property
    def CannotMakeRoofFromVerticalFace() -> FailureDefinitionId: ...
    @property
    def CannotMakeRoofFromVerticalFaceError() -> FailureDefinitionId: ...
    @property
    def CannotMakeSurface() -> FailureDefinitionId: ...
    @property
    def CannotMakeSurfaceError() -> FailureDefinitionId: ...
    @property
    def CannotMakeSurfaceWarn() -> FailureDefinitionId: ...
    @property
    def CannotMakeWall() -> FailureDefinitionId: ...
    @property
    def CannotUpdateWall() -> FailureDefinitionId: ...
    @property
    def SwitchFromLegendBeforeCreateSimilar() -> FailureDefinitionId: ...


class CurtainGridFamilyFailures:
    @property
    def AllMullionsAreTooShort() -> FailureDefinitionId: ...
    @property
    def CannotCreateCornerMullionDueAngle() -> FailureDefinitionId: ...
    @property
    def CannotCreateCurtainPanelCorruption() -> FailureDefinitionId: ...
    @property
    def CannotCreateCurtainPanelError() -> FailureDefinitionId: ...
    @property
    def CannotCreateCurtainPanelInOpeningCorruption() -> FailureDefinitionId: ...
    @property
    def CannotCreateCurtainPanelInOpeningWarning() -> FailureDefinitionId: ...
    @property
    def CannotGenerateAllNecessaryElements() -> FailureDefinitionId: ...
    @property
    def CannotPlaceSystemMullionFamilyOnCurtainWall() -> FailureDefinitionId: ...
    @property
    def CannotPlaceSystemPanelsInOldArcedCurtainWalls() -> FailureDefinitionId: ...
    @property
    def CornerMullionOverlapsOtherOnePlacedOnNeighboringRegion() -> FailureDefinitionId: ...
    @property
    def CornerMullionsNeighborsMustBeTangent() -> FailureDefinitionId: ...
    @property
    def CurtainPanelNotBelongsToElement() -> FailureDefinitionId: ...
    @property
    def CurtainPanelsParamDefinedTypeDefinedCirculary() -> FailureDefinitionId: ...
    @property
    def CurtainSystemCouldnotReacquireFaces() -> FailureDefinitionId: ...
    @property
    def InvalidCurtainPanelInModel() -> FailureDefinitionId: ...
    @property
    def MullionProfileContainsMoreThanOneOrOpenLoop() -> FailureDefinitionId: ...
    @property
    def NonSystemPanelFamiliesCannotBeUsed() -> FailureDefinitionId: ...
    @property
    def PanelsSlightlyMalformedCorruption() -> FailureDefinitionId: ...
    @property
    def PanelsSlightlyMalformedWarning() -> FailureDefinitionId: ...
    @property
    def SomeMullionsAreTooShort() -> FailureDefinitionId: ...


class CurtainWallFailures:
    @property
    def AdjustEndCurtainWallParameterNoCorners() -> FailureDefinitionId: ...
    @property
    def AllGridSegmentsRemoved() -> FailureDefinitionId: ...
    @property
    def CannotApplyGridSpecification() -> FailureDefinitionId: ...
    @property
    def CannotDivideCurtainGrid() -> FailureDefinitionId: ...
    @property
    def CannotGroupCurtainGridHost() -> FailureDefinitionId: ...
    @property
    def CannotHaveIndependentOverlappingGrids() -> FailureDefinitionId: ...
    @property
    def CannotPlaceSplitMullions() -> FailureDefinitionId: ...
    @property
    def CannotSplitOldMullions() -> FailureDefinitionId: ...
    @property
    def CannotSwitchToCurtainWall() -> FailureDefinitionId: ...
    @property
    def CannotUseCornerMullion() -> FailureDefinitionId: ...
    @property
    def CurtainGridFaceCannotBeReparamForGridRotation() -> FailureDefinitionId: ...
    @property
    def CurtainGridOffHost() -> FailureDefinitionId: ...
    @property
    def CurtainSystemHostInvisible() -> FailureDefinitionId: ...
    @property
    def DanglingCurtainWallCorner() -> FailureDefinitionId: ...
    @property
    def DeletingCurtainSystemFaceGridLines() -> FailureDefinitionId: ...
    @property
    def DependentGridlineMayBeDeleted() -> FailureDefinitionId: ...
    @property
    def ExceedMaxDrivenGridlines() -> FailureDefinitionId: ...
    @property
    def ExessiveBeltDistance() -> FailureDefinitionId: ...
    @property
    def GridOutOfOrder() -> FailureDefinitionId: ...
    @property
    def GridOutOfOrderError() -> FailureDefinitionId: ...
    @property
    def GridOutsideWall() -> FailureDefinitionId: ...
    @property
    def GridlinesOutOfBounds() -> FailureDefinitionId: ...
    @property
    def GridlinesOutOfBoundsWarn() -> FailureDefinitionId: ...
    @property
    def GridlinesOutsideWillBeRedependent() -> FailureDefinitionId: ...
    @property
    def GridlinesOverlap() -> FailureDefinitionId: ...
    @property
    def GridlinesWerePushed() -> FailureDefinitionId: ...
    @property
    def InvalidSkipSegments() -> FailureDefinitionId: ...
    @property
    def MullionLostRefReorder() -> FailureDefinitionId: ...
    @property
    def MullionsWillBeDeleted() -> FailureDefinitionId: ...
    @property
    def MultipleDominatingMullions() -> FailureDefinitionId: ...
    @property
    def MultipleIdsInCurtainSystem() -> FailureDefinitionId: ...
    @property
    def MustReplacePanels() -> FailureDefinitionId: ...
    @property
    def NegativeBeltDistance() -> FailureDefinitionId: ...
    @property
    def NoPanelsLoaded() -> FailureDefinitionId: ...
    @property
    def NonSupportedCurtainWall() -> FailureDefinitionId: ...
    @property
    def RequestOrphanMullionDeletion() -> FailureDefinitionId: ...
    @property
    def RuledCurtainElementLostCurves() -> FailureDefinitionId: ...
    @property
    def TypePanelsFronNonRectCellsUnlocked() -> FailureDefinitionId: ...


class CurveByPointFailures:
    @property
    def UnableToGenerateCurve() -> FailureDefinitionId: ...


class CurveFailures:
    @property
    def CannotFindAreaScheme() -> FailureDefinitionId: ...
    @property
    def CantKeepJoinTangent() -> FailureDefinitionId: ...
    @property
    def CurveNotEditable() -> FailureDefinitionId: ...
    @property
    def CurveNotEditableWarn() -> FailureDefinitionId: ...
    @property
    def InvalidCurveForElement() -> FailureDefinitionId: ...
    @property
    def LineTooShortError() -> FailureDefinitionId: ...
    @property
    def LineTooShortWarning() -> FailureDefinitionId: ...
    @property
    def PeriodicCurveBadParams() -> FailureDefinitionId: ...
    @property
    def SelfIntersectingSpline() -> FailureDefinitionId: ...
    @property
    def TooShort() -> FailureDefinitionId: ...


class CutFailures:
    @property
    def CannotCutGeometry() -> FailureDefinitionId: ...
    @property
    def CannotCutGeometryWarn() -> FailureDefinitionId: ...
    @property
    def CannotCutInstanceOut() -> FailureDefinitionId: ...
    @property
    def CannotCutInstanceOutError() -> FailureDefinitionId: ...
    @property
    def CannotCutInstanceOutGen() -> FailureDefinitionId: ...
    @property
    def CannotCutInstanceOutGenError() -> FailureDefinitionId: ...
    @property
    def CannotCutInstanceOutGenWarn() -> FailureDefinitionId: ...
    @property
    def CannotCutInstanceOutWarn() -> FailureDefinitionId: ...
    @property
    def CannotCutJoinedElement() -> FailureDefinitionId: ...
    @property
    def CannotCutRoof() -> FailureDefinitionId: ...
    @property
    def CannotCutRoofError() -> FailureDefinitionId: ...
    @property
    def CantCutHostWithInstance() -> FailureDefinitionId: ...
    @property
    def CutExactlyHalf() -> FailureDefinitionId: ...
    @property
    def CutoutNotCuttingAnything() -> FailureDefinitionId: ...
    @property
    def CutoutNotCuttingAnythingDeleteOpening() -> FailureDefinitionId: ...
    @property
    def DormerCutProblem() -> FailureDefinitionId: ...
    @property
    def DormerCutProblemWarn() -> FailureDefinitionId: ...
    @property
    def HostCutoutForInsertionFailure() -> FailureDefinitionId: ...
    @property
    def InstanceNotCuttingAnything() -> FailureDefinitionId: ...


class CutterFailures:
    @property
    def MakeCutterForPlanRegionsGStepFailed() -> FailureDefinitionId: ...
    @property
    def MakeCutterForSectionGStepFailed() -> FailureDefinitionId: ...


class CuttingFailures:
    @property
    def CannotCopyFromMultipleLinks() -> FailureDefinitionId: ...
    @property
    def ElementsWithNotCopiedParentsDeleted() -> FailureDefinitionId: ...
    @property
    def NoFileSaved() -> FailureDefinitionId: ...
    @property
    def NoSupported2DElementsToCopyFromView() -> FailureDefinitionId: ...
    @property
    def UnableToCopyElementsFromFile() -> FailureDefinitionId: ...
    @property
    def UnableToPasteToFile() -> FailureDefinitionId: ...
    @property
    def UnableToReplaceWithLink() -> FailureDefinitionId: ...


class DPartFailures:
    @property
    def BindLinkWillDeleteAllPartsWarning() -> FailureDefinitionId: ...
    @property
    def DeletingDPartWillDeleteAllPartsWarning() -> FailureDefinitionId: ...
    @property
    def DeletingDPartWillDeleteMorePartsError() -> FailureDefinitionId: ...
    @property
    def DeletingOriginalWillDeleteParts() -> FailureDefinitionId: ...
    @property
    def DivideVolumesProfilesEdgeMatchForWidthAll() -> FailureDefinitionId: ...
    @property
    def DivideVolumesProfilesEdgeMatchForWidthSome() -> FailureDefinitionId: ...
    @property
    def DivideVolumesProfilesForWidthAll() -> FailureDefinitionId: ...
    @property
    def DivideVolumesProfilesForWidthSome() -> FailureDefinitionId: ...
    @property
    def DivideVolumesProfilesGapForWidthAll() -> FailureDefinitionId: ...
    @property
    def DivideVolumesProfilesGapForWidthSome() -> FailureDefinitionId: ...
    @property
    def DivideVolumesProfilesNonSlabSources() -> FailureDefinitionId: ...
    @property
    def DivideVolumesSketchesWithProfileUnfriendlyCurves() -> FailureDefinitionId: ...
    @property
    def DivisionContainsNoParts() -> FailureDefinitionId: ...
    @property
    def DivisionContainsNoReferences() -> FailureDefinitionId: ...
    @property
    def ElementsAlreadyHaveParts() -> FailureDefinitionId: ...
    @property
    def IneligibleElementsForParts() -> FailureDefinitionId: ...
    @property
    def NoPartMakerCreatedInEditMode() -> FailureDefinitionId: ...
    @property
    def PartPhaseParametersConflictWithOriginal() -> FailureDefinitionId: ...
    @property
    def PartsCannotBeCreatedFromInvalidGeom() -> FailureDefinitionId: ...
    @property
    def RemovingInvalidDPartParents() -> FailureDefinitionId: ...
    @property
    def RemovingUndividedDPartParents() -> FailureDefinitionId: ...
    @property
    def SourceInUnloadedLink() -> FailureDefinitionId: ...


class DatumPlaneFailures:
    @property
    def ScopeBoxWrongPosition() -> FailureDefinitionId: ...


class DebugTabBindingFailures:
    @property
    def OptionValueOutOfRange() -> FailureDefinitionId: ...


class DecalFailures:
    @property
    def CannotPaste() -> FailureDefinitionId: ...
    @property
    def LongerThanPossible() -> FailureDefinitionId: ...
    @property
    def OutsideHost() -> FailureDefinitionId: ...


class DesignOptionFailures:
    @property
    def AreaTagLineCannotBeInDesignOption() -> FailureDefinitionId: ...
    @property
    def BadReferenceBetweenOptions() -> FailureDefinitionId: ...
    @property
    def BadReferenceBetweenOptionsWarn() -> FailureDefinitionId: ...
    @property
    def BadReferenceToSecondary() -> FailureDefinitionId: ...
    @property
    def BadReferenceToSecondaryWarn() -> FailureDefinitionId: ...
    @property
    def CannotAddToOptions() -> FailureDefinitionId: ...
    @property
    def CannotAddToOptionsWarn() -> FailureDefinitionId: ...
    @property
    def CannotPutSpaceInOption() -> FailureDefinitionId: ...
    @property
    def CannotPutZoneInOption() -> FailureDefinitionId: ...
    @property
    def ConfusingHostByElementsInAnotherDesignOption() -> FailureDefinitionId: ...
    @property
    def ConfusingHostByElementsInAnotherDesignOptionWarn() -> FailureDefinitionId: ...
    @property
    def ConfusingHostByElementsInDesignOption() -> FailureDefinitionId: ...
    @property
    def ConfusingHostByElementsInDesignOptionWarn() -> FailureDefinitionId: ...
    @property
    def ConfusingHostByElementsInMainModel() -> FailureDefinitionId: ...
    @property
    def ConfusingHostByElementsInMainModelWarn() -> FailureDefinitionId: ...
    @property
    def ConfusingPadByElementsInAnotherDesignOption() -> FailureDefinitionId: ...
    @property
    def ConfusingPadByElementsInAnotherDesignOptionWarn() -> FailureDefinitionId: ...
    @property
    def ConfusingPadByElementsInDesignOption() -> FailureDefinitionId: ...
    @property
    def ConfusingPadByElementsInDesignOptionWarn() -> FailureDefinitionId: ...
    @property
    def ConfusingPadByElementsInMainModel() -> FailureDefinitionId: ...
    @property
    def ConfusingPadByElementsInMainModelWarn() -> FailureDefinitionId: ...
    @property
    def ConfusingSweepByElementsInAnotherDesignOption() -> FailureDefinitionId: ...
    @property
    def ConfusingSweepByElementsInAnotherDesignOptionWarn() -> FailureDefinitionId: ...
    @property
    def ConfusingSweepByElementsInDesignOption() -> FailureDefinitionId: ...
    @property
    def ConfusingSweepByElementsInDesignOptionWarn() -> FailureDefinitionId: ...
    @property
    def ConfusingSweepByElementsInMainModel() -> FailureDefinitionId: ...
    @property
    def ConfusingSweepByElementsInMainModelWarn() -> FailureDefinitionId: ...
    @property
    def DebugLevelsInOptionsError() -> FailureDefinitionId: ...
    @property
    def DebugLevelsInOptionsWarn() -> FailureDefinitionId: ...
    @property
    def ElementsWillBeDeletedNoOption() -> FailureDefinitionId: ...
    @property
    def FabricationCannotBeInDesignOption() -> FailureDefinitionId: ...
    @property
    def KingNeverInOption() -> FailureDefinitionId: ...
    @property
    def KingNeverInOptionWarn() -> FailureDefinitionId: ...
    @property
    def MustAddKing() -> FailureDefinitionId: ...
    @property
    def MustAddKingWarn() -> FailureDefinitionId: ...
    @property
    def MustBeInMainModel() -> FailureDefinitionId: ...
    @property
    def NeverInOption() -> FailureDefinitionId: ...
    @property
    def NeverInOptionWarn() -> FailureDefinitionId: ...
    @property
    def NoSelectedInOption() -> FailureDefinitionId: ...
    @property
    def OptionElementsDeleted() -> FailureDefinitionId: ...
    @property
    def SelectionIncludesOptionItems() -> FailureDefinitionId: ...


class DetailFailures:
    @property
    def EavesAreAligned() -> FailureDefinitionId: ...
    @property
    def NeedsTwoToAlignEaves() -> FailureDefinitionId: ...
    @property
    def RepeatingDetailSpacingZeroError() -> FailureDefinitionId: ...


class DimensionFailures:
    @property
    def AngularDimensionRegenFailed() -> FailureDefinitionId: ...
    @property
    def ArcAlignmentRegenFailed() -> FailureDefinitionId: ...
    @property
    def ArcLengthDimensionNoReferencesOnArc() -> FailureDefinitionId: ...
    @property
    def ArcLengthDimensionReferencesNotIntersect() -> FailureDefinitionId: ...
    @property
    def AssocpropNeedJog() -> FailureDefinitionId: ...
    @property
    def CannotConstrainBasePointAlignments() -> FailureDefinitionId: ...
    @property
    def CannotConstrainBasePointDimensions() -> FailureDefinitionId: ...
    @property
    def CannotCreateDimensionNotParallel() -> FailureDefinitionId: ...
    @property
    def CannotDragWitnessLine() -> FailureDefinitionId: ...
    @property
    def CannotLockThisDimension() -> FailureDefinitionId: ...
    @property
    def CannotToggleDimensionEquality() -> FailureDefinitionId: ...
    @property
    def ChangeDimensionSegmentFailed() -> FailureDefinitionId: ...
    @property
    def ChangeSpotElevationFailed() -> FailureDefinitionId: ...
    @property
    def DifferentLabelsInMultiSegmentDim() -> FailureDefinitionId: ...
    @property
    def DimensionOverconstrained() -> FailureDefinitionId: ...
    @property
    def DimensionOverconstrainedError() -> FailureDefinitionId: ...
    @property
    def DimensionOverrideNearByIsLost() -> FailureDefinitionId: ...
    @property
    def DimensionPerpendicularToView() -> FailureDefinitionId: ...
    @property
    def DimensionReferencesInvalid() -> FailureDefinitionId: ...
    @property
    def DimensionUnequaled() -> FailureDefinitionId: ...
    @property
    def DimensionUnlocked() -> FailureDefinitionId: ...
    @property
    def DimensionUnlockedAndUnequaled() -> FailureDefinitionId: ...
    @property
    def EqualityConstraintsUnsatisfied() -> FailureDefinitionId: ...
    @property
    def EqualityConstraintsUnsatisfiedWarn() -> FailureDefinitionId: ...
    @property
    def ForbiddenGroupConstraint() -> FailureDefinitionId: ...
    @property
    def LabelOverconstrained() -> FailureDefinitionId: ...
    @property
    def LabelingDimWithGroupReferences() -> FailureDefinitionId: ...
    @property
    def LabelingMultiSegmentWithReporting() -> FailureDefinitionId: ...
    @property
    def LinearConstraintBadDirection() -> FailureDefinitionId: ...
    @property
    def LinearConstraintNotParallel() -> FailureDefinitionId: ...
    @property
    def LinearDimensionReferenceNotOrthogonalToView() -> FailureDefinitionId: ...
    @property
    def LockOverconstrained() -> FailureDefinitionId: ...
    @property
    def LockOverconstrainedAlignment() -> FailureDefinitionId: ...
    @property
    def LooseLabeledDimensionRegenFailure() -> FailureDefinitionId: ...
    @property
    def MoreThanOneDimsLabelToOneReportingParameter() -> FailureDefinitionId: ...
    @property
    def NoConstraintsInProperSketch() -> FailureDefinitionId: ...
    @property
    def NoConstraintsToLinks() -> FailureDefinitionId: ...
    @property
    def RadialDimensionCannotProjectToArc() -> FailureDefinitionId: ...
    @property
    def RadialDimensionChangeRadiusFailed() -> FailureDefinitionId: ...
    @property
    def RegenConstraintUnsatisfied() -> FailureDefinitionId: ...
    @property
    def RegenConstraintUnsatisfiedWarn() -> FailureDefinitionId: ...
    @property
    def ReportingParamAlreadyLabelsToAnotherDim() -> FailureDefinitionId: ...
    @property
    def SomeDimensionsLostOnPaste() -> FailureDefinitionId: ...
    @property
    def SomeDimensionsLostWitnessLines() -> FailureDefinitionId: ...
    @property
    def SomeSpotDimensionsLostOnPaste() -> FailureDefinitionId: ...
    @property
    def SpotDimensionFloatingPointError() -> FailureDefinitionId: ...
    @property
    def SpotDimensionFormerSetMoribundCall() -> FailureDefinitionId: ...
    @property
    def SpotDimensionReferencesNoLongerHorizontal() -> FailureDefinitionId: ...
    @property
    def SpotElevationLostEdgeReferences() -> FailureDefinitionId: ...
    @property
    def SpotElevationMissesReference() -> FailureDefinitionId: ...
    @property
    def SpotSlopeReferenceIsVertical() -> FailureDefinitionId: ...
    @property
    def SpotSlopeReferencePointIsSingular() -> FailureDefinitionId: ...
    @property
    def UnavailableDimensionHostReference() -> FailureDefinitionId: ...
    @property
    def UnstableConstraintInFamily() -> FailureDefinitionId: ...
    @property
    def WrongConstraintInGridChainSketch() -> FailureDefinitionId: ...
    @property
    def WrongConstraintInJoistSystemSketch() -> FailureDefinitionId: ...
    @property
    def WrongConstraintInSkeletonSketch() -> FailureDefinitionId: ...
    @property
    def WrongConstraintInTrussSketch() -> FailureDefinitionId: ...


class DirectContext3DFailures:
    @property
    def UnableToLoadCoordinationModel() -> FailureDefinitionId: ...


class DirectShapeFailures:
    @property
    def CannotCreateDirectShapeOrTypeDocumentCorruption() -> FailureDefinitionId: ...
    @property
    def CannotCreateDirectShapeOrTypeError() -> FailureDefinitionId: ...
    @property
    def CannotCreateDirectShapeOrTypeWarning() -> FailureDefinitionId: ...


class DisplacementElementFailures:
    @property
    def CannotCopyDisplacementSetIntoOtherDocument() -> FailureDefinitionId: ...
    @property
    def CannotRemoveLastDisplacedElement() -> FailureDefinitionId: ...
    @property
    def DetectedCycleInDisplacedElementParents() -> FailureDefinitionId: ...
    @property
    def ElementsAlreadyDisplacedInView() -> FailureDefinitionId: ...


class DividedPathFailures:
    @property
    def DividedPathCannotApplyDivideSettings() -> FailureDefinitionId: ...
    @property
    def DividedPathCannotBeMirroredWithoutItsCurves() -> FailureDefinitionId: ...
    @property
    def DividedPathCannotCreateFromGeometry() -> FailureDefinitionId: ...
    @property
    def DividedPathDistanceTooSmall() -> FailureDefinitionId: ...
    @property
    def DividedPathIndentsOverlap() -> FailureDefinitionId: ...
    @property
    def DividedPathIntersectionPolycurveParamsStepFailed() -> FailureDefinitionId: ...
    @property
    def DividedPathInvalidNumberOfPoints() -> FailureDefinitionId: ...
    @property
    def DividedPathLayoutStepFailed() -> FailureDefinitionId: ...
    @property
    def DividedPathUpdateMergedPointKeysStepFailed() -> FailureDefinitionId: ...


class DividedSurfaceFailures:
    @property
    def DividedSurfaceCannotApplyDivideSettings() -> FailureDefinitionId: ...
    @property
    def DividedSurfaceCoincidingSplittingWorkplanes() -> FailureDefinitionId: ...
    @property
    def DividedSurfaceCurveChainBelongsToMultipleBeltIntervals() -> FailureDefinitionId: ...
    @property
    def DividedSurfaceCurveChainBothUandV() -> FailureDefinitionId: ...
    @property
    def DividedSurfaceCurveChainDoesNotEngageUorV() -> FailureDefinitionId: ...
    @property
    def DividedSurfaceCurveChainGeneralProblem() -> FailureDefinitionId: ...
    @property
    def DividedSurfaceCurveChainIntersection() -> FailureDefinitionId: ...
    @property
    def DividedSurfaceCurveChainIsTooClosedToGridlines() -> FailureDefinitionId: ...
    @property
    def DividedSurfaceCurveChainMultipleSeqIntersWithDivLine() -> FailureDefinitionId: ...
    @property
    def DividedSurfaceCurveChainNonSeqIntersWithDivLines() -> FailureDefinitionId: ...
    @property
    def DividedSurfaceCurveChainUnsortableBucket() -> FailureDefinitionId: ...
    @property
    def DividedSurfaceCurveFromChainMultipleIntersWithDivLine() -> FailureDefinitionId: ...
    @property
    def DividedSurfaceCurveLoopChainIntersectedByExtensions() -> FailureDefinitionId: ...
    @property
    def DividedSurfaceCuttingSurfaceDoesNotCutMeshFace() -> FailureDefinitionId: ...
    @property
    def DividedSurfaceCuttingSurfaceGeneralProblem() -> FailureDefinitionId: ...
    @property
    def DividedSurfaceCuttingSurfaceMakesMultipleCuts() -> FailureDefinitionId: ...
    @property
    def DividedSurfaceDidNotRegenerateProperly() -> FailureDefinitionId: ...
    @property
    def DividedSurfaceDiscardedSplittersWarning() -> FailureDefinitionId: ...
    @property
    def DividedSurfaceIgnoresSplitters() -> FailureDefinitionId: ...
    @property
    def DividedSurfaceInvalidSpacing() -> FailureDefinitionId: ...
    @property
    def DividedSurfaceLoopsOfSplittingCurves() -> FailureDefinitionId: ...
    @property
    def DividedSurfaceMultipleIntersBetweenOppositeVirtualGrids() -> FailureDefinitionId: ...
    @property
    def DividedSurfaceSelfIntersectingCurveLoopChain() -> FailureDefinitionId: ...
    @property
    def DividedSurfaceSingleCurveLoopsAsSplitters() -> FailureDefinitionId: ...
    @property
    def DividedSurfaceSingleCurveMultipleIntersBetweenOppositeVirtualGrids() -> FailureDefinitionId: ...
    @property
    def DividedSurfaceSplitManagerProblem1dNonWPCurve() -> FailureDefinitionId: ...
    @property
    def DividedSurfaceSplitManagerProblemClosedArcOrEllipse() -> FailureDefinitionId: ...
    @property
    def DividedSurfaceSplitRefInvisible() -> FailureDefinitionId: ...
    @property
    def DividedSurfaceSplittingCurveChainsBetweenMultipleNeighbors() -> FailureDefinitionId: ...
    @property
    def DividedSurfaceSplittingCurvesWithMultipleNeighbors() -> FailureDefinitionId: ...
    @property
    def DividedSurfaceZeroLengthSplittingCurve() -> FailureDefinitionId: ...
    @property
    def MeshTopologicalSortFailed() -> FailureDefinitionId: ...


class DocumentFailures:
    @property
    def ApiDelayedUpdateFailed() -> FailureDefinitionId: ...
    @property
    def CannotAutoUpdate() -> FailureDefinitionId: ...
    @property
    def CannotLoadLink() -> FailureDefinitionId: ...
    @property
    def DUExcessiveRegeneration() -> FailureDefinitionId: ...
    @property
    def DUMisbehavingUpdater() -> FailureDefinitionId: ...


class DuctFailures:
    @property
    def CannotCreateGeometryForDuct() -> FailureDefinitionId: ...
    @property
    def FlexDuctLengthOutOfLimits() -> FailureDefinitionId: ...
    @property
    def NoDuctFittingsInProject() -> FailureDefinitionId: ...
    @property
    def PartNotFoundDueToNoDuctConnectedError() -> FailureDefinitionId: ...
    @property
    def PartNotFoundDueToNoDuctConnectedWarning() -> FailureDefinitionId: ...


class EditingFailures:
    @property
    def AllInvisibleInPlanViewWarn() -> FailureDefinitionId: ...
    @property
    def AllInvisibleInViewWarn() -> FailureDefinitionId: ...
    @property
    def BorrowElementsAtRisk() -> FailureDefinitionId: ...
    @property
    def CannotBorrowBusyContention() -> FailureDefinitionId: ...
    @property
    def CannotCheckoutWorksets() -> FailureDefinitionId: ...
    @property
    def CannotDeleteEditedElement() -> FailureDefinitionId: ...
    @property
    def CannotDeleteEditedElementError() -> FailureDefinitionId: ...
    @property
    def CannotDeletePredefinedFamilyElement() -> FailureDefinitionId: ...
    @property
    def CannotDrawInCurrentView() -> FailureDefinitionId: ...
    @property
    def CannotDuplicateType() -> FailureDefinitionId: ...
    @property
    def CannotEditDeletedElements() -> FailureDefinitionId: ...
    @property
    def CannotEditDeletedWorkset() -> FailureDefinitionId: ...
    @property
    def CannotEditEditingElements() -> FailureDefinitionId: ...
    @property
    def CannotEditElements() -> FailureDefinitionId: ...
    @property
    def CannotEditRenamedWorkset() -> FailureDefinitionId: ...
    @property
    def CannotMirrorInView() -> FailureDefinitionId: ...
    @property
    def CannotMoveElement() -> FailureDefinitionId: ...
    @property
    def CannotMoveElementWarn() -> FailureDefinitionId: ...
    @property
    def CannotMoveElementWithoutWorkplane() -> FailureDefinitionId: ...
    @property
    def CannotMoveHereInViewError() -> FailureDefinitionId: ...
    @property
    def CannotMoveInView() -> FailureDefinitionId: ...
    @property
    def CannotMoveInViewError() -> FailureDefinitionId: ...
    @property
    def CannotMoveLocked() -> FailureDefinitionId: ...
    @property
    def CannotMoveTogether() -> FailureDefinitionId: ...
    @property
    def CannotPickHereInCurrentView() -> FailureDefinitionId: ...
    @property
    def CannotRotateLocked() -> FailureDefinitionId: ...
    @property
    def CannotScaleInView() -> FailureDefinitionId: ...
    @property
    def DeleteElementsError() -> FailureDefinitionId: ...
    @property
    def DeleteElementsWarn() -> FailureDefinitionId: ...
    @property
    def DeletePreventedByGroup() -> FailureDefinitionId: ...
    @property
    def DeletedRequestedWarn() -> FailureDefinitionId: ...
    @property
    def ElementNotEditable() -> FailureDefinitionId: ...
    @property
    def ElementReversed() -> FailureDefinitionId: ...
    @property
    def ElementsDeleted() -> FailureDefinitionId: ...
    @property
    def ElementsDeletedPastedToKeep() -> FailureDefinitionId: ...
    @property
    def ElementsNotInPlane() -> FailureDefinitionId: ...
    @property
    def ElementsWillBeDeleted() -> FailureDefinitionId: ...
    @property
    def ExtendToOtherCrash() -> FailureDefinitionId: ...
    @property
    def ExtendToOtherWarn() -> FailureDefinitionId: ...
    @property
    def GeneratedByMassing() -> FailureDefinitionId: ...
    @property
    def HaveNoPermissionToEdit() -> FailureDefinitionId: ...
    @property
    def HiddenBeamsEditingWarning() -> FailureDefinitionId: ...
    @property
    def InvalidArrayObject() -> FailureDefinitionId: ...
    @property
    def InvalidElemsInSelection() -> FailureDefinitionId: ...
    @property
    def LockedDeleted() -> FailureDefinitionId: ...
    @property
    def LockedDeletedWarn() -> FailureDefinitionId: ...
    @property
    def MirrorProjectSuccess() -> FailureDefinitionId: ...
    @property
    def NElementsDeleted() -> FailureDefinitionId: ...
    @property
    def NElementsWrongPosition() -> FailureDefinitionId: ...
    @property
    def NoRotateMirrorZ() -> FailureDefinitionId: ...
    @property
    def NoRotateMirrorZError() -> FailureDefinitionId: ...
    @property
    def OutOfDateElements() -> FailureDefinitionId: ...
    @property
    def OwnElementsOutOfDate() -> FailureDefinitionId: ...
    @property
    def OwnedByOther() -> FailureDefinitionId: ...
    @property
    def PinnedObjectHostDeleted() -> FailureDefinitionId: ...
    @property
    def PinnedObjectNotDeleted() -> FailureDefinitionId: ...
    @property
    def PinnedObjectSomeDeleted() -> FailureDefinitionId: ...
    @property
    def PressShowToSee() -> FailureDefinitionId: ...
    @property
    def ReloadBeforeMakeEditable() -> FailureDefinitionId: ...
    @property
    def ReloadNoGood() -> FailureDefinitionId: ...
    @property
    def SourceInEditMode() -> FailureDefinitionId: ...
    @property
    def TargetInEditMode() -> FailureDefinitionId: ...
    @property
    def TemporaryChangesOutOfDate() -> FailureDefinitionId: ...
    @property
    def TemporaryChangesTransparentPermissions() -> FailureDefinitionId: ...
    @property
    def TooManyElementsToCheckout() -> FailureDefinitionId: ...
    @property
    def UnableFilletSpecifiedRadius() -> FailureDefinitionId: ...
    @property
    def UnableToMakeSourceWorksetEditable() -> FailureDefinitionId: ...
    @property
    def UnableToTransformElement() -> FailureDefinitionId: ...
    @property
    def UnableToTransformElementError() -> FailureDefinitionId: ...
    @property
    def WorksetHasChangedInCentralFile() -> FailureDefinitionId: ...


class ElectricalFailures:
    @property
    def AllSlotsOnPanelOccupied() -> FailureDefinitionId: ...
    @property
    def BankDistanceSmallerThanDiameter() -> FailureDefinitionId: ...
    @property
    def CableTrayModified() -> FailureDefinitionId: ...
    @property
    def CannotAddMorePolesToCircuit() -> FailureDefinitionId: ...
    @property
    def CannotAssignSecondaryDistSysToCircuit() -> FailureDefinitionId: ...
    @property
    def CannotConnectDifferentDesignOptsObjects() -> FailureDefinitionId: ...
    @property
    def CannotCreatePanelScheduleDuetoNoDefaultTemplate() -> FailureDefinitionId: ...
    @property
    def CannotRemoveMembersInCircuitHavingParent() -> FailureDefinitionId: ...
    @property
    def CircuitOverload() -> FailureDefinitionId: ...
    @property
    def CircuitsOverlapAndDeleteSpareSpace() -> FailureDefinitionId: ...
    @property
    def CircuitsOverlapDisconnectCircuits() -> FailureDefinitionId: ...
    @property
    def ConduitModified() -> FailureDefinitionId: ...
    @property
    def ElementsBelongToOtherCircuit() -> FailureDefinitionId: ...
    @property
    def FamilyMismatchCircuit() -> FailureDefinitionId: ...
    @property
    def FeedThroughLugsIsDisabled() -> FailureDefinitionId: ...
    @property
    def FeedThroughLugsIsNotEnabledAndBindFormulaInFamily() -> FailureDefinitionId: ...
    @property
    def FeedThroughLugsIsNotEnabledAndBindGlobalParam() -> FailureDefinitionId: ...
    @property
    def FeedThroughLugsIsOccupied() -> FailureDefinitionId: ...
    @property
    def FeedThroughLugsIsOccupiedAndDisconnectOtherCircuits() -> FailureDefinitionId: ...
    @property
    def InvalidNumberOfCircuitValueForSwitchPanel() -> FailureDefinitionId: ...
    @property
    def InvalidNumwiresSinglephase() -> FailureDefinitionId: ...
    @property
    def InvalidPathOfParallelConduits() -> FailureDefinitionId: ...
    @property
    def MaximumNumberOfPolesExceeded() -> FailureDefinitionId: ...
    @property
    def MismatchConnectorDistSysToCircuit() -> FailureDefinitionId: ...
    @property
    def MismatchNmbAssignedDistSysToCircuit() -> FailureDefinitionId: ...
    @property
    def MismatchNmbOfPolesToCircuit() -> FailureDefinitionId: ...
    @property
    def MismatchPoleBrakesSlotsNumbers() -> FailureDefinitionId: ...
    @property
    def MismatchVoltageLineToLine() -> FailureDefinitionId: ...
    @property
    def MismatchVoltageToCircuit() -> FailureDefinitionId: ...
    @property
    def MissingOrInvalidWireSizeTable() -> FailureDefinitionId: ...
    @property
    def NoAvailableMatchingConnector() -> FailureDefinitionId: ...
    @property
    def NotAllowedCableTrayConduitRotation() -> FailureDefinitionId: ...
    @property
    def NotEnoughAvailSlotsAndLugsOnPanel() -> FailureDefinitionId: ...
    @property
    def NotEnoughAvailSlotsAndLugsOnSwitchPanel() -> FailureDefinitionId: ...
    @property
    def NotEnoughAvailSlotsOnPanel() -> FailureDefinitionId: ...
    @property
    def NotEnoughRoomForParallelConduits() -> FailureDefinitionId: ...
    @property
    def NotEnoughRoomForParallelPipes() -> FailureDefinitionId: ...
    @property
    def NotEnoughSlotsOnlyLugAvailable() -> FailureDefinitionId: ...
    @property
    def NotEnoughSlotsOnlyLugAvailableForSwitchPanel() -> FailureDefinitionId: ...
    @property
    def NotPositiveBendRadius() -> FailureDefinitionId: ...
    @property
    def NotSupportConcentricBend() -> FailureDefinitionId: ...
    @property
    def NumberOfCircuitFullOnSwitchPanel() -> FailureDefinitionId: ...
    @property
    def ObjsDemolished() -> FailureDefinitionId: ...
    @property
    def PanelMismatchCircuitType() -> FailureDefinitionId: ...
    @property
    def PanelMismatchDistSysWhenCircuitAssigned() -> FailureDefinitionId: ...
    @property
    def SelectedElementsArePartOfOtherCircuit() -> FailureDefinitionId: ...
    @property
    def SmallBendRadius() -> FailureDefinitionId: ...
    @property
    def UnsignedCircuit() -> FailureDefinitionId: ...
    @property
    def VoltageIsOutOfRange() -> FailureDefinitionId: ...
    @property
    def WireMaxSizeNonexistent() -> FailureDefinitionId: ...


class ElectricityFailures:
    @property
    def FamilyMismatchCircuitDisconnected() -> FailureDefinitionId: ...


class ElementFailures:
    @property
    def FailedToRemoveElement() -> FailureDefinitionId: ...
    @property
    def NotAllowedToRemoveAllElements() -> FailureDefinitionId: ...
    @property
    def SplitElementHasTagsWithoutLeaders() -> FailureDefinitionId: ...


class ElementTypeFailures:
    @property
    def NoDefaultType() -> FailureDefinitionId: ...
    @property
    def WarnLastType1() -> FailureDefinitionId: ...


class ElevationFailures:
    @property
    def ElevationDetach() -> FailureDefinitionId: ...
    @property
    def IncompatibleElevationTagFamily() -> FailureDefinitionId: ...
    @property
    def WarnElevSheet() -> FailureDefinitionId: ...


class EnergyAnalysisFailures:
    @property
    def ComputeRoomVolumeNotCheckedWarn() -> FailureDefinitionId: ...
    @property
    def ModelWithNoConditionedSpacesWarn() -> FailureDefinitionId: ...
    @property
    def ModelWithNoOccupiedSpacesWarn() -> FailureDefinitionId: ...
    @property
    def NoRoofsRoomBoundingWarn() -> FailureDefinitionId: ...
    @property
    def NoRoofsSpacesBoundingWarn() -> FailureDefinitionId: ...
    @property
    def NoRoomBoundingElements() -> FailureDefinitionId: ...
    @property
    def NoRoomBoundingElementsWarn() -> FailureDefinitionId: ...
    @property
    def NoRoomsWarn() -> FailureDefinitionId: ...
    @property
    def NoSpaceBoundingElements() -> FailureDefinitionId: ...
    @property
    def NoSpaceBoundingElementsWarn() -> FailureDefinitionId: ...
    @property
    def NoSpaces() -> FailureDefinitionId: ...
    @property
    def NoSpacesWarn() -> FailureDefinitionId: ...
    @property
    def PlenumWithNoCeilingWarn() -> FailureDefinitionId: ...
    @property
    def ProblemWithLightingLoadWarn() -> FailureDefinitionId: ...
    @property
    def ProblemWithPeopleLoadWarn() -> FailureDefinitionId: ...
    @property
    def ProblemWithPowerLoadWarn() -> FailureDefinitionId: ...
    @property
    def RoomGeometryCannotFindFreeFacesBoundingElement() -> FailureDefinitionId: ...
    @property
    def RoomGeometryCannotOverlapBoundingElement() -> FailureDefinitionId: ...
    @property
    def RoomGeometryCannotTrimBoundingElement() -> FailureDefinitionId: ...
    @property
    def RoomNotPlacedWarn() -> FailureDefinitionId: ...
    @property
    def RoomNotUpperBoundedByElement() -> FailureDefinitionId: ...
    @property
    def RoomVolumeNegativeWarn() -> FailureDefinitionId: ...
    @property
    def RoomVolumeNotComputedWarn() -> FailureDefinitionId: ...
    @property
    def SpaceResolutionOutOfRange() -> FailureDefinitionId: ...
    @property
    def SurfaceResolutionOutOfRange() -> FailureDefinitionId: ...
    @property
    def UndefinedRooms() -> FailureDefinitionId: ...
    @property
    def UndefinedSpaces() -> FailureDefinitionId: ...
    @property
    def ZoneWithoutSpacesWarn() -> FailureDefinitionId: ...


class EnergyAnalysisUtilitiesDBFailures:
    @property
    def AimErrEmptyName() -> FailureDefinitionId: ...


class ExportFailures:
    @property
    def IFCFatalExportError() -> FailureDefinitionId: ...
    @property
    def IFCFatalToolkitExportError() -> FailureDefinitionId: ...
    @property
    def IFCGenericExportWarning() -> FailureDefinitionId: ...


class ExternalResourceReferenceFailures:
    @property
    def ReferenceToLocalFile() -> FailureDefinitionId: ...


class ExtrusionFailures:
    @property
    def CannotDrawExtrusions() -> FailureDefinitionId: ...
    @property
    def CannotDrawExtrusionsError() -> FailureDefinitionId: ...
    @property
    def ExtrusionTooThin() -> FailureDefinitionId: ...
    @property
    def InvalidExtrusionCurveloop() -> FailureDefinitionId: ...
    @property
    def InvalidExtrusionCurveloopError() -> FailureDefinitionId: ...


class FabricAreaFailures:
    @property
    def FabricAreaLapSplicesIncorrect() -> FailureDefinitionId: ...
    @property
    def FabricAreaOutSideOfHost() -> FailureDefinitionId: ...


class FabricFailures:
    @property
    def BendDiameterNegative() -> FailureDefinitionId: ...
    @property
    def BendPolylineInvalid() -> FailureDefinitionId: ...
    @property
    def BentHiddenWires() -> FailureDefinitionId: ...
    @property
    def CannotPlaceFabricArea() -> FailureDefinitionId: ...
    @property
    def CannotPlaceFabricAreaWarn() -> FailureDefinitionId: ...
    @property
    def CannotPlaceFabricSheet() -> FailureDefinitionId: ...
    @property
    def CannotPlaceFabricSheetWarn() -> FailureDefinitionId: ...
    @property
    def CoverOffsetTooLong() -> FailureDefinitionId: ...
    @property
    def CoverOffsetTooLongTemp() -> FailureDefinitionId: ...
    @property
    def FabricAreaWrongHost() -> FailureDefinitionId: ...
    @property
    def FabricAreaWrongLapSplice() -> FailureDefinitionId: ...
    @property
    def FabricAreaWrongSheetAlignment() -> FailureDefinitionId: ...
    @property
    def FabricSheetWrongHost() -> FailureDefinitionId: ...
    @property
    def MajorLapSpliceFailure() -> FailureDefinitionId: ...
    @property
    def MajorOverhangFailure() -> FailureDefinitionId: ...
    @property
    def MajorSpacingFailure() -> FailureDefinitionId: ...
    @property
    def MinorLapSpliceFailure() -> FailureDefinitionId: ...
    @property
    def MinorOverhangFailure() -> FailureDefinitionId: ...
    @property
    def MinorSpacingFailure() -> FailureDefinitionId: ...
    @property
    def NoSurfPatternOnWire() -> FailureDefinitionId: ...
    @property
    def NoWireMaterialDensity() -> FailureDefinitionId: ...
    @property
    def WireDiameterTooLarge() -> FailureDefinitionId: ...
    @property
    def WrongFabricSheetEndOverhang() -> FailureDefinitionId: ...
    @property
    def WrongFabricSheetLayoutPattern() -> FailureDefinitionId: ...
    @property
    def WrongFabricSheetNumberOfWires() -> FailureDefinitionId: ...
    @property
    def WrongFabricSheetOverallLength() -> FailureDefinitionId: ...
    @property
    def WrongFabricSheetSpacing() -> FailureDefinitionId: ...
    @property
    def WrongFabricSheetStartOverhang() -> FailureDefinitionId: ...


class FabricSheetFailures:
    @property
    def BentFabricSheetTooLongBendingProfile() -> FailureDefinitionId: ...
    @property
    def FabricSheetOutSideOfHostError() -> FailureDefinitionId: ...
    @property
    def FabricSheetOutSideOfHostWarning() -> FailureDefinitionId: ...


class FaceSplitterFailures:
    @property
    def CannotUseCurvesForFaceSplit() -> FailureDefinitionId: ...
    @property
    def EndsNotOnEdgeError() -> FailureDefinitionId: ...
    @property
    def InvalidClosedLoopsForFaceSplit() -> FailureDefinitionId: ...
    @property
    def InvalidOpenLoopsForFaceSplit() -> FailureDefinitionId: ...
    @property
    def LoopsDoNotSubdivideFace() -> FailureDefinitionId: ...
    @property
    def LoopsOutsideFaceSplitError() -> FailureDefinitionId: ...
    @property
    def NoFaceForSplit() -> FailureDefinitionId: ...


class FamilyFailures:
    @property
    def CannotAddParameterToFamily() -> FailureDefinitionId: ...
    @property
    def CannotChangeCategory() -> FailureDefinitionId: ...
    @property
    def CannotChangeInstFam() -> FailureDefinitionId: ...
    @property
    def CannotConvertInstHostToWorkPlane() -> FailureDefinitionId: ...
    @property
    def CannotConvertInstWorkPlaneToHost() -> FailureDefinitionId: ...
    @property
    def CannotCopyByPatternFamilies() -> FailureDefinitionId: ...
    @property
    def CannotCopyInplaceFamily() -> FailureDefinitionId: ...
    @property
    def CannotCutRefPlane() -> FailureDefinitionId: ...
    @property
    def CannotFindHost() -> FailureDefinitionId: ...
    @property
    def CannotLoadImperialFamilyToMetricProject() -> FailureDefinitionId: ...
    @property
    def CannotLoadMetricFamilyToImperialProject() -> FailureDefinitionId: ...
    @property
    def CannotMakeType() -> FailureDefinitionId: ...
    @property
    def CannotMakeTypeCB() -> FailureDefinitionId: ...
    @property
    def CannotMakeTypeFamilySaved() -> FailureDefinitionId: ...
    @property
    def CannotPasteLabelsAcrossFamilies() -> FailureDefinitionId: ...
    @property
    def CannotPasteObject() -> FailureDefinitionId: ...
    @property
    def CannotRegenerateCorruptFamily() -> FailureDefinitionId: ...
    @property
    def CannotRotateElement() -> FailureDefinitionId: ...
    @property
    def CannotSetFamilyTypeToNone() -> FailureDefinitionId: ...
    @property
    def CannotUnlockFamilyTemplate() -> FailureDefinitionId: ...
    @property
    def CantCopySelectionToNonStory() -> FailureDefinitionId: ...
    @property
    def CantEditWhileGrouped() -> FailureDefinitionId: ...
    @property
    def CantMirrorInstWoHost() -> FailureDefinitionId: ...
    @property
    def CantMoveFrozenInstance() -> FailureDefinitionId: ...
    @property
    def CantPasteSelection() -> FailureDefinitionId: ...
    @property
    def CantPlaceATOnDuctError() -> FailureDefinitionId: ...
    @property
    def CantPlaceInsertsError() -> FailureDefinitionId: ...
    @property
    def CantPlaceInsertsWarning() -> FailureDefinitionId: ...
    @property
    def CantPlaceInstanceError() -> FailureDefinitionId: ...
    @property
    def CantPlaceInstanceWarning() -> FailureDefinitionId: ...
    @property
    def CantSetSlantedColumnEndPlane() -> FailureDefinitionId: ...
    @property
    def CantSolve() -> FailureDefinitionId: ...
    @property
    def CircularRefsForInstParams() -> FailureDefinitionId: ...
    @property
    def ColumnAlreadyAttachedWillBeReattached() -> FailureDefinitionId: ...
    @property
    def ColumnAndTargetAlreadyJoined() -> FailureDefinitionId: ...
    @property
    def ColumnHeightZeroBecauseOfInvalidOffset() -> FailureDefinitionId: ...
    @property
    def ColumnTooLong() -> FailureDefinitionId: ...
    @property
    def ContainsSharedSameNameFamily() -> FailureDefinitionId: ...
    @property
    def CouldNotGenerateReferencesForFamilyInstance() -> FailureDefinitionId: ...
    @property
    def CouldNotPlaceAdaptiveFamInst() -> FailureDefinitionId: ...
    @property
    def CustomFittingCreated() -> FailureDefinitionId: ...
    @property
    def DeletingBadFamElemCorruption() -> FailureDefinitionId: ...
    @property
    def DeletingBadFamElemError() -> FailureDefinitionId: ...
    @property
    def DeletingBadFamType() -> FailureDefinitionId: ...
    @property
    def DeletingBadFamTypeDumped() -> FailureDefinitionId: ...
    @property
    def DummyHostMustBePerpendicularToXY() -> FailureDefinitionId: ...
    @property
    def DuplicateFamilyParameterNameWithSharedParameter() -> FailureDefinitionId: ...
    @property
    def DuplicateParamName() -> FailureDefinitionId: ...
    @property
    def DuplicateTypeName() -> FailureDefinitionId: ...
    @property
    def ElementTypeParameterized() -> FailureDefinitionId: ...
    @property
    def FailedToBecomeNonParametric() -> FailureDefinitionId: ...
    @property
    def FailedToSetParameters() -> FailureDefinitionId: ...
    @property
    def FailedWhenLoadingFamily() -> FailureDefinitionId: ...
    @property
    def FamilyBadUnattachedVoids() -> FailureDefinitionId: ...
    @property
    def FamilyCannotBeUpgraded() -> FailureDefinitionId: ...
    @property
    def FamilyConnectorDeletedError() -> FailureDefinitionId: ...
    @property
    def FamilyConnectorDeletedWarning() -> FailureDefinitionId: ...
    @property
    def FamilyDoesntMatchSystemPropertiesDisconnected() -> FailureDefinitionId: ...
    @property
    def FamilyIsCorruptError() -> FailureDefinitionId: ...
    @property
    def FamilyIsCorruptWarning() -> FailureDefinitionId: ...
    @property
    def FamilyMembersReferToOutsideFamily() -> FailureDefinitionId: ...
    @property
    def FamilyNoExternalParametersError() -> FailureDefinitionId: ...
    @property
    def FamilyNoExternalParametersWarning() -> FailureDefinitionId: ...
    @property
    def FamilyNotFitHostShape() -> FailureDefinitionId: ...
    @property
    def FamilyOverconstraint() -> FailureDefinitionId: ...
    @property
    def FamilyOverconstraintCB() -> FailureDefinitionId: ...
    @property
    def FamilyParameterNoExist() -> FailureDefinitionId: ...
    @property
    def FamilyValidationResult() -> FailureDefinitionId: ...
    @property
    def FormulaBasedParameterCannotBeChanged() -> FailureDefinitionId: ...
    @property
    def FormulasFailedForType() -> FailureDefinitionId: ...
    @property
    def FrozenBecauseFaceGone() -> FailureDefinitionId: ...
    @property
    def FrozenBecauseMonitorRelationshipGone() -> FailureDefinitionId: ...
    @property
    def HighlightedElementFamRefsInvalidError() -> FailureDefinitionId: ...
    @property
    def HighlightedElementFamRefsInvalidWarning() -> FailureDefinitionId: ...
    @property
    def InstMayCutMoreOrFewerHosts() -> FailureDefinitionId: ...
    @property
    def InstOutsideFaceBoundary() -> FailureDefinitionId: ...
    @property
    def InvalidContextForAdaptivePlacement() -> FailureDefinitionId: ...
    @property
    def InvalidFamilyType() -> FailureDefinitionId: ...
    @property
    def InvalidFormularFoundInParameter() -> FailureDefinitionId: ...
    @property
    def InvalidParameterValue() -> FailureDefinitionId: ...
    @property
    def InvalidSlantedColumnOffsets() -> FailureDefinitionId: ...
    @property
    def InvalidSlantedColumnOffsetsInNestedFamily() -> FailureDefinitionId: ...
    @property
    def MightntPlaceInsertsWarning() -> FailureDefinitionId: ...
    @property
    def NoInstparamFormulas() -> FailureDefinitionId: ...
    @property
    def NonGenericAnnotationsOutsideLegend() -> FailureDefinitionId: ...
    @property
    def NotFamilyFile() -> FailureDefinitionId: ...
    @property
    def ProfileContainsNoLoops() -> FailureDefinitionId: ...
    @property
    def ReferencePlanesOverconstrained() -> FailureDefinitionId: ...
    @property
    def SetbackTooLarge() -> FailureDefinitionId: ...
    @property
    def SharedParameterReplacedByBuiltInOne() -> FailureDefinitionId: ...
    @property
    def SizeLookupTableIsNotAvailableForType() -> FailureDefinitionId: ...
    @property
    def SketchCannotBeAutomaticallyDimensioned() -> FailureDefinitionId: ...
    @property
    def SlantedColumnEndCutPlaneIsParallelToGeometry() -> FailureDefinitionId: ...
    @property
    def SlantedColumnEndPlanesHaveFlipped() -> FailureDefinitionId: ...
    @property
    def StructuralColumnAttachedToNonStructuralTarget() -> FailureDefinitionId: ...
    @property
    def TitleblockBadViewType() -> FailureDefinitionId: ...
    @property
    def TryingToAttachWhenJoined() -> FailureDefinitionId: ...
    @property
    def TypeRecursiveElementIdParameter() -> FailureDefinitionId: ...
    @property
    def UnableGenerateTrussByFamilyAndOrientation() -> FailureDefinitionId: ...
    @property
    def UnableToUpgradeDueToCorruptFamilies() -> FailureDefinitionId: ...
    @property
    def UnexpectedFamilyChangeResultsError() -> FailureDefinitionId: ...
    @property
    def UnexpectedFamilyChangeResultsWarning() -> FailureDefinitionId: ...
    @property
    def ValueOutOfRange() -> FailureDefinitionId: ...
    @property
    def WhileLoadingFamily() -> FailureDefinitionId: ...
    @property
    def WhileLoadingFamilyShared() -> FailureDefinitionId: ...
    @property
    def WhileScanningParametersForType() -> FailureDefinitionId: ...


class FilledRegionFailures:
    @property
    def BadViewType() -> FailureDefinitionId: ...
    @property
    def CannotDrawFilledRegion() -> FailureDefinitionId: ...
    @property
    def CannotDrawFilledRegionError() -> FailureDefinitionId: ...


class FloorFailures:
    @property
    def FloorSlopeExceedsThreshold() -> FailureDefinitionId: ...


class FluidFailures:
    @property
    def UndefinedFluidType() -> FailureDefinitionId: ...


class ForeignFileFailures:
    @property
    def ForeignFile() -> FailureDefinitionId: ...
    @property
    def ForeignLink() -> FailureDefinitionId: ...


class FormFailures:
    @property
    def AddProfileFailure() -> FailureDefinitionId: ...
    @property
    def DissolveNoValidInputs() -> FailureDefinitionId: ...
    @property
    def DissolveUnableToDissolveForm() -> FailureDefinitionId: ...
    @property
    def FormCreationInvalidGeomCombination() -> FailureDefinitionId: ...
    @property
    def FormElemRegenFailure() -> FailureDefinitionId: ...
    @property
    def FormElemRegenFailureError() -> FailureDefinitionId: ...
    @property
    def FormElemRegenSelfIntersection() -> FailureDefinitionId: ...
    @property
    def FormElemRegenSelfIntersectionReorderProfiles() -> FailureDefinitionId: ...
    @property
    def FormElemRegenSelfIntersectionResetConnections() -> FailureDefinitionId: ...
    @property
    def NoSoludGeometryForVoidFormsInMass() -> FailureDefinitionId: ...
    @property
    def OpenProfileMultiSegmentSweepsNotSupported() -> FailureDefinitionId: ...
    @property
    def VoidFormsNotUsed() -> FailureDefinitionId: ...


class GeneralFailures:
    @property
    def CannotFixProblem() -> FailureDefinitionId: ...
    @property
    def CannotSetParameter() -> FailureDefinitionId: ...
    @property
    def CharactersNotAllowed() -> FailureDefinitionId: ...
    @property
    def ContentDocTreeCorruption() -> FailureDefinitionId: ...
    @property
    def ConvertingOldAxisToNormal() -> FailureDefinitionId: ...
    @property
    def CoreElemTestingError() -> FailureDefinitionId: ...
    @property
    def DuplicateValue() -> FailureDefinitionId: ...
    @property
    def EnterValidRealGreaterThan() -> FailureDefinitionId: ...
    @property
    def EnterValueBetween() -> FailureDefinitionId: ...
    @property
    def ErrorInFamilyResolved() -> FailureDefinitionId: ...
    @property
    def ErrorInSymbolFamilyResolved() -> FailureDefinitionId: ...
    @property
    def ErrorResolved() -> FailureDefinitionId: ...
    @property
    def FailedToOpenFile() -> FailureDefinitionId: ...
    @property
    def FailedToReadLine() -> FailureDefinitionId: ...
    @property
    def FamilySeparationTestingError() -> FailureDefinitionId: ...
    @property
    def GenericCorruption() -> FailureDefinitionId: ...
    @property
    def GenericError() -> FailureDefinitionId: ...
    @property
    def GenericErrorNone() -> FailureDefinitionId: ...
    @property
    def GenericFatalError() -> FailureDefinitionId: ...
    @property
    def GenericNonFatalError() -> FailureDefinitionId: ...
    @property
    def GenericWarning() -> FailureDefinitionId: ...
    @property
    def InaccuracyDetected() -> FailureDefinitionId: ...
    @property
    def InternalProblemsParameter() -> FailureDefinitionId: ...
    @property
    def InvalidInput() -> FailureDefinitionId: ...
    @property
    def InvalidInputWarn() -> FailureDefinitionId: ...
    @property
    def InvalidValue() -> FailureDefinitionId: ...
    @property
    def NameInUse() -> FailureDefinitionId: ...
    @property
    def NameIsEmpty() -> FailureDefinitionId: ...
    @property
    def NameNotUnique() -> FailureDefinitionId: ...
    @property
    def NoRelatedWarnings() -> FailureDefinitionId: ...
    @property
    def ParameterValueNotInRange() -> FailureDefinitionId: ...
    @property
    def ParameterValuesConflict() -> FailureDefinitionId: ...
    @property
    def SeriousElementReferenceCorruption() -> FailureDefinitionId: ...
    @property
    def TransactionFailed() -> FailureDefinitionId: ...
    @property
    def TransactionFailedWarn() -> FailureDefinitionId: ...
    @property
    def UnresolvableErrorInFamily() -> FailureDefinitionId: ...
    @property
    def UnresolvableErrorInFamilyWarn() -> FailureDefinitionId: ...
    @property
    def UnspecifiedError() -> FailureDefinitionId: ...
    @property
    def ValueOutOfRange() -> FailureDefinitionId: ...
    @property
    def WarningInFamilyDismissed() -> FailureDefinitionId: ...


class GenericFailures:
    @property
    def ElementsInInvalidContext() -> FailureDefinitionId: ...


class GenericMEPFailures:
    @property
    def CapWasAddedWarning() -> FailureDefinitionId: ...
    @property
    def CapsWereAddedWarning() -> FailureDefinitionId: ...
    @property
    def FailedToPlaceCapWarning() -> FailureDefinitionId: ...
    @property
    def FlowConfigMismatch() -> FailureDefinitionId: ...
    @property
    def FlowDirectionMismatch() -> FailureDefinitionId: ...
    @property
    def InlineEndoflineMismatch() -> FailureDefinitionId: ...
    @property
    def MaxWidthAndHeightReached() -> FailureDefinitionId: ...
    @property
    def SegmentIsTooShort() -> FailureDefinitionId: ...
    @property
    def SizingFailedZeroFlow() -> FailureDefinitionId: ...
    @property
    def ValidatePHSegmentConnWarning() -> FailureDefinitionId: ...
    @property
    def ValidatePHSegmentLengthWarning() -> FailureDefinitionId: ...


class GeometryFailures:
    @property
    def CannotFindClosest() -> FailureDefinitionId: ...
    @property
    def ConvertFaceRegionsToFacesCrashed() -> FailureDefinitionId: ...
    @property
    def ConvertFaceRegionsToFacesFailed() -> FailureDefinitionId: ...
    @property
    def CurveAndSurfaceDoNotIntersect() -> FailureDefinitionId: ...
    @property
    def CurveDriverError() -> FailureDefinitionId: ...
    @property
    def CurveProjectTooShort() -> FailureDefinitionId: ...
    @property
    def ElementIsTooThin() -> FailureDefinitionId: ...
    @property
    def ElementTooSmall() -> FailureDefinitionId: ...
    @property
    def FailToConvertLine() -> FailureDefinitionId: ...
    @property
    def FailedReplaceCurveElemCurveDriver() -> FailureDefinitionId: ...
    @property
    def FailedUpdateCurveChain() -> FailureDefinitionId: ...
    @property
    def LineArcTangentFailure() -> FailureDefinitionId: ...
    @property
    def OffsetFaceFailed() -> FailureDefinitionId: ...
    @property
    def PolygonSegmentTooShort() -> FailureDefinitionId: ...
    @property
    def SiteInvisible() -> FailureDefinitionId: ...
    @property
    def SuccessToConvertLine() -> FailureDefinitionId: ...
    @property
    def SymbolicLineInvalidPlane() -> FailureDefinitionId: ...
    @property
    def TooManyFacesEdges() -> FailureDefinitionId: ...


class GlobalParameterFailures:
    @property
    def ElementPropLinkCircularChain() -> FailureDefinitionId: ...
    @property
    def ElementPropLinkCircularChainError() -> FailureDefinitionId: ...
    @property
    def GlobalParamFormulaCircularChain() -> FailureDefinitionId: ...
    @property
    def GlobalParamFormulaCircularChainError() -> FailureDefinitionId: ...
    @property
    def GlobalParamInvalidElemParamValue() -> FailureDefinitionId: ...
    @property
    def InvalidElementPropToGlobalParamLink() -> FailureDefinitionId: ...


class GridChainSketchFailures:
    @property
    def ClosedLoop() -> FailureDefinitionId: ...
    @property
    def InvalidSketch() -> FailureDefinitionId: ...
    @property
    def MoreThanOneLoop() -> FailureDefinitionId: ...
    @property
    def OverlappingLines() -> FailureDefinitionId: ...


class GridFailures:
    @property
    def GridEndSegmentsLengthTooShort() -> FailureDefinitionId: ...
    @property
    def GridInGridChainCannotMirror() -> FailureDefinitionId: ...
    @property
    def GridlineAxisTooClose() -> FailureDefinitionId: ...
    @property
    def GridlineAxisTooFar() -> FailureDefinitionId: ...


class GroupFailures:
    @property
    def AdditionalElementsRequired() -> FailureDefinitionId: ...
    @property
    def AdditionalElementsRequiredRemove() -> FailureDefinitionId: ...
    @property
    def AllElementsRemovedFromGroup() -> FailureDefinitionId: ...
    @property
    def AtomTouchedNotAllowed() -> FailureDefinitionId: ...
    @property
    def AtomTouchedNotAllowedDelete() -> FailureDefinitionId: ...
    @property
    def AtomViolationWhenMultiPlacedInstances() -> FailureDefinitionId: ...
    @property
    def AtomViolationWhenOnePlaceInstance() -> FailureDefinitionId: ...
    @property
    def AttachedGroupNoMirror() -> FailureDefinitionId: ...
    @property
    def AttachedGroupNoPasteToView() -> FailureDefinitionId: ...
    @property
    def BadProblemWithGroup() -> FailureDefinitionId: ...
    @property
    def BadViewForAttachedGroup() -> FailureDefinitionId: ...
    @property
    def BadViewForAttachedGroupWarn() -> FailureDefinitionId: ...
    @property
    def CannotAddAlreadyMemberToDiffGroup() -> FailureDefinitionId: ...
    @property
    def CannotAddToGroupFormat() -> FailureDefinitionId: ...
    @property
    def CannotAddToGroupFormatWarn() -> FailureDefinitionId: ...
    @property
    def CannotCopyGroup() -> FailureDefinitionId: ...
    @property
    def CannotCreateGroup() -> FailureDefinitionId: ...
    @property
    def CannotCreateGroupWithInvalidReferences() -> FailureDefinitionId: ...
    @property
    def CannotFinishGroupInSketchMode() -> FailureDefinitionId: ...
    @property
    def CannotLinkAnnotationsForSomeViews() -> FailureDefinitionId: ...
    @property
    def CannotPlaceGroup() -> FailureDefinitionId: ...
    @property
    def CannotReloadWithFile() -> FailureDefinitionId: ...
    @property
    def CannotRemoveGroupMemberConstraint() -> FailureDefinitionId: ...
    @property
    def CannotRemoveGroupMemberConstraintWarn() -> FailureDefinitionId: ...
    @property
    def CannotRemoveSubordFromGroup() -> FailureDefinitionId: ...
    @property
    def CannotRemoveSubordFromGroupWarn() -> FailureDefinitionId: ...
    @property
    def CannotSaveGroup() -> FailureDefinitionId: ...
    @property
    def CannotSwapNestedGroups() -> FailureDefinitionId: ...
    @property
    def ChildrenDeletedOnGroupSwap() -> FailureDefinitionId: ...
    @property
    def ChildrenLostOnGroupSwap() -> FailureDefinitionId: ...
    @property
    def DetailsOfNestedGroupsLost() -> FailureDefinitionId: ...
    @property
    def DimRefsGroupMemberSketch() -> FailureDefinitionId: ...
    @property
    def DimensionsOrTagsReferecedRemoved() -> FailureDefinitionId: ...
    @property
    def DontEditNestedGroup() -> FailureDefinitionId: ...
    @property
    def ElementChangedMoreThanAllowed() -> FailureDefinitionId: ...
    @property
    def ElementsContainsFabricationData() -> FailureDefinitionId: ...
    @property
    def ExcludedElementsRestoredInLink() -> FailureDefinitionId: ...
    @property
    def FailedToChangeGroupLevelRef() -> FailureDefinitionId: ...
    @property
    def FailedToSetMasterGroupId() -> FailureDefinitionId: ...
    @property
    def FailedToTransformAttachedGroup() -> FailureDefinitionId: ...
    @property
    def GroupAmongstLoadedRenamed() -> FailureDefinitionId: ...
    @property
    def GroupCannotMixBackAndForegroundDetail() -> FailureDefinitionId: ...
    @property
    def GroupCannotSave() -> FailureDefinitionId: ...
    @property
    def GroupCannotSaveWarn() -> FailureDefinitionId: ...
    @property
    def GroupChangeNoPlaceElements() -> FailureDefinitionId: ...
    @property
    def GroupEditModeNoDuplicates() -> FailureDefinitionId: ...
    @property
    def GroupHadFailedElementsWhileUpdating() -> FailureDefinitionId: ...
    @property
    def GroupPropagationFailedSketch() -> FailureDefinitionId: ...
    @property
    def GroupPropagationFailedUngroup() -> FailureDefinitionId: ...
    @property
    def GroupPropagationUserCancelled() -> FailureDefinitionId: ...
    @property
    def GroupViewSpecificDiffViews() -> FailureDefinitionId: ...
    @property
    def GroupedModelElemHasViewSpecificSubordinates() -> FailureDefinitionId: ...
    @property
    def GroupsHasCycle() -> FailureDefinitionId: ...
    @property
    def GroupsHaveDifferentMembers() -> FailureDefinitionId: ...
    @property
    def GroupsNotCompatibleForTypeChange() -> FailureDefinitionId: ...
    @property
    def InvalidGroup() -> FailureDefinitionId: ...
    @property
    def LastCopyOfGroupDeleted() -> FailureDefinitionId: ...
    @property
    def LastGroupMemberExcluded() -> FailureDefinitionId: ...
    @property
    def LinkVisibilityLost() -> FailureDefinitionId: ...
    @property
    def LoadOfGroupAbortedByUser() -> FailureDefinitionId: ...
    @property
    def MembersAlignWarn() -> FailureDefinitionId: ...
    @property
    def MembersExcluded() -> FailureDefinitionId: ...
    @property
    def MembersExcludedWarn() -> FailureDefinitionId: ...
    @property
    def MembersMovedToProjectToMakeConsistent() -> FailureDefinitionId: ...
    @property
    def ModifyingMultiGroups() -> FailureDefinitionId: ...
    @property
    def MoveElemFailed() -> FailureDefinitionId: ...
    @property
    def NoAppropriateGroup() -> FailureDefinitionId: ...
    @property
    def NoDetailGroups() -> FailureDefinitionId: ...
    @property
    def NoModelGroups() -> FailureDefinitionId: ...
    @property
    def NoSwapGroupBeingEdited() -> FailureDefinitionId: ...
    @property
    def NoneOfSelElemsGroupable() -> FailureDefinitionId: ...
    @property
    def NotAGroupFile() -> FailureDefinitionId: ...
    @property
    def NotAllGroupsFullyRestored() -> FailureDefinitionId: ...
    @property
    def PlaceGroupFailed() -> FailureDefinitionId: ...
    @property
    def ProblemRegeneratingInGroupUpdate() -> FailureDefinitionId: ...
    @property
    def ReferencesOutsideGroupAreNotAllowed() -> FailureDefinitionId: ...
    @property
    def RemoveGroupSketchConstraintParent() -> FailureDefinitionId: ...
    @property
    def RemovingElemCannotBeGrouped() -> FailureDefinitionId: ...
    @property
    def RemovingReferencesFromGroupedCurve() -> FailureDefinitionId: ...
    @property
    def RevitUnableToUpadateGroups() -> FailureDefinitionId: ...
    @property
    def SomeGroupInstsBecameEmpty() -> FailureDefinitionId: ...
    @property
    def SomeMembersNotRestored() -> FailureDefinitionId: ...
    @property
    def UnableToBindLink() -> FailureDefinitionId: ...
    @property
    def UnableToBindLinkInstances() -> FailureDefinitionId: ...
    @property
    def UnableToConvertGroupsToLinks() -> FailureDefinitionId: ...
    @property
    def UnableToCreateAttachedGroup() -> FailureDefinitionId: ...
    @property
    def UnableToDetachGroup() -> FailureDefinitionId: ...
    @property
    def UnableToExcludeElems() -> FailureDefinitionId: ...
    @property
    def UnableToGroupElems() -> FailureDefinitionId: ...
    @property
    def UnableToLoadAttachedGroup() -> FailureDefinitionId: ...
    @property
    def UnableToLoadDetailGroup() -> FailureDefinitionId: ...
    @property
    def UnableToLoadGroup() -> FailureDefinitionId: ...
    @property
    def UnableToMaintainExclusions() -> FailureDefinitionId: ...
    @property
    def UnableToMaintainExclusionsWarn() -> FailureDefinitionId: ...
    @property
    def UnableToMoveElemsToProject() -> FailureDefinitionId: ...
    @property
    def UnableToRemapDetails() -> FailureDefinitionId: ...
    @property
    def UnableToReplaceSelectedGroups() -> FailureDefinitionId: ...
    @property
    def UnableToRestoreAllMembersOfGroups() -> FailureDefinitionId: ...
    @property
    def UnableToSaveGroupType() -> FailureDefinitionId: ...
    @property
    def UnableToTransferAttachedGroup() -> FailureDefinitionId: ...


class HostObjFailures:
    @property
    def HostMismatch() -> FailureDefinitionId: ...
    @property
    def ReferencesNulled() -> FailureDefinitionId: ...


class HvacFailures:
    @property
    def PanelDoesntMatchCircuitPropertiesDisconnected() -> FailureDefinitionId: ...


class IlluminationFailures:
    @property
    def IESFileNotFoundWarning() -> FailureDefinitionId: ...
    @property
    def LightingFixtureLumensWarning() -> FailureDefinitionId: ...
    @property
    def RoomCoefficientUtilizationWarning() -> FailureDefinitionId: ...
    @property
    def RoomLightLossFactorWarning() -> FailureDefinitionId: ...


class ImageFailures:
    @property
    def BadViewType() -> FailureDefinitionId: ...
    @property
    def InvalidHeight() -> FailureDefinitionId: ...
    @property
    def InvalidWidth() -> FailureDefinitionId: ...


class ImportExportFailures:
    @property
    def ViewBoundariesTooLarge() -> FailureDefinitionId: ...


class ImportFailures:
    @property
    def ATFNonUniformScalingTransform() -> FailureDefinitionId: ...
    @property
    def BadFaceFoundInDwg() -> FailureDefinitionId: ...
    @property
    def CannotChangeImportSymbol() -> FailureDefinitionId: ...
    @property
    def CannotExplodeElement() -> FailureDefinitionId: ...
    @property
    def CannotImportFile() -> FailureDefinitionId: ...
    @property
    def FailedToSetWorkplane() -> FailureDefinitionId: ...
    @property
    def IFCCantUpdateLinkedFile() -> FailureDefinitionId: ...
    @property
    def IFCGenericImportWarning() -> FailureDefinitionId: ...
    @property
    def IFCGenericRevitImportWarning() -> FailureDefinitionId: ...
    @property
    def ImportModelOutOfRange() -> FailureDefinitionId: ...
    @property
    def ImportModelTooLarge() -> FailureDefinitionId: ...
    @property
    def ImportScaleTooLarge() -> FailureDefinitionId: ...
    @property
    def ImportTooFarAway() -> FailureDefinitionId: ...
    @property
    def ImportTooManyElmentsToExplode() -> FailureDefinitionId: ...
    @property
    def LostAcisObjectsOnImport() -> FailureDefinitionId: ...
    @property
    def SomeObjectsNotExploded() -> FailureDefinitionId: ...
    @property
    def TextNotImported() -> FailureDefinitionId: ...
    @property
    def TooManyPickFaces() -> FailureDefinitionId: ...
    @property
    def WorksetCreatedForLinkWarning() -> FailureDefinitionId: ...


class InaccurateFailures:
    @property
    def InaccurateAreaLine() -> FailureDefinitionId: ...
    @property
    def InaccurateBeamOrBrace() -> FailureDefinitionId: ...
    @property
    def InaccurateCurveBasedFamily() -> FailureDefinitionId: ...
    @property
    def InaccurateDriveCurve() -> FailureDefinitionId: ...
    @property
    def InaccurateGrid() -> FailureDefinitionId: ...
    @property
    def InaccurateLevel() -> FailureDefinitionId: ...
    @property
    def InaccurateLine() -> FailureDefinitionId: ...
    @property
    def InaccurateMassingSketchLine() -> FailureDefinitionId: ...
    @property
    def InaccurateRefPlane() -> FailureDefinitionId: ...
    @property
    def InaccurateRoomSeparation() -> FailureDefinitionId: ...
    @property
    def InaccurateSketchLine() -> FailureDefinitionId: ...
    @property
    def InaccurateSpaceSeparation() -> FailureDefinitionId: ...
    @property
    def InaccurateWall() -> FailureDefinitionId: ...


class InfillFailures:
    @property
    def CannotDeleteInfill() -> FailureDefinitionId: ...
    @property
    def FamilyInstanceIsNotCuttingHost() -> FailureDefinitionId: ...
    @property
    def InPlaceFamilyNotCuttingHost() -> FailureDefinitionId: ...
    @property
    def InfillCannotChangeType() -> FailureDefinitionId: ...
    @property
    def InfillCannotHaveDiffThickness() -> FailureDefinitionId: ...
    @property
    def InfillDifferentPhase() -> FailureDefinitionId: ...
    @property
    def InfillLost() -> FailureDefinitionId: ...
    @property
    def InfillNoSlopeGlazing() -> FailureDefinitionId: ...
    @property
    def InfillNoThicknessCeiling() -> FailureDefinitionId: ...
    @property
    def InfillNoThicknessMultiface() -> FailureDefinitionId: ...
    @property
    def InsertJoinedWall() -> FailureDefinitionId: ...
    @property
    def InsertOverlapsOrOut() -> FailureDefinitionId: ...
    @property
    def MovedInfillToHost() -> FailureDefinitionId: ...


class InterferenceFailures:
    @property
    def GeometryWarning() -> FailureDefinitionId: ...


class JoinElementsFailures:
    @property
    def CannotCope() -> FailureDefinitionId: ...
    @property
    def CannotCutJoinedGeometry() -> FailureDefinitionId: ...
    @property
    def CannotJoinDesignOptions() -> FailureDefinitionId: ...
    @property
    def CannotJoinElements() -> FailureDefinitionId: ...
    @property
    def CannotJoinElementsError() -> FailureDefinitionId: ...
    @property
    def CannotJoinElementsMultiPlaneError() -> FailureDefinitionId: ...
    @property
    def CannotJoinElementsStructural() -> FailureDefinitionId: ...
    @property
    def CannotJoinElementsStructuralError() -> FailureDefinitionId: ...
    @property
    def CannotJoinElementsWarn() -> FailureDefinitionId: ...
    @property
    def CannotJoinRoof() -> FailureDefinitionId: ...
    @property
    def CannotJoinRoofError() -> FailureDefinitionId: ...
    @property
    def CannotKeepJoined() -> FailureDefinitionId: ...
    @property
    def CannotKeepReferenceOfJoinedElement() -> FailureDefinitionId: ...
    @property
    def CannotKeepReferenceOfJoinedElementWarning() -> FailureDefinitionId: ...
    @property
    def CannotKeepTrussJoined() -> FailureDefinitionId: ...
    @property
    def CannotKeepWallJoinToRoof() -> FailureDefinitionId: ...
    @property
    def CannotKeepWallJoinToRoofError() -> FailureDefinitionId: ...
    @property
    def ElementWillBeDetachedFromPlane() -> FailureDefinitionId: ...
    @property
    def FootingWillMoveToBottom() -> FailureDefinitionId: ...
    @property
    def JoiningDisjoint() -> FailureDefinitionId: ...
    @property
    def JoiningDisjointWarn() -> FailureDefinitionId: ...
    @property
    def StairsComponentTypeUnsupportedError() -> FailureDefinitionId: ...
    @property
    def StructGroupMemberWillDetachFromGrid() -> FailureDefinitionId: ...
    @property
    def WallTypeUnsupportedError() -> FailureDefinitionId: ...


class KeyBasedTreeEntryFailures:
    @property
    def BadClassificationLevel() -> FailureDefinitionId: ...
    @property
    def CircularParentage() -> FailureDefinitionId: ...
    @property
    def DuplicateEntry() -> FailureDefinitionId: ...
    @property
    def MissingParent() -> FailureDefinitionId: ...


class KeyBasedTreeFileFailures:
    @property
    def CannotOpenFileForRead() -> FailureDefinitionId: ...
    @property
    def CannotUnderstandAtLine() -> FailureDefinitionId: ...


class KeynoteFailures:
    @property
    def MissKeynoteParameter() -> FailureDefinitionId: ...
    @property
    def MissKeynotingSystem() -> FailureDefinitionId: ...
    @property
    def NotAssociatedKeynoteParameter() -> FailureDefinitionId: ...


class KeynoteTagFailures:
    @property
    def KeynoteOnLinkWithDifferentKeynoteFile() -> FailureDefinitionId: ...
    @property
    def NoKeynoteAssignedToLinkedElement() -> FailureDefinitionId: ...


class LegendFailures:
    @property
    def LegendComponentBadViewType() -> FailureDefinitionId: ...
    @property
    def LegendComponentNotVisible() -> FailureDefinitionId: ...


class LevelFailures:
    @property
    def NoLevelsLeft() -> FailureDefinitionId: ...
    @property
    def NoLevelsLeftReloading() -> FailureDefinitionId: ...
    @property
    def StoryAboveDeleted() -> FailureDefinitionId: ...
    @property
    def StoryAboveMoved() -> FailureDefinitionId: ...
    @property
    def StoryAboveNonStoryLevel() -> FailureDefinitionId: ...


class LinkFailures:
    @property
    def CannotModifyLinkedFile() -> FailureDefinitionId: ...
    @property
    def CannotOpenLinkedFileServerFound() -> FailureDefinitionId: ...
    @property
    def CannotOpenLinkedFileServerNotFound() -> FailureDefinitionId: ...
    @property
    def CannotPublishSharedCoordinatesToMirroredNonRevitLinks() -> FailureDefinitionId: ...
    @property
    def CannotReloadFile() -> FailureDefinitionId: ...
    @property
    def CannotUnlinkFile() -> FailureDefinitionId: ...
    @property
    def DataDictionaryDifferentInLink() -> FailureDefinitionId: ...
    @property
    def DeleteLinkSymbolPrompt() -> FailureDefinitionId: ...
    @property
    def LinkInstanceNeedsReconcile() -> FailureDefinitionId: ...
    @property
    def LinkedFileOpenInOtherDoc() -> FailureDefinitionId: ...
    @property
    def ModifiedLinkedFile() -> FailureDefinitionId: ...
    @property
    def ModifyingLinkedFile() -> FailureDefinitionId: ...
    @property
    def MultipleLinks() -> FailureDefinitionId: ...
    @property
    def NoConstraintsToLinks1() -> FailureDefinitionId: ...
    @property
    def SourceFileDrivenByOtherTarget() -> FailureDefinitionId: ...
    @property
    def WatchedLinkMoved() -> FailureDefinitionId: ...


class LoadFailures:
    @property
    def CannotCopyHostedLoad() -> FailureDefinitionId: ...
    @property
    def CannotMirrorHostedLoad() -> FailureDefinitionId: ...
    @property
    def CannotMirrorLoad() -> FailureDefinitionId: ...
    @property
    def CannotMoveHostedLoad() -> FailureDefinitionId: ...
    @property
    def CannotRotateLoad() -> FailureDefinitionId: ...
    @property
    def LineLoadAllZero() -> FailureDefinitionId: ...
    @property
    def PointLoadAllZero() -> FailureDefinitionId: ...


class LooseDimensionFailures:
    @property
    def LooseCurtainWallData() -> FailureDefinitionId: ...
    @property
    def LooseDimensionsForCurtainWall() -> FailureDefinitionId: ...
    @property
    def LooseFaceSplitsForCurtainWall() -> FailureDefinitionId: ...
    @property
    def LooseInsertsForCurtainWall() -> FailureDefinitionId: ...
    @property
    def LooseWallsweepsForCurtainWall() -> FailureDefinitionId: ...


class MEPCalculationFailures:
    @property
    def AtLeastOneEquipmentOnDuty() -> FailureDefinitionId: ...
    @property
    def ClassificationNotSetInFamily() -> FailureDefinitionId: ...
    @property
    def DemandFlowAndPressureLossNotSetInLossFamily() -> FailureDefinitionId: ...
    @property
    def DemandFlowNotSetInLossFamily() -> FailureDefinitionId: ...
    @property
    def DuctFittingAndAccessoryPressureDropCalculatorNotAvailable() -> FailureDefinitionId: ...
    @property
    def DuctPressureDropCalculatorNotAvailable() -> FailureDefinitionId: ...
    @property
    def ExtraPumpSet() -> FailureDefinitionId: ...
    @property
    def FlowAndPressureCalculationMethodHasBeenImproved() -> FailureDefinitionId: ...
    @property
    def HydraulicSeparationAmbiguity() -> FailureDefinitionId: ...
    @property
    def HydraulicSeparationOfOneSystem() -> FailureDefinitionId: ...
    @property
    def InvalidFluidProperty() -> FailureDefinitionId: ...
    @property
    def InvalidNumberOfMechanicalEquipmentOnDuty() -> FailureDefinitionId: ...
    @property
    def LoopSeparationNotCompleted() -> FailureDefinitionId: ...
    @property
    def MechanicalEquipmentSetBeingDeleted() -> FailureDefinitionId: ...
    @property
    def NetworkCanNotDeterminCriticalPath() -> FailureDefinitionId: ...
    @property
    def NetworkDefaultToPressure() -> FailureDefinitionId: ...
    @property
    def NetworkDefaultToReynolds() -> FailureDefinitionId: ...
    @property
    def NetworkEnergyEquationNotConverge() -> FailureDefinitionId: ...
    @property
    def NetworkErrorCalculatingPressure() -> FailureDefinitionId: ...
    @property
    def NetworkErrorElementWithDownUpStreamNode() -> FailureDefinitionId: ...
    @property
    def NetworkErrorExtractCurveData() -> FailureDefinitionId: ...
    @property
    def NetworkErrorModelTooBig() -> FailureDefinitionId: ...
    @property
    def NetworkErrorOverConstrained() -> FailureDefinitionId: ...
    @property
    def NetworkExtraPumpOutsideSet() -> FailureDefinitionId: ...
    @property
    def NetworkInconsistentDemandFlow() -> FailureDefinitionId: ...
    @property
    def NetworkMinorLossNotConverge() -> FailureDefinitionId: ...
    @property
    def NetworkPressureNotConverge() -> FailureDefinitionId: ...
    @property
    def NetworkUnderConstrained() -> FailureDefinitionId: ...
    @property
    def Network_ElementNodeIsNotPartOfNetwork() -> FailureDefinitionId: ...
    @property
    def Network_NoInputNode() -> FailureDefinitionId: ...
    @property
    def Network_NoOutputNode() -> FailureDefinitionId: ...
    @property
    def Network_NoPressureConstraint() -> FailureDefinitionId: ...
    @property
    def Network_NodePropertyNotSet() -> FailureDefinitionId: ...
    @property
    def Network_NotEnoughElements() -> FailureDefinitionId: ...
    @property
    def Network_NotEnoughNodes() -> FailureDefinitionId: ...
    @property
    def Network_NotFullyConnected() -> FailureDefinitionId: ...
    @property
    def Network_OverConstrained() -> FailureDefinitionId: ...
    @property
    def PipeConnectorsAreNotLined() -> FailureDefinitionId: ...
    @property
    def PipeFittingAndAccessoryPressureDropCalculatorNotAvailable() -> FailureDefinitionId: ...
    @property
    def PipePressureDropCalculatorNotAvailable() -> FailureDefinitionId: ...
    @property
    def PlumbingFlowCalculatorNotAvailable() -> FailureDefinitionId: ...
    @property
    def PressureLossNotSetInLossFamily() -> FailureDefinitionId: ...
    @property
    def PumpPressureNotComputed() -> FailureDefinitionId: ...
    @property
    def SeparationNotAtJunction() -> FailureDefinitionId: ...
    @property
    def SeparationWithOddJunction() -> FailureDefinitionId: ...


class MEPFabricationFailures:
    @property
    def AdditionalPartNotLoaded() -> FailureDefinitionId: ...
    @property
    def CannotConvertFlexPipeToPart() -> FailureDefinitionId: ...
    @property
    def CannotMatchFabricationHangerSizeToHost() -> FailureDefinitionId: ...
    @property
    def FabDbChangeConn() -> FailureDefinitionId: ...
    @property
    def FabDbOpenJobConn() -> FailureDefinitionId: ...
    @property
    def FabDbSwapOut() -> FailureDefinitionId: ...
    @property
    def FabricationConfigurationCorrupted() -> FailureDefinitionId: ...
    @property
    def FabricationHangerCannotBeSloped() -> FailureDefinitionId: ...
    @property
    def FabricationHangerHostNotFound() -> FailureDefinitionId: ...
    @property
    def FabricationHangerNotConnectToHost() -> FailureDefinitionId: ...
    @property
    def FabricationHangerOutOfHost() -> FailureDefinitionId: ...
    @property
    def FabricationHangerSizeNotMatch() -> FailureDefinitionId: ...
    @property
    def FabricationOutOfSizeCondition() -> FailureDefinitionId: ...
    @property
    def FabricationOverSizedCheck() -> FailureDefinitionId: ...
    @property
    def FabricationPartCannotBeMirrored() -> FailureDefinitionId: ...
    @property
    def FabricationPartCannotChangeServiceSizeWarning() -> FailureDefinitionId: ...
    @property
    def FabricationPartCannotChangeSlopeError() -> FailureDefinitionId: ...
    @property
    def FabricationPartCannotChangeTypeBadDimError() -> FailureDefinitionId: ...
    @property
    def FabricationPartCannotChangeTypeBadDimUnConnError() -> FailureDefinitionId: ...
    @property
    def FabricationPartCannotChangeTypeError() -> FailureDefinitionId: ...
    @property
    def FabricationPartCannotChangeTypeIncompatError() -> FailureDefinitionId: ...
    @property
    def FabricationPartCannotChangeTypeIncompatUnConnError() -> FailureDefinitionId: ...
    @property
    def FabricationPartCannotChangeTypeMisalignedError() -> FailureDefinitionId: ...
    @property
    def FabricationPartCannotChangeTypeMisalignedUnConnError() -> FailureDefinitionId: ...
    @property
    def FabricationPartCannotChangeTypeUnConnError() -> FailureDefinitionId: ...
    @property
    def FabricationPartCannotChangeTypeWarning() -> FailureDefinitionId: ...
    @property
    def FabricationPartFitFailWarning() -> FailureDefinitionId: ...
    @property
    def FabricationPartFitFailure() -> FailureDefinitionId: ...
    @property
    def FabricationPartHasInvalidGeometry() -> FailureDefinitionId: ...
    @property
    def FabricationPartInvalidConnection() -> FailureDefinitionId: ...
    @property
    def FabricationPartInvalidSpecification() -> FailureDefinitionId: ...
    @property
    def FabricationPartNoPartTypeFound() -> FailureDefinitionId: ...
    @property
    def FabricationPartNotAttachedToStraight() -> FailureDefinitionId: ...
    @property
    def FabricationPartOptimizeInvalidConnection() -> FailureDefinitionId: ...
    @property
    def FabricationRodDetachFromHangerError() -> FailureDefinitionId: ...
    @property
    def FabricationRodsConnectionChangedWarning() -> FailureDefinitionId: ...
    @property
    def FabricationRodsDisconnectedError() -> FailureDefinitionId: ...
    @property
    def FabricationRodsDisconnectedWarning() -> FailureDefinitionId: ...
    @property
    def FabricationServiceMismatch() -> FailureDefinitionId: ...
    @property
    def FabricationStraigtLengthOversized() -> FailureDefinitionId: ...
    @property
    def FixedFabricationPartNotChangeLength() -> FailureDefinitionId: ...
    @property
    def GroupedFabricationPartNotReposition() -> FailureDefinitionId: ...
    @property
    def HangerProfileNotMatchWithHost() -> FailureDefinitionId: ...
    @property
    def HangerWidthOutOfRange() -> FailureDefinitionId: ...
    @property
    def InvalidConnectionsHaveBeenDisconnected() -> FailureDefinitionId: ...
    @property
    def InvalidSelectionThereCannotBeOpenConnectors() -> FailureDefinitionId: ...
    @property
    def NoStructuralHostToAttachWarning() -> FailureDefinitionId: ...
    @property
    def NotAllPartsWereConvertedUnsuportedFittingOffsets() -> FailureDefinitionId: ...
    @property
    def PinnedFabricationPartNotChangeExtension() -> FailureDefinitionId: ...
    @property
    def PinnedFabricationPartNotReposition() -> FailureDefinitionId: ...
    @property
    def PlaceCutinFittingFailed() -> FailureDefinitionId: ...
    @property
    def SizeNotAvailableInFabricationService() -> FailureDefinitionId: ...
    @property
    def UneditableFabricationPartNotReposition() -> FailureDefinitionId: ...


class MassFailures:
    @property
    def AutoGlazingFailed() -> FailureDefinitionId: ...
    @property
    def AutoGlazingFailedError() -> FailureDefinitionId: ...
    @property
    def BooleanUnionFailed() -> FailureDefinitionId: ...
    @property
    def CannotIntegrate() -> FailureDefinitionId: ...
    @property
    def CannotMergeGeometry() -> FailureDefinitionId: ...
    @property
    def CannotMoveMassing() -> FailureDefinitionId: ...
    @property
    def CreateCoreGeometryFailed() -> FailureDefinitionId: ...
    @property
    def DividePerimeterZoneFailed() -> FailureDefinitionId: ...
    @property
    def FaceRegionCreationFailed() -> FailureDefinitionId: ...
    @property
    def FaceSplitFailed() -> FailureDefinitionId: ...
    @property
    def FloorAreaFaceFailed() -> FailureDefinitionId: ...
    @property
    def FloorMightLookWrong() -> FailureDefinitionId: ...
    @property
    def MinSkylightWidthImperial() -> FailureDefinitionId: ...
    @property
    def MinSkylightWidthMetric() -> FailureDefinitionId: ...
    @property
    def MultipleMassing() -> FailureDefinitionId: ...
    @property
    def NoCurtainRoofsInMassing() -> FailureDefinitionId: ...
    @property
    def NoSolidInMass() -> FailureDefinitionId: ...
    @property
    def NonOccupiableMassZone() -> FailureDefinitionId: ...
    @property
    def OpenAndSolidGeometry() -> FailureDefinitionId: ...
    @property
    def OpenGeometryOnly() -> FailureDefinitionId: ...
    @property
    def OverlappingSolids() -> FailureDefinitionId: ...
    @property
    def SketchCurveNotModelable() -> FailureDefinitionId: ...
    @property
    def SplitFacesByGroundPlaneCrashed() -> FailureDefinitionId: ...
    @property
    def SplitFacesByGroundPlaneFailed() -> FailureDefinitionId: ...
    @property
    def SplitOverlappingFacesFailed() -> FailureDefinitionId: ...
    @property
    def TooManyGeometries() -> FailureDefinitionId: ...
    @property
    def UpgradedMassingWarning() -> FailureDefinitionId: ...


class MatchlineFailures:
    @property
    def CreationFailed() -> FailureDefinitionId: ...


class MechanicalFailures:
    @property
    def InitialEqualFrictionSizingFailed() -> FailureDefinitionId: ...
    @property
    def LiningThicknessIsLargeForDiameter() -> FailureDefinitionId: ...
    @property
    def LiningThicknessIsLargeForHeight() -> FailureDefinitionId: ...
    @property
    def LiningThicknessIsLargeForWidth() -> FailureDefinitionId: ...
    @property
    def PanelDoesntMatchCircuitProperties() -> FailureDefinitionId: ...
    @property
    def PanelValidateConfigurationError() -> FailureDefinitionId: ...
    @property
    def TwoPointsSelectedBeforeEdit() -> FailureDefinitionId: ...


class MirrorFailures:
    @property
    def BadMirror() -> FailureDefinitionId: ...


class MultiReferenceAnnotationFailures:
    @property
    def ElementCategoryChangeInvalidatesMultiReferenceAnnotation() -> FailureDefinitionId: ...
    @property
    def MultiReferenceAnnotationReferenceCategoryForcesDeletion() -> FailureDefinitionId: ...


class NumberingFailures:
    @property
    def SampleNumberingError() -> FailureDefinitionId: ...


class OffsetFacesCellLegacyFailures:
    @property
    def OffsetFaceFailed() -> FailureDefinitionId: ...


class OpeningFailures:
    @property
    def HostForCutHasNoGeometry() -> FailureDefinitionId: ...
    @property
    def HostForCutHasNoGeometryWarn() -> FailureDefinitionId: ...
    @property
    def InvalidComplexCut() -> FailureDefinitionId: ...
    @property
    def OpenStringerConflictNosing() -> FailureDefinitionId: ...
    @property
    def OpeningCutAll() -> FailureDefinitionId: ...
    @property
    def OpeningDoesnotCutHost() -> FailureDefinitionId: ...
    @property
    def OpeningDoesnotCutHostDelete() -> FailureDefinitionId: ...
    @property
    def OpeningNegativeHeight() -> FailureDefinitionId: ...
    @property
    def OpeningPartiallyCutsHost() -> FailureDefinitionId: ...
    @property
    def OpeningRectDoesnotCutHost() -> FailureDefinitionId: ...
    @property
    def OpeningRemovesHost() -> FailureDefinitionId: ...
    @property
    def PropertyNotClosed() -> FailureDefinitionId: ...


class OverlapFailures:
    @property
    def AreaBoundaryLinesOverlap() -> FailureDefinitionId: ...
    @property
    def CurvesOverlap() -> FailureDefinitionId: ...
    @property
    def DivisionSketchOverlap() -> FailureDefinitionId: ...
    @property
    def DuplicateFabricSheet() -> FailureDefinitionId: ...
    @property
    def DuplicateInstances() -> FailureDefinitionId: ...
    @property
    def DuplicatePoints() -> FailureDefinitionId: ...
    @property
    def DuplicateRebar() -> FailureDefinitionId: ...
    @property
    def FloorsOverlap() -> FailureDefinitionId: ...
    @property
    def LevelsOverlap() -> FailureDefinitionId: ...
    @property
    def OverlappingElementsTest() -> FailureDefinitionId: ...
    @property
    def RoomSeparationLinesOverlap() -> FailureDefinitionId: ...
    @property
    def SpaceSeparationLinesOverlap() -> FailureDefinitionId: ...
    @property
    def WallAreaBoundaryOverlap() -> FailureDefinitionId: ...
    @property
    def WallRoomSeparationOverlap() -> FailureDefinitionId: ...
    @property
    def WallSpaceSeparationOverlap() -> FailureDefinitionId: ...
    @property
    def WallsOverlap() -> FailureDefinitionId: ...


class ParameterFailures:
    @property
    def InconsistentSharedParameterDefinitions() -> FailureDefinitionId: ...


class PartMakerMethodForMergePartFailures:
    @property
    def MergedPartHasDisConnectedGeometries() -> FailureDefinitionId: ...
    @property
    def NeedTwoPartsToMerge() -> FailureDefinitionId: ...
    @property
    def PartNotIncludedInMerge() -> FailureDefinitionId: ...
    @property
    def PartsCannotBeMerged() -> FailureDefinitionId: ...
    @property
    def UnableToIncludePartInMerge() -> FailureDefinitionId: ...


class PartMakerMethodForWallFailures:
    @property
    def CouldNotAdjustWallPartsAtJoin() -> FailureDefinitionId: ...
    @property
    def CouldNotCreateWallPart() -> FailureDefinitionId: ...


class PathFailures:
    @property
    def Path3dRegenError() -> FailureDefinitionId: ...


class PathOfTravelFailures:
    @property
    def CannotBePasted() -> FailureDefinitionId: ...
    @property
    def ResultAffectedByCrop() -> FailureDefinitionId: ...
    @property
    def UpdateFailureMultiple() -> FailureDefinitionId: ...
    @property
    def UpdateFailureSingle() -> FailureDefinitionId: ...
    @property
    def UpdateSummary() -> FailureDefinitionId: ...


class PerformanceFailures:
    @property
    def ClippingIsDisabled() -> FailureDefinitionId: ...
    @property
    def DisjoinedSolidsInInPlaceFamily() -> FailureDefinitionId: ...
    @property
    def DuplicateInstances() -> FailureDefinitionId: ...
    @property
    def FamilyContainsViewSpecificImports() -> FailureDefinitionId: ...
    @property
    def HostHasTooManyInserts() -> FailureDefinitionId: ...
    @property
    def InteriorCategoriesEnabledInLargeView() -> FailureDefinitionId: ...
    @property
    def LargeFamilyFile() -> FailureDefinitionId: ...
    @property
    def ManyElementInFamily() -> FailureDefinitionId: ...
    @property
    def ManyUnusedNestedFamilies() -> FailureDefinitionId: ...
    @property
    def MultipleLoopsInSketch() -> FailureDefinitionId: ...
    @property
    def TooLargeSketch() -> FailureDefinitionId: ...
    @property
    def TooManyAreaBoundaryLinesFound() -> FailureDefinitionId: ...
    @property
    def TooManyElementsInSketch() -> FailureDefinitionId: ...
    @property
    def UnjoinedRoomSeparationLinesFound() -> FailureDefinitionId: ...
    @property
    def UnusedTypesInTheProject() -> FailureDefinitionId: ...
    @property
    def ViewDetailLevelIsHighInLargeView() -> FailureDefinitionId: ...
    @property
    def WallsOverlap() -> FailureDefinitionId: ...


class PipingFailures:
    @property
    def CannotCreateGeometryForPipe() -> FailureDefinitionId: ...
    @property
    def CircularLoopInPipeSizing() -> FailureDefinitionId: ...
    @property
    def DuctPipeModified() -> FailureDefinitionId: ...
    @property
    def DuctPipeSizeMismatch() -> FailureDefinitionId: ...
    @property
    def FabFittingFailed() -> FailureDefinitionId: ...
    @property
    def InvalidPipeSize() -> FailureDefinitionId: ...
    @property
    def MaxPipeSizeReached() -> FailureDefinitionId: ...
    @property
    def PartNotFoundDueToNoPipeConnectedError() -> FailureDefinitionId: ...
    @property
    def PartNotFoundDueToNoPipeConnectedWarning() -> FailureDefinitionId: ...
    @property
    def PartNotFoundInRoutingPreferenceError() -> FailureDefinitionId: ...
    @property
    def PartNotFoundInRoutingPreferenceWarning() -> FailureDefinitionId: ...


class PlanRegionFailures:
    @property
    def DeletedViewRangeLevel() -> FailureDefinitionId: ...
    @property
    def Intersecting() -> FailureDefinitionId: ...
    @property
    def InvalidPlanRegion() -> FailureDefinitionId: ...
    @property
    def InvalidPlanRegionError() -> FailureDefinitionId: ...
    @property
    def Nested() -> FailureDefinitionId: ...


class PointFailures:
    @property
    def CannotMakePointHostedByIntersection() -> FailureDefinitionId: ...
    @property
    def CantChangeParamFlip() -> FailureDefinitionId: ...
    @property
    def CantChangeParamMirror() -> FailureDefinitionId: ...
    @property
    def CantChangeParamRotate() -> FailureDefinitionId: ...
    @property
    def EdgeHostedPointToBeUnhosted() -> FailureDefinitionId: ...
    @property
    def HostMeasurementError() -> FailureDefinitionId: ...
    @property
    def HostParameterRangeError() -> FailureDefinitionId: ...
    @property
    def RegenFailure() -> FailureDefinitionId: ...


class ProfileFailures:
    @property
    def SketchNotEmpty() -> FailureDefinitionId: ...


class PropertySetElementFailures:
    @property
    def EmptyPropertySetName() -> FailureDefinitionId: ...
    @property
    def NonStringParameterValue() -> FailureDefinitionId: ...
    @property
    def NonUniquePropertySetName() -> FailureDefinitionId: ...


class RebarCouplerFailures:
    @property
    def CantKeepConstraintsToBars() -> FailureDefinitionId: ...
    @property
    def CouplerRequiredRemoveFromGroup() -> FailureDefinitionId: ...
    @property
    def CouplerTypeInvalid() -> FailureDefinitionId: ...
    @property
    def DisconnectElements() -> FailureDefinitionId: ...
    @property
    def DistanceBetweenBarsError() -> FailureDefinitionId: ...
    @property
    def DistanceBetweenBarsWarning() -> FailureDefinitionId: ...
    @property
    def EngagementBiggerThanLengthError() -> FailureDefinitionId: ...
    @property
    def EngagementBiggerThanLengthWarning() -> FailureDefinitionId: ...
    @property
    def LengthParameterError() -> FailureDefinitionId: ...
    @property
    def LengthParameterWarning() -> FailureDefinitionId: ...
    @property
    def MainEngagementParameterError() -> FailureDefinitionId: ...
    @property
    def MainEngagementParameterWarning() -> FailureDefinitionId: ...
    @property
    def NoBarSizeError() -> FailureDefinitionId: ...
    @property
    def NoBarSizeWarning() -> FailureDefinitionId: ...
    @property
    def NoTypeParamsDefinedWarning() -> FailureDefinitionId: ...
    @property
    def SecondaryEngagementParameterError() -> FailureDefinitionId: ...
    @property
    def SecondaryEngagementParameterWarning() -> FailureDefinitionId: ...
    @property
    def WidthParameterError() -> FailureDefinitionId: ...
    @property
    def WidthParameterWarning() -> FailureDefinitionId: ...


class RebarFailures:
    @property
    def BarDiameterTooLarge() -> FailureDefinitionId: ...
    @property
    def BarTypeDoesNotAllowHooksOfCurrentShape() -> FailureDefinitionId: ...
    @property
    def BendDiameterTooLarge() -> FailureDefinitionId: ...
    @property
    def BendDiameterTooSmall() -> FailureDefinitionId: ...
    @property
    def CannotCreateFreeFormSetDueToShortBar() -> FailureDefinitionId: ...
    @property
    def CannotKeepVariabilityOfRebarInGroup() -> FailureDefinitionId: ...
    @property
    def CannotPlaceRebar() -> FailureDefinitionId: ...
    @property
    def CannotPlaceRebarWarn() -> FailureDefinitionId: ...
    @property
    def CannotSolveRebarShapeUsingDataFromDimension() -> FailureDefinitionId: ...
    @property
    def CannotSolveRebarWithDelayedConstraints() -> FailureDefinitionId: ...
    @property
    def CantMakeFillets() -> FailureDefinitionId: ...
    @property
    def ChangeUnitsFormatWarn() -> FailureDefinitionId: ...
    @property
    def ClearPresentationForAllBarsInRebarSet() -> FailureDefinitionId: ...
    @property
    def CoverTooLong() -> FailureDefinitionId: ...
    @property
    def DelayedConstraintForHandle() -> FailureDefinitionId: ...
    @property
    def HideAllBarsInRebarSet() -> FailureDefinitionId: ...
    @property
    def HostTopologyChange() -> FailureDefinitionId: ...
    @property
    def IncompleteShape() -> FailureDefinitionId: ...
    @property
    def InvalidRebarHost() -> FailureDefinitionId: ...
    @property
    def InvalidRebarHostFamilyCanHostRebarParam() -> FailureDefinitionId: ...
    @property
    def InvalidRebarHostNonConcrete() -> FailureDefinitionId: ...
    @property
    def InvalidRebarHostNonStructural() -> FailureDefinitionId: ...
    @property
    def InvalidRebarHostWrongCategory() -> FailureDefinitionId: ...
    @property
    def Inverted3dShape() -> FailureDefinitionId: ...
    @property
    def MaxHookExtensionMultiplierWarn() -> FailureDefinitionId: ...
    @property
    def MissingCurrentConstraintForHandle() -> FailureDefinitionId: ...
    @property
    def NoRebarSelected() -> FailureDefinitionId: ...
    @property
    def NoSurfPatternOnRebar() -> FailureDefinitionId: ...
    @property
    def NoVisibleRebarHandle() -> FailureDefinitionId: ...
    @property
    def NoVisibleTargetsForCurrentConstraint() -> FailureDefinitionId: ...
    @property
    def OutOfPlaneBendDiameterTooSmall() -> FailureDefinitionId: ...
    @property
    def OutSideOfHost() -> FailureDefinitionId: ...
    @property
    def PathShapeFailure() -> FailureDefinitionId: ...
    @property
    def RebarArrayTooShort() -> FailureDefinitionId: ...
    @property
    def RebarBendRadiusTooBig() -> FailureDefinitionId: ...
    @property
    def RebarBendRadiusTooBigWarn() -> FailureDefinitionId: ...
    @property
    def RebarConstraintWarning() -> FailureDefinitionId: ...
    @property
    def RebarContainerOutSideOfHostWarning() -> FailureDefinitionId: ...
    @property
    def RebarEndTreatmentOverHook() -> FailureDefinitionId: ...
    @property
    def RebarHookOverEndTreatment() -> FailureDefinitionId: ...
    @property
    def RebarHooksDontMatchShape() -> FailureDefinitionId: ...
    @property
    def RebarIllegalBarType() -> FailureDefinitionId: ...
    @property
    def RebarNoConstraints() -> FailureDefinitionId: ...
    @property
    def RebarNoMatchingHooks() -> FailureDefinitionId: ...
    @property
    def RebarShapeFailure() -> FailureDefinitionId: ...
    @property
    def RebarShapeFailureCustomError() -> FailureDefinitionId: ...
    @property
    def RebarShapeFailureCustomWarning() -> FailureDefinitionId: ...
    @property
    def RebarSpacingTooSmall() -> FailureDefinitionId: ...
    @property
    def RebarTooShortImperial() -> FailureDefinitionId: ...
    @property
    def RebarTooShortMetric() -> FailureDefinitionId: ...
    @property
    def SketchDimensionsRemoved() -> FailureDefinitionId: ...
    @property
    def SketchDimsBWFRemoved() -> FailureDefinitionId: ...
    @property
    def SketchFreeFormSet() -> FailureDefinitionId: ...
    @property
    def SketchNonPlanarFreeForm() -> FailureDefinitionId: ...
    @property
    def StandardHookBendDiameterTooLarge() -> FailureDefinitionId: ...
    @property
    def StandardHookBendDiameterTooSmall() -> FailureDefinitionId: ...
    @property
    def TooLargeNumberOfBars() -> FailureDefinitionId: ...
    @property
    def TooSmallNumberOfBars() -> FailureDefinitionId: ...
    @property
    def TrySmallerBarType() -> FailureDefinitionId: ...
    @property
    def UnconstrainableRebarHandle() -> FailureDefinitionId: ...


class RebarShapeFailures:
    @property
    def CircleMultiPlanarShape() -> FailureDefinitionId: ...
    @property
    def CircleUnbounded() -> FailureDefinitionId: ...
    @property
    def CurveOverconstrained() -> FailureDefinitionId: ...
    @property
    def CurveUnderconstrained() -> FailureDefinitionId: ...
    @property
    def CurvesCollinear() -> FailureDefinitionId: ...
    @property
    def CurvesUnlooped() -> FailureDefinitionId: ...
    @property
    def DefaultParamaterValuesIncorrect() -> FailureDefinitionId: ...
    @property
    def DepthDimensionNotExisted() -> FailureDefinitionId: ...
    @property
    def DiagonalEdgesAreUnderconstrained() -> FailureDefinitionId: ...
    @property
    def DimensionLoose() -> FailureDefinitionId: ...
    @property
    def DimensionWithCommonLengthUnit() -> FailureDefinitionId: ...
    @property
    def DimensionWithoutParameter() -> FailureDefinitionId: ...
    @property
    def FormulaDrivenDimension() -> FailureDefinitionId: ...
    @property
    def HooksAndEndTreatmentAtTheSameEnd() -> FailureDefinitionId: ...
    @property
    def MultiPlanarDepth() -> FailureDefinitionId: ...
    @property
    def MultipleArcsMustOverlap() -> FailureDefinitionId: ...
    @property
    def ParameterValueNotDefined() -> FailureDefinitionId: ...
    @property
    def PlanarMultiPlanarShape() -> FailureDefinitionId: ...
    @property
    def ShapeFailure() -> FailureDefinitionId: ...
    @property
    def WrongDepthDimensionLabel() -> FailureDefinitionId: ...


class RebarSystemFailures:
    @property
    def AreaReinforcementOutSideOfHost() -> FailureDefinitionId: ...
    @property
    def AreaReinforcementRegenFail() -> FailureDefinitionId: ...
    @property
    def AreaReinforcementWrongHost() -> FailureDefinitionId: ...
    @property
    def AreaReinforcementsCollision() -> FailureDefinitionId: ...
    @property
    def BarsTooCloseNumber() -> FailureDefinitionId: ...
    @property
    def BarsTooCloseSpacing() -> FailureDefinitionId: ...
    @property
    def BarsTooSparseSpacing() -> FailureDefinitionId: ...
    @property
    def CannotPlaceAreaReinforcement() -> FailureDefinitionId: ...
    @property
    def CannotPlaceAreaReinforcementWarn() -> FailureDefinitionId: ...
    @property
    def CannotPlaceAreaReininforcement() -> FailureDefinitionId: ...
    @property
    def CannotPlaceAreaReininforcementWarn() -> FailureDefinitionId: ...
    @property
    def CannotPlacePathReinforcement() -> FailureDefinitionId: ...
    @property
    def CannotPlacePathReinforcementWarn() -> FailureDefinitionId: ...
    @property
    def CannotPlacePathReininforcement() -> FailureDefinitionId: ...
    @property
    def CannotPlacePathReininforcementWarn() -> FailureDefinitionId: ...
    @property
    def CannotUseAreaReinforcementHookTypeStyle() -> FailureDefinitionId: ...
    @property
    def CannotUsePathReinforcementHookTypeStyle() -> FailureDefinitionId: ...
    @property
    def DPartReinfDeletedEditDivision() -> FailureDefinitionId: ...
    @property
    def DPartReinforcementDeleted() -> FailureDefinitionId: ...
    @property
    def HostFlagAreaOff() -> FailureDefinitionId: ...
    @property
    def HostFlagAreaOn() -> FailureDefinitionId: ...
    @property
    def HostFlagPathOff() -> FailureDefinitionId: ...
    @property
    def HostFlagPathOn() -> FailureDefinitionId: ...
    @property
    def PathReinforcementWrongHost() -> FailureDefinitionId: ...
    @property
    def RebarSystemOffset() -> FailureDefinitionId: ...
    @property
    def ThinHostFloor() -> FailureDefinitionId: ...
    @property
    def ThinHostFloorError() -> FailureDefinitionId: ...
    @property
    def ThinHostWall() -> FailureDefinitionId: ...
    @property
    def ThinHostWallError() -> FailureDefinitionId: ...


class RefPlaneFailures:
    @property
    def AlreadyHaveTwoClosurePlanes() -> FailureDefinitionId: ...


class RegenFailures:
    @property
    def CannotRegenFamily() -> FailureDefinitionId: ...
    @property
    def CircularDependency() -> FailureDefinitionId: ...
    @property
    def CircularDependencyAssocProp() -> FailureDefinitionId: ...
    @property
    def CircularDependencyAssocPropError() -> FailureDefinitionId: ...
    @property
    def CircularDependencyConstraint() -> FailureDefinitionId: ...
    @property
    def CircularDependencyConstraintError() -> FailureDefinitionId: ...
    @property
    def CircularDependencyError() -> FailureDefinitionId: ...
    @property
    def CircularDependencyResolved() -> FailureDefinitionId: ...
    @property
    def CircularDependencySketch() -> FailureDefinitionId: ...
    @property
    def CircularDependencySketchError() -> FailureDefinitionId: ...
    @property
    def CircularDependencyUncut() -> FailureDefinitionId: ...
    @property
    def CircularDependencyUncutError() -> FailureDefinitionId: ...
    @property
    def CircularDependencyWall() -> FailureDefinitionId: ...
    @property
    def CircularDependencyWallError() -> FailureDefinitionId: ...
    @property
    def ForceRegenSketch() -> FailureDefinitionId: ...
    @property
    def GeomStepFailed() -> FailureDefinitionId: ...
    @property
    def GeomStepFailedError() -> FailureDefinitionId: ...
    @property
    def RegenElements() -> FailureDefinitionId: ...
    @property
    def RegenFailure() -> FailureDefinitionId: ...
    @property
    def RegeneratedElements() -> FailureDefinitionId: ...
    @property
    def UserCancelled() -> FailureDefinitionId: ...
    @property
    def UserCancelledError() -> FailureDefinitionId: ...


class RenderFailures:
    @property
    def LightParametersNotInRange() -> FailureDefinitionId: ...
    @property
    def LightSourceInsideGeometry() -> FailureDefinitionId: ...
    @property
    def ProhibitDeletionLightSource() -> FailureDefinitionId: ...
    @property
    def RenderLibNotInstalledWarn() -> FailureDefinitionId: ...


class RevisionCloudFailures:
    @property
    def ModifyingIssuedRevisionCloudOnUpgrade() -> FailureDefinitionId: ...
    @property
    def ProhibitCreationInIssued() -> FailureDefinitionId: ...
    @property
    def ProhibitModificationOfIssuedRevisionCloud() -> FailureDefinitionId: ...
    @property
    def ProhibitSwitchFromIssuedRevision() -> FailureDefinitionId: ...
    @property
    def ProhibitSwitchToIssuedRevision() -> FailureDefinitionId: ...


class RevisionFailures:
    @property
    def RevisionSettingsDuplicateName() -> FailureDefinitionId: ...


class RevolutionFailures:
    @property
    def CannotDrawRevolution() -> FailureDefinitionId: ...
    @property
    def ProfileCrossesRevolutionAxis() -> FailureDefinitionId: ...
    @property
    def ProfileNotPlanar() -> FailureDefinitionId: ...


class RoofFailures:
    @property
    def CurveRoofSkippedLoops() -> FailureDefinitionId: ...
    @property
    def CurveRoofSkippedLoopsError() -> FailureDefinitionId: ...
    @property
    def CurveRoofSkippedLoopsWarn() -> FailureDefinitionId: ...
    @property
    def ExtrudedRoofCutBySketch() -> FailureDefinitionId: ...
    @property
    def HadToAlignEaves() -> FailureDefinitionId: ...
    @property
    def HoleInRoofFailed() -> FailureDefinitionId: ...
    @property
    def InvalidArcSegmentation() -> FailureDefinitionId: ...
    @property
    def JoinedRoofMissesTarget() -> FailureDefinitionId: ...
    @property
    def JoinedRoofMissesTargetError() -> FailureDefinitionId: ...
    @property
    def NoFlatCurtainRoofs() -> FailureDefinitionId: ...
    @property
    def OnlyOneSlopeCurtainRoof() -> FailureDefinitionId: ...
    @property
    def OnlyUpwardFacesUsed() -> FailureDefinitionId: ...
    @property
    def RoofCutoffRemoved() -> FailureDefinitionId: ...
    @property
    def RoofExceedsMaxHeight() -> FailureDefinitionId: ...
    @property
    def RoofMeetsRoofTangentially() -> FailureDefinitionId: ...
    @property
    def RoofMeetsRoofTangentiallyError() -> FailureDefinitionId: ...
    @property
    def RoofSlopeExceedsThreshold() -> FailureDefinitionId: ...
    @property
    def RoofToRefPlanes() -> FailureDefinitionId: ...
    @property
    def RoofToRefPlanesError() -> FailureDefinitionId: ...
    @property
    def UnusedSlopeArrow() -> FailureDefinitionId: ...
    @property
    def UptoHeightTooLow() -> FailureDefinitionId: ...
    @property
    def UserCancelledRoof() -> FailureDefinitionId: ...
    @property
    def WorkplaneShouldBeLevel() -> FailureDefinitionId: ...


class RoomFailures:
    @property
    def AreaTagBadViewType() -> FailureDefinitionId: ...
    @property
    def AreaUnplaceWarning() -> FailureDefinitionId: ...
    @property
    def CannotMakeRoomsGeometry() -> FailureDefinitionId: ...
    @property
    def ExtensionsOverlapWarning() -> FailureDefinitionId: ...
    @property
    def InvalidReflectivityPercentage() -> FailureDefinitionId: ...
    @property
    def InvisibleRoomBoundElemement() -> FailureDefinitionId: ...
    @property
    def OptionConflictBoundariesVaryMainAddToOptionSet() -> FailureDefinitionId: ...
    @property
    def OptionConflictBoundariesVaryMainSeparate() -> FailureDefinitionId: ...
    @property
    def OptionConflictBoundariesVaryOptionSeparate() -> FailureDefinitionId: ...
    @property
    def OptionConflictInLinkBoundariesVaryMainAddToOptionSet() -> FailureDefinitionId: ...
    @property
    def OptionConflictInLinkBoundariesVaryMainSeparate() -> FailureDefinitionId: ...
    @property
    def OptionConflictInLinkBoundariesVaryOptionSeparate() -> FailureDefinitionId: ...
    @property
    def OptionConflictInLinkRoomOverlapMain() -> FailureDefinitionId: ...
    @property
    def OptionConflictInLinkRoomOverlapOption() -> FailureDefinitionId: ...
    @property
    def OptionConflictRoomOverlapMain() -> FailureDefinitionId: ...
    @property
    def OptionConflictRoomOverlapOption() -> FailureDefinitionId: ...
    @property
    def RoomBaseAboveComputationHeight() -> FailureDefinitionId: ...
    @property
    def RoomBelowCompHeight() -> FailureDefinitionId: ...
    @property
    def RoomBoundaryMisalignment() -> FailureDefinitionId: ...
    @property
    def RoomHeightNegative() -> FailureDefinitionId: ...
    @property
    def RoomLevelElevs() -> FailureDefinitionId: ...
    @property
    def RoomNotEnclosed() -> FailureDefinitionId: ...
    @property
    def RoomNotEnclosedAreas() -> FailureDefinitionId: ...
    @property
    def RoomNotEnclosedRooms() -> FailureDefinitionId: ...
    @property
    def RoomNotEnclosedSpaces() -> FailureDefinitionId: ...
    @property
    def RoomTagBadViewType() -> FailureDefinitionId: ...
    @property
    def RoomTagDeleted() -> FailureDefinitionId: ...
    @property
    def RoomTagNotInRoom() -> FailureDefinitionId: ...
    @property
    def RoomTagNotInRoomToArea() -> FailureDefinitionId: ...
    @property
    def RoomTagNotInRoomToRoom() -> FailureDefinitionId: ...
    @property
    def RoomTagNotInRoomToSpace() -> FailureDefinitionId: ...
    @property
    def RoomTagVolumeNotComputed() -> FailureDefinitionId: ...
    @property
    def RoomTooShort() -> FailureDefinitionId: ...
    @property
    def RoomUnplaceWarning() -> FailureDefinitionId: ...
    @property
    def RoomsCreatedAutomatically() -> FailureDefinitionId: ...
    @property
    def RoomsFailed() -> FailureDefinitionId: ...
    @property
    def RoomsInSameRegion() -> FailureDefinitionId: ...
    @property
    def RoomsInSameRegionAreas() -> FailureDefinitionId: ...
    @property
    def RoomsInSameRegionRooms() -> FailureDefinitionId: ...
    @property
    def RoomsInSameRegionSpaces() -> FailureDefinitionId: ...
    @property
    def RoomsOverlapInHeight() -> FailureDefinitionId: ...
    @property
    def RoomsReallyFailed() -> FailureDefinitionId: ...
    @property
    def ShowRoomBoundingElements() -> FailureDefinitionId: ...
    @property
    def SpaceUnplaceWarning() -> FailureDefinitionId: ...


class ScheduleViewFailures:
    @property
    def BadViewType() -> FailureDefinitionId: ...
    @property
    def CannotResizeColumn() -> FailureDefinitionId: ...
    @property
    def ColumnsExceedSegment() -> FailureDefinitionId: ...
    @property
    def ColumnsExcluded() -> FailureDefinitionId: ...
    @property
    def DuplicateFieldRemovedFromKeySchedule() -> FailureDefinitionId: ...
    @property
    def NoColumnsJoinedToGridLines() -> FailureDefinitionId: ...
    @property
    def NotGridName() -> FailureDefinitionId: ...
    @property
    def PanelScheduleLoadClassInconsistency() -> FailureDefinitionId: ...
    @property
    def PanelScheduleSlotInconsistency() -> FailureDefinitionId: ...
    @property
    def PanelScheduleSwitchboardSlotInconsistency() -> FailureDefinitionId: ...
    @property
    def SchedulesCanBePlacedOnSheetsOnly() -> FailureDefinitionId: ...
    @property
    def SegmentsStartIsGreaterThanSegmentsEnd() -> FailureDefinitionId: ...


class SculptingFailures:
    @property
    def FaceSculptEditFailed() -> FailureDefinitionId: ...
    @property
    def FaceSculptingFaceLoss() -> FailureDefinitionId: ...


class SectionViewFailures:
    @property
    def ScopeBoxBehindSection() -> FailureDefinitionId: ...


class SelectionFailures:
    @property
    def NoElementSelected() -> FailureDefinitionId: ...
    @property
    def NoValidElementSelected() -> FailureDefinitionId: ...


class SheetFailures:
    @property
    def SheetNumberDuplicated() -> FailureDefinitionId: ...
    @property
    def SheetNumberEmpty() -> FailureDefinitionId: ...


class SiteFailures:
    @property
    def BuildingPadNotConnected() -> FailureDefinitionId: ...
    @property
    def BuildingPadOverlap() -> FailureDefinitionId: ...
    @property
    def CannotComputeProperArea() -> FailureDefinitionId: ...
    @property
    def CannotIntersectSiteRegions() -> FailureDefinitionId: ...
    @property
    def CannotMakeSurface() -> FailureDefinitionId: ...
    @property
    def ContourLabelEmpty() -> FailureDefinitionId: ...
    @property
    def EnterValueOrFormula() -> FailureDefinitionId: ...
    @property
    def GradingInSamePhase() -> FailureDefinitionId: ...
    @property
    def NoHostForSubregion() -> FailureDefinitionId: ...
    @property
    def NoHostForSubregionWarn() -> FailureDefinitionId: ...
    @property
    def NotEnoughPointsInSurface() -> FailureDefinitionId: ...
    @property
    def PointNotInSurface() -> FailureDefinitionId: ...
    @property
    def PointRelativeOutside() -> FailureDefinitionId: ...
    @property
    def PropertyIntersect() -> FailureDefinitionId: ...
    @property
    def RegionPhaseMismatch() -> FailureDefinitionId: ...
    @property
    def ResetToposurfacePhaseCreated() -> FailureDefinitionId: ...
    @property
    def SiteEditPointsClipped() -> FailureDefinitionId: ...
    @property
    def SiteEditPointsInvisible() -> FailureDefinitionId: ...
    @property
    def SiteMergeDisconnected() -> FailureDefinitionId: ...
    @property
    def SitePhasesDontOverlap() -> FailureDefinitionId: ...
    @property
    def SiteRegionOptionConflict() -> FailureDefinitionId: ...
    @property
    def SurfaceSelfIntersection() -> FailureDefinitionId: ...
    @property
    def SurfaceSplit() -> FailureDefinitionId: ...
    @property
    def SurfaceSplitError() -> FailureDefinitionId: ...
    @property
    def SurfaceSplitNoIntersection() -> FailureDefinitionId: ...
    @property
    def SurfaceTriangulationFailed() -> FailureDefinitionId: ...


class SiteImportFailures:
    @property
    def BoundaryDetectError() -> FailureDefinitionId: ...
    @property
    def ContoursNoncontours() -> FailureDefinitionId: ...
    @property
    def DifferentEntityTypes() -> FailureDefinitionId: ...
    @property
    def NoPoints() -> FailureDefinitionId: ...
    @property
    def NoViewSpecificSiteImports() -> FailureDefinitionId: ...
    @property
    def SurfaceExists() -> FailureDefinitionId: ...
    @property
    def TooFarAway() -> FailureDefinitionId: ...
    @property
    def TooLarge() -> FailureDefinitionId: ...
    @property
    def TooManyMeshes() -> FailureDefinitionId: ...
    @property
    def UnusedPoints() -> FailureDefinitionId: ...


class SketchFailures:
    @property
    def SketchTooLarge() -> FailureDefinitionId: ...
    @property
    def SketchWasDeleted() -> FailureDefinitionId: ...
    @property
    def SketchedRunInvalidPath() -> FailureDefinitionId: ...
    @property
    def SketchedShapeNotAvailable() -> FailureDefinitionId: ...
    @property
    def SketchingInTheWrongView() -> FailureDefinitionId: ...
    @property
    def SketchingInWrongView() -> FailureDefinitionId: ...
    @property
    def StairClosedBoundaries() -> FailureDefinitionId: ...
    @property
    def StairClosedBoundariesError() -> FailureDefinitionId: ...
    @property
    def StairNotEnoughBoundaryCurves() -> FailureDefinitionId: ...
    @property
    def StairNotEnoughBoundaryCurvesError() -> FailureDefinitionId: ...
    @property
    def StairNotEnoughRiserCurves() -> FailureDefinitionId: ...
    @property
    def StairNotEnoughRiserCurvesError() -> FailureDefinitionId: ...
    @property
    def StairOnlyOneConnectedBoundary() -> FailureDefinitionId: ...
    @property
    def StairOnlyOneConnectedBoundaryError() -> FailureDefinitionId: ...
    @property
    def StairRiserDoesntIntersectBoundary() -> FailureDefinitionId: ...
    @property
    def StairRiserDoesntIntersectBoundaryError() -> FailureDefinitionId: ...
    @property
    def StairTooManyConnectedBoundaries() -> FailureDefinitionId: ...
    @property
    def StairTooManyConnectedBoundariesError() -> FailureDefinitionId: ...
    @property
    def SubregionNoHostSurf() -> FailureDefinitionId: ...
    @property
    def SuggestMakingFamilyNonParametric() -> FailureDefinitionId: ...
    @property
    def SuspendedSketchWarn() -> FailureDefinitionId: ...
    @property
    def TooFewParamsForSketch() -> FailureDefinitionId: ...
    @property
    def TooManyElementsInSketch() -> FailureDefinitionId: ...
    @property
    def TooManySlopes() -> FailureDefinitionId: ...
    @property
    def TooManySlopesError() -> FailureDefinitionId: ...
    @property
    def TrussClosedReference() -> FailureDefinitionId: ...
    @property
    def TrussCrossingReferences() -> FailureDefinitionId: ...
    @property
    def TrussMissingReference() -> FailureDefinitionId: ...
    @property
    def TrussOverlappingReference() -> FailureDefinitionId: ...
    @property
    def TrussSegmentedReference() -> FailureDefinitionId: ...
    @property
    def TrussShiftedReferences() -> FailureDefinitionId: ...
    @property
    def TrussSwappedReferences() -> FailureDefinitionId: ...
    @property
    def UnsatisfiedSupportAssocProp() -> FailureDefinitionId: ...
    @property
    def UnsatisfiedWallAssocProp() -> FailureDefinitionId: ...
    @property
    def VarSketchFailure() -> FailureDefinitionId: ...
    @property
    def VarSketchInElementFailure() -> FailureDefinitionId: ...
    @property
    def WrongCutBoundaryLoops() -> FailureDefinitionId: ...
    @property
    def WrongFaceSplitterLoopTypesNum() -> FailureDefinitionId: ...
    @property
    def AreaLoadNoForce() -> FailureDefinitionId: ...
    @property
    def AxisNotSpecified() -> FailureDefinitionId: ...
    @property
    def BadNosingProfile() -> FailureDefinitionId: ...
    @property
    def BadRailingsProfile() -> FailureDefinitionId: ...
    @property
    def BeamDirectionNotSpecified() -> FailureDefinitionId: ...
    @property
    def BeamDirectionNotSpecifiedError() -> FailureDefinitionId: ...
    @property
    def BentFabricSheetClosedLoopInSketch() -> FailureDefinitionId: ...
    @property
    def BentFabricSheetEmptySketch() -> FailureDefinitionId: ...
    @property
    def BentFabricSheetInvalidElementInSketch() -> FailureDefinitionId: ...
    @property
    def BentFabricSheetLinesOverlapOrIntersect() -> FailureDefinitionId: ...
    @property
    def BentFabricSheetManyLoopsInSketch() -> FailureDefinitionId: ...
    @property
    def BentFabricSheetTooShortSegments() -> FailureDefinitionId: ...
    @property
    def BuildingPadNoSurface() -> FailureDefinitionId: ...
    @property
    def BuildingPadNoSurfaceError() -> FailureDefinitionId: ...
    @property
    def CannotChangeUserSketchPlane() -> FailureDefinitionId: ...
    @property
    def CannotChangeUserSketchPlaneError() -> FailureDefinitionId: ...
    @property
    def CannotChangeWorkplaneVisibility() -> FailureDefinitionId: ...
    @property
    def CannotComputeRailingsElevation() -> FailureDefinitionId: ...
    @property
    def CannotComputeRailingsElevationError() -> FailureDefinitionId: ...
    @property
    def CannotComputeRailingsElevationWarn() -> FailureDefinitionId: ...
    @property
    def CannotConvertSketch() -> FailureDefinitionId: ...
    @property
    def CannotDrawExtrusionRoof() -> FailureDefinitionId: ...
    @property
    def CannotDrawProfileRoof() -> FailureDefinitionId: ...
    @property
    def CannotDrawZone() -> FailureDefinitionId: ...
    @property
    def CannotGetSketchReferences() -> FailureDefinitionId: ...
    @property
    def CannotHaveArcs() -> FailureDefinitionId: ...
    @property
    def CannotHaveArcsPath3d() -> FailureDefinitionId: ...
    @property
    def CircleMultiPlanarShapeInSketch() -> FailureDefinitionId: ...
    @property
    def ClosedProfileRoof() -> FailureDefinitionId: ...
    @property
    def ConstantHeightNotParallel() -> FailureDefinitionId: ...
    @property
    def ConstantHeightNotParallelError() -> FailureDefinitionId: ...
    @property
    def ContainedInOtherLoops() -> FailureDefinitionId: ...
    @property
    def ConvertSplineToLineFailed() -> FailureDefinitionId: ...
    @property
    def CurveFromPickedFailed() -> FailureDefinitionId: ...
    @property
    def CurveIntersectsCutFace() -> FailureDefinitionId: ...
    @property
    def CurveIntersectsSplitFace() -> FailureDefinitionId: ...
    @property
    def CurveTooShort() -> FailureDefinitionId: ...
    @property
    def DifferentOffsets() -> FailureDefinitionId: ...
    @property
    def ElementsSketchTooLarge() -> FailureDefinitionId: ...
    @property
    def ElevationSketchNotAllowed() -> FailureDefinitionId: ...
    @property
    def EndsNotOnCutFace() -> FailureDefinitionId: ...
    @property
    def EndsNotOnEdge() -> FailureDefinitionId: ...
    @property
    def FloorCannotAddDirectionCurve() -> FailureDefinitionId: ...
    @property
    def FloorCannotAddDirectionCurveError() -> FailureDefinitionId: ...
    @property
    def FloorDirectionNotSpecified() -> FailureDefinitionId: ...
    @property
    def FloorManyDirectionCurves() -> FailureDefinitionId: ...
    @property
    def InvalidAreaLoadSketch() -> FailureDefinitionId: ...
    @property
    def InvalidAreaLoadSketchError() -> FailureDefinitionId: ...
    @property
    def InvalidCropAreaSketch() -> FailureDefinitionId: ...
    @property
    def InvalidCropAreaSketchRegen() -> FailureDefinitionId: ...
    @property
    def InvalidElevationSketch() -> FailureDefinitionId: ...
    @property
    def InvalidElevationSketchError() -> FailureDefinitionId: ...
    @property
    def InvalidProfile() -> FailureDefinitionId: ...
    @property
    def InvalidProfileError() -> FailureDefinitionId: ...
    @property
    def InvalidRoofCurveloop() -> FailureDefinitionId: ...
    @property
    def InvalidRoofCurveloopError() -> FailureDefinitionId: ...
    @property
    def InvalidRoofCurveloopFailure() -> FailureDefinitionId: ...
    @property
    def InvalidSketch() -> FailureDefinitionId: ...
    @property
    def InvalidSketchError() -> FailureDefinitionId: ...
    @property
    def InvalidSketchForBuildingpad() -> FailureDefinitionId: ...
    @property
    def InvalidSketchForCeiling() -> FailureDefinitionId: ...
    @property
    def InvalidSketchForFloor() -> FailureDefinitionId: ...
    @property
    def InvalidSketchForRoofsoffit() -> FailureDefinitionId: ...
    @property
    def InvalidSketchPath3d() -> FailureDefinitionId: ...
    @property
    def LandingNotEnoughBoundaryCurves() -> FailureDefinitionId: ...
    @property
    def LandingTwoManyLoops() -> FailureDefinitionId: ...
    @property
    def LinesOverlap() -> FailureDefinitionId: ...
    @property
    def LinesOverlapError() -> FailureDefinitionId: ...
    @property
    def LinesOverlapPath3d() -> FailureDefinitionId: ...
    @property
    def LoopIntersect() -> FailureDefinitionId: ...
    @property
    def LoopIntersectError() -> FailureDefinitionId: ...
    @property
    def LoopIntersectPath3d() -> FailureDefinitionId: ...
    @property
    def LoopsOutsideFaceSplit() -> FailureDefinitionId: ...
    @property
    def LoopsOutsideFaceSplitterTooShort() -> FailureDefinitionId: ...
    @property
    def ManyCCWLoops() -> FailureDefinitionId: ...
    @property
    def ManyCCWLoopsError() -> FailureDefinitionId: ...
    @property
    def ManyDirectionCurves() -> FailureDefinitionId: ...
    @property
    def ManyDirectionCurvesError() -> FailureDefinitionId: ...
    @property
    def MissingLapInSketch() -> FailureDefinitionId: ...
    @property
    def MoreThanOneAxis() -> FailureDefinitionId: ...
    @property
    def MutipleStairsPathInOneRunFailure() -> FailureDefinitionId: ...
    @property
    def NestedLoops() -> FailureDefinitionId: ...
    @property
    def NoLoops() -> FailureDefinitionId: ...
    @property
    def NoLoopsError() -> FailureDefinitionId: ...
    @property
    def NoLoopsPath3d() -> FailureDefinitionId: ...
    @property
    def NoPlane() -> FailureDefinitionId: ...
    @property
    def NonMonotoneRoof() -> FailureDefinitionId: ...
    @property
    def NotOneCCWLoop() -> FailureDefinitionId: ...
    @property
    def NotOneCurve() -> FailureDefinitionId: ...
    @property
    def NotOneCurveError() -> FailureDefinitionId: ...
    @property
    def NotOneCurvePath3d() -> FailureDefinitionId: ...
    @property
    def NotOneLoop() -> FailureDefinitionId: ...
    @property
    def NotOneLoopPath3d() -> FailureDefinitionId: ...
    @property
    def OpenAreaLoadLoop() -> FailureDefinitionId: ...
    @property
    def OpenAreaLoadLoopError() -> FailureDefinitionId: ...
    @property
    def OpenLoop() -> FailureDefinitionId: ...
    @property
    def OpenLoopError() -> FailureDefinitionId: ...
    @property
    def OpenLoopPath3d() -> FailureDefinitionId: ...
    @property
    def PathCannotBeClosedLoop() -> FailureDefinitionId: ...
    @property
    def PathCannotBeClosedLoopPath3d() -> FailureDefinitionId: ...
    @property
    def PathReinforcementClosedLoop() -> FailureDefinitionId: ...
    @property
    def PathReinforcementEmptySketch() -> FailureDefinitionId: ...
    @property
    def PathReinforcementManyLoops() -> FailureDefinitionId: ...
    @property
    def PlanarMultiPlanarShapeInSketch() -> FailureDefinitionId: ...
    @property
    def RailingDoublyConnected() -> FailureDefinitionId: ...
    @property
    def RailingDoublyConnectedError() -> FailureDefinitionId: ...
    @property
    def RailingNotConnected() -> FailureDefinitionId: ...
    @property
    def RailingNotConnectedError() -> FailureDefinitionId: ...
    @property
    def RebarEmptySketch() -> FailureDefinitionId: ...
    @property
    def RebarEmptySketchError() -> FailureDefinitionId: ...
    @property
    def RebarManyLoops() -> FailureDefinitionId: ...
    @property
    def RebarManyLoopsError() -> FailureDefinitionId: ...
    @property
    def RebarSystemDirectionNotSpecified() -> FailureDefinitionId: ...
    @property
    def RebarSystemDirectionNotSpecifiedError() -> FailureDefinitionId: ...
    @property
    def RunInvalidSketch() -> FailureDefinitionId: ...
    @property
    def RunNotEnoughBoundaryCurves() -> FailureDefinitionId: ...
    @property
    def SculptingCurvesCannotFormClosedLoop() -> FailureDefinitionId: ...
    @property
    def SculptingCurvesCrossAxis() -> FailureDefinitionId: ...
    @property
    def SculptingCurvesTouchAxis() -> FailureDefinitionId: ...
    @property
    def SculptingLoopsOnBothSidesOfAxis() -> FailureDefinitionId: ...
    @property
    def SculptingSingleLineLoopLiesOnAxis() -> FailureDefinitionId: ...
    @property
    def ShortCurveInSketch() -> FailureDefinitionId: ...
    @property
    def ShortCurveInSketchRoof() -> FailureDefinitionId: ...
    @property
    def SiteCannotDrawSurfaceBoundary() -> FailureDefinitionId: ...
    @property
    def SketchFailurePlanes() -> FailureDefinitionId: ...
    @property
    def SketchOverconstrained() -> FailureDefinitionId: ...
    @property
    def SketchOverconstrainedError() -> FailureDefinitionId: ...
    @property
    def SketchOverconstrainedWarn() -> FailureDefinitionId: ...


class SkylightFailures:
    @property
    def MinSkylightWidthImperial() -> FailureDefinitionId: ...
    @property
    def MinSkylightWidthMetric() -> FailureDefinitionId: ...


class SlabFailures:
    @property
    def CantileverValueTooBig() -> FailureDefinitionId: ...


class SlabShapeFailures:
    @property
    def SlabShapeEditFailed() -> FailureDefinitionId: ...
    @property
    def SlabShapeEditFailedError() -> FailureDefinitionId: ...
    @property
    def SlabShapeFailedNotHorz() -> FailureDefinitionId: ...
    @property
    def SlabShapeFailedNotOnlyLines() -> FailureDefinitionId: ...
    @property
    def SlabShapeFailedTooThin() -> FailureDefinitionId: ...
    @property
    def SlabShapeWarnVerticesCoincident() -> FailureDefinitionId: ...
    @property
    def SlabShapeWarnVerticesDeleted() -> FailureDefinitionId: ...
    @property
    def SlopeTailInsideSlopeLine() -> FailureDefinitionId: ...
    @property
    def SlopeZero() -> FailureDefinitionId: ...
    @property
    def SlopedInnerEdge() -> FailureDefinitionId: ...


class SlantedColumnFailures:
    @property
    def CannotCutParallelToLocationCurve() -> FailureDefinitionId: ...
    @property
    def SlantedColumnCannotCutEnd() -> FailureDefinitionId: ...
    @property
    def SlantedColumnCannotCutEndWarn() -> FailureDefinitionId: ...


class SpanDirectionSymbolFailures:
    @property
    def NonPlanView() -> FailureDefinitionId: ...


class SplineFailures:
    @property
    def CannotCreateSpline() -> FailureDefinitionId: ...
    @property
    def ClosedSpline() -> FailureDefinitionId: ...


class StairRampFailures:
    @property
    def StairsAreUpdatedDueToLevelHeightChange() -> FailureDefinitionId: ...
    @property
    def StairsAutomaticLandingLayoutFailure() -> FailureDefinitionId: ...
    @property
    def StairsAutomaticLandingLayoutWarn() -> FailureDefinitionId: ...
    @property
    def StairsBottomEndExceedsOrNotReachWarning() -> FailureDefinitionId: ...
    @property
    def StairsCannotExtendToFloorStructureLayerWarning() -> FailureDefinitionId: ...
    @property
    def StairsCommonRunGenerateLayoutFailure() -> FailureDefinitionId: ...
    @property
    def StairsComponentJoinFailure() -> FailureDefinitionId: ...
    @property
    def StairsCrossingRisersDisallowedFailure() -> FailureDefinitionId: ...
    @property
    def StairsGenericFailure() -> FailureDefinitionId: ...
    @property
    def StairsGenericTransformFailure() -> FailureDefinitionId: ...
    @property
    def StairsIllegalDesiredNumRisers() -> FailureDefinitionId: ...
    @property
    def StairsInMultistoryExceedTopConstraint() -> FailureDefinitionId: ...
    @property
    def StairsOnlySingleBoundaryHasRiserWithBothEndsOnBoundaryFailure() -> FailureDefinitionId: ...
    @property
    def StairsOtherThan2IntsByRiserAndBoundaryFailure() -> FailureDefinitionId: ...
    @property
    def StairsPathPositionResetWarning() -> FailureDefinitionId: ...
    @property
    def StairsRunRunJoinNotAllowedFailure() -> FailureDefinitionId: ...
    @property
    def StairsStartHigherThanEnd() -> FailureDefinitionId: ...
    @property
    def StairsStringerCannotBeCreated() -> FailureDefinitionId: ...
    @property
    def StairsSubElementsNotConnectedWarning() -> FailureDefinitionId: ...
    @property
    def StairsSupportOverlapFailure() -> FailureDefinitionId: ...
    @property
    def StairsSupportTooShort() -> FailureDefinitionId: ...
    @property
    def StairsTopEndExceedsOrNotReachWarning() -> FailureDefinitionId: ...
    @property
    def StairsTopLowerThanBaseFailure() -> FailureDefinitionId: ...
    @property
    def StairsWinderGenLayoutFailure() -> FailureDefinitionId: ...
    @property
    def StairsWinderInvalidParamsFailure() -> FailureDefinitionId: ...
    @property
    def StairsZeroDesiredRisers() -> FailureDefinitionId: ...
    @property
    def StringerCurveTooShort() -> FailureDefinitionId: ...
    @property
    def StringerCurvesNotSplitStairs() -> FailureDefinitionId: ...
    @property
    def TooShortCurveDowngradeGeometry() -> FailureDefinitionId: ...
    @property
    def TreadDepthBelowMin() -> FailureDefinitionId: ...
    @property
    def TreadDepthFailsEq() -> FailureDefinitionId: ...
    @property
    def TreadDepthTooBigFailure() -> FailureDefinitionId: ...
    @property
    def TreadFrontProfileInvalid() -> FailureDefinitionId: ...
    @property
    def UnableToCreateMultistoryStairs() -> FailureDefinitionId: ...
    @property
    def UnexpectedCurveIntersectionFailure() -> FailureDefinitionId: ...
    @property
    def WinderFilletRadiusTooLargeFailure() -> FailureDefinitionId: ...
    @property
    def WinderFirstLegTooShortOrRunWidthTooGreatFailure() -> FailureDefinitionId: ...
    @property
    def WinderGenericError() -> FailureDefinitionId: ...
    @property
    def WinderLegIsTooShortFailure() -> FailureDefinitionId: ...
    @property
    def WinderLegTooShortOrRunWidthTooGreatFailure() -> FailureDefinitionId: ...
    @property
    def WinderLegsAngleTooGreatOrRunWidthTooSmallFailure() -> FailureDefinitionId: ...
    @property
    def WinderMinWidthTooLargeFailure() -> FailureDefinitionId: ...
    @property
    def WinderMinWidthTooLargeForParallelTreadsFailure() -> FailureDefinitionId: ...
    @property
    def WinderParallelLegsFailure() -> FailureDefinitionId: ...
    @property
    def WinderParallelTreadsNumberFailure() -> FailureDefinitionId: ...
    @property
    def WinderRunCreationFailure() -> FailureDefinitionId: ...
    @property
    def WinderRunInsideMinTreadDepthFailure() -> FailureDefinitionId: ...
    @property
    def WinderRunInsideWalklineOffsetFailure() -> FailureDefinitionId: ...
    @property
    def WinderRunWidthLessThan2TimesMinWidthFailure() -> FailureDefinitionId: ...
    @property
    def WinderRunWidthLessThanWalkLineOffsetFailure() -> FailureDefinitionId: ...
    @property
    def WinderRunWidthOrMinWidthOrTooGreatParallelTreadsFailure() -> FailureDefinitionId: ...
    @property
    def WinderRunWidthOrMinWidthOrTooShortFailure() -> FailureDefinitionId: ...
    @property
    def WinderSecondLegTooShortOrRunwidthTooGreatFailure() -> FailureDefinitionId: ...
    @property
    def WinderStraightStepsNumberFailure() -> FailureDefinitionId: ...
    @property
    def WinderThirdLegTooShortOrRunWidthTooGreatFailure() -> FailureDefinitionId: ...
    @property
    def WinderTooManyEndParallelTreadsOrRunWidthFailure() -> FailureDefinitionId: ...
    @property
    def WinderTooManyParallelTreadsAtEndFailure() -> FailureDefinitionId: ...
    @property
    def WinderTooManyParallelTreadsAtHeadFailure() -> FailureDefinitionId: ...
    @property
    def WinderTooManyStartParallelTreadsOrRunWidthFailure() -> FailureDefinitionId: ...
    @property
    def ActualRiserHeightChanged() -> FailureDefinitionId: ...
    @property
    def AntiparallelRampRisers() -> FailureDefinitionId: ...
    @property
    def AntiparallelRampRisersError() -> FailureDefinitionId: ...
    @property
    def ArcRunRadiusTooSmall() -> FailureDefinitionId: ...
    @property
    def ArcRunWidthTooLongFailure() -> FailureDefinitionId: ...
    @property
    def AutomaticLandingConvertedToSketchedLandingWarning() -> FailureDefinitionId: ...
    @property
    def BadBalustersPerTread() -> FailureDefinitionId: ...
    @property
    def BadFillingSpacing() -> FailureDefinitionId: ...
    @property
    def BadRailProfile() -> FailureDefinitionId: ...
    @property
    def BadRailings() -> FailureDefinitionId: ...
    @property
    def BadRailingsError() -> FailureDefinitionId: ...
    @property
    def BadTreadRiserProfile() -> FailureDefinitionId: ...
    @property
    def BalusterUpsideDown() -> FailureDefinitionId: ...
    @property
    def BalustersTooClose() -> FailureDefinitionId: ...
    @property
    def BalustersTooCloseAbsolute() -> FailureDefinitionId: ...
    @property
    def CannotAlignSupportOnPosts() -> FailureDefinitionId: ...
    @property
    def CannotComputeRailElevation() -> FailureDefinitionId: ...
    @property
    def CannotCreateBaluster() -> FailureDefinitionId: ...
    @property
    def CannotCreateBalusterPatterns() -> FailureDefinitionId: ...
    @property
    def CannotCreateCornerBalusters() -> FailureDefinitionId: ...
    @property
    def CannotCreateLandingStringer() -> FailureDefinitionId: ...
    @property
    def CannotCreateMiddleStringer() -> FailureDefinitionId: ...
    @property
    def CannotCreateMonolithicStairs() -> FailureDefinitionId: ...
    @property
    def CannotCreateNosing() -> FailureDefinitionId: ...
    @property
    def CannotCreateOneOrMoreBaluster() -> FailureDefinitionId: ...
    @property
    def CannotCreateOneOrMoreTreads() -> FailureDefinitionId: ...
    @property
    def CannotCreateOpenMiddleStringers() -> FailureDefinitionId: ...
    @property
    def CannotCreateRail() -> FailureDefinitionId: ...
    @property
    def CannotCreateRailGeom() -> FailureDefinitionId: ...
    @property
    def CannotCreateRailWarn() -> FailureDefinitionId: ...
    @property
    def CannotCreateRiser() -> FailureDefinitionId: ...
    @property
    def CannotCreateSideStringer() -> FailureDefinitionId: ...
    @property
    def CannotCreateStairForLevelOverlapping() -> FailureDefinitionId: ...
    @property
    def CannotCreateStringers() -> FailureDefinitionId: ...
    @property
    def CannotDrawStairs() -> FailureDefinitionId: ...
    @property
    def CannotDrawStairsError() -> FailureDefinitionId: ...
    @property
    def CannotEndWithZeroRiser() -> FailureDefinitionId: ...
    @property
    def CannotGenerateFaces() -> FailureDefinitionId: ...
    @property
    def CannotGenerateFacesError() -> FailureDefinitionId: ...
    @property
    def CannotGenerateRamp() -> FailureDefinitionId: ...
    @property
    def CannotGenerateRampError() -> FailureDefinitionId: ...
    @property
    def CannotMakeLanding() -> FailureDefinitionId: ...
    @property
    def CannotOffsetBoundary() -> FailureDefinitionId: ...
    @property
    def CannotOffsetRail() -> FailureDefinitionId: ...
    @property
    def CannotPlaceBalusterOffset() -> FailureDefinitionId: ...
    @property
    def CannotPlaceBalusterPatterns() -> FailureDefinitionId: ...
    @property
    def CannotPlaceRailingOnStringerWarning() -> FailureDefinitionId: ...
    @property
    def CannotProcessInStairsSketchEditMode() -> FailureDefinitionId: ...
    @property
    def CannotSplitRailingWithExtensions() -> FailureDefinitionId: ...
    @property
    def ContinuousRailFilletCreationError() -> FailureDefinitionId: ...
    @property
    def ContinuousRailFilletCreationParallel() -> FailureDefinitionId: ...
    @property
    def ContinuousRailFilletCreationWarning() -> FailureDefinitionId: ...
    @property
    def ContinuousRailGometryCreationFailure() -> FailureDefinitionId: ...
    @property
    def ContinuousRailNotContinuous() -> FailureDefinitionId: ...
    @property
    def ContinuousRailSupportPlacementFailure() -> FailureDefinitionId: ...
    @property
    def ContinuousRailTransitionFailure() -> FailureDefinitionId: ...
    @property
    def ExtendBelowBaseGreaterThanLandingBaseElevation() -> FailureDefinitionId: ...
    @property
    def ExtendBelowBaseGreaterThanRunTopElevation() -> FailureDefinitionId: ...
    @property
    def FailToReOrientSketchCurvesFailure() -> FailureDefinitionId: ...
    @property
    def HeightOfRunIsTooSmall() -> FailureDefinitionId: ...
    @property
    def IntermediateLandingHigherThanTopRunFailure() -> FailureDefinitionId: ...
    @property
    def InvalidBalustersPattern() -> FailureDefinitionId: ...
    @property
    def InvalidLocationLineJustificationFailure() -> FailureDefinitionId: ...
    @property
    def InvalidParameters() -> FailureDefinitionId: ...
    @property
    def InvalidRailProfile() -> FailureDefinitionId: ...
    @property
    def InvalidStairsPathFailure() -> FailureDefinitionId: ...
    @property
    def InvalidStartLevel() -> FailureDefinitionId: ...
    @property
    def InvalidStartLevelRamp() -> FailureDefinitionId: ...
    @property
    def LandingDepthIsLessThanRunWidthWarning() -> FailureDefinitionId: ...
    @property
    def LandingHeightUnderStairsBottom() -> FailureDefinitionId: ...
    @property
    def LandingShapeHandleOnPinnedRunFailure() -> FailureDefinitionId: ...
    @property
    def MayUnjoinRailAndSupports() -> FailureDefinitionId: ...
    @property
    def MultistoryLevelBelowTopbottomLevel() -> FailureDefinitionId: ...
    @property
    def MultistoryLevelBelowTopbottomLevelError() -> FailureDefinitionId: ...
    @property
    def MultistoryStairDoesntReach() -> FailureDefinitionId: ...
    @property
    def MultistoryStairsAutomaticLevelLandingsDeleted() -> FailureDefinitionId: ...
    @property
    def MultistoryStairsComponentJoinFailure() -> FailureDefinitionId: ...
    @property
    def MultistoryStairsHideTopLevelParameter() -> FailureDefinitionId: ...
    @property
    def MultistoryStandardStairBottomEndExceedsOrNotReach() -> FailureDefinitionId: ...
    @property
    def MultistoryStandardStairTopEndExceedsOrNotReach() -> FailureDefinitionId: ...
    @property
    def MultusegmentRampRiser() -> FailureDefinitionId: ...
    @property
    def MultusegmentRampRiserError() -> FailureDefinitionId: ...
    @property
    def NoCurvesInRailing() -> FailureDefinitionId: ...
    @property
    def NoProfileForRail() -> FailureDefinitionId: ...
    @property
    def NoRailingsStringer() -> FailureDefinitionId: ...
    @property
    def NoRisersInPureMonolithicStairs() -> FailureDefinitionId: ...
    @property
    def NoRunsRamp() -> FailureDefinitionId: ...
    @property
    def NoRunsRampError() -> FailureDefinitionId: ...
    @property
    def NotALineRiserRamp() -> FailureDefinitionId: ...
    @property
    def NotALineRiserRampError() -> FailureDefinitionId: ...
    @property
    def NotEnoughRisers() -> FailureDefinitionId: ...
    @property
    def NotchThicknessIsLargerThanLandingWarning() -> FailureDefinitionId: ...
    @property
    def OnlyMonolithicStairs() -> FailureDefinitionId: ...
    @property
    def PartOfRiserLiesOnBoundaryFailure() -> FailureDefinitionId: ...
    @property
    def PathDoesntJoinToBorderRisersFailure() -> FailureDefinitionId: ...
    @property
    def RailCurveTooShort() -> FailureDefinitionId: ...
    @property
    def RailPathCloseLoopForExtensionWarning() -> FailureDefinitionId: ...
    @property
    def RailPlacedOutsideOfHost() -> FailureDefinitionId: ...
    @property
    def RailProfileLowerThanFilletError() -> FailureDefinitionId: ...
    @property
    def RailProfileLowerThanFilletFailure() -> FailureDefinitionId: ...
    @property
    def RailProfileOpen() -> FailureDefinitionId: ...
    @property
    def RailTypeChangeInconsistancyWarningWithResetBtn() -> FailureDefinitionId: ...
    @property
    def RailingBadOffset() -> FailureDefinitionId: ...
    @property
    def RailingCurvesNotSplitRamp() -> FailureDefinitionId: ...
    @property
    def RailingCurvesNotSplitStairs() -> FailureDefinitionId: ...
    @property
    def RailingDoublyConnected() -> FailureDefinitionId: ...
    @property
    def RailingNotConnected() -> FailureDefinitionId: ...
    @property
    def RampDoesntReach() -> FailureDefinitionId: ...
    @property
    def RampDoesntReachOffset() -> FailureDefinitionId: ...
    @property
    def RampLandingNotCreated() -> FailureDefinitionId: ...
    @property
    def RampRunTooComplex() -> FailureDefinitionId: ...
    @property
    def RampStartHigherThanEnd() -> FailureDefinitionId: ...
    @property
    def RiserCurveTooShort() -> FailureDefinitionId: ...
    @property
    def RiserHeightIsTooSmall() -> FailureDefinitionId: ...
    @property
    def RiserIntWithBoundaryMoreThanOnceFailure() -> FailureDefinitionId: ...
    @property
    def RiserThicknesssResetToZero() -> FailureDefinitionId: ...
    @property
    def RisersAtSameLocation() -> FailureDefinitionId: ...
    @property
    def RunBottomHigherThanTopFailure() -> FailureDefinitionId: ...
    @property
    def RunBottomUnderStairsBottomFailure() -> FailureDefinitionId: ...
    @property
    def RunIsJoiningLandingWithRiserSoNotchDoesNotWorkWarning() -> FailureDefinitionId: ...
    @property
    def RunTopLowerThanBottomFailure() -> FailureDefinitionId: ...
    @property
    def SpiralRunRadiusTooSmallFailure() -> FailureDefinitionId: ...
    @property
    def StairIncompleteFailure() -> FailureDefinitionId: ...
    @property
    def StairStringerCantOffset() -> FailureDefinitionId: ...
    @property
    def StairsActualRiserHeightGreaterThanMaximumFailure() -> FailureDefinitionId: ...
    @property
    def StairsActualRunWidthLessThanMinimumFailure() -> FailureDefinitionId: ...
    @property
    def StairsActualTreadDepthLessThanMinimumFailure() -> FailureDefinitionId: ...
    @property
    def StairsAlreadyAttachedToCurrentLevel() -> FailureDefinitionId: ...


class SteelElementFailures:
    @property
    def SteelElementModifyParametersTaskNotFinished() -> FailureDefinitionId: ...
    @property
    def SteelElementPreviewTaskNotFinished() -> FailureDefinitionId: ...
    @property
    def SteelElementPropagationTaskNotFinished() -> FailureDefinitionId: ...
    @property
    def SteelElementTaskNotFinished() -> FailureDefinitionId: ...


class SteelElementsFailures:
    @property
    def SteelElementInvisibleInCurrentLevelOfDetailWarn() -> FailureDefinitionId: ...
    @property
    def SteelElementModifiersWillBeIgnoredWarn() -> FailureDefinitionId: ...


class StructuralAssetFailures:
    @property
    def StructuralMaterialAssetInvalid() -> FailureDefinitionId: ...


class StructuralConnectionFailures:
    @property
    def StructuralConnectionCannotGenerate() -> FailureDefinitionId: ...
    @property
    def StructuralConnectionCannotReplaceRefs() -> FailureDefinitionId: ...
    @property
    def StructuralConnectionForbiddenElementInGroup() -> FailureDefinitionId: ...
    @property
    def StructuralConnectionNoSingleRef() -> FailureDefinitionId: ...
    @property
    def StructuralConnectionNotEnoughRefs() -> FailureDefinitionId: ...
    @property
    def StructuralConnectionSetOfRefsChanged() -> FailureDefinitionId: ...
    @property
    def StructuralConnectionTooFarNotEnoughRefs() -> FailureDefinitionId: ...
    @property
    def StructuralConnectionTooFarRefs() -> FailureDefinitionId: ...
    @property
    def StructuralConnectionTypeChangedToGeneric() -> FailureDefinitionId: ...
    @property
    def StructuralConnectionTypeInfoNotAvailable() -> FailureDefinitionId: ...
    @property
    def StructuralConnectionWrongType() -> FailureDefinitionId: ...
    @property
    def StructuralSectionHasIncompleteDefinition() -> FailureDefinitionId: ...


class StructuralCustomConnectionFailures:
    @property
    def SimpleConnectionTooFarRefs() -> FailureDefinitionId: ...
    @property
    def StructuralCannotCreateCustomConnection() -> FailureDefinitionId: ...
    @property
    def StructuralCustomConnectionComponentsRelationship() -> FailureDefinitionId: ...
    @property
    def StructuralCustomConnectionEmpty() -> FailureDefinitionId: ...
    @property
    def StructuralCustomConnectionWrongType() -> FailureDefinitionId: ...


class StructuralLoadFailures:
    @property
    def CannotMirrorBoundaryCondition() -> FailureDefinitionId: ...
    @property
    def CannotMoveBoundaryCondition() -> FailureDefinitionId: ...
    @property
    def CannotPlaceBoundaryConditions() -> FailureDefinitionId: ...
    @property
    def HostChangeDisallowsLoadOrBoundaryConditions() -> FailureDefinitionId: ...


class SweepFailures:
    @property
    def CannotDrawSweep() -> FailureDefinitionId: ...
    @property
    def ComplexPathWithComplexProfile() -> FailureDefinitionId: ...
    @property
    def ProfileLoopEmpty() -> FailureDefinitionId: ...
    @property
    def SweepFailed() -> FailureDefinitionId: ...
    @property
    def SweepFailedError() -> FailureDefinitionId: ...


class SweptBlendFailures:
    @property
    def CannotDrawSweptblend() -> FailureDefinitionId: ...


class SystemNavigatorFailures:
    @property
    def CannottFindCorrectTreeNode() -> FailureDefinitionId: ...
    @property
    def MultipleSelectNumberIsWrong() -> FailureDefinitionId: ...


class SystemsFailures:
    @property
    def AddingOtherConnectedMembersToSystem() -> FailureDefinitionId: ...
    @property
    def CircuitWorksetClosedWarning() -> FailureDefinitionId: ...
    @property
    def CreatePartsWithInvalidService() -> FailureDefinitionId: ...
    @property
    def CreatePartsWithInvalidSystem() -> FailureDefinitionId: ...
    @property
    def CreatePartsWithoutDabasebase() -> FailureDefinitionId: ...
    @property
    def DefaultSystemOver50Elems() -> FailureDefinitionId: ...
    @property
    def ElementsBelongToOtherSystem() -> FailureDefinitionId: ...
    @property
    def FamilyDoesntMatchSystemProperties() -> FailureDefinitionId: ...
    @property
    def FamilyDoesntMatchSystemPropertiesWasDisconnected() -> FailureDefinitionId: ...
    @property
    def MismatchSystemType() -> FailureDefinitionId: ...
    @property
    def PastePartsWithInvalidService() -> FailureDefinitionId: ...
    @property
    def SelectedElementsArePartOfOtherSystem() -> FailureDefinitionId: ...


class TagFailures:
    @property
    def CannotCopyTag() -> FailureDefinitionId: ...
    @property
    def CannotCopyTagWarn() -> FailureDefinitionId: ...
    @property
    def CannotPasteOrphanTags() -> FailureDefinitionId: ...
    @property
    def CannotPasteOrphanTagsWarn() -> FailureDefinitionId: ...
    @property
    def CannotPasteTag() -> FailureDefinitionId: ...
    @property
    def ElementCategoryChangeInvalidatesTag() -> FailureDefinitionId: ...
    @property
    def ElementCategoryChangeInvalidatesTagUpgrade() -> FailureDefinitionId: ...
    @property
    def MultiCategoryTagFilterParamNotFoundInElement() -> FailureDefinitionId: ...
    @property
    def TagsCannotBePlacedInUnlocked3dViews() -> FailureDefinitionId: ...


class TextFailures:
    @property
    def CannotCreateModeltext() -> FailureDefinitionId: ...
    @property
    def ModeltextIsEmpty() -> FailureDefinitionId: ...


class TilePatternTileFailures:
    @property
    def TilePatternTile_InvalidFamily() -> FailureDefinitionId: ...


class ToggleViewFailures:
    @property
    def LoseSavedOrientation() -> FailureDefinitionId: ...


class TrussFailures:
    @property
    def IncorrectWallUsageWithAttachedStruct() -> FailureDefinitionId: ...
    @property
    def InvalidWorkplaneForStructuralFraming() -> FailureDefinitionId: ...
    @property
    def RemoveTrussSketch() -> FailureDefinitionId: ...
    @property
    def TrussBadTransformation() -> FailureDefinitionId: ...
    @property
    def TrussChordUntransformable() -> FailureDefinitionId: ...
    @property
    def TrussDuplicateEngineeringType() -> FailureDefinitionId: ...
    @property
    def TrussInvalidSymbolGeom() -> FailureDefinitionId: ...
    @property
    def TrussIsAttachedTo() -> FailureDefinitionId: ...
    @property
    def TrussLayoutNonSympleTopChord() -> FailureDefinitionId: ...
    @property
    def TrussLayoutOverlapedCurves() -> FailureDefinitionId: ...
    @property
    def TrussNotJoinedWebs() -> FailureDefinitionId: ...
    @property
    def TrussUserDefinedMemberDeleted() -> FailureDefinitionId: ...
    @property
    def TrussUserDefinedMemberNotJoined() -> FailureDefinitionId: ...


class UniqueElementFailures:
    @property
    def ProhibitUniqueElementDeletion() -> FailureDefinitionId: ...


class ViewFailures:
    @property
    def BadViewDirectionSetting() -> FailureDefinitionId: ...
    @property
    def CanNotDeleteLastOpenView() -> FailureDefinitionId: ...
    @property
    def CannotPasteViewReferences() -> FailureDefinitionId: ...
    @property
    def CannotToggleToPerspective() -> FailureDefinitionId: ...
    @property
    def DetailNumberDuplicate() -> FailureDefinitionId: ...
    @property
    def DetailNumberEmpty() -> FailureDefinitionId: ...
    @property
    def InitialViewDeleted() -> FailureDefinitionId: ...
    @property
    def InsertColumnViewError() -> FailureDefinitionId: ...
    @property
    def InsertColumnViewFailure() -> FailureDefinitionId: ...
    @property
    def InsertComponentViewError() -> FailureDefinitionId: ...
    @property
    def InsertComponentViewFailure() -> FailureDefinitionId: ...
    @property
    def InvalidDBviewScopeBox() -> FailureDefinitionId: ...
    @property
    def NoTargetsForDependentViewPropagation() -> FailureDefinitionId: ...
    @property
    def NothingToApplyError() -> FailureDefinitionId: ...
    @property
    def NothingToApplyWarning() -> FailureDefinitionId: ...
    @property
    def ReloadLatestDeletedLastOpenView() -> FailureDefinitionId: ...
    @property
    def TurnCropRegionOffRemovesViewBreaks() -> FailureDefinitionId: ...
    @property
    def ViewPublishFailed() -> FailureDefinitionId: ...
    @property
    def ZeroLengthViewBreaksRemoved() -> FailureDefinitionId: ...
    @property
    def ZeroLengthViewRegionsRemoved() -> FailureDefinitionId: ...


class WallFailures:
    @property
    def CannotChangeSubwall() -> FailureDefinitionId: ...
    @property
    def CannotChangeTypeOfOldCurtainPanel() -> FailureDefinitionId: ...
    @property
    def CannotMaintainKeyReference() -> FailureDefinitionId: ...
    @property
    def CannotMirrorWallPanel() -> FailureDefinitionId: ...
    @property
    def CannotRedoFaceBased() -> FailureDefinitionId: ...
    @property
    def CannotRedoFaceBasedWarn() -> FailureDefinitionId: ...
    @property
    def CannotRedoFaceRoof() -> FailureDefinitionId: ...
    @property
    def CannotSlantStackedWallError() -> FailureDefinitionId: ...
    @property
    def CannotSplitJoinHostsInplaceFamilies() -> FailureDefinitionId: ...
    @property
    def CannotSplitVerticallyCompoundWall() -> FailureDefinitionId: ...
    @property
    def CannotToSplitWallPanels() -> FailureDefinitionId: ...
    @property
    def CannotUpdateWallPanel() -> FailureDefinitionId: ...
    @property
    def ChangingWallsweepType() -> FailureDefinitionId: ...
    @property
    def ConstrainedToWall() -> FailureDefinitionId: ...
    @property
    def ConstrainedToWallError() -> FailureDefinitionId: ...
    @property
    def ContFootingCannotJoin() -> FailureDefinitionId: ...
    @property
    def ContFootingRadiusTooSmall() -> FailureDefinitionId: ...
    @property
    def DisallowedPathCurve() -> FailureDefinitionId: ...
    @property
    def EmbeddedButShouldNotBe() -> FailureDefinitionId: ...
    @property
    def ExtrudedWallMustBeVertical() -> FailureDefinitionId: ...
    @property
    def FaceBecameVertical() -> FailureDefinitionId: ...
    @property
    def FaceIsNoGoodForWall() -> FailureDefinitionId: ...
    @property
    def FaceIsNoLongerVertical() -> FailureDefinitionId: ...
    @property
    def FaceWallBadType() -> FailureDefinitionId: ...
    @property
    def FaceWallComplexType() -> FailureDefinitionId: ...
    @property
    def FaceWallFailedToMake() -> FailureDefinitionId: ...
    @property
    def FaceWallMissingFace() -> FailureDefinitionId: ...
    @property
    def FailedConvertWallToPanel() -> FailureDefinitionId: ...
    @property
    def FailedToChangeInstSymbol() -> FailureDefinitionId: ...
    @property
    def FailedToStoreSideFace() -> FailureDefinitionId: ...
    @property
    def InvalidBaseConstraintForLevel() -> FailureDefinitionId: ...
    @property
    def InvalidCompoundStructure() -> FailureDefinitionId: ...
    @property
    def InvalidTargetPosition() -> FailureDefinitionId: ...
    @property
    def InvalidTargetPositionError() -> FailureDefinitionId: ...
    @property
    def InvalidTopConstraintForLevel() -> FailureDefinitionId: ...
    @property
    def LostEditsJoinsRedoFaceBased() -> FailureDefinitionId: ...
    @property
    def ParameterChangeNotAffectingGeometry() -> FailureDefinitionId: ...
    @property
    def RecursionParameterIgnored() -> FailureDefinitionId: ...
    @property
    def RemapConstrainLocationLine() -> FailureDefinitionId: ...
    @property
    def ShorterThanMinWall() -> FailureDefinitionId: ...
    @property
    def ShorterThanMinWallError() -> FailureDefinitionId: ...
    @property
    def ShorterThanMinWallFailure() -> FailureDefinitionId: ...
    @property
    def ShouldAdjustWallParameters() -> FailureDefinitionId: ...
    @property
    def StackedWallNeedsUnjoin() -> FailureDefinitionId: ...
    @property
    def TooShortStackedWall() -> FailureDefinitionId: ...
    @property
    def UnableToCreateWallForPanel() -> FailureDefinitionId: ...
    @property
    def UnableToDeleteWallForPanel() -> FailureDefinitionId: ...
    @property
    def UnjoinOnEditWallChange() -> FailureDefinitionId: ...
    @property
    def VerticalLayerExtensionFailure() -> FailureDefinitionId: ...
    @property
    def VerticalLayerExtensionFailureError() -> FailureDefinitionId: ...
    @property
    def WallCutoutForInsertionFailure() -> FailureDefinitionId: ...
    @property
    def WallLacksCurve() -> FailureDefinitionId: ...
    @property
    def WallNegativeHeight() -> FailureDefinitionId: ...
    @property
    def WallSettingsChanged() -> FailureDefinitionId: ...


class WallJoinFailures:
    @property
    def FailedToChangeWallJointsTypeFailure() -> FailureDefinitionId: ...


class WallJoinRoofFailures:
    @property
    def NoFromRoofForWall() -> FailureDefinitionId: ...
    @property
    def NoUptoRoofForWall() -> FailureDefinitionId: ...
    @property
    def NotCoveredAtAllByTarget() -> FailureDefinitionId: ...
    @property
    def WallMeetsRoofTangentially() -> FailureDefinitionId: ...
    @property
    def WallNotCoveredByRoof() -> FailureDefinitionId: ...


class WorksharingFailures:
    @property
    def DuplicateNamesChanged() -> FailureDefinitionId: ...
    @property
    def MissingUpdaterLatestOrCentralPlural() -> FailureDefinitionId: ...
    @property
    def MissingUpdaterLatestOrCentralSingular() -> FailureDefinitionId: ...
    @property
    def SeriousElementReferenceCorruption() -> FailureDefinitionId: ...


class ITransactionFinalizer:
    def OnCommitted(self, document: Document, strTransactionName: str) -> None: ...
    def OnRolledBack(self, document: Document, strTransactionName: str) -> None: ...


class FailuresAccessor:
    @property
    def IsValidObject(self) -> bool: ...
    def IsActive(self) -> bool: ...
    def GetDocument(self) -> Document: ...
    def GetSeverity(self) -> FailureSeverity: ...
    def GetTransactionName(self) -> str: ...
    def SetTransactionName(self, transactionName: str) -> None: ...
    @overload
    def GetFailureMessages(self, severity: FailureSeverity) -> List[FailureMessageAccessor]: ...
    @overload
    def GetFailureMessages(self) -> List[FailureMessageAccessor]: ...
    def IsTransactionBeingCommitted(self) -> bool: ...
    @overload
    def IsFailureResolutionPermitted(self, failure: FailureMessageAccessor, resolutionType: FailureResolutionType) -> bool: ...
    @overload
    def IsFailureResolutionPermitted(self, failure: FailureMessageAccessor) -> bool: ...
    @overload
    def IsFailureResolutionPermitted(self) -> bool: ...
    @overload
    def IsElementsDeletionPermitted(self, idsToDelete: List[ElementId]) -> Tuple[bool, str]: ...
    @overload
    def IsElementsDeletionPermitted(self, idsToDelete: List[ElementId]) -> bool: ...
    @overload
    def IsElementsDeletionPermitted(self) -> bool: ...
    def GetFailureHandlingOptions(self) -> FailureHandlingOptions: ...
    def SetFailureHandlingOptions(self, options: FailureHandlingOptions) -> None: ...
    def ReplaceFailures(self, failure: FailureMessage) -> None: ...
    def PostFailure(self, failure: FailureMessage) -> None: ...
    def DeleteWarning(self, failure: FailureMessageAccessor) -> None: ...
    def DeleteAllWarnings(self) -> None: ...
    def ResolveFailure(self, failure: FailureMessageAccessor) -> None: ...
    def ResolveFailures(self, failures: List[FailureMessageAccessor]) -> None: ...
    def DeleteElements(self, idsToDelete: List[ElementId]) -> None: ...
    def GetAttemptedResolutionTypes(self, failure: FailureMessageAccessor) -> List[FailureResolutionType]: ...
    def CanCommitPendingTransaction(self) -> bool: ...
    def CanRollBackPendingTransaction(self) -> bool: ...
    def IsPending(self) -> bool: ...
    def CommitPendingTransaction(self) -> TransactionStatus: ...
    def RollBackPendingTransaction(self) -> TransactionStatus: ...
    def JournalFailures(self, failures: List[FailureMessageAccessor]) -> None: ...
    def Dispose(self) -> None: ...


class FamilyThermalProperties:
    def __init__(self): ...
    @property
    def HeatTransferCoefficient(self) -> float: ...
    @property
    def SolarHeatGainCoefficient(self) -> float: ...
    @property
    def VisualLightTransmittance(self) -> float: ...
    @property
    def AnalyticConstructionTypeId(self) -> str: ...
    @property
    def AnalyticConstructionName(self) -> str: ...
    @property
    def ThermalResistance(self) -> float: ...
    @property
    def IsValidObject(self) -> bool: ...
    def IsValid(self) -> bool: ...
    def Find(pADoc: Document, constructionId: str) -> FamilyThermalProperties: ...
    def Dispose(self) -> None: ...


class FamilySizeTableErrorInfo:
    def __init__(self): ...
    @property
    def FamilySizeTableErrorType(self) -> FamilySizeTableErrorType: ...
    @property
    def FilePath(self) -> str: ...
    @property
    def InvalidHeaderText(self) -> str: ...
    @property
    def InvalidColumnIndex(self) -> int: ...
    @property
    def InvalidRowIndex(self) -> int: ...
    @property
    def IsValidObject(self) -> bool: ...
    def Dispose(self) -> None: ...


class FamilySizeTableColumn:
    @property
    def Name(self) -> str: ...
    @property
    def UnitType(self) -> UnitType: ...
    @property
    def DisplayUnitType(self) -> DisplayUnitType: ...
    @property
    def IsValidObject(self) -> bool: ...
    def GetSpecTypeId(self) -> ForgeTypeId: ...
    def GetUnitTypeId(self) -> ForgeTypeId: ...
    def Dispose(self) -> None: ...


class FamilySizeTable:
    @property
    def NumberOfRows(self) -> int: ...
    @property
    def NumberOfColumns(self) -> int: ...
    @property
    def IsValidObject(self) -> bool: ...
    def GetColumnHeader(self, index: int) -> FamilySizeTableColumn: ...
    def IsValidColumnIndex(self, index: int) -> bool: ...
    def AsValueString(self, row: int, column: int) -> str: ...
    def Dispose(self) -> None: ...


class FamilySizeTableManager:
    @property
    def NumberOfSizeTables(self) -> int: ...
    @property
    def IsValidObject(self) -> bool: ...
    def GetAllSizeTableNames(self) -> List[str]: ...
    def GetSizeTable(self, tableName: str) -> FamilySizeTable: ...
    def HasSizeTable(self, tableName: str) -> bool: ...
    def ImportSizeTable(self, document: Document, filePath: str, errorInfo: FamilySizeTableErrorInfo) -> bool: ...
    def ExportSizeTable(self, tableName: str, filePath: str) -> bool: ...
    def RemoveSizeTable(self, tableName: str) -> bool: ...
    def CreateFamilySizeTableManager(document: Document, familyId: ElementId) -> bool: ...
    def GetFamilySizeTableManager(document: Document, familyId: ElementId) -> FamilySizeTableManager: ...
    def Dispose(self) -> None: ...


class FamilyUtils:
    def ConvertFamilyToFaceHostBased(document: Document, familyId: ElementId) -> None: ...
    def FamilyCanConvertToFaceHostBased(document: Document, familyId: ElementId) -> bool: ...
    def GetProfileSymbols(document: Document, profileFamilyUsage: ProfileFamilyUsage, oneCurveLoopOnly: bool) -> ICollection: ...


class ValueAtPointBase:
    @property
    def IsValidObject(self) -> bool: ...
    @overload
    def SetFlags(self, flags: int, measurement: int) -> None: ...
    @overload
    def SetFlags(self, flags: int) -> None: ...
    @overload
    def SetFlags(self, flags: List[int]) -> None: ...
    def ClearAllFlags(self) -> None: ...
    def ClearFlagsAt(self, measurement: int) -> None: ...
    def GetFlags(self, measurement: int) -> int: ...
    def Dispose(self) -> None: ...


class FillGrid:
    @overload
    def __init__(self, angle: float, offset: float): ...
    @overload
    def __init__(self): ...
    @overload
    def __init__(self, other: FillGrid): ...
    @property
    def Angle(self) -> float: ...
    @Angle.setter
    def Angle(self, angle: float) -> None: ...
    @property
    def Origin(self) -> UV: ...
    @Origin.setter
    def Origin(self, origin: UV) -> None: ...
    @property
    def Offset(self) -> float: ...
    @Offset.setter
    def Offset(self, offset: float) -> None: ...
    @property
    def Shift(self) -> float: ...
    @Shift.setter
    def Shift(self, shift: float) -> None: ...
    @property
    def IsValidObject(self) -> bool: ...
    def GetSegments(self) -> List[float]: ...
    def SetSegments(self, segArr: List[float]) -> None: ...
    def IsEqual(self, other: FillGrid) -> bool: ...
    def CalculateLengthPerArea(self) -> float: ...
    def CalculateStrokesPerArea(self) -> float: ...
    def CalculateLinesPerLength(self) -> float: ...
    def GetHatchingDirection(self) -> UV: ...
    def GetSegmentDirection(self) -> UV: ...
    @overload
    def GetPointLineZone(self, point: UV) -> Tuple[int, UV]: ...
    @overload
    def GetPointLineZone(self, point: UV) -> int: ...
    def Dispose(self) -> None: ...


class FillPattern:
    @overload
    def __init__(self, name: str, target: FillPatternTarget, orientation: FillPatternHostOrientation, angle: float, spacing1: float, spacing2: float): ...
    @overload
    def __init__(self, name: str, target: FillPatternTarget, orientation: FillPatternHostOrientation, angle: float, spacing1: float): ...
    @overload
    def __init__(self, name: str, target: FillPatternTarget, orientation: FillPatternHostOrientation): ...
    @overload
    def __init__(self): ...
    @overload
    def __init__(self, other: FillPattern): ...
    @property
    def HostOrientation(self) -> FillPatternHostOrientation: ...
    @HostOrientation.setter
    def HostOrientation(self, hostOrientation: FillPatternHostOrientation) -> None: ...
    @property
    def Target(self) -> FillPatternTarget: ...
    @Target.setter
    def Target(self, target: FillPatternTarget) -> None: ...
    @property
    def GridCount(self) -> int: ...
    @property
    def IsSolidFill(self) -> bool: ...
    @property
    def LengthPerArea(self) -> float: ...
    @property
    def StrokesPerArea(self) -> float: ...
    @property
    def LinesPerLength(self) -> float: ...
    @property
    def Name(self) -> str: ...
    @Name.setter
    def Name(self, name: str) -> None: ...
    @property
    def IsValidObject(self) -> bool: ...
    def GetFillGrid(self, gridIdx: int) -> FillGrid: ...
    def SetFillGrid(self, gridIdx: int, fillGrid: FillGrid) -> None: ...
    def GetFillGrids(self) -> List[FillGrid]: ...
    def SetFillGrids(self, fillGrids: List[FillGrid]) -> None: ...
    def IsEqual(self, other: FillPattern) -> bool: ...
    def ExpandDots(self) -> bool: ...
    def Dispose(self) -> None: ...


class FilledRegion(Element):
    @property
    def IsMasking(self) -> bool: ...
    def Create(document: Document, typeId: ElementId, viewId: ElementId, boundaries: List[CurveLoop]) -> FilledRegion: ...
    def GetBoundaries(self) -> List[CurveLoop]: ...
    def SetLineStyleId(self, lineStyleId: ElementId) -> None: ...
    def GetValidLineStyleIdsForFilledRegion(document: Document) -> List[ElementId]: ...
    def IsValidLineStyleIdForFilledRegion(document: Document, lineStyleId: ElementId) -> bool: ...
    def IsValidFilledRegionTypeId(document: Document, typeId: ElementId) -> bool: ...


class FilledRegionType(LineAndTextAttrSymbol):
    @property
    def ForegroundPatternId(self) -> ElementId: ...
    @ForegroundPatternId.setter
    def ForegroundPatternId(self, patternId: ElementId) -> None: ...
    @property
    def BackgroundPatternId(self) -> ElementId: ...
    @BackgroundPatternId.setter
    def BackgroundPatternId(self, patternId: ElementId) -> None: ...
    @property
    def IsMasking(self) -> bool: ...
    @IsMasking.setter
    def IsMasking(self, background: bool) -> None: ...
    @property
    def LineWeight(self) -> int: ...
    @LineWeight.setter
    def LineWeight(self, lineWeight: int) -> None: ...
    @property
    def ForegroundPatternColor(self) -> Color: ...
    @ForegroundPatternColor.setter
    def ForegroundPatternColor(self, color: Color) -> None: ...
    @property
    def BackgroundPatternColor(self) -> Color: ...
    @BackgroundPatternColor.setter
    def BackgroundPatternColor(self, color: Color) -> None: ...
    def IsValidLineWeight(lineWeight: int) -> bool: ...


class FilterElement(Element):
    @overload
    def IsNameUnique(aDocument: Document, name: str) -> bool: ...
    @overload
    def IsNameUnique(self, name: str) -> bool: ...


class FormUtils:
    @overload
    def DissolveForms(ADoc: Document, elements: ICollection) -> ICollection: ...
    @overload
    def DissolveForms(ADoc: Document, elements: ICollection) -> Tuple[ICollection, ICollection]: ...
    def CanBeDissolved(ADoc: Document, elements: ICollection) -> bool: ...


class FormatValueOptions:
    def __init__(self): ...
    @property
    def AppendUnitSymbol(self) -> bool: ...
    @AppendUnitSymbol.setter
    def AppendUnitSymbol(self, appendUnitSymbol: bool) -> None: ...
    @property
    def IsValidObject(self) -> bool: ...
    def SetFormatOptions(self, formatOptions: FormatOptions) -> None: ...
    def GetFormatOptions(self) -> FormatOptions: ...
    def Dispose(self) -> None: ...


class FormattedText:
    @overload
    def __init__(self, plainText: str): ...
    @overload
    def __init__(self): ...
    @property
    def IsValidObject(self) -> bool: ...
    def Find(self, searchString: str, startIndex: int, matchCase: bool, matchWholeWord: bool) -> TextRange: ...
    def AsTextRange(self) -> TextRange: ...
    @overload
    def GetPlainText(self, textRange: TextRange) -> str: ...
    @overload
    def GetPlainText(self) -> str: ...
    @overload
    def SetPlainText(self, textRange: TextRange, plainText: str) -> None: ...
    @overload
    def SetPlainText(self, plainText: str) -> None: ...
    @overload
    def GetBoldStatus(self) -> FormatStatus: ...
    @overload
    def GetBoldStatus(self, textRange: TextRange) -> FormatStatus: ...
    @overload
    def GetItalicStatus(self) -> FormatStatus: ...
    @overload
    def GetItalicStatus(self, textRange: TextRange) -> FormatStatus: ...
    @overload
    def GetUnderlineStatus(self) -> FormatStatus: ...
    @overload
    def GetUnderlineStatus(self, textRange: TextRange) -> FormatStatus: ...
    @overload
    def GetSubscriptStatus(self) -> FormatStatus: ...
    @overload
    def GetSubscriptStatus(self, textRange: TextRange) -> FormatStatus: ...
    @overload
    def GetSuperscriptStatus(self) -> FormatStatus: ...
    @overload
    def GetSuperscriptStatus(self, textRange: TextRange) -> FormatStatus: ...
    @overload
    def GetAllCapsStatus(self) -> FormatStatus: ...
    @overload
    def GetAllCapsStatus(self, textRange: TextRange) -> FormatStatus: ...
    @overload
    def SetBoldStatus(self, isBold: bool) -> None: ...
    @overload
    def SetBoldStatus(self, textRange: TextRange, isBold: bool) -> None: ...
    @overload
    def SetItalicStatus(self, isItalic: bool) -> None: ...
    @overload
    def SetItalicStatus(self, textRange: TextRange, isItalic: bool) -> None: ...
    @overload
    def SetUnderlineStatus(self, isUnderlined: bool) -> None: ...
    @overload
    def SetUnderlineStatus(self, textRange: TextRange, isUnderlined: bool) -> None: ...
    @overload
    def SetSubscriptStatus(self, isSubscript: bool) -> None: ...
    @overload
    def SetSubscriptStatus(self, textRange: TextRange, isSubscript: bool) -> None: ...
    @overload
    def SetSuperscriptStatus(self, isSuperscript: bool) -> None: ...
    @overload
    def SetSuperscriptStatus(self, textRange: TextRange, isSuperscript: bool) -> None: ...
    @overload
    def SetAllCapsStatus(self, isAllCaps: bool) -> None: ...
    @overload
    def SetAllCapsStatus(self, textRange: TextRange, isAllCaps: bool) -> None: ...
    def GetListType(self, textRange: TextRange) -> ListType: ...
    def SetListType(self, textRange: TextRange, listType: ListType) -> None: ...
    def GetListStartNumber(self, textRange: TextRange) -> int: ...
    def GetMaximumListStartNumber(self) -> int: ...
    def GetMinimumListStartNumber(self) -> int: ...
    def SetListStartNumber(self, textRange: TextRange, value: int) -> None: ...
    def GetIndentLevel(self, textRange: TextRange) -> int: ...
    def GetMaximumIndentLevel(self) -> int: ...
    def SetIndentLevel(self, textRange: TextRange, level: int) -> None: ...
    def Dispose(self) -> None: ...


class TextRange:
    @overload
    def __init__(self, start: int, length: int): ...
    @overload
    def __init__(self): ...
    @overload
    def __init__(self, other: TextRange): ...
    @property
    def Start(self) -> int: ...
    @Start.setter
    def Start(self, start: int) -> None: ...
    @property
    def Length(self) -> int: ...
    @Length.setter
    def Length(self, length: int) -> None: ...
    @property
    def End(self) -> int: ...
    @property
    def IsValidObject(self) -> bool: ...
    def Dispose(self) -> None: ...


class FormulaManager:
    @property
    def IsValidObject(self) -> bool: ...
    def Evaluate(parameterId: ElementId, document: Document, formula: str) -> str: ...
    def Validate(parameterId: ElementId, document: Document, formula: str) -> str: ...
    def GetFunctions() -> List[str]: ...
    def GetOperators() -> List[str]: ...
    def Dispose(self) -> None: ...


class FreeFormElement(GenericForm):
    def Create(document: Document, geometry: Solid) -> FreeFormElement: ...
    def SetFaceOffset(self, face: Face, offset: float) -> None: ...
    def CanOffsetFace(self, face: Face) -> bool: ...
    def UpdateSolidGeometry(self, newGeometry: Solid) -> None: ...


class ConnectionResolution:
    Disconnected = 0


class ConnectionWarning:
    Unknown = 0
    Alignment = 1
    Size = 2
    Shape = 3
    Connectivity = 4


class FabricationDimensionType:
    Internal = 0
    Width = 1
    Depth = 2
    Diameter = 3
    Angle = 4
    Length = 5


class FabricationDimensionUnitType:
    NoUnits = 0
    Linear = 1
    Angular = 2


class FamilyHostingBehavior:
    #None = 0
    Wall = 1
    Floor = 2
    Ceiling = 3
    Roof = 4
    Face = 5


class FamilySizeTableErrorType:
    FileNotFound = 0
    CannotOpenFile = 1
    CannotReadFile = 2
    InvalidHeaderSeparator = 3
    CannotParseColumnHeader = 4
    IncorrectNumberOfColumns = 5
    Undefined = -1


class ProfileFamilyUsage:
    Any = 0
    WallSweep = 1
    Reveal = 2
    Fascia = 3
    Gutter = 4
    SlabEdge = 5
    Railing = 6
    StairNosing = 7
    Mullion = 8
    SlabMetalDeck = 9
    ContinuousFooting = 10
    StairTread = 11
    StairRiser = 12
    StairSupport = 13


class ValueAtPointFlags:
    #None = 0
    DisplayText = 1
    DisplayFence = 2


class FittingAngleUsage:
    UseAnyAngle = 0
    UseAnAngleIncrement = 1
    UseSpecificAngles = 2


class FormatStatus:
    #None = 0
    All = 1
    Mixed = 2


class ListType:
    Mixed = 0
    #None = 1
    Bullet = 2
    ArabicNumbers = 3
    LowerCaseLetters = 4
    UpperCaseLetters = 5


class VertexPair:
    def __init__(self, firstVertexIdx: int, secondVertexIdx: int): ...
    @property
    def First(self) -> int: ...
    @First.setter
    def First(self, firstVertexIdx: int) -> None: ...
    @property
    def Second(self) -> int: ...
    @Second.setter
    def Second(self, secondVertexIdx: int) -> None: ...
    @property
    def IsValidObject(self) -> bool: ...
    def Dispose(self) -> None: ...


class MultiSegmentGrid(Element):
    @property
    def Text(self) -> str: ...
    @Text.setter
    def Text(self, text: str) -> None: ...
    def Create(document: Document, typeId: ElementId, curveLoop: CurveLoop, sketchPlaneId: ElementId) -> ElementId: ...
    def GetMultiSegementGridId(grid: Grid) -> ElementId: ...
    def AreGridsInSameMultiSegmentGrid(grid1: Grid, grid2: Grid) -> bool: ...
    def IsValidSketchPlaneId(document: Document, elemId: ElementId) -> bool: ...
    def IsValidCurveLoop(curveLoop: CurveLoop) -> bool: ...
    def GetGridIds(self) -> ICollection: ...


class HermiteSurface(Surface):
    @overload
    def Create(nU: int, nV: int, points: List[XYZ], periodicU: bool, periodicV: bool) -> HermiteSurface: ...
    @overload
    def Create(nU: int, nV: int, points: List[XYZ]) -> HermiteSurface: ...
    def IsValid(self) -> bool: ...


class DisableAnalyticalModelCB(FailureResolution):


class HostObjectUtils:
    def GetTopFaces(hostObject: HostObject) -> List[Reference]: ...
    def GetBottomFaces(hostObject: HostObject) -> List[Reference]: ...
    def GetSideFaces(hostObject: HostObject, side: ShellLayerType) -> List[Reference]: ...


class IATFTranslationServer:
    def Translate(self, serviceData: ATFTranslationServiceData) -> bool: ...


class ICentralLockedCallback:
    def ShouldWaitForLockAvailability(self) -> bool: ...


class RenderNode:
    @property
    def NodeName(self) -> str: ...
    @property
    def IsValidObject(self) -> bool: ...
    def Dispose(self) -> None: ...


class ViewNode(RenderNode):
    @property
    def LevelOfDetail(self) -> int: ...
    @LevelOfDetail.setter
    def LevelOfDetail(self, LevelOfDetail: int) -> None: ...
    @property
    def ViewId(self) -> ElementId: ...
    def GetCameraInfo(self) -> CameraInfo: ...


class GroupNode(RenderNode):
    def GetSymbolId(self) -> ElementId: ...
    def GetTransform(self) -> Transform: ...


class InstanceNode(GroupNode):


class LinkNode(GroupNode):
    def GetDocument(self) -> Document: ...


class FaceNode(RenderNode):
    def GetFace(self) -> Face: ...


class LineProperties:
    @property
    def Color(self) -> Color: ...
    @property
    def Transparency(self) -> int: ...
    @property
    def LineWidth(self) -> float: ...
    @property
    def PatternId(self) -> ElementId: ...
    @property
    def IsValidObject(self) -> bool: ...
    def Dispose(self) -> None: ...


class ModelCurveNode(RenderNode):
    @property
    def LineProperties(self) -> LineProperties: ...


class CurveNode(ModelCurveNode):
    def GetCurve(self) -> Curve: ...


class PolylineNode(ModelCurveNode):
    def GetPolyline(self) -> PolyLine: ...


class PointNode(ModelCurveNode):
    def GetPoint(self) -> Point: ...


class FaceDetailNode(RenderNode):
    @property
    def LineProperties(self) -> LineProperties: ...
    def GetLinkTransform(self) -> Transform: ...
    def GetInstanceTransform(self) -> Transform: ...


class FaceEdgeNode(FaceDetailNode):
    def GetFaceEdge(self) -> Edge: ...


class FaceSilhouetteNode(FaceDetailNode):
    def GetFace(self) -> Face: ...


class LineSegment:
    @property
    def StartPoint(self) -> XYZ: ...
    @property
    def EndPoint(self) -> XYZ: ...
    @property
    def StartParameter(self) -> float: ...
    @property
    def EndParameter(self) -> float: ...
    @property
    def LineProperties(self) -> LineProperties: ...
    @property
    def IsValidObject(self) -> bool: ...
    def Dispose(self) -> None: ...


class PolylineSegments:
    @property
    def StartParameter(self) -> float: ...
    @property
    def EndParameter(self) -> float: ...
    @property
    def StartLocalParameter(self) -> float: ...
    @property
    def EndLocalParameter(self) -> float: ...
    @property
    def IsFilled(self) -> bool: ...
    @property
    def LineProperties(self) -> LineProperties: ...
    @property
    def IsValidObject(self) -> bool: ...
    def GetVertices(self) -> List[XYZ]: ...
    def Dispose(self) -> None: ...


class ContentNode(RenderNode):
    def GetTransform(self) -> Transform: ...
    def GetAsset(self) -> Asset: ...


class RPCNode(ContentNode):


class LightNode(ContentNode):


class TextNode(RenderNode):
    @property
    def Color(self) -> Color: ...
    @property
    def FontName(self) -> str: ...
    @property
    def Text(self) -> str: ...
    @property
    def Position(self) -> XYZ: ...
    @property
    def BaseDirection(self) -> XYZ: ...
    @property
    def UpDirection(self) -> XYZ: ...
    @property
    def Width(self) -> float: ...
    @property
    def WidthScale(self) -> float: ...
    @property
    def Height(self) -> float: ...
    @property
    def FontHeight(self) -> float: ...
    @property
    def TabSize(self) -> float: ...
    @property
    def IsBold(self) -> bool: ...
    @property
    def IsItalic(self) -> bool: ...
    @property
    def IsUnderlined(self) -> bool: ...
    @property
    def IsTransparent(self) -> bool: ...
    @property
    def IsKeptReadable(self) -> bool: ...
    @property
    def HorizontalAlignment(self) -> HorizontalTextAlignment: ...
    @property
    def VerticalAlignment(self) -> VerticalTextAlignment: ...
    def GetFormattedText(self) -> FormattedText: ...


class MaterialNode(RenderNode):
    @property
    def HasOverriddenAppearance(self) -> bool: ...
    @property
    def MaterialId(self) -> ElementId: ...
    @property
    def Transparency(self) -> float: ...
    @property
    def Color(self) -> Color: ...
    @property
    def Smoothness(self) -> int: ...
    @property
    def Glossiness(self) -> int: ...
    @property
    def ThumbnailFile(self) -> str: ...
    def GetAppearance(self) -> Asset: ...
    def GetAppearanceOverride(self) -> Asset: ...


class ElementNode(RenderNode):
    @property
    def ElementId(self) -> ElementId: ...
    @property
    def Document(self) -> Document: ...
    @property
    def LinkInstanceId(self) -> ElementId: ...


class CameraInfo:
    @property
    def IsPespective(self) -> bool: ...
    @property
    def IsPerspective(self) -> bool: ...
    @property
    def VerticalExtent(self) -> float: ...
    @property
    def HorizontalExtent(self) -> float: ...
    @property
    def FarDistance(self) -> float: ...
    @property
    def NearDistance(self) -> float: ...
    @property
    def TargetDistance(self) -> float: ...
    @property
    def RightOffset(self) -> float: ...
    @property
    def UpOffset(self) -> float: ...
    @property
    def IsValidObject(self) -> bool: ...
    def Dispose(self) -> None: ...


class LinkConversionData:
    @property
    def ServerId(self) -> Guid: ...
    @property
    def Path(self) -> str: ...
    @property
    def IsValidObject(self) -> bool: ...
    def GetOptions(self) -> IDictionary: ...
    def Dispose(self) -> None: ...


class IGetLocalPathForOpenCallback:
    def GetLocalPathForOpen(self, desiredResource: ExternalResourceReference) -> str: ...


class INavisworksExporter:
    def Export(self, document: Document, folder: str, name: str, options: NavisworksExportOptions) -> None: ...
    def ValidateExportOptions(self, document: Document, folder: str, name: str, options: NavisworksExportOptions) -> Tuple[bool, str]: ...


class IOnLocalLinkSharedCoordinatesSavedCallback:
    def OnLocalLinkSharedCoordinatesSaved(self, changedResource: ExternalResourceReference) -> None: ...


class ISaveSharedCoordinatesCallback:
    def GetSaveModifiedLinksOption(self, link: RevitLinkType) -> SaveModifiedLinksOptions: ...


class RevitLinkType(ElementType):
    @property
    def PathType(self) -> PathType: ...
    @PathType.setter
    def PathType(self, pathType: PathType) -> None: ...
    @property
    def IsNestedLink(self) -> bool: ...
    @property
    def AttachmentType(self) -> AttachmentType: ...
    @AttachmentType.setter
    def AttachmentType(self, attachType: AttachmentType) -> None: ...
    @property
    def LocallyUnloaded(self) -> bool: ...
    @overload
    def Create(document: Document, resourceReference: ExternalResourceReference, options: RevitLinkOptions) -> LinkLoadResult: ...
    @overload
    def Create(document: Document, path: ModelPath, options: RevitLinkOptions) -> LinkLoadResult: ...
    @overload
    def CreateFromIFC(document: Document, resourceReference: ExternalResourceReference, revitLinkedFilePath: str, recreateLink: bool, options: RevitLinkOptions) -> LinkLoadResult: ...
    @overload
    def CreateFromIFC(document: Document, ifcFilePath: str, revitLinkedFilePath: str, recreateLink: bool, options: RevitLinkOptions) -> LinkLoadResult: ...
    @overload
    def UpdateFromIFC(self, document: Document, resourceReference: ExternalResourceReference, revitLinkedFilePath: str, recreateLink: bool) -> bool: ...
    @overload
    def UpdateFromIFC(self, document: Document, ifcFilePath: str, revitLinkedFilePath: str, recreateLink: bool) -> bool: ...
    def Load(self) -> LinkLoadResult: ...
    def Reload(self) -> LinkLoadResult: ...
    def RevertLocalUnloadStatus(self) -> LinkedFileStatus: ...
    def IsNotLoadedIntoMultipleOpenDocuments(self) -> bool: ...
    def IsLoaded(document: Document, typeId: ElementId) -> bool: ...
    @overload
    def LoadFrom(self, path: ModelPath, config: WorksetConfiguration) -> LinkLoadResult: ...
    @overload
    def LoadFrom(self, resourceReference: ExternalResourceReference, config: WorksetConfiguration) -> LinkLoadResult: ...
    def Unload(self, callback: ISaveSharedCoordinatesCallback) -> None: ...
    def SavePositions(self, callback: ISaveSharedCoordinatesCallback) -> bool: ...
    def HasSaveablePositions(self) -> bool: ...
    def GetPhaseMap(self) -> IDictionary: ...
    def GetConversionData(self) -> LinkConversionData: ...
    def IsFromRevitServer(self) -> bool: ...
    def IsFromLocalPath(self) -> bool: ...
    def GetLinkedFileStatus(self) -> LinkedFileStatus: ...
    @overload
    def GetTopLevelLink(document: Document, reference: ExternalResourceReference) -> ElementId: ...
    @overload
    def GetTopLevelLink(document: Document, path: ModelPath) -> ElementId: ...
    def GetParentId(self) -> ElementId: ...
    def GetRootId(self) -> ElementId: ...
    def GetChildIds(self) -> ICollection: ...
    def UnloadLocally(self, callback: ISaveSharedCoordinatesCallbackForUnloadLocally) -> bool: ...


class ISaveSharedCoordinatesCallbackForUnloadLocally:
    def GetSaveModifiedLinksOptionForUnloadLocally(self, link: RevitLinkType) -> SaveModifiedLinksOptionsForUnloadLocally: ...


class ImageInstance(Element):
    @property
    def Width(self) -> float: ...
    @Width.setter
    def Width(self, width: float) -> None: ...
    @property
    def Height(self) -> float: ...
    @Height.setter
    def Height(self, height: float) -> None: ...
    @property
    def WidthScale(self) -> float: ...
    @WidthScale.setter
    def WidthScale(self, widthScale: float) -> None: ...
    @property
    def HeightScale(self) -> float: ...
    @HeightScale.setter
    def HeightScale(self, heightScale: float) -> None: ...
    @property
    def LockProportions(self) -> bool: ...
    @LockProportions.setter
    def LockProportions(self, lockProportions: bool) -> None: ...
    @property
    def DrawLayer(self) -> DrawLayer: ...
    @DrawLayer.setter
    def DrawLayer(self, drawLayer: DrawLayer) -> None: ...
    @property
    def EnableSnaps(self) -> bool: ...
    @EnableSnaps.setter
    def EnableSnaps(self, enableSnaps: bool) -> None: ...
    @property
    def CanHaveSnaps(self) -> bool: ...
    def Create(document: Document, view: View, imageTypeId: ElementId, placementOptions: ImagePlacementOptions) -> ImageInstance: ...
    def GetLocation(self, placementPoint: BoxPlacement) -> XYZ: ...
    def SetLocation(self, newLocation: XYZ, placementPoint: BoxPlacement) -> None: ...
    def IsValidView(view: View) -> bool: ...


class ImagePlacementOptions:
    @overload
    def __init__(self, location: XYZ, placementPoint: BoxPlacement): ...
    @overload
    def __init__(self): ...
    @property
    def Location(self) -> XYZ: ...
    @Location.setter
    def Location(self, location: XYZ) -> None: ...
    @property
    def PlacementPoint(self) -> BoxPlacement: ...
    @PlacementPoint.setter
    def PlacementPoint(self, placementPoint: BoxPlacement) -> None: ...
    @property
    def IsValidObject(self) -> bool: ...
    def Dispose(self) -> None: ...


class LinkLoadResult:
    @overload
    def __init__(self, other: LinkLoadResult): ...
    @overload
    def __init__(self): ...
    @property
    def ElementId(self) -> ElementId: ...
    @property
    def IsCircularLink(self) -> bool: ...
    @property
    def IsNested(self) -> bool: ...
    @property
    def LoadResult(self) -> LinkLoadResultType: ...
    @property
    def IsValidObject(self) -> bool: ...
    def GetModelName(self) -> ModelPath: ...
    def GetParentModelName(self) -> ModelPath: ...
    def GetCentralModelName(self) -> ModelPath: ...
    def GetExternalResourceReference(self) -> ExternalResourceReference: ...
    def GetLinkLoadResult(self, matchExtResRef: ExternalResourceReference) -> LinkLoadResult: ...
    def GetNestedLinkLoadResults(self) -> IDictionary: ...
    def GetExternalResourceReferencesFromFailedLoads(self) -> List[ExternalResourceReference]: ...
    def IsCodeSuccess(code: LinkLoadResultType) -> bool: ...
    def Dispose(self) -> None: ...


class StartingViewSettings(Element):
    @property
    def ViewId(self) -> ElementId: ...
    @ViewId.setter
    def ViewId(self, viewId: ElementId) -> None: ...
    def GetStartingViewSettings(doc: Document) -> StartingViewSettings: ...
    def IsAcceptableStartingView(self, viewId: ElementId) -> bool: ...


class InstanceVoidCutUtils:
    def CanBeCutWithVoid(element: Element) -> bool: ...
    def IsVoidInstanceCuttingElement(element: Element) -> bool: ...
    def AddInstanceVoidCut(document: Document, element: Element, cuttingInstance: Element) -> None: ...
    def RemoveInstanceVoidCut(document: Document, element: Element, cuttingInstance: Element) -> None: ...
    def InstanceVoidCutExists(element: Element, cuttingInstance: Element) -> bool: ...
    def GetElementsBeingCut(cuttingInstance: Element) -> ICollection: ...
    def GetCuttingVoidInstances(element: Element) -> ICollection: ...


class IntegerRange:
    @property
    def Low(self) -> int: ...
    @property
    def High(self) -> int: ...
    @property
    def IsValidObject(self) -> bool: ...
    def Dispose(self) -> None: ...


class ElevationMarker(Element):
    @property
    def CurrentViewCount(self) -> int: ...
    @property
    def MaximumViewCount(self) -> int: ...
    @property
    def IsReference(self) -> bool: ...
    def CreateElevationMarker(document: Document, viewFamilyTypeId: ElementId, origin: XYZ, initialViewScale: int) -> ElevationMarker: ...
    def CreateReferenceElevationMarker(document: Document, viewFamilyTypeId: ElementId, origin: XYZ, viewPlanId: ElementId) -> ElevationMarker: ...
    def CreateElevation(self, document: Document, viewPlanId: ElementId, index: int) -> ViewSection: ...
    def CreateReferenceElevation(self, document: Document, index: int, viewIdToReference: ElementId) -> None: ...
    def GetViewId(self, index: int) -> ElementId: ...
    def IsAvailableIndex(self, index: int) -> bool: ...
    def HasElevations(self) -> bool: ...


class DrawLayer:
    Foreground = 0
    Background = 1


class JoinGeometryUtils:
    def JoinGeometry(document: Document, firstElement: Element, secondElement: Element) -> None: ...
    def UnjoinGeometry(document: Document, firstElement: Element, secondElement: Element) -> None: ...
    def SwitchJoinOrder(document: Document, firstElement: Element, secondElement: Element) -> None: ...
    def AreElementsJoined(document: Document, firstElement: Element, secondElement: Element) -> bool: ...
    def IsCuttingElementInJoin(document: Document, firstElement: Element, secondElement: Element) -> bool: ...
    def GetJoinedElements(document: Document, element: Element) -> ICollection: ...


class KeyBasedTreeEntryError:
    @property
    def ErrorType(self) -> KeyBasedTreeEntryErrorType: ...
    @property
    def IsValidObject(self) -> bool: ...
    def GetEntry(self) -> KeyBasedTreeEntry: ...
    def Dispose(self) -> None: ...


class KeyBasedTreeEntriesLoadResults:
    def __init__(self): ...
    @property
    def IsValidObject(self) -> bool: ...
    def GetFailureMessages(self) -> List[FailureMessage]: ...
    def GetFileSyntaxErrors(self) -> List[str]: ...
    @overload
    def GetKeyBasedTreeEntryErrors(self, type: KeyBasedTreeEntryErrorType) -> List[KeyBasedTreeEntryError]: ...
    @overload
    def GetKeyBasedTreeEntryErrors(self) -> List[KeyBasedTreeEntryError]: ...
    def GetFileReadErrors(self) -> List[str]: ...
    def Dispose(self) -> None: ...


class KeynoteEntries(KeyBasedTreeEntries):
    def LoadKeynoteEntriesFromFile(filePath: str, keynoteContent: KeyBasedTreeEntriesLoadContent) -> bool: ...


class KeynoteEntry(KeyBasedTreeEntry):
    @overload
    def __init__(self, key: str, text: str): ...
    @overload
    def __init__(self, key: str, parentKey: str, text: str): ...
    @property
    def KeynoteText(self) -> str: ...


class KeynoteTable(KeyBasedTreeEntryTable):
    def GetKeynoteTable(aDoc: Document) -> KeynoteTable: ...


class KeyBasedTreeEntryErrorType:
    DuplicateEntry = 0
    MissingParent = 1
    CircularParentage = 2
    InvalidClassificationCode = 3
    BadClassificationLevel = 4
    BadClassificationCategoryId = 5


class LinePatternSegment:
    @overload
    def __init__(self, type: LinePatternSegmentType, length: float): ...
    @overload
    def __init__(self): ...
    @property
    def Type(self) -> LinePatternSegmentType: ...
    @Type.setter
    def Type(self, type: LinePatternSegmentType) -> None: ...
    @property
    def Length(self) -> float: ...
    @Length.setter
    def Length(self, length: float) -> None: ...
    @property
    def IsValidObject(self) -> bool: ...
    def Dispose(self) -> None: ...


class LinePattern:
    @overload
    def __init__(self, name: str): ...
    @overload
    def __init__(self): ...
    @property
    def Name(self) -> str: ...
    @Name.setter
    def Name(self, name: str) -> None: ...
    @property
    def IsValidObject(self) -> bool: ...
    def GetSegments(self) -> List[LinePatternSegment]: ...
    def SetSegments(self, lineSegs: List[LinePatternSegment]) -> None: ...
    def Dispose(self) -> None: ...


class LinkLoadContent(ExternalResourceLoadContent):
    def GetLinkDataPath(self) -> ModelPath: ...
    def SetLinkDataPath(self, linkPath: ModelPath) -> None: ...
    def GetLinkLoadResult(self) -> LinkLoadResult: ...


class LoadedFamilyIntegrityCheck:
    def CheckAllFamilies(ADoc: Document, corruptFamilyIds: ISet) -> bool: ...
    def CheckFamily(ADoc: Document, familyId: ElementId) -> bool: ...
    def CheckAllFamiliesSlow(ADoc: Document, corruptFamilyIds: ISet) -> bool: ...


class LinePatternSegmentType:
    Dash = 0
    Space = 1
    Dot = 2
    Invalid = 3


class MEPAnalyticalConnection(MEPCurve):
    def Create(doc: Document, typeId: ElementId, startConnector: Connector, endConnector: Connector) -> MEPAnalyticalConnection: ...
    def CanSupportAnalyticalConnection(connector: Connector) -> bool: ...
    def CreateMultipleConnections(doc: Document, typeId: ElementId, equipmentOpenConnectors: List[Connector], curveIdsToConnect: List[ElementId]) -> ISet: ...
    def GetFlow(self) -> float: ...


class MEPAnalyticalConnectionType(ElementType):
    @property
    def PressureLoss(self) -> float: ...
    @PressureLoss.setter
    def PressureLoss(self, pressureLoss: float) -> None: ...
    def Create(doc: Document, name: str) -> MEPAnalyticalConnectionType: ...
    def IsNameUnused(doc: Document, name: str) -> bool: ...
    def FindTypeByName(doc: Document, name: str) -> ElementId: ...


class MEPCalculationServerInfo:
    @overload
    def __init__(self, other: MEPCalculationServerInfo): ...
    @overload
    def __init__(self, server: IExternalServer): ...
    @overload
    def __init__(self): ...
    @property
    def ServerId(self) -> Guid: ...
    @ServerId.setter
    def ServerId(self, serverId: Guid) -> None: ...
    @property
    def ServerName(self) -> str: ...
    @ServerName.setter
    def ServerName(self, serverName: str) -> None: ...
    @property
    def Description(self) -> str: ...
    @Description.setter
    def Description(self, description: str) -> None: ...
    @property
    def PipeUseDefinitionOnTypeGUID() -> Guid: ...
    @property
    def IsValidObject(self) -> bool: ...
    def GetMEPCalculationServerInfo(famInst: FamilyInstance) -> MEPCalculationServerInfo: ...
    def Dispose(self) -> None: ...


class MEPFamilyConnectorInfo(MEPConnectorInfo):
    def GetConnectorParameterValue(self, connectorParameterId: ElementId) -> ParameterValue: ...
    def GetAssociateFamilyParameterId(self, connectorParameterId: ElementId) -> ElementId: ...


class ParameterValue:
    @property
    def IsValidObject(self) -> bool: ...
    def Copy(self) -> ParameterValue: ...
    def IsEqual(self, other: ParameterValue) -> bool: ...
    def IsSameType(self, other: ParameterValue) -> bool: ...
    def Dispose(self) -> None: ...


class NullParameterValue(ParameterValue):
    def __init__(self): ...


class IntegerParameterValue(ParameterValue):
    @overload
    def __init__(self, value: int): ...
    @overload
    def __init__(self): ...
    @property
    def Value(self) -> int: ...
    @Value.setter
    def Value(self, value: int) -> None: ...


class DoubleParameterValue(ParameterValue):
    @overload
    def __init__(self, value: float): ...
    @overload
    def __init__(self): ...
    @property
    def Value(self) -> float: ...
    @Value.setter
    def Value(self, value: float) -> None: ...


class ElementIdParameterValue(ParameterValue):
    @overload
    def __init__(self, value: ElementId): ...
    @overload
    def __init__(self): ...
    @property
    def Value(self) -> ElementId: ...
    @Value.setter
    def Value(self, value: ElementId) -> None: ...


class StringParameterValue(ParameterValue):
    @overload
    def __init__(self, value: str): ...
    @overload
    def __init__(self): ...
    @property
    def Value(self) -> str: ...
    @Value.setter
    def Value(self, value: str) -> None: ...


class MassInstanceUtils:
    @property
    def IsValidObject(self) -> bool: ...
    def AddMassLevelDataToMassInstance(document: Document, massInstanceId: ElementId, levelId: ElementId) -> ElementId: ...
    def RemoveMassLevelDataFromMassInstance(document: Document, massInstanceId: ElementId, levelId: ElementId) -> None: ...
    def GetMassLevelDataIds(document: Document, massInstanceId: ElementId) -> List[ElementId]: ...
    def GetMassLevelIds(document: Document, massInstanceId: ElementId) -> List[ElementId]: ...
    def GetGrossFloorArea(document: Document, massInstanceId: ElementId) -> float: ...
    def GetGrossSurfaceArea(document: Document, massInstanceId: ElementId) -> float: ...
    def GetGrossVolume(document: Document, massInstanceId: ElementId) -> float: ...
    def GetJoinedElementIds(document: Document, massInstanceId: ElementId) -> List[ElementId]: ...
    def Dispose(self) -> None: ...


class CADLinkType(ElementType):
    @overload
    def Reload(self, options: CADLinkOptions) -> LinkLoadResult: ...
    @overload
    def Reload(self) -> LinkLoadResult: ...
    @overload
    def LoadFrom(self, resourceReference: ExternalResourceReference) -> LinkLoadResult: ...
    @overload
    def LoadFrom(self, path: str) -> LinkLoadResult: ...


class MathComparisonUtils:
    def IsAlmostEqual(value1: float, value2: float) -> bool: ...
    def IsGreaterThanOrAlmostEqual(value1: float, value2: float) -> bool: ...
    def IsGreaterThan(value1: float, value2: float) -> bool: ...
    def IsLessThanOrAlmostEqual(value1: float, value2: float) -> bool: ...
    def IsLessThan(value1: float, value2: float) -> bool: ...
    def IsAlmostZero(value: float) -> bool: ...


class MultiReferenceAnnotation(Element):
    @property
    def DimensionId(self) -> ElementId: ...
    @property
    def TagId(self) -> ElementId: ...
    def Create(document: Document, ownerViewId: ElementId, options: MultiReferenceAnnotationOptions) -> MultiReferenceAnnotation: ...
    def IsLinearFixedDimensionDirectionValid(document: Document, viewId: ElementId, options: MultiReferenceAnnotationOptions) -> bool: ...
    def AreElementsValidForMultiReferenceAnnotation(document: Document, options: MultiReferenceAnnotationOptions) -> bool: ...
    def AreReferencesValidForLinearDimension(document: Document, ownerViewId: ElementId, options: MultiReferenceAnnotationOptions) -> bool: ...
    def AreReferencesValidForLinearFixedDimension(document: Document, ownerViewId: ElementId, options: MultiReferenceAnnotationOptions) -> bool: ...
    def Is3DViewValidForDimension(document: Document, ownerViewId: ElementId, options: MultiReferenceAnnotationOptions) -> bool: ...


class MultiReferenceAnnotationOptions:
    def __init__(self, multiReferenceAnnotationType: MultiReferenceAnnotationType): ...
    @property
    def MultiReferenceAnnotationType(self) -> MultiReferenceAnnotationType: ...
    @property
    def DimensionPlaneNormal(self) -> XYZ: ...
    @DimensionPlaneNormal.setter
    def DimensionPlaneNormal(self, dimensionPlaneNormal: XYZ) -> None: ...
    @property
    def DimensionLineDirection(self) -> XYZ: ...
    @DimensionLineDirection.setter
    def DimensionLineDirection(self, dimensionLineDirection: XYZ) -> None: ...
    @property
    def DimensionLineOrigin(self) -> XYZ: ...
    @DimensionLineOrigin.setter
    def DimensionLineOrigin(self, dimensionLineOrigin: XYZ) -> None: ...
    @property
    def DimensionStyleType(self) -> DimensionStyleType: ...
    @DimensionStyleType.setter
    def DimensionStyleType(self, dimensionStyleType: DimensionStyleType) -> None: ...
    @property
    def TagHeadPosition(self) -> XYZ: ...
    @TagHeadPosition.setter
    def TagHeadPosition(self, tagHeadPosition: XYZ) -> None: ...
    @property
    def TagHasLeader(self) -> bool: ...
    @TagHasLeader.setter
    def TagHasLeader(self, tagHasLeader: bool) -> None: ...
    @property
    def IsValidObject(self) -> bool: ...
    def IsAllowedDimensionStyleType(self, dimensionStyleType: DimensionStyleType) -> bool: ...
    def GetAdditionalReferencesToDimension(self) -> List[Reference]: ...
    def SetAdditionalReferencesToDimension(self, referencesToDimension: List[Reference]) -> None: ...
    def ReferencesDontMatchReferenceCategory(self, references: List[Reference]) -> bool: ...
    def GetElementsToDimension(self) -> ICollection: ...
    def SetElementsToDimension(self, elementsToDimension: ICollection) -> None: ...
    def ElementsMatchReferenceCategory(self, elements: ICollection) -> bool: ...
    def Dispose(self) -> None: ...


class MultiReferenceAnnotationType(ElementType):
    @property
    def ReferenceCategoryId(self) -> ElementId: ...
    @property
    def TagTypeId(self) -> ElementId: ...
    @TagTypeId.setter
    def TagTypeId(self, tagTypeId: ElementId) -> None: ...
    @property
    def GroupTagHeads(self) -> bool: ...
    @GroupTagHeads.setter
    def GroupTagHeads(self, groupTagHeads: bool) -> None: ...
    @property
    def ShowDimensionText(self) -> bool: ...
    @ShowDimensionText.setter
    def ShowDimensionText(self, showDimensionText: bool) -> None: ...
    @property
    def DimensionStyleId(self) -> ElementId: ...
    @DimensionStyleId.setter
    def DimensionStyleId(self, dimensionStyleId: ElementId) -> None: ...
    def CreateDefault(document: Document) -> MultiReferenceAnnotationType: ...
    def GetAllowedTagCategory(self) -> ElementId: ...
    def IsAllowedTagType(self, tagTypeId: ElementId) -> bool: ...
    def IsAllowedTagCategory(tagCategoryId: ElementId) -> bool: ...
    def IsAllowedReferenceCategory(self, referenceCategoryId: ElementId) -> bool: ...
    def IsAllowedDimensionStyle(self, dimensionStyleId: ElementId) -> bool: ...


class FittingAndAccessoryCalculationType:
    Undefined = 0
    CalculatePressureDrop = 1
    CalculateDefaultSettings = 2
    ValidateCurrentSettings = 4


class ModelUpdatesStatus:
    CurrentWithCentral = 0
    NotYetInCentral = 1
    DeletedInCentral = 2
    UpdatedInCentral = 3


class NamingUtils:
    def IsValidName(string: str) -> bool: ...
    def CompareNames(nameA: str, nameB: str) -> int: ...


class NestedFamilyTypeReference(Element):
    @property
    def CategoryId(self) -> ElementId: ...
    @property
    def FamilyName(self) -> str: ...
    @property
    def TypeName(self) -> str: ...


class NumberingSchema(Element):
    @property
    def NumberingParameterId(self) -> ElementId: ...
    @property
    def SchemaType(self) -> NumberingSchemaType: ...
    @property
    def MaximumStartingNumber() -> int: ...
    def GetSchemasInDocument(document: Document) -> ISet: ...
    def GetNumberingSchema(document: Document, schemaType: NumberingSchemaType) -> NumberingSchema: ...
    def GetMinimumNumberOfDigits(document: Document) -> int: ...
    def SetMinimumNumberOfDigits(document: Document, value: int) -> None: ...
    def GetNumberingSequences(self) -> List[str]: ...
    def GetNumbers(self, partition: str) -> List[IntegerRange]: ...
    def RemoveGaps(self, partition: str) -> None: ...
    def ShiftNumbers(self, partition: str, firstNumber: int) -> None: ...
    def ChangeNumber(self, partition: str, fromNumber: int, toNumber: int) -> List[ElementId]: ...
    def MoveSequence(self, fromPartition: str, newPartition: str) -> None: ...
    def AppendSequence(self, fromPartition: str, toPartition: str) -> None: ...
    def MergeSequences(self, sourcePartitions: List[str], newPartition: str) -> None: ...
    def AssignElementsToSequence(self, elementIds: ISet, partitionName: str) -> None: ...
    def IsValidPartitionName(name: str) -> Tuple[bool, str]: ...


class NumberingSchemaType(GuidEnum):
    def __init__(self, guid: Guid): ...
    def op_Equality(first: NumberingSchemaType, second: NumberingSchemaType) -> bool: ...
    def op_Inequality(first: NumberingSchemaType, second: NumberingSchemaType) -> bool: ...


class NumberingSchemaTypes:


class StructuralNumberingSchemas:
    @property
    def Rebar() -> NumberingSchemaType: ...
    @property
    def RebarCoupler() -> NumberingSchemaType: ...
    @property
    def ReinforcementFabric() -> NumberingSchemaType: ...


class OffsetSurface(Surface):
    def GetBasisSurface(self) -> Surface: ...
    def GetOffsetDistance(self) -> float: ...
    def IsOrientationSameAsBasisSurface(self) -> bool: ...


class WorksetConfiguration:
    @overload
    def __init__(self, option: WorksetConfigurationOption): ...
    @overload
    def __init__(self): ...
    @overload
    def __init__(self, other: WorksetConfiguration): ...
    @property
    def IsValidObject(self) -> bool: ...
    def Open(self, worksetsToOpen: List[WorksetId]) -> None: ...
    def Close(self, worksetsToClose: List[WorksetId]) -> None: ...
    def Dispose(self) -> None: ...


class WorksetConfigurationOption:
    OpenAllWorksets = 0
    CloseAllWorksets = 1
    OpenLastViewed = 2


class ParameterElement(Element):
    def GetDefinition(self) -> InternalDefinition: ...


class GlobalParameter(ParameterElement):
    @property
    def IsReporting(self) -> bool: ...
    @IsReporting.setter
    def IsReporting(self, reporting: bool) -> None: ...
    @property
    def IsDrivenByFormula(self) -> bool: ...
    @property
    def IsDrivenByDimension(self) -> bool: ...
    def Create(document: Document, name: str, datatype: ParameterType) -> GlobalParameter: ...
    def CanChangeReporting(self) -> bool: ...
    def SetDrivingDimension(self, dimensionId: ElementId) -> None: ...
    def GetAffectedElements(self) -> ISet: ...
    def GetAffectedGlobalParameters(self) -> ISet: ...
    def GetFormula(self) -> str: ...
    def SetFormula(self, expression: str) -> None: ...
    def GetLabelName(self) -> str: ...
    def LabelDimension(self, dimensionId: ElementId) -> None: ...
    def UnlabelDimension(self, dimensionId: ElementId) -> None: ...
    def CanLabelDimension(self, dimensionId: ElementId) -> bool: ...
    def GetLabeledDimensions(self) -> ISet: ...
    def GetValue(self) -> ParameterValue: ...
    def SetValue(self, value: ParameterValue) -> None: ...
    def IsValidFormula(self, expression: str) -> bool: ...
    def IsValidDataType(datatype: ParameterType) -> bool: ...
    def HasValidTypeForReporting(self) -> bool: ...


class ParameterValuePresenceRule(FilterRule):
    @property
    def Parameter(self) -> ElementId: ...
    @Parameter.setter
    def Parameter(self, parameter: ElementId) -> None: ...


class HasValueFilterRule(ParameterValuePresenceRule):
    def __init__(self, parameter: ElementId): ...


class HasNoValueFilterRule(ParameterValuePresenceRule):
    def __init__(self, parameter: ElementId): ...


class SharedParameterApplicableRule(FilterRule):
    def __init__(self, parameterName: str): ...
    @property
    def ParameterName(self) -> str: ...
    @ParameterName.setter
    def ParameterName(self, parameterName: str) -> None: ...


class ParameterFilterRuleFactory:
    @property
    def IsValidObject(self) -> bool: ...
    def CreateSharedParameterApplicableRule(parameterName: str) -> FilterRule: ...
    @overload
    def CreateEqualsRule(parameter: ElementId, value: ElementId) -> FilterRule: ...
    @overload
    def CreateEqualsRule(parameter: ElementId, value: int) -> FilterRule: ...
    @overload
    def CreateEqualsRule(parameter: ElementId, value: float, epsilon: float) -> FilterRule: ...
    @overload
    def CreateEqualsRule(parameter: ElementId, value: str, caseSensitive: bool) -> FilterRule: ...
    @overload
    def CreateNotEqualsRule(parameter: ElementId, value: ElementId) -> FilterRule: ...
    @overload
    def CreateNotEqualsRule(parameter: ElementId, value: int) -> FilterRule: ...
    @overload
    def CreateNotEqualsRule(parameter: ElementId, value: float, epsilon: float) -> FilterRule: ...
    @overload
    def CreateNotEqualsRule(parameter: ElementId, value: str, caseSensitive: bool) -> FilterRule: ...
    @overload
    def CreateGreaterRule(parameter: ElementId, value: ElementId) -> FilterRule: ...
    @overload
    def CreateGreaterRule(parameter: ElementId, value: int) -> FilterRule: ...
    @overload
    def CreateGreaterRule(parameter: ElementId, value: float, epsilon: float) -> FilterRule: ...
    @overload
    def CreateGreaterRule(parameter: ElementId, value: str, caseSensitive: bool) -> FilterRule: ...
    @overload
    def CreateGreaterOrEqualRule(parameter: ElementId, value: ElementId) -> FilterRule: ...
    @overload
    def CreateGreaterOrEqualRule(parameter: ElementId, value: int) -> FilterRule: ...
    @overload
    def CreateGreaterOrEqualRule(parameter: ElementId, value: float, epsilon: float) -> FilterRule: ...
    @overload
    def CreateGreaterOrEqualRule(parameter: ElementId, value: str, caseSensitive: bool) -> FilterRule: ...
    @overload
    def CreateLessRule(parameter: ElementId, value: ElementId) -> FilterRule: ...
    @overload
    def CreateLessRule(parameter: ElementId, value: int) -> FilterRule: ...
    @overload
    def CreateLessRule(parameter: ElementId, value: float, epsilon: float) -> FilterRule: ...
    @overload
    def CreateLessRule(parameter: ElementId, value: str, caseSensitive: bool) -> FilterRule: ...
    @overload
    def CreateLessOrEqualRule(parameter: ElementId, value: ElementId) -> FilterRule: ...
    @overload
    def CreateLessOrEqualRule(parameter: ElementId, value: int) -> FilterRule: ...
    @overload
    def CreateLessOrEqualRule(parameter: ElementId, value: float, epsilon: float) -> FilterRule: ...
    @overload
    def CreateLessOrEqualRule(parameter: ElementId, value: str, caseSensitive: bool) -> FilterRule: ...
    def CreateContainsRule(parameter: ElementId, value: str, caseSensitive: bool) -> FilterRule: ...
    def CreateNotContainsRule(parameter: ElementId, value: str, caseSensitive: bool) -> FilterRule: ...
    def CreateBeginsWithRule(parameter: ElementId, value: str, caseSensitive: bool) -> FilterRule: ...
    def CreateNotBeginsWithRule(parameter: ElementId, value: str, caseSensitive: bool) -> FilterRule: ...
    def CreateEndsWithRule(parameter: ElementId, value: str, caseSensitive: bool) -> FilterRule: ...
    def CreateNotEndsWithRule(parameter: ElementId, value: str, caseSensitive: bool) -> FilterRule: ...
    def CreateIsAssociatedWithGlobalParameterRule(parameter: ElementId, value: ElementId) -> FilterRule: ...
    def CreateIsNotAssociatedWithGlobalParameterRule(parameter: ElementId, value: ElementId) -> FilterRule: ...
    def CreateHasValueParameterRule(parameter: ElementId) -> FilterRule: ...
    def CreateHasNoValueParameterRule(parameter: ElementId) -> FilterRule: ...
    def Dispose(self) -> None: ...


class ParameterFilterElement(FilterElement):
    @overload
    def Create(aDocument: Document, name: str, categories: ICollection, elementFilter: ElementFilter) -> ParameterFilterElement: ...
    @overload
    def Create(aDocument: Document, name: str, categories: ICollection) -> ParameterFilterElement: ...
    def GetCategories(self) -> ICollection: ...
    def SetCategories(self, categories: ICollection) -> None: ...
    @overload
    def ElementFilterIsAcceptableForParameterFilterElement(aDocument: Document, categories: ISet, elementFilter: ElementFilter) -> bool: ...
    @overload
    def ElementFilterIsAcceptableForParameterFilterElement(self, elementFilter: ElementFilter) -> bool: ...
    def GetElementFilter(self) -> ElementFilter: ...
    def SetElementFilter(self, elementFilter: ElementFilter) -> bool: ...
    def ClearRules(self) -> None: ...
    @overload
    def AllRuleParametersApplicable(self, elementFilter: ElementFilter) -> bool: ...
    @overload
    def AllRuleParametersApplicable(aDocument: Document, categories: ICollection, elementFilter: ElementFilter) -> bool: ...
    def GetElementFilterParameters(self) -> ISet: ...
    def GetElementFilterParametersForCategory(self, categoryId: ElementId) -> ISet: ...


class ParameterFilterUtilities:
    def GetAllFilterableCategories() -> ICollection: ...
    def GetFilterableParametersInCommon(aDoc: Document, categories: ICollection) -> ICollection: ...
    def GetInapplicableParameters(aDoc: Document, categories: ICollection, parameters: List[ElementId]) -> List[ElementId]: ...
    def IsParameterApplicable(element: Element, parameter: ElementId) -> bool: ...
    def RemoveUnfilterableCategories(categories: ICollection) -> ICollection: ...


class PartUtils:
    @overload
    def CreateParts(document: Document, elementIds: ICollection) -> None: ...
    @overload
    def CreateParts(document: Document, hostOrLinkElementIds: ICollection) -> None: ...
    def DivideParts(document: Document, elementIdsToDivide: ICollection, intersectingReferenceIds: ICollection, curveArray: List[Curve], sketchPlaneId: ElementId) -> PartMaker: ...
    def IsValidForCreateParts(document: Document, hostOrLinkElementId: LinkElementId) -> bool: ...
    def GetSplittingElements(document: Document, partId: ElementId) -> ISet: ...
    @overload
    def GetSplittingCurves(document: Document, partId: ElementId) -> Tuple[List[Curve], Plane]: ...
    @overload
    def GetSplittingCurves(document: Document, partId: ElementId) -> List[Curve]: ...
    def AreElementsValidForCreateParts(document: Document, elementIds: ICollection) -> bool: ...
    def ArePartsValidForDivide(document: Document, elementIdsToDivide: ICollection) -> bool: ...
    def GetChainLengthToOriginal(part: Part) -> int: ...
    @overload
    def HasAssociatedParts(hostDocument: Document, elementId: ElementId) -> bool: ...
    @overload
    def HasAssociatedParts(hostDocument: Document, hostOrLinkElementId: LinkElementId) -> bool: ...
    @overload
    def GetAssociatedParts(hostDocument: Document, elementId: ElementId, includePartsWithAssociatedParts: bool, includeAllChildren: bool) -> ICollection: ...
    @overload
    def GetAssociatedParts(hostDocument: Document, hostOrLinkElementId: LinkElementId, includePartsWithAssociatedParts: bool, includeAllChildren: bool) -> ICollection: ...
    @overload
    def GetAssociatedPartMaker(hostDocument: Document, elementId: ElementId) -> PartMaker: ...
    @overload
    def GetAssociatedPartMaker(hostDocument: Document, hostOrLinkElementId: LinkElementId) -> PartMaker: ...
    def ArePartsValidForMerge(document: Document, partIds: ICollection) -> bool: ...
    def CreateMergedPart(document: Document, partIds: ICollection) -> PartMaker: ...
    def FindMergeableClusters(doc: Document, partIds: ICollection) -> List[ElementId]: ...
    def IsMergedPart(part: Part) -> bool: ...
    def GetMergedParts(part: Part) -> ICollection: ...
    def IsPartDerivedFromLink(dPart: Part) -> bool: ...
    def GetPartMakerMethodToDivideVolumeFW(partMaker: PartMaker) -> PartMakerMethodToDivideVolumes: ...


class PerformanceAdviser:
    @property
    def IsValidObject(self) -> bool: ...
    def GetPerformanceAdviser() -> PerformanceAdviser: ...
    def AddRule(self, id: PerformanceAdviserRuleId, rule: IPerformanceAdviserRule) -> None: ...
    def DeleteRule(self, id: PerformanceAdviserRuleId) -> None: ...
    def GetNumberOfRules(self) -> int: ...
    def GetRuleId(self, index: int) -> PerformanceAdviserRuleId: ...
    def GetAllRuleIds(self) -> List[PerformanceAdviserRuleId]: ...
    @overload
    def IsRuleEnabled(self, id: PerformanceAdviserRuleId) -> bool: ...
    @overload
    def IsRuleEnabled(self, index: int) -> bool: ...
    @overload
    def SetRuleEnabled(self, id: PerformanceAdviserRuleId, enabled: bool) -> None: ...
    @overload
    def SetRuleEnabled(self, index: int, enabled: bool) -> None: ...
    def ExecuteAllRules(self, document: Document) -> List[FailureMessage]: ...
    @overload
    def ExecuteRules(self, document: Document, rules: List[int]) -> List[FailureMessage]: ...
    @overload
    def ExecuteRules(self, document: Document, rules: List[PerformanceAdviserRuleId]) -> List[FailureMessage]: ...
    def PostWarning(self, message: FailureMessage) -> None: ...
    @overload
    def WillRuleCheckElements(self, index: int) -> bool: ...
    @overload
    def WillRuleCheckElements(self, id: PerformanceAdviserRuleId) -> bool: ...
    @overload
    def GetElementFilterFromRule(self, index: int, document: Document) -> ElementFilter: ...
    @overload
    def GetElementFilterFromRule(self, id: PerformanceAdviserRuleId, document: Document) -> ElementFilter: ...
    @overload
    def GetRuleName(self, index: int) -> str: ...
    @overload
    def GetRuleName(self, id: PerformanceAdviserRuleId) -> str: ...
    @overload
    def GetRuleDescription(self, index: int) -> str: ...
    @overload
    def GetRuleDescription(self, id: PerformanceAdviserRuleId) -> str: ...
    def Dispose(self) -> None: ...


class IPerformanceAdviserRule:
    def InitCheck(self, document: Document) -> None: ...
    def FinalizeCheck(self, document: Document) -> None: ...
    def ExecuteElementCheck(self, document: Document, element: Element) -> None: ...
    def WillCheckElements(self) -> bool: ...
    def GetElementFilter(self, document: Document) -> ElementFilter: ...
    def GetName(self) -> str: ...
    def GetDescription(self) -> str: ...


class PerformanceAdviserRuleId(GuidEnum):
    def __init__(self, guid: Guid): ...
    def op_Equality(first: PerformanceAdviserRuleId, second: PerformanceAdviserRuleId) -> bool: ...
    def op_Inequality(first: PerformanceAdviserRuleId, second: PerformanceAdviserRuleId) -> bool: ...


class PerformanceAdviserRules:


class PhaseFilter(Element):
    @property
    def IsDefault(self) -> bool: ...
    def GetPhaseStatusPresentation(self, status: ElementOnPhaseStatus) -> PhaseStatusPresentation: ...
    def SetPhaseStatusPresentation(self, status: ElementOnPhaseStatus, presentation: PhaseStatusPresentation) -> None: ...
    def Create(document: Document, name: str) -> PhaseFilter: ...


class Segment(Element):
    @property
    def Description(self) -> str: ...
    @Description.setter
    def Description(self, description: str) -> None: ...
    @property
    def Roughness(self) -> float: ...
    @Roughness.setter
    def Roughness(self, roughness: float) -> None: ...
    @property
    def MaterialId(self) -> ElementId: ...
    @property
    def SizeCount(self) -> int: ...
    def AddSize(self, size: MEPSize) -> None: ...
    def RemoveSize(self, nominalDiameter: float) -> None: ...
    def GetSizes(self) -> ICollection: ...


class PointCloudInstance(Instance):
    @property
    def FilterAction(self) -> SelectionFilterAction: ...
    @FilterAction.setter
    def FilterAction(self, FilterAction: SelectionFilterAction) -> None: ...
    @property
    def SupportsOverrides(self) -> bool: ...
    def HasColor(self) -> bool: ...
    def GetScans(self) -> List[str]: ...
    def GetScanOrigin(self, scanName: str) -> XYZ: ...
    def GetRegions(self) -> List[str]: ...
    def GetSelectionFilter(self) -> PointCloudFilter: ...
    def SetSelectionFilter(self, pFilter: PointCloudFilter) -> None: ...
    def ContainsScan(self, scanName: str) -> bool: ...
    def Create(document: Document, typeId: ElementId, transform: Transform) -> PointCloudInstance: ...
    def GetPoints(self, filter: PointCloudFilter, averageDistance: float, numPoints: int) -> PointCollection: ...


class PointCloudType(ElementType):
    @property
    def EngineIdentifier(self) -> str: ...
    @property
    def Scale(self) -> float: ...
    @Scale.setter
    def Scale(self, scale: float) -> None: ...
    @property
    def Offset(self) -> XYZ: ...
    @property
    def ColorEncoding(self) -> PointCloudColorEncoding: ...
    @property
    def FoundStatus(self) -> PointCloudFoundStatus: ...
    def Create(document: Document, engineIdentifier: str, typeIdentifier: str) -> PointCloudType: ...
    def GetPath(self) -> ModelPath: ...


class RoutingCriterionBase:
    @property
    def IsValidObject(self) -> bool: ...
    def IsEqual(self, pOther: RoutingCriterionBase) -> bool: ...
    def Dispose(self) -> None: ...


class PrimarySizeCriterion(RoutingCriterionBase):
    def __init__(self, minimumSize: float, maximumSize: float): ...
    @property
    def MinimumSize(self) -> float: ...
    @MinimumSize.setter
    def MinimumSize(self, minimumSize: float) -> None: ...
    @property
    def MaximumSize(self) -> float: ...
    @MaximumSize.setter
    def MaximumSize(self, maximumSize: float) -> None: ...
    def All() -> PrimarySizeCriterion: ...
    def None() -> PrimarySizeCriterion: ...


class Revision(Element):
    @property
    def SequenceNumber(self) -> int: ...
    @property
    def RevisionNumber(self) -> str: ...
    @property
    def Description(self) -> str: ...
    @Description.setter
    def Description(self, description: str) -> None: ...
    @property
    def Issued(self) -> bool: ...
    @Issued.setter
    def Issued(self, issued: bool) -> None: ...
    @property
    def IssuedTo(self) -> str: ...
    @IssuedTo.setter
    def IssuedTo(self, issuedTo: str) -> None: ...
    @property
    def IssuedBy(self) -> str: ...
    @IssuedBy.setter
    def IssuedBy(self, issuedBy: str) -> None: ...
    @property
    def RevisionDate(self) -> str: ...
    @RevisionDate.setter
    def RevisionDate(self, revisionDate: str) -> None: ...
    @property
    def Visibility(self) -> RevisionVisibility: ...
    @Visibility.setter
    def Visibility(self, visibility: RevisionVisibility) -> None: ...
    @property
    def NumberType(self) -> RevisionNumberType: ...
    @NumberType.setter
    def NumberType(self, numberType: RevisionNumberType) -> None: ...
    def GetAllRevisionIds(document: Document) -> List[ElementId]: ...
    def Create(document: Document) -> Revision: ...
    def ReorderRevisionSequence(document: Document, newSequence: List[ElementId]) -> None: ...
    def CombineWithPrevious(document: Document, revisionId: ElementId) -> ISet: ...
    def CombineWithNext(document: Document, revisionId: ElementId) -> ISet: ...


class PropertySetElement(Element):
    def Duplicate(self, document: Document, name: str) -> PropertySetElement: ...
    @overload
    def Create(document: Document, thermalAsset: ThermalAsset) -> PropertySetElement: ...
    @overload
    def Create(document: Document, structuralAsset: StructuralAsset) -> PropertySetElement: ...
    def GetStructuralAsset(self) -> StructuralAsset: ...
    def SetStructuralAsset(self, structuralAsset: StructuralAsset) -> None: ...
    def GetThermalAsset(self) -> ThermalAsset: ...
    def SetThermalAsset(self, thermalAsset: ThermalAsset) -> None: ...


class StructuralAsset:
    def __init__(self, name: str, structuralAssetClass: StructuralAssetClass): ...
    @property
    def StructuralAssetClass(self) -> StructuralAssetClass: ...
    @property
    def YoungModulus(self) -> XYZ: ...
    @YoungModulus.setter
    def YoungModulus(self, youngModulus: XYZ) -> None: ...
    @property
    def PoissonRatio(self) -> XYZ: ...
    @PoissonRatio.setter
    def PoissonRatio(self, poissonRatio: XYZ) -> None: ...
    @property
    def ShearModulus(self) -> XYZ: ...
    @ShearModulus.setter
    def ShearModulus(self, shearModulus: XYZ) -> None: ...
    @property
    def ThermalExpansionCoefficient(self) -> XYZ: ...
    @ThermalExpansionCoefficient.setter
    def ThermalExpansionCoefficient(self, thermalExpansionCoefficient: XYZ) -> None: ...
    @property
    def Lightweight(self) -> bool: ...
    @Lightweight.setter
    def Lightweight(self, lightweight: bool) -> None: ...
    @property
    def Behavior(self) -> StructuralBehavior: ...
    @Behavior.setter
    def Behavior(self, Behavior: StructuralBehavior) -> None: ...
    @property
    def ConcreteCompression(self) -> float: ...
    @ConcreteCompression.setter
    def ConcreteCompression(self, concreteCompression: float) -> None: ...
    @property
    def ConcreteBendingReinforcement(self) -> float: ...
    @ConcreteBendingReinforcement.setter
    def ConcreteBendingReinforcement(self, ConcreteBendingReinforcement: float) -> None: ...
    @property
    def ConcreteShearReinforcement(self) -> float: ...
    @ConcreteShearReinforcement.setter
    def ConcreteShearReinforcement(self, ConcreteShearReinforcement: float) -> None: ...
    @property
    def ConcreteShearStrengthReduction(self) -> float: ...
    @ConcreteShearStrengthReduction.setter
    def ConcreteShearStrengthReduction(self, ConcreteShearStrengthReduction: float) -> None: ...
    @property
    def MinimumYieldStress(self) -> float: ...
    @MinimumYieldStress.setter
    def MinimumYieldStress(self, minimumYieldStress: float) -> None: ...
    @property
    def MinimumTensileStrength(self) -> float: ...
    @MinimumTensileStrength.setter
    def MinimumTensileStrength(self, minimumTensileStrength: float) -> None: ...
    @property
    def MetalThermallyTreated(self) -> bool: ...
    @MetalThermallyTreated.setter
    def MetalThermallyTreated(self, MetalThermallyTreated: bool) -> None: ...
    @property
    def MetalReductionFactor(self) -> float: ...
    @MetalReductionFactor.setter
    def MetalReductionFactor(self, MetalReductionFactor: float) -> None: ...
    @property
    def MetalResistanceCalculationStrength(self) -> float: ...
    @MetalResistanceCalculationStrength.setter
    def MetalResistanceCalculationStrength(self, MetalResistanceCalculationStrength: float) -> None: ...
    @property
    def WoodBendingStrength(self) -> float: ...
    @WoodBendingStrength.setter
    def WoodBendingStrength(self, WoodBendingStrength: float) -> None: ...
    @property
    def WoodParallelCompressionStrength(self) -> float: ...
    @WoodParallelCompressionStrength.setter
    def WoodParallelCompressionStrength(self, WoodParallelCompressionStrength: float) -> None: ...
    @property
    def WoodPerpendicularCompressionStrength(self) -> float: ...
    @WoodPerpendicularCompressionStrength.setter
    def WoodPerpendicularCompressionStrength(self, WoodPerpendicularCompressionStrength: float) -> None: ...
    @property
    def WoodParallelShearStrength(self) -> float: ...
    @WoodParallelShearStrength.setter
    def WoodParallelShearStrength(self, WoodParallelShearStrength: float) -> None: ...
    @property
    def WoodPerpendicularShearStrength(self) -> float: ...
    @WoodPerpendicularShearStrength.setter
    def WoodPerpendicularShearStrength(self, WoodPerpendicularShearStrength: float) -> None: ...
    @property
    def WoodSpecies(self) -> str: ...
    @WoodSpecies.setter
    def WoodSpecies(self, WoodSpecies: str) -> None: ...
    @property
    def WoodGrade(self) -> str: ...
    @WoodGrade.setter
    def WoodGrade(self, WoodGrade: str) -> None: ...
    @property
    def SubClass(self) -> str: ...
    @SubClass.setter
    def SubClass(self, subClass: str) -> None: ...
    @property
    def Density(self) -> float: ...
    @Density.setter
    def Density(self, density: float) -> None: ...
    @property
    def Name(self) -> str: ...
    @Name.setter
    def Name(self, name: str) -> None: ...
    @property
    def IsValidObject(self) -> bool: ...
    def Copy(self) -> StructuralAsset: ...
    @overload
    def Equals(self, other: StructuralAsset) -> bool: ...
    def SetYoungModulus(self, youngModulus: float) -> None: ...
    def SetPoissonRatio(self, poissonRatio: float) -> None: ...
    def SetShearModulus(self, shearModulus: float) -> None: ...
    def SetThermalExpansionCoefficient(self, thermalExpCoeff: float) -> None: ...
    def Dispose(self) -> None: ...


class ThermalAsset:
    def __init__(self, name: str, materialType: ThermalMaterialType): ...
    @property
    def ThermalMaterialType(self) -> ThermalMaterialType: ...
    @property
    def Emissivity(self) -> float: ...
    @Emissivity.setter
    def Emissivity(self, emissivity: float) -> None: ...
    @property
    def GasViscosity(self) -> float: ...
    @GasViscosity.setter
    def GasViscosity(self, gasViscosity: float) -> None: ...
    @property
    def Compressibility(self) -> float: ...
    @Compressibility.setter
    def Compressibility(self, compressibility: float) -> None: ...
    @property
    def LiquidViscosity(self) -> float: ...
    @LiquidViscosity.setter
    def LiquidViscosity(self, liquidViscosity: float) -> None: ...
    @property
    def SpecificHeatOfVaporization(self) -> float: ...
    @SpecificHeatOfVaporization.setter
    def SpecificHeatOfVaporization(self, specificHeatOfVaporization: float) -> None: ...
    @property
    def SpecificHeat(self) -> float: ...
    @SpecificHeat.setter
    def SpecificHeat(self, specificHeat: float) -> None: ...
    @property
    def VaporPressure(self) -> float: ...
    @VaporPressure.setter
    def VaporPressure(self, vaporPressure: float) -> None: ...
    @property
    def TransmitsLight(self) -> bool: ...
    @TransmitsLight.setter
    def TransmitsLight(self, transmitsLight: bool) -> None: ...
    @property
    def Permeability(self) -> float: ...
    @Permeability.setter
    def Permeability(self, permeability: float) -> None: ...
    @property
    def Porosity(self) -> float: ...
    @Porosity.setter
    def Porosity(self, porosity: float) -> None: ...
    @property
    def Reflectivity(self) -> float: ...
    @Reflectivity.setter
    def Reflectivity(self, reflectivity: float) -> None: ...
    @property
    def ElectricalResistivity(self) -> float: ...
    @ElectricalResistivity.setter
    def ElectricalResistivity(self, electricalResistivity: float) -> None: ...
    @property
    def Density(self) -> float: ...
    @Density.setter
    def Density(self, density: float) -> None: ...
    @property
    def ThermalConductivity(self) -> float: ...
    @ThermalConductivity.setter
    def ThermalConductivity(self, thermalConductivity: float) -> None: ...
    @property
    def Behavior(self) -> StructuralBehavior: ...
    @Behavior.setter
    def Behavior(self, behavior: StructuralBehavior) -> None: ...
    @property
    def Name(self) -> str: ...
    @Name.setter
    def Name(self, name: str) -> None: ...
    @property
    def IsValidObject(self) -> bool: ...
    def Copy(self) -> ThermalAsset: ...
    @overload
    def Equals(self, other: ThermalAsset) -> bool: ...
    def EqualsThermalOnly(self, other: ThermalAsset) -> bool: ...
    def Dispose(self) -> None: ...


class PhaseStatusPresentation:
    DontShow = 0
    ShowByCategory = 1
    ShowOverriden = 2


class PlanViewRangeLevel:
    Unused = -5
    Below = -4
    Current = -3
    Above = -2
    Unlimited = -1


class SelectionFilterAction:
    #None = 0
    Highlight = 1
    Isolate = 2


class PointCloudFoundStatus:
    Unknown = 0
    NotFound = 1
    FoundOK = 2


class RevisionNumberType:
    Numeric = 0
    #None = 2
    Alphanumeric = 3


class RevisionVisibility:
    Hidden = 0
    CloudAndTagVisible = 1
    TagVisible = 2


class StructuralAssetClass:
    Undefined = 0
    Basic = 1
    Generic = 2
    Metal = 3
    Concrete = 4
    Wood = 5
    Liquid = 6
    Gas = 7
    Plastic = 8


class StructuralBehavior:
    Isotropic = 0
    Orthotropic = 1
    TransverseIsotropic = 2


class ThermalMaterialType:
    Undefined = 0
    Gas = 1
    Liquid = 2
    Solid = 3


class RoutingPreferenceManager:
    @property
    def PreferredJunctionType(self) -> PreferredJunctionType: ...
    @PreferredJunctionType.setter
    def PreferredJunctionType(self, preferredJunctionType: PreferredJunctionType) -> None: ...
    @property
    def OwnerId(self) -> ElementId: ...
    @property
    def IsValidObject(self) -> bool: ...
    def GetNumberOfRules(self, eGroupType: RoutingPreferenceRuleGroupType) -> int: ...
    def GetRule(self, groupType: RoutingPreferenceRuleGroupType, index: int) -> RoutingPreferenceRule: ...
    @overload
    def AddRule(self, groupType: RoutingPreferenceRuleGroupType, rule: RoutingPreferenceRule, index: int) -> None: ...
    @overload
    def AddRule(self, groupType: RoutingPreferenceRuleGroupType, rule: RoutingPreferenceRule) -> None: ...
    def RemoveRule(self, groupType: RoutingPreferenceRuleGroupType, index: int) -> None: ...
    def GetMEPPartId(self, groupType: RoutingPreferenceRuleGroupType, conditions: RoutingConditions) -> ElementId: ...
    def GetSharedSizes(self, size: float, shape: ConnectorProfileType) -> List[ElementId]: ...
    def Dispose(self) -> None: ...


class InsulationLiningBase(MEPCurve):
    @property
    def Thickness(self) -> float: ...
    @Thickness.setter
    def Thickness(self, thickness: float) -> None: ...
    @property
    def HostElementId(self) -> ElementId: ...
    def GetInsulationIds(document: Document, elemId: ElementId) -> ICollection: ...
    def GetLiningIds(document: Document, elemId: ElementId) -> ICollection: ...
    def IsValidThickness(thickness: float) -> bool: ...


class ReferenceIntersector:
    @overload
    def __init__(self, filter: ElementFilter, targetType: FindReferenceTarget, view3d: View3D): ...
    @overload
    def __init__(self, targetElementIds: ICollection, targetType: FindReferenceTarget, view3d: View3D): ...
    @overload
    def __init__(self, targetElementId: ElementId, targetType: FindReferenceTarget, view3d: View3D): ...
    @overload
    def __init__(self, view3d: View3D): ...
    @property
    def ViewId(self) -> ElementId: ...
    @ViewId.setter
    def ViewId(self, viewId: ElementId) -> None: ...
    @property
    def TargetType(self) -> FindReferenceTarget: ...
    @TargetType.setter
    def TargetType(self, targetType: FindReferenceTarget) -> None: ...
    @property
    def FindReferencesInRevitLinks(self) -> bool: ...
    @FindReferencesInRevitLinks.setter
    def FindReferencesInRevitLinks(self, findReferencesInRevitLinks: bool) -> None: ...
    @property
    def IsValidObject(self) -> bool: ...
    def Find(self, origin: XYZ, direction: XYZ) -> List[ReferenceWithContext]: ...
    def FindNearest(self, origin: XYZ, direction: XYZ) -> ReferenceWithContext: ...
    def GetFilter(self) -> ElementFilter: ...
    def SetFilter(self, filter: ElementFilter) -> None: ...
    def GetTargetElementIds(self) -> ICollection: ...
    def SetTargetElementIds(self, elementIds: ICollection) -> None: ...
    def Dispose(self) -> None: ...


class RelinquishedItems:
    @property
    def IsValidObject(self) -> bool: ...
    def GetRelinquishedElements(self) -> ICollection: ...
    def GetRelinquishedWorksets(self) -> ICollection: ...
    def Dispose(self) -> None: ...


class RepeaterBounds:
    @property
    def DimensionCount(self) -> int: ...
    @property
    def IsValidObject(self) -> bool: ...
    def GetLowerBound(self, dimension: int) -> int: ...
    def GetUpperBound(self, dimension: int) -> int: ...
    def IsCyclical(self, dimension: int) -> bool: ...
    def AreCoordinatesInBounds(self, coordinates: RepeaterCoordinates, treatCyclicalBoundsAsInfinite: bool) -> bool: ...
    def AdjustForCyclicalBounds(self, coordinates: RepeaterCoordinates) -> RepeaterCoordinates: ...
    def Dispose(self) -> None: ...


class RepeaterCoordinates:
    @overload
    def __init__(self, x: int, y: int): ...
    @overload
    def __init__(self, x: int): ...
    @overload
    def __init__(self): ...
    @property
    def DimensionCount(self) -> int: ...
    @property
    def IsValidObject(self) -> bool: ...
    def GetCoordinate(self, dimension: int) -> int: ...
    def Dispose(self) -> None: ...


class RevisionCloud(Element):
    @property
    def RevisionId(self) -> ElementId: ...
    @RevisionId.setter
    def RevisionId(self, revisionId: ElementId) -> None: ...
    def Create(document: Document, view: View, revisionId: ElementId, curves: List[Curve]) -> RevisionCloud: ...
    def IsRevisionIssued(self) -> bool: ...
    def GetSheetIds(self) -> ISet: ...
    def GetSketchCurves(self) -> List[Curve]: ...


class RevisionSettings(Element):
    @property
    def RevisionNumbering(self) -> RevisionNumbering: ...
    @RevisionNumbering.setter
    def RevisionNumbering(self, revisionNumbering: RevisionNumbering) -> None: ...
    @property
    def RevisionCloudSpacing(self) -> float: ...
    @RevisionCloudSpacing.setter
    def RevisionCloudSpacing(self, desiredCloudSpacing: float) -> None: ...
    def GetRevisionSettings(ccda: Document) -> RevisionSettings: ...
    def GetNumericRevisionSettings(self) -> NumericRevisionSettings: ...
    def SetNumericRevisionSettings(self, newSettings: NumericRevisionSettings) -> None: ...
    def GetAlphanumericRevisionSettings(self) -> AlphanumericRevisionSettings: ...
    def SetAlphanumericRevisionSettings(self, newSettings: AlphanumericRevisionSettings) -> None: ...
    def RoundRevisionCloudSpacing(ccda: Document, rawValue: float) -> float: ...
    def IsAcceptableRevisionCloudSpacing(self, rawValue: float) -> bool: ...


class NumericRevisionSettings:
    @overload
    def __init__(self, startNumber: int, prefix: str, suffix: str): ...
    @overload
    def __init__(self): ...
    @overload
    def __init__(self, other: NumericRevisionSettings): ...
    @property
    def StartNumber(self) -> int: ...
    @StartNumber.setter
    def StartNumber(self, number: int) -> None: ...
    @property
    def Prefix(self) -> str: ...
    @Prefix.setter
    def Prefix(self, prefix: str) -> None: ...
    @property
    def Suffix(self) -> str: ...
    @Suffix.setter
    def Suffix(self, prefix: str) -> None: ...
    @property
    def IsValidObject(self) -> bool: ...
    def IsEqual(self, other: NumericRevisionSettings) -> bool: ...
    def IsValid(self) -> bool: ...
    def Dispose(self) -> None: ...


class AlphanumericRevisionSettings:
    @overload
    def __init__(self, sequence: List[str], prefix: str, suffix: str): ...
    @overload
    def __init__(self): ...
    @overload
    def __init__(self, other: AlphanumericRevisionSettings): ...
    @property
    def Prefix(self) -> str: ...
    @Prefix.setter
    def Prefix(self, prefix: str) -> None: ...
    @property
    def Suffix(self) -> str: ...
    @Suffix.setter
    def Suffix(self, prefix: str) -> None: ...
    @property
    def IsValidObject(self) -> bool: ...
    def IsEqual(self, other: AlphanumericRevisionSettings) -> bool: ...
    def IsValid(self) -> bool: ...
    def GetSequence(self) -> List[str]: ...
    def SetSequence(self, sequence: List[str]) -> None: ...
    def Dispose(self) -> None: ...


class RevitLinkOptions:
    @overload
    def __init__(self, relative: bool): ...
    @overload
    def __init__(self, relative: bool, config: WorksetConfiguration): ...
    @overload
    def __init__(self, other: RevitLinkOptions): ...
    @property
    def IsRelative(self) -> bool: ...
    @IsRelative.setter
    def IsRelative(self, isRelative: bool) -> None: ...
    @property
    def IsValidObject(self) -> bool: ...
    def GetWorksetConfiguration(self) -> WorksetConfiguration: ...
    def SetWorksetConfiguration(self, config: WorksetConfiguration) -> None: ...
    def Dispose(self) -> None: ...


class AreaFilter(ElementSlowFilter):
    def __init__(self): ...


class AreaTagFilter(ElementSlowFilter):
    def __init__(self): ...


class SpatialElementCalculationLocation(Element):
    @property
    def MarkerPosition(self) -> XYZ: ...


class SpatialElementCalculationPoint(SpatialElementCalculationLocation):
    @property
    def Position(self) -> XYZ: ...
    @Position.setter
    def Position(self, position: XYZ) -> None: ...


class SpatialElementFromToCalculationPoints(SpatialElementCalculationLocation):
    @property
    def FromPosition(self) -> XYZ: ...
    @FromPosition.setter
    def FromPosition(self, fromPosition: XYZ) -> None: ...
    @property
    def ToPosition(self) -> XYZ: ...
    @ToPosition.setter
    def ToPosition(self, toPosition: XYZ) -> None: ...
    def Flip(self) -> None: ...
    def MakeFromPositionAcceptable(self, newFromLocation: XYZ) -> XYZ: ...
    def MakeToPositionAcceptable(self, newToLocation: XYZ) -> XYZ: ...
    def IsAcceptableFromPosition(self, fromPosition: XYZ) -> bool: ...
    def IsAcceptableToPosition(self, toPosition: XYZ) -> bool: ...


class SpatialElementBoundarySubface:
    @property
    def SpatialBoundaryElement(self) -> LinkElementId: ...
    @property
    def SubfaceArisesFromElementFace(self) -> bool: ...
    @property
    def SubfaceType(self) -> SubfaceType: ...
    @property
    def Valid(self) -> bool: ...
    @property
    def IsValidObject(self) -> bool: ...
    def GetSpatialElementFace(self) -> Face: ...
    def GetSubface(self) -> Face: ...
    def GetBoundingElementFace(self) -> Face: ...
    def Dispose(self) -> None: ...


class SpatialElementGeometryResults:
    @property
    def IsValidObject(self) -> bool: ...
    def GetGeometry(self) -> Solid: ...
    def GetBoundaryFaceInfo(self, face: Face) -> List[SpatialElementBoundarySubface]: ...
    def Dispose(self) -> None: ...


class SpatialElementGeometryCalculator:
    @overload
    def __init__(self, aDoc: Document, options: SpatialElementBoundaryOptions): ...
    @overload
    def __init__(self, aDoc: Document): ...
    @property
    def IsValidObject(self) -> bool: ...
    def CalculateSpatialElementGeometry(self, spatialElement: SpatialElement) -> SpatialElementGeometryResults: ...
    def IsRoomOrSpace(spatialElement: SpatialElement) -> bool: ...
    def CanCalculateGeometry(spatialElement: SpatialElement) -> bool: ...
    def GetOptions(self) -> SpatialElementBoundaryOptions: ...
    def Dispose(self) -> None: ...


class RoutingCondition:
    def __init__(self, diameter: float): ...
    @property
    def Diameter(self) -> float: ...
    @property
    def IsValidObject(self) -> bool: ...
    def Dispose(self) -> None: ...


class RoutingConditions:
    def __init__(self, errorLevel: RoutingPreferenceErrorLevel): ...
    @property
    def ErrorLevel(self) -> RoutingPreferenceErrorLevel: ...
    @ErrorLevel.setter
    def ErrorLevel(self, errorLevel: RoutingPreferenceErrorLevel) -> None: ...
    @property
    def PreferredJunctionType(self) -> PreferredJunctionType: ...
    @PreferredJunctionType.setter
    def PreferredJunctionType(self, junctionType: PreferredJunctionType) -> None: ...
    @property
    def IsValidObject(self) -> bool: ...
    def GetNumberOfConditions(self) -> int: ...
    def Clear(self) -> None: ...
    def AppendCondition(self, condition: RoutingCondition) -> None: ...
    def GetConditionAt(self, index: int) -> RoutingCondition: ...
    def Dispose(self) -> None: ...


class RoutingPreferenceRule:
    def __init__(self, MEPPartId: ElementId, description: str): ...
    @property
    def Description(self) -> str: ...
    @property
    def MEPPartId(self) -> ElementId: ...
    @property
    def NumberOfCriteria(self) -> int: ...
    @property
    def RoutingPreferenceManager(self) -> RoutingPreferenceManager: ...
    @property
    def IsValidObject(self) -> bool: ...
    def GetCriterion(self, index: int) -> RoutingCriterionBase: ...
    def AddCriterion(self, myCriterion: RoutingCriterionBase) -> None: ...
    def RemoveCriteron(self, index: int) -> None: ...
    def Dispose(self) -> None: ...


class RuledSurface(Surface):
    @overload
    def Create(profileCurve: Curve, point: XYZ) -> Surface: ...
    @overload
    def Create(profileCurve1: Curve, profileCurve2: Curve) -> Surface: ...
    def GetFirstProfileCurve(self) -> Curve: ...
    def HasFirstProfilePoint(self) -> bool: ...
    def GetFirstProfilePoint(self) -> XYZ: ...
    def GetSecondProfileCurve(self) -> Curve: ...
    def HasSecondProfilePoint(self) -> bool: ...
    def GetSecondProfilePoint(self) -> XYZ: ...


class RoutingPreferenceRuleGroupType:
    Segments = 0
    Elbows = 1
    Junctions = 2
    Crosses = 3
    Transitions = 4
    Unions = 5
    MechanicalJoints = 6
    TransitionsRectangularToRound = 7
    TransitionsRectangularToOval = 8
    TransitionsOvalToRound = 9
    Caps = 10
    Undefined = -1


class PreferredJunctionType:
    Tee = 0
    Tap = 1


class FindReferenceTarget:
    Element = 1
    Mesh = 2
    Edge = 4
    Curve = 8
    Face = 16
    All = 31


class RevisionNumbering:
    PerProject = 0
    PerSheet = 1


class SubfaceType:
    Bottom = 0
    Top = 1
    Side = 2


class RoutingPreferenceErrorLevel:
    #None = 0
    Warning = 1
    Error = 2


class NumberSystem(Element):
    @property
    def ReferenceOffset(self) -> float: ...
    @ReferenceOffset.setter
    def ReferenceOffset(self, referenceOffset: float) -> None: ...
    @property
    def JustifyOffset(self) -> float: ...
    @JustifyOffset.setter
    def JustifyOffset(self, justifyOffset: float) -> None: ...
    @property
    def PlacementLevelId(self) -> LinkElementId: ...
    @property
    def NumberedElementId(self) -> LinkElementId: ...
    @property
    def NumberDisplayRule(self) -> NumberSystemDisplayRule: ...
    @NumberDisplayRule.setter
    def NumberDisplayRule(self, numberDisplayRule: NumberSystemDisplayRule) -> None: ...
    @property
    def NumberOrientation(self) -> TagOrientation: ...
    @NumberOrientation.setter
    def NumberOrientation(self, numberOrientation: TagOrientation) -> None: ...
    @property
    def JustifyOption(self) -> NumberSystemJustifyOption: ...
    @JustifyOption.setter
    def JustifyOption(self, justifyOption: NumberSystemJustifyOption) -> None: ...
    def GetReferencePick(self) -> Reference: ...
    def SetReferencePick(self, referencePick: Reference) -> None: ...
    @overload
    def Create(document: Document, viewId: ElementId, hostElementId: LinkElementId, referenceOption: StairsNumberSystemReferenceOption, placementLevelId: LinkElementId) -> NumberSystem: ...
    @overload
    def Create(document: Document, viewId: ElementId, numberedElementId: LinkElementId, referenceCurve: Reference) -> NumberSystem: ...


class SketchedStairsCurveData:
    def __init__(self, boundaryCurve: Curve, height: float, slopeType: SketchedCurveSlopeOption): ...
    @property
    def IsValidObject(self) -> bool: ...
    def GetCurve(self) -> Curve: ...
    def Dispose(self) -> None: ...


class WorksharingSaveAsOptions:
    def __init__(self): ...
    @property
    def SaveAsCentral(self) -> bool: ...
    @SaveAsCentral.setter
    def SaveAsCentral(self, saveAsCentral: bool) -> None: ...
    @property
    def OpenWorksetsDefault(self) -> SimpleWorksetConfiguration: ...
    @OpenWorksetsDefault.setter
    def OpenWorksetsDefault(self, openWorksetsDefault: SimpleWorksetConfiguration) -> None: ...
    @property
    def ClearTransmitted(self) -> bool: ...
    @ClearTransmitted.setter
    def ClearTransmitted(self, clearTransmitted: bool) -> None: ...
    @property
    def IsValidObject(self) -> bool: ...
    def Dispose(self) -> None: ...


class ScheduleField:
    @property
    def FieldType(self) -> ScheduleFieldType: ...
    @property
    def ParameterId(self) -> ElementId: ...
    @property
    def PercentageOf(self) -> ScheduleFieldId: ...
    @PercentageOf.setter
    def PercentageOf(self, percentageOf: ScheduleFieldId) -> None: ...
    @property
    def PercentageBy(self) -> ScheduleFieldId: ...
    @PercentageBy.setter
    def PercentageBy(self, percentageBy: ScheduleFieldId) -> None: ...
    @property
    def IsHidden(self) -> bool: ...
    @IsHidden.setter
    def IsHidden(self, isHidden: bool) -> None: ...
    @property
    def ColumnHeading(self) -> str: ...
    @ColumnHeading.setter
    def ColumnHeading(self, columnHeading: str) -> None: ...
    @property
    def TotalByAssemblyType(self) -> bool: ...
    @TotalByAssemblyType.setter
    def TotalByAssemblyType(self, totalByAssemblyType: bool) -> None: ...
    @property
    def DisplayType(self) -> ScheduleFieldDisplayType: ...
    @DisplayType.setter
    def DisplayType(self, displayType: ScheduleFieldDisplayType) -> None: ...
    @property
    def HorizontalAlignment(self) -> ScheduleHorizontalAlignment: ...
    @HorizontalAlignment.setter
    def HorizontalAlignment(self, horizontalAlignment: ScheduleHorizontalAlignment) -> None: ...
    @property
    def HeadingOrientation(self) -> ScheduleHeadingOrientation: ...
    @HeadingOrientation.setter
    def HeadingOrientation(self, headingOrientation: ScheduleHeadingOrientation) -> None: ...
    @property
    def IsOverridden(self) -> bool: ...
    @property
    def SheetColumnWidth(self) -> float: ...
    @SheetColumnWidth.setter
    def SheetColumnWidth(self, sheetColumnWidth: float) -> None: ...
    @property
    def GridColumnWidth(self) -> float: ...
    @GridColumnWidth.setter
    def GridColumnWidth(self, gridColumnWidth: float) -> None: ...
    @property
    def UnitType(self) -> UnitType: ...
    @property
    def IsCalculatedField(self) -> bool: ...
    @property
    def IsCombinedParameterField(self) -> bool: ...
    @property
    def HasSchedulableField(self) -> bool: ...
    @property
    def Schedule(self) -> ViewSchedule: ...
    @property
    def Definition(self) -> ScheduleDefinition: ...
    @property
    def FieldId(self) -> ScheduleFieldId: ...
    @property
    def FieldIndex(self) -> int: ...
    @property
    def IsValidObject(self) -> bool: ...
    def IsValidCombinedParameters(self, data: List[TableCellCombinedParameterData]) -> bool: ...
    def GetCombinedParameters(self) -> List[TableCellCombinedParameterData]: ...
    def SetCombinedParameters(self, data: List[TableCellCombinedParameterData]) -> None: ...
    def CreatesCircularReferences(self, fieldId: ScheduleFieldId) -> bool: ...
    def CanTotal(self) -> bool: ...
    def CanTotalByAssemblyType(self) -> bool: ...
    def CanDisplayMinMax(self) -> bool: ...
    def GetStyle(self) -> TableCellStyle: ...
    def SetStyle(self, style: TableCellStyle) -> None: ...
    def ResetOverride(self) -> None: ...
    def GetFormatOptions(self) -> FormatOptions: ...
    def SetFormatOptions(self, formatOptions: FormatOptions) -> None: ...
    def GetSpecTypeId(self) -> ForgeTypeId: ...
    def GetSchedulableField(self) -> SchedulableField: ...
    def GetName(self) -> str: ...
    def Dispose(self) -> None: ...


class FilterOperatorAndTextString:
    @property
    def OperatorType(self) -> ScheduleFilterType: ...
    @property
    def FilterOperatorStr(self) -> str: ...
    @property
    def IsValidObject(self) -> bool: ...
    def Dispose(self) -> None: ...


class ScheduleFilter:
    @overload
    def __init__(self, fieldId: ScheduleFieldId, filterType: ScheduleFilterType, value: ElementId): ...
    @overload
    def __init__(self, fieldId: ScheduleFieldId, filterType: ScheduleFilterType, value: str): ...
    @overload
    def __init__(self, fieldId: ScheduleFieldId, filterType: ScheduleFilterType, value: float): ...
    @overload
    def __init__(self, fieldId: ScheduleFieldId, filterType: ScheduleFilterType, value: int): ...
    @overload
    def __init__(self, fieldId: ScheduleFieldId, filterType: ScheduleFilterType): ...
    @overload
    def __init__(self): ...
    @property
    def FieldId(self) -> ScheduleFieldId: ...
    @FieldId.setter
    def FieldId(self, fieldId: ScheduleFieldId) -> None: ...
    @property
    def FilterType(self) -> ScheduleFilterType: ...
    @FilterType.setter
    def FilterType(self, filterType: ScheduleFilterType) -> None: ...
    @property
    def IsNullValue(self) -> bool: ...
    @property
    def IsIntegerValue(self) -> bool: ...
    @property
    def IsStringValue(self) -> bool: ...
    @property
    def IsDoubleValue(self) -> bool: ...
    @property
    def IsElementIdValue(self) -> bool: ...
    @property
    def IsValidObject(self) -> bool: ...
    def GetIntegerValue(self) -> int: ...
    def GetDoubleValue(self) -> float: ...
    def GetStringValue(self) -> str: ...
    def GetElementIdValue(self) -> ElementId: ...
    def SetNullValue(self) -> None: ...
    @overload
    def SetValue(self, id: ElementId) -> None: ...
    @overload
    def SetValue(self, string: str) -> None: ...
    @overload
    def SetValue(self, value: float) -> None: ...
    @overload
    def SetValue(self, value: int) -> None: ...
    def Dispose(self) -> None: ...


class ScheduleSheetInstance(Element):
    @property
    def ScheduleId(self) -> ElementId: ...
    @property
    def Point(self) -> XYZ: ...
    @Point.setter
    def Point(self, xyz: XYZ) -> None: ...
    @property
    def Rotation(self) -> ViewportRotation: ...
    @Rotation.setter
    def Rotation(self, rotation: ViewportRotation) -> None: ...
    @property
    def IsTitleblockRevisionSchedule(self) -> bool: ...
    def Create(document: Document, viewSheetId: ElementId, scheduleId: ElementId, origin: XYZ) -> ScheduleSheetInstance: ...


class ScheduleSortGroupField:
    @overload
    def __init__(self, fieldId: ScheduleFieldId, sortOrder: ScheduleSortOrder): ...
    @overload
    def __init__(self, fieldId: ScheduleFieldId): ...
    @overload
    def __init__(self): ...
    @property
    def FieldId(self) -> ScheduleFieldId: ...
    @FieldId.setter
    def FieldId(self, fieldId: ScheduleFieldId) -> None: ...
    @property
    def SortOrder(self) -> ScheduleSortOrder: ...
    @SortOrder.setter
    def SortOrder(self, sortOrder: ScheduleSortOrder) -> None: ...
    @property
    def ShowHeader(self) -> bool: ...
    @ShowHeader.setter
    def ShowHeader(self, showHeader: bool) -> None: ...
    @property
    def ShowBlankLine(self) -> bool: ...
    @ShowBlankLine.setter
    def ShowBlankLine(self, showBlankLine: bool) -> None: ...
    @property
    def ShowFooter(self) -> bool: ...
    @ShowFooter.setter
    def ShowFooter(self, showFooter: bool) -> None: ...
    @property
    def ShowFooterTitle(self) -> bool: ...
    @ShowFooterTitle.setter
    def ShowFooterTitle(self, showFooterTitle: bool) -> None: ...
    @property
    def ShowFooterCount(self) -> bool: ...
    @ShowFooterCount.setter
    def ShowFooterCount(self, showFooterCount: bool) -> None: ...
    @property
    def IsValidObject(self) -> bool: ...
    def Dispose(self) -> None: ...


class SelectionFilterElement(FilterElement):
    def Create(document: Document, name: str) -> SelectionFilterElement: ...
    def SetElementIds(self, ids: ICollection) -> None: ...
    def GetElementIds(self) -> ICollection: ...
    def IsEmpty(self) -> bool: ...
    def AddSingle(self, id: ElementId) -> None: ...
    def AddSet(self, ids: ICollection) -> None: ...
    def RemoveSingle(self, id: ElementId) -> None: ...
    def RemoveSet(self, ids: ICollection) -> int: ...
    def Contains(self, id: ElementId) -> bool: ...
    def Clear(self) -> None: ...


class ShapeImporter:
    def __init__(self): ...
    @property
    def InputFormat(self) -> ShapeImporterSourceFormat: ...
    @InputFormat.setter
    def InputFormat(self, inputFormat: ShapeImporterSourceFormat) -> None: ...
    @property
    def DefaultLengthUnit(self) -> ImportUnit: ...
    @property
    def IsValidObject(self) -> bool: ...
    def Convert(self, document: Document, filename: str) -> List[GeometryObject]: ...
    def IsServiceAvailable() -> bool: ...
    def SetDefaultLengthUnit(self, defaultLengthUnit: ImportUnit) -> None: ...
    def Dispose(self) -> None: ...


class SharedParameterElement(ParameterElement):
    @property
    def GuidValue(self) -> Guid: ...
    def Create(document: Document, sharedParameterDefinition: ExternalDefinition) -> SharedParameterElement: ...
    def Lookup(document: Document, guidValue: Guid) -> SharedParameterElement: ...
    def ShouldHideWhenNoValue(self) -> bool: ...


class SolidSolidCutUtils:
    @overload
    def AddCutBetweenSolids(document: Document, solidToBeCut: Element, cuttingSolid: Element, splitFacesOfCuttingSolid: bool) -> None: ...
    @overload
    def AddCutBetweenSolids(document: Document, solidToBeCut: Element, cuttingSolid: Element) -> None: ...
    def RemoveCutBetweenSolids(document: Document, first: Element, second: Element) -> None: ...
    def IsAllowedForSolidCut(element: Element) -> bool: ...
    def CanElementCutElement(cuttingElement: Element, cutElement: Element) -> Tuple[bool, CutFailureReason]: ...
    def GetCuttingSolids(element: Element) -> ICollection: ...
    def GetSolidsBeingCut(element: Element) -> ICollection: ...
    def IsElementFromAppropriateContext(element: Element) -> bool: ...
    def CutExistsBetweenElements(first: Element, second: Element) -> Tuple[bool, bool]: ...
    def SplitFacesOfCuttingSolid(first: Element, second: Element, split: bool) -> None: ...


class StairsEditScope(EditScope):
    def __init__(self, document: Document, transactionName: str): ...
    @property
    def IsPermitted(self) -> bool: ...
    @overload
    def Start(self, stairsId: ElementId) -> ElementId: ...
    @overload
    def Start(self, baseLevelId: ElementId, topLevelId: ElementId) -> ElementId: ...


class StdPostedWarning:
    @property
    def IsValidObject(self) -> bool: ...
    def Dispose(self) -> None: ...


class RevolvedSurface(Surface):
    @property
    def Axis(self) -> XYZ: ...
    @property
    def XDir(self) -> XYZ: ...
    @property
    def YDir(self) -> XYZ: ...
    @property
    def Origin(self) -> XYZ: ...
    @overload
    def Create(frameOfReference: Frame, profileCurve: Curve, startAngle: float, endAngle: float) -> Surface: ...
    @overload
    def Create(frameOfReference: Frame, profileCurve: Curve) -> Surface: ...
    @overload
    def Create(axisBasePoint: XYZ, axisDirection: XYZ, profileCurve: Curve, startAngle: float, endAngle: float) -> Surface: ...
    @overload
    def Create(axisBasePoint: XYZ, axisDirection: XYZ, profileCurve: Curve) -> Surface: ...
    def GetProfileCurve(self) -> Curve: ...
    def GetProfileCurveInWorldCoordinates(self) -> Curve: ...
    @overload
    def IsValidProfileCurve(frameOfReference: Frame, profileCurve: Curve) -> bool: ...
    @overload
    def IsValidProfileCurve(axisBasePoint: XYZ, axisDirection: XYZ, profileCurve: Curve) -> bool: ...


class NumberSystemDisplayRule:
    All = 0
    Odd = 1
    Even = 2
    StartAndEnd = 3


class NumberSystemJustifyOption:
    Front = 0
    Center = 1
    Back = 2


class SimpleWorksetConfiguration:
    AllWorksets = 0
    AllEditable = 1
    LastViewed = 2
    AskUserToSpecify = 3


class ScheduleFieldDisplayType:
    Standard = 0
    Totals = 1
    MinMax = 2
    Max = 3
    Min = 4


class ScheduleHeadingOrientation:
    Horizontal = 0
    Vertical = 1


class ScheduleHorizontalAlignment:
    Left = 0
    Center = 1
    Right = 2


class ScheduleFilterType:
    Invalid = 0
    HasParameter = 1
    Equal = 2
    NotEqual = 3
    GreaterThan = 4
    GreaterThanOrEqual = 5
    LessThan = 6
    LessThanOrEqual = 7
    Contains = 8
    NotContains = 9
    BeginsWith = 10
    NotBeginsWith = 11
    EndsWith = 12
    NotEndsWith = 13
    IsAssociatedWithGlobalParameter = 14
    IsNotAssociatedWithGlobalParameter = 15
    HasValue = 16
    HasNoValue = 17


class ScheduleSortOrder:
    Ascending = 0
    Descending = 1


class ShapeImporterSourceFormat:
    Auto = 0
    SAT = 1
    Rhino = 2


class CutFailureReason:
    CutAllowed = 0
    CutAlreadyExists = 1
    OppositeCutExists = 2
    CutNotAppropriateForElements = 3


class TessellatedBuildIssue:
    @property
    def NumberEncountered(self) -> int: ...
    @property
    def IsValidObject(self) -> bool: ...
    def IsValidIssue(self) -> bool: ...
    def GetIssueDescription(self) -> str: ...
    def MakesDataUnusable(self) -> bool: ...
    def ReportIssueToDataSource(self) -> bool: ...
    def Dispose(self) -> None: ...


class TessellatedFace:
    @overload
    def __init__(self, allLoopVertices: List[XYZ], materialId: ElementId): ...
    @overload
    def __init__(self, outerLoopVertices: List[XYZ], materialId: ElementId): ...
    @property
    def MaterialId(self) -> ElementId: ...
    @MaterialId.setter
    def MaterialId(self, materialId: ElementId) -> None: ...
    @property
    def IsValidObject(self) -> bool: ...
    def GetBoundaryLoops(self) -> List[XYZ]: ...
    def Dispose(self) -> None: ...


class TessellatedShapeBuilderResult:
    @property
    def HasInvalidData(self) -> bool: ...
    @property
    def Outcome(self) -> TessellatedShapeBuilderOutcome: ...
    @property
    def AreObjectsAvailable(self) -> bool: ...
    @property
    def IsValidObject(self) -> bool: ...
    def GetGeometricalObjects(self) -> List[GeometryObject]: ...
    def GetNumberOfFaceSets(self) -> int: ...
    def GetIssuesForFaceSet(self, setIndex: int) -> List[TessellatedBuildIssue]: ...
    def Dispose(self) -> None: ...


class MeshFromGeometryOperationResult:
    @property
    def HasInvalidData(self) -> bool: ...
    @property
    def Tessellated(self) -> bool: ...
    @property
    def IsMeshAvailable(self) -> bool: ...
    @property
    def IsValidObject(self) -> bool: ...
    def GetMesh(self) -> Mesh: ...
    def GetIssues(self) -> List[MeshFromGeometryOperationIssue]: ...
    def Dispose(self) -> None: ...


class TessellatedShapeBuilder(ShapeBuilder):
    def __init__(self): ...
    @property
    def IsFaceSetOpen(self) -> bool: ...
    @property
    def Target(self) -> TessellatedShapeBuilderTarget: ...
    @Target.setter
    def Target(self, target: TessellatedShapeBuilderTarget) -> None: ...
    @property
    def Fallback(self) -> TessellatedShapeBuilderFallback: ...
    @Fallback.setter
    def Fallback(self, fallback: TessellatedShapeBuilderFallback) -> None: ...
    @property
    def GraphicsStyleId(self) -> ElementId: ...
    @GraphicsStyleId.setter
    def GraphicsStyleId(self, graphicsStyleId: ElementId) -> None: ...
    @property
    def LogString(self) -> str: ...
    @LogString.setter
    def LogString(self, logString: str) -> None: ...
    @property
    def LogInteger(self) -> int: ...
    @LogInteger.setter
    def LogInteger(self, logInteger: int) -> None: ...
    @property
    def OwnerInfo(self) -> str: ...
    @OwnerInfo.setter
    def OwnerInfo(self, ownerInfo: str) -> None: ...
    @property
    def NumberOfCompletedFaceSets(self) -> int: ...
    def OpenConnectedFaceSet(self, isSolid: bool) -> None: ...
    def CloseConnectedFaceSet(self) -> None: ...
    def CancelConnectedFaceSet(self) -> None: ...
    def Clear(self) -> None: ...
    def DoesFaceHaveEnoughLoopsAndVertices(self, face: TessellatedFace) -> bool: ...
    def AddFace(self, face: TessellatedFace) -> None: ...
    def AreTargetAndFallbackCompatible(self, target: TessellatedShapeBuilderTarget, fallback: TessellatedShapeBuilderFallback) -> bool: ...
    def Build(self) -> None: ...
    def CreateMeshByExtrusion(profileLoops: List[CurveLoop], extrusionDirection: XYZ, extrusionDistance: float, materialId: ElementId) -> MeshFromGeometryOperationResult: ...
    def GetBuildResult(self) -> TessellatedShapeBuilderResult: ...


class TransactionGroup:
    @overload
    def __init__(self, document: Document, transGroupName: str): ...
    @overload
    def __init__(self, document: Document): ...
    @property
    def IsFailureHandlingForcedModal(self) -> bool: ...
    @IsFailureHandlingForcedModal.setter
    def IsFailureHandlingForcedModal(self, isFailureHandlingForcedModal: bool) -> None: ...
    @property
    def IsValidObject(self) -> bool: ...
    @overload
    def Start(self, transGroupName: str) -> TransactionStatus: ...
    @overload
    def Start(self) -> TransactionStatus: ...
    def Commit(self) -> TransactionStatus: ...
    def Assimilate(self) -> TransactionStatus: ...
    def RollBack(self) -> TransactionStatus: ...
    def GetStatus(self) -> TransactionStatus: ...
    def HasStarted(self) -> bool: ...
    def HasEnded(self) -> bool: ...
    def SetName(self, name: str) -> None: ...
    def GetName(self) -> str: ...
    def Dispose(self) -> None: ...


class TransmissionData:
    def __init__(self, other: TransmissionData): ...
    @property
    def IsTransmitted(self) -> bool: ...
    @IsTransmitted.setter
    def IsTransmitted(self, isTransmitted: bool) -> None: ...
    @property
    def UserData(self) -> str: ...
    @UserData.setter
    def UserData(self, userData: str) -> None: ...
    @property
    def Version(self) -> int: ...
    @property
    def IsValidObject(self) -> bool: ...
    def GetAllExternalFileReferenceIds(self) -> ICollection: ...
    def GetLastSavedReferenceData(self, elemId: ElementId) -> ExternalFileReference: ...
    def GetDesiredReferenceData(self, elemId: ElementId) -> ExternalFileReference: ...
    def SetDesiredReferenceData(self, elemId: ElementId, path: ModelPath, pathType: PathType, shouldLoad: bool) -> None: ...
    def ReadTransmissionData(path: ModelPath) -> TransmissionData: ...
    def WriteTransmissionData(path: ModelPath, data: TransmissionData) -> None: ...
    def IsDocumentTransmitted(filePath: ModelPath) -> bool: ...
    def DocumentIsNotTransmitted(filePath: ModelPath) -> bool: ...
    def Dispose(self) -> None: ...


class Transform1D:
    @overload
    def __init__(self, scale: float): ...
    @overload
    def __init__(self, scale: float, translation: float): ...
    @overload
    def __init__(self, other: Transform1D): ...
    @property
    def Scale(self) -> float: ...
    @Scale.setter
    def Scale(self, scale: float) -> None: ...
    @property
    def Translation(self) -> float: ...
    @Translation.setter
    def Translation(self, translation: float) -> None: ...
    @property
    def IsIdentity(self) -> bool: ...
    @property
    def Determinant(self) -> float: ...
    @property
    def IsValidObject(self) -> bool: ...
    def AlmostEqual(self, right: Transform1D) -> bool: ...
    def Assign(self, from_: Transform1D) -> None: ...
    def SetToIdentity(self) -> Transform1D: ...
    def Multiply(self, right: Transform1D) -> Transform1D: ...
    def OfPoint(self, point: float) -> float: ...
    def OfVector(self, vector: float) -> float: ...
    def GetInverse(self) -> Transform1D: ...
    def TransformParameterDomain(self, domainStart: float, domainEnd: float) -> List[float]: ...
    def Dispose(self) -> None: ...


class TessellatedBuildIssueType:
    AllFine = 0
    EmptyFace = 1
    EmptyLoop = 2
    TooFewOriginalVertices = 3
    TooShortOriginalLoopMeshSegment = 4
    TooShortOriginalLoopGeomSegment = 5
    LostTooManyLoopVertices = 6
    OriginalLoopGeomAcuteAngle = 7
    OriginalLoopMeshAcuteAngle = 8
    LostAllLoops = 9
    NonPlanarFace = 10
    OriginalPointsTooFarFromTheirPlane = 11
    TooSmallVertexSegementDistInOriginalLoop = 12
    LoopOnBestFitSelfIntersects = 13
    IntersectingOriginalLoops = 14
    FaceWithIslands = 15
    OriginalLoopsProximity = 16
    OuterLoopIsNotFirst = 17
    DegenOriginalLoop = 18
    InconsistentInnerOuterOriginalLoopCCW = 19
    EdgeTwiceUsedByFace = 20
    NonManifoldEdge = 21
    OverlappingAdjacentFaces = 22
    PartitionPointsTooFarFromTrueEdge = 23
    EdgeTraversalForFlip = 24
    InconsitentMultiEdgeTraversalForFlip = 25
    TooSmallVertexSegementDistInFinalLoop = 26
    InternalUtilityError = 27
    InternalError = 28
    InternalLightError = 29
    InternalMissingError = 30
    UnarticulatedNonManifoldEdge = 31
    NotSetYet = 32
    NumberOfIssueTypes = 33


class MeshFromGeometryOperationIssue:
    AllFine = 0
    NoUsableCurveLoopsInInput = 1
    MissingCurveLoopsInInput = 2
    EmptyCurveLoopsInInput = 3
    CurveLoopsWithoutCurvesInInput = 4
    NonPlanarProfileLoop = 5
    InputCurveLoopProblemWithFallback = 6
    InputCurveLoopWrongOpenFlag = 7
    NonContinuousInputCurveLoop = 8
    MissingCurvesInInputLoop = 9
    InternalUtilityError = 10
    InternalMissingError = 11
    InternalError = 12
    NotSetYet = 13
    NumberOfIssueTypes = 14


class TessellatedShapeBuilderTarget:
    Solid = 0
    AnyGeometry = 1
    Mesh = 2


class TessellatedShapeBuilderFallback:
    Abort = 0
    Salvage = 1
    Mesh = 2


class TessellatedShapeBuilderOutcome:
    Mesh = 1
    Mixed = 2
    Nothing = 3
    Solid = 4
    Sheet = 5


class Transaction:
    @overload
    def __init__(self, document: Document, name: str): ...
    @overload
    def __init__(self, document: Document): ...
    @property
    def IsValidObject(self) -> bool: ...
    @overload
    def Start(self, name: str) -> TransactionStatus: ...
    @overload
    def Start(self) -> TransactionStatus: ...
    @overload
    def Commit(self, options: FailureHandlingOptions) -> TransactionStatus: ...
    @overload
    def Commit(self) -> TransactionStatus: ...
    @overload
    def RollBack(self, options: FailureHandlingOptions) -> TransactionStatus: ...
    @overload
    def RollBack(self) -> TransactionStatus: ...
    def GetStatus(self) -> TransactionStatus: ...
    def HasStarted(self) -> bool: ...
    def HasEnded(self) -> bool: ...
    def SetName(self, name: str) -> None: ...
    def GetName(self) -> str: ...
    def GetFailureHandlingOptions(self) -> FailureHandlingOptions: ...
    def SetFailureHandlingOptions(self, options: FailureHandlingOptions) -> None: ...
    def Dispose(self) -> None: ...


class UnitFormatUtils:
    @overload
    def Format(units: Units, specTypeId: ForgeTypeId, value: float, forEditing: bool) -> str: ...
    @overload
    def Format(units: Units, unitType: UnitType, value: float, forEditing: bool) -> str: ...
    @overload
    def Format(units: Units, unitType: UnitType, value: float, maxAccuracy: bool, forEditing: bool) -> str: ...
    @overload
    def Format(units: Units, specTypeId: ForgeTypeId, value: float, forEditing: bool, formatValueOptions: FormatValueOptions) -> str: ...
    @overload
    def Format(units: Units, unitType: UnitType, value: float, forEditing: bool, formatValueOptions: FormatValueOptions) -> str: ...
    @overload
    def Format(units: Units, unitType: UnitType, value: float, maxAccuracy: bool, forEditing: bool, formatValueOptions: FormatValueOptions) -> str: ...
    @overload
    def TryParse(units: Units, specTypeId: ForgeTypeId, stringToParse: str) -> Tuple[bool, float, str]: ...
    @overload
    def TryParse(units: Units, unitType: UnitType, stringToParse: str) -> Tuple[bool, float, str]: ...
    @overload
    def TryParse(units: Units, specTypeId: ForgeTypeId, stringToParse: str) -> Tuple[bool, float]: ...
    @overload
    def TryParse(units: Units, unitType: UnitType, stringToParse: str) -> Tuple[bool, float]: ...
    @overload
    def TryParse(units: Units, specTypeId: ForgeTypeId, stringToParse: str, valueParsingOptions: ValueParsingOptions) -> Tuple[bool, float, str]: ...
    @overload
    def TryParse(units: Units, unitType: UnitType, stringToParse: str, valueParsingOptions: ValueParsingOptions) -> Tuple[bool, float, str]: ...
    @overload
    def TryParse(units: Units, specTypeId: ForgeTypeId, stringToParse: str, valueParsingOptions: ValueParsingOptions) -> Tuple[bool, float]: ...
    @overload
    def TryParse(units: Units, unitType: UnitType, stringToParse: str, valueParsingOptions: ValueParsingOptions) -> Tuple[bool, float]: ...


class ValueParsingOptions:
    def __init__(self): ...
    @property
    def AllowedValues(self) -> AllowedValues: ...
    @AllowedValues.setter
    def AllowedValues(self, allowedValues: AllowedValues) -> None: ...
    @property
    def IsValidObject(self) -> bool: ...
    def SetFormatOptions(self, formatOptions: FormatOptions) -> None: ...
    def GetFormatOptions(self) -> FormatOptions: ...
    def Dispose(self) -> None: ...


class IUpdater:
    def Execute(self, data: UpdaterData) -> None: ...
    def GetUpdaterId(self) -> UpdaterId: ...
    def GetChangePriority(self) -> ChangePriority: ...
    def GetUpdaterName(self) -> str: ...
    def GetAdditionalInformation(self) -> str: ...


class UpdaterData:
    @property
    def IsValidObject(self) -> bool: ...
    def GetAddedElementIds(self) -> ICollection: ...
    def GetDeletedElementIds(self) -> ICollection: ...
    def GetModifiedElementIds(self) -> ICollection: ...
    def IsChangeTriggered(self, id: ElementId, type: ChangeType) -> bool: ...
    def GetDocument(self) -> Document: ...
    def Dispose(self) -> None: ...


class UpdaterId:
    def __init__(self, addInId: AddInId, val: Guid): ...
    @property
    def IsValidObject(self) -> bool: ...
    def GetGUID(self) -> Guid: ...
    def GetAddInId(self) -> AddInId: ...
    def Dispose(self) -> None: ...


class UpdaterInfo:
    @property
    def UpdaterName(self) -> str: ...
    @property
    def AdditionalInformation(self) -> str: ...
    @property
    def ApplicationName(self) -> str: ...
    @property
    def IsOptional(self) -> bool: ...
    @property
    def IsValidObject(self) -> bool: ...
    def Dispose(self) -> None: ...


class UpdaterRegistry:
    @property
    def IsValidObject(self) -> bool: ...
    @overload
    def RegisterUpdater(updater: IUpdater, document: Document, isOptional: bool) -> None: ...
    @overload
    def RegisterUpdater(updater: IUpdater, isOptional: bool) -> None: ...
    @overload
    def RegisterUpdater(updater: IUpdater, document: Document) -> None: ...
    @overload
    def RegisterUpdater(updater: IUpdater) -> None: ...
    @overload
    def UnregisterUpdater(id: UpdaterId, document: Document) -> None: ...
    @overload
    def UnregisterUpdater(id: UpdaterId) -> None: ...
    @overload
    def IsUpdaterRegistered(id: UpdaterId, document: Document) -> bool: ...
    @overload
    def IsUpdaterRegistered(id: UpdaterId) -> bool: ...
    def SetExecutionOrder(first: UpdaterId, second: UpdaterId) -> None: ...
    @overload
    def AddTrigger(id: UpdaterId, filter: ElementFilter, change: ChangeType) -> None: ...
    @overload
    def AddTrigger(id: UpdaterId, document: Document, filter: ElementFilter, change: ChangeType) -> None: ...
    @overload
    def AddTrigger(id: UpdaterId, document: Document, elements: ICollection, change: ChangeType) -> None: ...
    def RemoveAllTriggers(id: UpdaterId) -> None: ...
    def RemoveDocumentTriggers(id: UpdaterId, document: Document) -> None: ...
    def GetIsUpdaterOptional(id: UpdaterId) -> bool: ...
    def SetIsUpdaterOptional(id: UpdaterId, isOptional: bool) -> None: ...
    def EnableUpdater(id: UpdaterId) -> None: ...
    def DisableUpdater(id: UpdaterId) -> None: ...
    def IsUpdaterEnabled(id: UpdaterId) -> bool: ...
    @overload
    def GetRegisteredUpdaterInfos() -> List[UpdaterInfo]: ...
    @overload
    def GetRegisteredUpdaterInfos(document: Document) -> List[UpdaterInfo]: ...
    def Dispose(self) -> None: ...


class ViewShapeBuilder(ShapeBuilder):
    @overload
    def __init__(self, targetViewType: DirectShapeTargetViewType): ...
    @overload
    def __init__(self): ...
    @property
    def ViewNormal(self) -> XYZ: ...
    @ViewNormal.setter
    def ViewNormal(self, viewNormal: XYZ) -> None: ...
    @property
    def ViewType(self) -> DirectShapeTargetViewType: ...
    @ViewType.setter
    def ViewType(self, viewType: DirectShapeTargetViewType) -> None: ...
    def Reset(self) -> None: ...
    def AddCurve(self, GCurve: Curve) -> None: ...
    @overload
    def ValidateCurve(GCurve: Curve, targetViewType: DirectShapeTargetViewType) -> bool: ...
    @overload
    def ValidateCurve(self, GCurve: Curve) -> bool: ...
    def ValidateViewType(targetViewType: DirectShapeTargetViewType) -> bool: ...
    def ValidateShape(shape: List[GeometryObject], targetViewType: DirectShapeTargetViewType) -> bool: ...


class VisibleInViewFilter(ElementQuickFilter):
    @overload
    def __init__(self, document: Document, viewId: ElementId, inverted: bool): ...
    @overload
    def __init__(self, document: Document, viewId: ElementId): ...


class ViewTemplateApplicationOption:
    AllParameters = 0
    UncontrolledParameters = 1
    AllParametersAndStickIfNone = 2


class WallSweep(HostObject):
    def GetWallSweepInfo(self) -> WallSweepInfo: ...
    def GetHostIds(self) -> List[ElementId]: ...
    def Create(wall: Wall, wallSweepType: ElementId, wallSweepInfo: WallSweepInfo) -> WallSweep: ...
    def WallAllowsWallSweep(wall: Wall) -> bool: ...


class WallUtils:
    def DisallowWallJoinAtEnd(wall: Wall, end: int) -> None: ...
    def AllowWallJoinAtEnd(wall: Wall, end: int) -> None: ...
    def IsWallJoinAllowedAtEnd(wall: Wall, end: int) -> bool: ...


class WireframeBuilder(ShapeBuilder):
    def __init__(self): ...
    def Reset(self) -> None: ...
    def AddPoint(self, GPoint: Point) -> None: ...
    def AddCurve(self, GCurve: Curve) -> None: ...
    def ValidatePoint(GPoint: Point) -> bool: ...
    def ValidateCurve(GCurve: Curve) -> bool: ...


class WorksetDefaultVisibilitySettings(Element):
    def IsWorksetVisible(self, worksetId: WorksetId) -> bool: ...
    def SetWorksetVisibility(self, worksetId: WorksetId, visible: bool) -> None: ...
    def GetWorksetDefaultVisibilitySettings(aDoc: Document) -> WorksetDefaultVisibilitySettings: ...


class WorksharingTooltipInfo:
    @property
    def Owner(self) -> str: ...
    @property
    def Creator(self) -> str: ...
    @property
    def LastChangedBy(self) -> str: ...
    @property
    def IsValidObject(self) -> bool: ...
    def GetRequesters(self) -> List[str]: ...
    def Dispose(self) -> None: ...


class WorksharingUtils:
    @property
    def IsValidObject(self) -> bool: ...
    def GetModelUpdatesStatus(document: Document, elementId: ElementId) -> ModelUpdatesStatus: ...
    @overload
    def GetCheckoutStatus(document: Document, elementId: ElementId) -> CheckoutStatus: ...
    @overload
    def GetCheckoutStatus(document: Document, elementId: ElementId) -> Tuple[CheckoutStatus, str]: ...
    @overload
    def CheckoutElements(document: Document, elementsToCheckout: ISet, options: TransactWithCentralOptions) -> ISet: ...
    @overload
    def CheckoutElements(document: Document, elementsToCheckout: ICollection) -> ICollection: ...
    @overload
    def CheckoutWorksets(document: Document, worksetsToCheckout: ISet, options: TransactWithCentralOptions) -> ISet: ...
    @overload
    def CheckoutWorksets(document: Document, worksetsToCheckout: ICollection) -> ICollection: ...
    def RelinquishOwnership(document: Document, generalCategories: RelinquishOptions, options: TransactWithCentralOptions) -> RelinquishedItems: ...
    def GetUserWorksetInfo(path: ModelPath) -> List[WorksetPreview]: ...
    def CreateNewLocal(sourcePath: ModelPath, targetPath: ModelPath) -> None: ...
    def GetWorksharingTooltipInfo(document: Document, elementId: ElementId) -> WorksharingTooltipInfo: ...
    def Dispose(self) -> None: ...


class WorksharingDisplayGraphicSettings:
    def __init__(self, shouldApply: bool, lineColor: Color): ...
    @property
    def IsApplied(self) -> bool: ...
    @property
    def LineColor(self) -> Color: ...
    @property
    def FillColor(self) -> Color: ...
    @property
    def IsValidObject(self) -> bool: ...
    def Dispose(self) -> None: ...


class WorksharingDisplaySettings(Element):
    def GetOrCreateWorksharingDisplaySettings(doc: Document) -> WorksharingDisplaySettings: ...
    def UserHasGraphicOverrides(self, username: str) -> bool: ...
    def RemoveUsers(self, document: Document, usersToRemove: ICollection) -> Tuple[ICollection]: ...
    def CanUserHaveOverrides(self, username: str) -> bool: ...
    def RestoreUsers(self, usersToRestore: ICollection) -> int: ...
    def GetRemovedUsers(self) -> ICollection: ...
    def GetAllUsersWithGraphicOverrides(self) -> ICollection: ...
    @overload
    def GetGraphicOverrides(self, worksetId: WorksetId) -> WorksharingDisplayGraphicSettings: ...
    @overload
    def GetGraphicOverrides(self, username: str) -> WorksharingDisplayGraphicSettings: ...
    @overload
    def GetGraphicOverrides(self, statusInCentral: ModelUpdatesStatus) -> WorksharingDisplayGraphicSettings: ...
    @overload
    def GetGraphicOverrides(self, ownershipStatus: CheckoutStatus) -> WorksharingDisplayGraphicSettings: ...
    @overload
    def SetGraphicOverrides(self, worksetId: WorksetId, overrides: WorksharingDisplayGraphicSettings) -> None: ...
    @overload
    def SetGraphicOverrides(self, status: CheckoutStatus, overrides: WorksharingDisplayGraphicSettings) -> None: ...
    @overload
    def SetGraphicOverrides(self, status: ModelUpdatesStatus, overrides: WorksharingDisplayGraphicSettings) -> None: ...
    @overload
    def SetGraphicOverrides(self, username: str, overrides: WorksharingDisplayGraphicSettings) -> None: ...
